pub struct ClidrEl1(/* private fields */);Expand description
CLIDR_EL1 system register value.
Cache Level ID.
Implementations
Sourceimpl ClidrEl1
impl ClidrEl1
Sourcepub fn icb_level(self) -> Option<CacheLevel>
Available on crate feature el1 only.
pub fn icb_level(self) -> Option<CacheLevel>
el1 only.Returns the inner cache boundary level.
Sourcepub fn cache_type(self, level: CacheLevel) -> CacheType
Available on crate feature el1 only.
pub fn cache_type(self, level: CacheLevel) -> CacheType
el1 only.Returns Cache Type [1-7] fields.
Sourceimpl ClidrEl1
impl ClidrEl1
Sourcepub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u64) -> Option<Self>
pub const fn from_bits(bits: u64) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u64) -> Self
pub const fn from_bits_truncate(bits: u64) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u64) -> Self
pub const fn from_bits_retain(bits: u64) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl ClidrEl1
impl ClidrEl1
Sourcepub const fn iter(&self) -> Iter<ClidrEl1>
pub const fn iter(&self) -> Iter<ClidrEl1>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<ClidrEl1>
pub const fn iter_names(&self) -> IterNames<ClidrEl1>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl ClidrEl1
impl ClidrEl1
Sourcepub const CTYPE_SHIFT: u32 = 0
Available on crate feature el1 only.
pub const CTYPE_SHIFT: u32 = 0
el1 only.Offset of the Ctype<n> field.
Sourcepub const CTYPE_MASK: u64 = 0b111
Available on crate feature el1 only.
pub const CTYPE_MASK: u64 = 0b111
el1 only.Mask for the Ctype<n> field.
Sourcepub const LOUIS_SHIFT: u32 = 21
Available on crate feature el1 only.
pub const LOUIS_SHIFT: u32 = 21
el1 only.Offset of the LoUIS field.
Sourcepub const LOUIS_MASK: u64 = 0b111
Available on crate feature el1 only.
pub const LOUIS_MASK: u64 = 0b111
el1 only.Mask for the LoUIS field.
Sourcepub const LOUU_SHIFT: u32 = 27
Available on crate feature el1 only.
pub const LOUU_SHIFT: u32 = 27
el1 only.Offset of the LoUU field.
Sourcepub const TTYPE_SHIFT: u32 = 33
Available on crate feature el1 only.
pub const TTYPE_SHIFT: u32 = 33
el1 only.Offset of the Ttype<n> field.
Sourcepub const TTYPE_MASK: u64 = 0b11
Available on crate feature el1 only.
pub const TTYPE_MASK: u64 = 0b11
el1 only.Mask for the Ttype<n> field.
Sourcepub fn ctype(self, n: u32) -> CacheType
Available on crate feature el1 only.
pub fn ctype(self, n: u32) -> CacheType
el1 only.Returns the value of the given Ctype<n> field.
Sourcepub fn set_ctype(&mut self, n: u32, value: CacheType)
Available on crate feature el1 only.
pub fn set_ctype(&mut self, n: u32, value: CacheType)
el1 only.Sets the value of the Ctype<n> field.
Sourcepub fn with_ctype(self, n: u32, value: CacheType) -> Self
Available on crate feature el1 only.
pub fn with_ctype(self, n: u32, value: CacheType) -> Self
el1 only.Returns a copy with the Ctype<n> field set to the given value.
Sourcepub const fn louis(self) -> u8
Available on crate feature el1 only.
pub const fn louis(self) -> u8
el1 only.Returns the value of the LoUIS field.
Level of Unification Inner Shareable for the cache hierarchy.
Sourcepub const fn set_louis(&mut self, value: u8)
Available on crate feature el1 only.
pub const fn set_louis(&mut self, value: u8)
el1 only.Sets the value of the LoUIS field.
Level of Unification Inner Shareable for the cache hierarchy.
Sourcepub const fn with_louis(self, value: u8) -> Self
Available on crate feature el1 only.
pub const fn with_louis(self, value: u8) -> Self
el1 only.Returns a copy with the LoUIS field set to the given value.
Level of Unification Inner Shareable for the cache hierarchy.
Sourcepub const fn loc(self) -> u8
Available on crate feature el1 only.
pub const fn loc(self) -> u8
el1 only.Returns the value of the LoC field.
Level of Coherence for the cache hierarchy.
Sourcepub const fn set_loc(&mut self, value: u8)
Available on crate feature el1 only.
pub const fn set_loc(&mut self, value: u8)
el1 only.Sets the value of the LoC field.
Level of Coherence for the cache hierarchy.
Sourcepub const fn with_loc(self, value: u8) -> Self
Available on crate feature el1 only.
pub const fn with_loc(self, value: u8) -> Self
el1 only.Returns a copy with the LoC field set to the given value.
Level of Coherence for the cache hierarchy.
Sourcepub const fn louu(self) -> u8
Available on crate feature el1 only.
pub const fn louu(self) -> u8
el1 only.Returns the value of the LoUU field.
Level of Unification Uniprocessor for the cache hierarchy.
Sourcepub const fn set_louu(&mut self, value: u8)
Available on crate feature el1 only.
pub const fn set_louu(&mut self, value: u8)
el1 only.Sets the value of the LoUU field.
Level of Unification Uniprocessor for the cache hierarchy.
Sourcepub const fn with_louu(self, value: u8) -> Self
Available on crate feature el1 only.
pub const fn with_louu(self, value: u8) -> Self
el1 only.Returns a copy with the LoUU field set to the given value.
Level of Unification Uniprocessor for the cache hierarchy.
Sourcepub const fn icb(self) -> u8
Available on crate feature el1 only.
pub const fn icb(self) -> u8
el1 only.Returns the value of the ICB field.
Inner cache boundary level.
Sourcepub const fn set_icb(&mut self, value: u8)
Available on crate feature el1 only.
pub const fn set_icb(&mut self, value: u8)
el1 only.Sets the value of the ICB field.
Inner cache boundary level.
Sourcepub const fn with_icb(self, value: u8) -> Self
Available on crate feature el1 only.
pub const fn with_icb(self, value: u8) -> Self
el1 only.Returns a copy with the ICB field set to the given value.
Inner cache boundary level.
Sourcepub const fn ttype(self, n: u32) -> u8
Available on crate feature el1 only.
pub const fn ttype(self, n: u32) -> u8
el1 only.Returns the value of the given Ttype<n> field.
Sourcepub const fn set_ttype(&mut self, n: u32, value: u8)
Available on crate feature el1 only.
pub const fn set_ttype(&mut self, n: u32, value: u8)
el1 only.Sets the value of the Ttype<n> field.
Sourcepub const fn with_ttype(self, n: u32, value: u8) -> Self
Available on crate feature el1 only.
pub const fn with_ttype(self, n: u32, value: u8) -> Self
el1 only.Returns a copy with the Ttype<n> field set to the given value.