pub struct CnthctlEl2(/* private fields */);Expand description
CNTHCTL_EL2 system register value.
Counter-timer Hypervisor Control Register
Implementations
Sourceimpl CnthctlEl2
impl CnthctlEl2
Sourceimpl CnthctlEl2
impl CnthctlEl2
Sourcepub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u64) -> Option<Self>
pub const fn from_bits(bits: u64) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u64) -> Self
pub const fn from_bits_truncate(bits: u64) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u64) -> Self
pub const fn from_bits_retain(bits: u64) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl CnthctlEl2
impl CnthctlEl2
Sourcepub const fn iter(&self) -> Iter<CnthctlEl2>
pub const fn iter(&self) -> Iter<CnthctlEl2>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<CnthctlEl2>
pub const fn iter_names(&self) -> IterNames<CnthctlEl2>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl CnthctlEl2
impl CnthctlEl2
Sourcepub const EL0PCTEN_SHIFT: u32 = 0
Available on crate feature el2 only.
pub const EL0PCTEN_SHIFT: u32 = 0
el2 only.Offset of the EL0PCTEN field.
Sourcepub const EL0VCTEN_SHIFT: u32 = 1
Available on crate feature el2 only.
pub const EL0VCTEN_SHIFT: u32 = 1
el2 only.Offset of the EL0VCTEN field.
Sourcepub const EL1PCEN_SHIFT: u32 = 1
Available on crate feature el2 only.
pub const EL1PCEN_SHIFT: u32 = 1
el2 only.Offset of the EL1PCEN field.
Sourcepub const EVNTEN_SHIFT: u32 = 2
Available on crate feature el2 only.
pub const EVNTEN_SHIFT: u32 = 2
el2 only.Offset of the EVNTEN field.
Sourcepub const EVNTDIR_SHIFT: u32 = 3
Available on crate feature el2 only.
pub const EVNTDIR_SHIFT: u32 = 3
el2 only.Offset of the EVNTDIR field.
Sourcepub const EVNTI_SHIFT: u32 = 4
Available on crate feature el2 only.
pub const EVNTI_SHIFT: u32 = 4
el2 only.Offset of the EVNTI field.
Sourcepub const EVNTI_MASK: u64 = 0b1111
Available on crate feature el2 only.
pub const EVNTI_MASK: u64 = 0b1111
el2 only.Mask for the EVNTI field.
Sourcepub const EL0VTEN_SHIFT: u32 = 8
Available on crate feature el2 only.
pub const EL0VTEN_SHIFT: u32 = 8
el2 only.Offset of the EL0VTEN field.
Sourcepub const EL0PTEN_SHIFT: u32 = 9
Available on crate feature el2 only.
pub const EL0PTEN_SHIFT: u32 = 9
el2 only.Offset of the EL0PTEN field.
Sourcepub const EL1PTEN_SHIFT: u32 = 11
Available on crate feature el2 only.
pub const EL1PTEN_SHIFT: u32 = 11
el2 only.Offset of the EL1PTEN field.
Sourcepub const EL1TVT_SHIFT: u32 = 13
Available on crate feature el2 only.
pub const EL1TVT_SHIFT: u32 = 13
el2 only.Offset of the EL1TVT field.
Sourcepub const EL1TVCT_SHIFT: u32 = 14
Available on crate feature el2 only.
pub const EL1TVCT_SHIFT: u32 = 14
el2 only.Offset of the EL1TVCT field.
Sourcepub const EL1NVPCT_SHIFT: u32 = 15
Available on crate feature el2 only.
pub const EL1NVPCT_SHIFT: u32 = 15
el2 only.Offset of the EL1NVPCT field.
Sourcepub const EL1NVVCT_SHIFT: u32 = 16
Available on crate feature el2 only.
pub const EL1NVVCT_SHIFT: u32 = 16
el2 only.Offset of the EL1NVVCT field.
Sourcepub const EVNTIS_SHIFT: u32 = 17
Available on crate feature el2 only.
pub const EVNTIS_SHIFT: u32 = 17
el2 only.Offset of the EVNTIS field.
Sourcepub const CNTVMASK_SHIFT: u32 = 18
Available on crate feature el2 only.
pub const CNTVMASK_SHIFT: u32 = 18
el2 only.Offset of the CNTVMASK field.
Sourcepub const CNTPMASK_SHIFT: u32 = 19
Available on crate feature el2 only.
pub const CNTPMASK_SHIFT: u32 = 19
el2 only.Offset of the CNTPMASK field.
Sourcepub const fn evnti(self) -> u8
Available on crate feature el2 only.
pub const fn evnti(self) -> u8
el2 only.Returns the value of the EVNTI field.
Sourcepub const fn set_evnti(&mut self, value: u8)
Available on crate feature el2 only.
pub const fn set_evnti(&mut self, value: u8)
el2 only.Sets the value of the EVNTI field.
Sourcepub const fn with_evnti(self, value: u8) -> Self
Available on crate feature el2 only.
pub const fn with_evnti(self, value: u8) -> Self
el2 only.Returns a copy with the EVNTI field set to the given value.