pub struct CntvCvalEl0(/* private fields */);Expand description
CNTV_CVAL_EL0 system register value.
Counter-timer Virtual Timer CompareValue Register
Implementations
Sourceimpl CntvCvalEl0
impl CntvCvalEl0
Sourcepub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u64) -> Option<Self>
pub const fn from_bits(bits: u64) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u64) -> Self
pub const fn from_bits_truncate(bits: u64) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u64) -> Self
pub const fn from_bits_retain(bits: u64) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl CntvCvalEl0
impl CntvCvalEl0
Sourcepub const fn iter(&self) -> Iter<CntvCvalEl0>
pub const fn iter(&self) -> Iter<CntvCvalEl0>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<CntvCvalEl0>
pub const fn iter_names(&self) -> IterNames<CntvCvalEl0>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl CntvCvalEl0
impl CntvCvalEl0
Sourcepub const COMPAREVALUE_SHIFT: u32 = 0
pub const COMPAREVALUE_SHIFT: u32 = 0
Offset of the CompareValue field.
Sourcepub const COMPAREVALUE_MASK: u64 = 0b1111111111111111111111111111111111111111111111111111111111111111
pub const COMPAREVALUE_MASK: u64 = 0b1111111111111111111111111111111111111111111111111111111111111111
Mask for the CompareValue field.
Sourcepub const fn comparevalue(self) -> u64
pub const fn comparevalue(self) -> u64
Returns the value of the CompareValue field.
Sourcepub const fn set_comparevalue(&mut self, value: u64)
pub const fn set_comparevalue(&mut self, value: u64)
Sets the value of the CompareValue field.
Sourcepub const fn with_comparevalue(self, value: u64) -> Self
pub const fn with_comparevalue(self, value: u64) -> Self
Returns a copy with the CompareValue field set to the given value.