Dbgdevid

Struct Dbgdevid 

pub struct Dbgdevid(/* private fields */);
DBGDEVID system register value.

Implementations

Source

impl Dbgdevid

pub const fn empty() -> Self

Get a flags value with all bits unset.

pub const fn all() -> Self

Get a flags value with all known bits set.

pub const fn bits(&self) -> u32

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u32) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u32) -> Self

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u32) -> Self

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in this flags value are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Self) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

pub const fn contains(&self, other: Self) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

pub fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in two flags values.

pub fn remove(&mut self, other: Self)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Self)

The bitwise exclusive-or (^) of the bits in two flags values.

pub fn set(&mut self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Self) -> Self

The bitwise and (&) of the bits in two flags values.

pub const fn union(self, other: Self) -> Self

The bitwise or (|) of the bits in two flags values.

pub const fn difference(self, other: Self) -> Self

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in two flags values.

pub const fn complement(self) -> Self

The bitwise negation (!) of the bits in a flags value, truncating the result.

Source

impl Dbgdevid

pub const fn iter(&self) -> Iter<Dbgdevid>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<Dbgdevid>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.

Source

impl Dbgdevid

pub const PCSAMPLE_SHIFT: u32 = 0

Offset of the PCSample field.

pub const PCSAMPLE_MASK: u32 = 0b1111

Mask for the PCSample field.

pub const WPADDRMASK_SHIFT: u32 = 4

Offset of the WPAddrMask field.

pub const WPADDRMASK_MASK: u32 = 0b1111

Mask for the WPAddrMask field.

pub const BPADDRMASK_SHIFT: u32 = 8

Offset of the BPAddrMask field.

pub const BPADDRMASK_MASK: u32 = 0b1111

Mask for the BPAddrMask field.

pub const VECTORCATCH_SHIFT: u32 = 12

Offset of the VectorCatch field.

pub const VECTORCATCH_MASK: u32 = 0b1111

Mask for the VectorCatch field.

pub const VIRTEXTNS_SHIFT: u32 = 16

Offset of the VirtExtns field.

pub const VIRTEXTNS_MASK: u32 = 0b1111

Mask for the VirtExtns field.

pub const DOUBLELOCK_SHIFT: u32 = 20

Offset of the DoubleLock field.

pub const DOUBLELOCK_MASK: u32 = 0b1111

Mask for the DoubleLock field.

pub const AUXREGS_SHIFT: u32 = 24

Offset of the AuxRegs field.

pub const AUXREGS_MASK: u32 = 0b1111

Mask for the AuxRegs field.

pub const CIDMASK_SHIFT: u32 = 28

Offset of the CIDMask field.

pub const CIDMASK_MASK: u32 = 0b1111

Mask for the CIDMask field.

pub const fn pcsample(self) -> u8

Returns the value of the PCSample field.

pub const fn set_pcsample(&mut self, value: u8)

Sets the value of the PCSample field.

pub const fn with_pcsample(self, value: u8) -> Self

Returns a copy with the PCSample field set to the given value.

pub const fn wpaddrmask(self) -> u8

Returns the value of the WPAddrMask field.

pub const fn set_wpaddrmask(&mut self, value: u8)

Sets the value of the WPAddrMask field.

pub const fn with_wpaddrmask(self, value: u8) -> Self

Returns a copy with the WPAddrMask field set to the given value.

pub const fn bpaddrmask(self) -> u8

Returns the value of the BPAddrMask field.

pub const fn set_bpaddrmask(&mut self, value: u8)

Sets the value of the BPAddrMask field.

pub const fn with_bpaddrmask(self, value: u8) -> Self

Returns a copy with the BPAddrMask field set to the given value.

pub const fn vectorcatch(self) -> u8

Returns the value of the VectorCatch field.

pub const fn set_vectorcatch(&mut self, value: u8)

Sets the value of the VectorCatch field.

pub const fn with_vectorcatch(self, value: u8) -> Self

Returns a copy with the VectorCatch field set to the given value.

pub const fn virtextns(self) -> u8

Returns the value of the VirtExtns field.

pub const fn set_virtextns(&mut self, value: u8)

Sets the value of the VirtExtns field.

pub const fn with_virtextns(self, value: u8) -> Self

Returns a copy with the VirtExtns field set to the given value.

pub const fn doublelock(self) -> u8

Returns the value of the DoubleLock field.

pub const fn set_doublelock(&mut self, value: u8)

Sets the value of the DoubleLock field.

pub const fn with_doublelock(self, value: u8) -> Self

Returns a copy with the DoubleLock field set to the given value.

pub const fn auxregs(self) -> u8

Returns the value of the AuxRegs field.

pub const fn set_auxregs(&mut self, value: u8)

Sets the value of the AuxRegs field.

pub const fn with_auxregs(self, value: u8) -> Self

Returns a copy with the AuxRegs field set to the given value.

pub const fn cidmask(self) -> u8

Returns the value of the CIDMask field.

pub const fn set_cidmask(&mut self, value: u8)

Sets the value of the CIDMask field.

pub const fn with_cidmask(self, value: u8) -> Self

Returns a copy with the CIDMask field set to the given value.