pub struct Dbgdidr(/* private fields */);Expand description
DBGDIDR system register value.
Implementations
Sourceimpl Dbgdidr
impl Dbgdidr
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl Dbgdidr
impl Dbgdidr
Sourcepub const fn iter(&self) -> Iter<Dbgdidr>
pub const fn iter(&self) -> Iter<Dbgdidr>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<Dbgdidr>
pub const fn iter_names(&self) -> IterNames<Dbgdidr>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl Dbgdidr
impl Dbgdidr
Sourcepub const SE_IMP_SHIFT: u32 = 12
pub const SE_IMP_SHIFT: u32 = 12
Offset of the SE_imp field.
Sourcepub const NSUHD_IMP_SHIFT: u32 = 14
pub const NSUHD_IMP_SHIFT: u32 = 14
Offset of the nSUHD_imp field.
Sourcepub const VERSION_SHIFT: u32 = 16
pub const VERSION_SHIFT: u32 = 16
Offset of the Version field.
Sourcepub const VERSION_MASK: u32 = 0b1111
pub const VERSION_MASK: u32 = 0b1111
Mask for the Version field.
Sourcepub const CTX_CMPS_SHIFT: u32 = 20
pub const CTX_CMPS_SHIFT: u32 = 20
Offset of the CTX_CMPs field.
Sourcepub const CTX_CMPS_MASK: u32 = 0b1111
pub const CTX_CMPS_MASK: u32 = 0b1111
Mask for the CTX_CMPs field.
Sourcepub const BRPS_SHIFT: u32 = 24
pub const BRPS_SHIFT: u32 = 24
Offset of the BRPs field.
Sourcepub const WRPS_SHIFT: u32 = 28
pub const WRPS_SHIFT: u32 = 28
Offset of the WRPs field.
Sourcepub const fn set_version(&mut self, value: u8)
pub const fn set_version(&mut self, value: u8)
Sets the value of the Version field.
Sourcepub const fn with_version(self, value: u8) -> Self
pub const fn with_version(self, value: u8) -> Self
Returns a copy with the Version field set to the given value.
Sourcepub const fn set_ctx_cmps(&mut self, value: u8)
pub const fn set_ctx_cmps(&mut self, value: u8)
Sets the value of the CTX_CMPs field.
Sourcepub const fn with_ctx_cmps(self, value: u8) -> Self
pub const fn with_ctx_cmps(self, value: u8) -> Self
Returns a copy with the CTX_CMPs field set to the given value.