DisrEl1

Struct DisrEl1 

pub struct DisrEl1(/* private fields */);
DISR_EL1 system register value.

Implementations

Source

impl DisrEl1

pub const WNR: Self

WnR bit.

pub const WNRV: Self

WnRV bit.

pub const EA: Self

EA bit.

pub const IDS: Self

IDS bit.

pub const A: Self

A bit.

Source

impl DisrEl1

pub const fn empty() -> Self

Get a flags value with all bits unset.

pub const fn all() -> Self

Get a flags value with all known bits set.

pub const fn bits(&self) -> u64

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u64) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u64) -> Self

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u64) -> Self

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in this flags value are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Self) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

pub const fn contains(&self, other: Self) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

pub fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in two flags values.

pub fn remove(&mut self, other: Self)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Self)

The bitwise exclusive-or (^) of the bits in two flags values.

pub fn set(&mut self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Self) -> Self

The bitwise and (&) of the bits in two flags values.

pub const fn union(self, other: Self) -> Self

The bitwise or (|) of the bits in two flags values.

pub const fn difference(self, other: Self) -> Self

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in two flags values.

pub const fn complement(self) -> Self

The bitwise negation (!) of the bits in a flags value, truncating the result.

Source

impl DisrEl1

pub const fn iter(&self) -> Iter<DisrEl1>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<DisrEl1>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.

Source

impl DisrEl1

pub const DFSC_SHIFT: u32 = 0

Available on crate feature el1 only.

Offset of the DFSC field.

pub const DFSC_MASK: u64 = 0b111111

Available on crate feature el1 only.

Mask for the DFSC field.

pub const WNR_SHIFT: u32 = 6

Available on crate feature el1 only.

Offset of the WnR field.

pub const WNRV_SHIFT: u32 = 7

Available on crate feature el1 only.

Offset of the WnRV field.

pub const EA_SHIFT: u32 = 9

Available on crate feature el1 only.

Offset of the EA field.

pub const AET_SHIFT: u32 = 10

Available on crate feature el1 only.

Offset of the AET field.

pub const AET_MASK: u64 = 0b111

Available on crate feature el1 only.

Mask for the AET field.

pub const WU_SHIFT: u32 = 16

Available on crate feature el1 only.

Offset of the WU field.

pub const WU_MASK: u64 = 0b11

Available on crate feature el1 only.

Mask for the WU field.

pub const IDS_SHIFT: u32 = 24

Available on crate feature el1 only.

Offset of the IDS field.

pub const A_SHIFT: u32 = 31

Available on crate feature el1 only.

Offset of the A field.

pub const fn dfsc(self) -> u8

Available on crate feature el1 only.

Returns the value of the DFSC field.

pub const fn set_dfsc(&mut self, value: u8)

Available on crate feature el1 only.

Sets the value of the DFSC field.

pub const fn with_dfsc(self, value: u8) -> Self

Available on crate feature el1 only.

Returns a copy with the DFSC field set to the given value.

pub const fn aet(self) -> u8

Available on crate feature el1 only.

Returns the value of the AET field.

pub const fn set_aet(&mut self, value: u8)

Available on crate feature el1 only.

Sets the value of the AET field.

pub const fn with_aet(self, value: u8) -> Self

Available on crate feature el1 only.

Returns a copy with the AET field set to the given value.

pub const fn wu(self) -> u8

Available on crate feature el1 only.

Returns the value of the WU field.

pub const fn set_wu(&mut self, value: u8)

Available on crate feature el1 only.

Sets the value of the WU field.

pub const fn with_wu(self, value: u8) -> Self

Available on crate feature el1 only.

Returns a copy with the WU field set to the given value.