pub struct EsrEl3(/* private fields */);Expand description
ESR_EL3 system register value.
Implementations
Sourceimpl EsrEl3
impl EsrEl3
Sourcepub const ISS_SYSREG_OPCODE_MASK: Self
Available on crate feature el3 only.
pub const ISS_SYSREG_OPCODE_MASK: Self
el3 only.Mask for the parts of an ESR value containing the opcode.
Sourceimpl EsrEl3
impl EsrEl3
Sourcepub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u64) -> Option<Self>
pub const fn from_bits(bits: u64) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u64) -> Self
pub const fn from_bits_truncate(bits: u64) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u64) -> Self
pub const fn from_bits_retain(bits: u64) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl EsrEl3
impl EsrEl3
Sourcepub const fn iter(&self) -> Iter<EsrEl3>
pub const fn iter(&self) -> Iter<EsrEl3>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<EsrEl3>
pub const fn iter_names(&self) -> IterNames<EsrEl3>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl EsrEl3
impl EsrEl3
Sourcepub const ISS_MASK: u64 = 0b1111111111111111111111111
Available on crate feature el3 only.
pub const ISS_MASK: u64 = 0b1111111111111111111111111
el3 only.Mask for the ISS field.
Sourcepub const ISS2_SHIFT: u32 = 32
Available on crate feature el3 only.
pub const ISS2_SHIFT: u32 = 32
el3 only.Offset of the ISS2 field.
Sourcepub const ISS2_MASK: u64 = 0b111111111111111111111111
Available on crate feature el3 only.
pub const ISS2_MASK: u64 = 0b111111111111111111111111
el3 only.Mask for the ISS2 field.
Sourcepub const fn iss(self) -> u32
Available on crate feature el3 only.
pub const fn iss(self) -> u32
el3 only.Returns the value of the ISS field.
Sourcepub const fn set_iss(&mut self, value: u32)
Available on crate feature el3 only.
pub const fn set_iss(&mut self, value: u32)
el3 only.Sets the value of the ISS field.
Sourcepub const fn with_iss(self, value: u32) -> Self
Available on crate feature el3 only.
pub const fn with_iss(self, value: u32) -> Self
el3 only.Returns a copy with the ISS field set to the given value.
Sourcepub const fn ec(self) -> u8
Available on crate feature el3 only.
pub const fn ec(self) -> u8
el3 only.Returns the value of the EC field.
Sourcepub const fn set_ec(&mut self, value: u8)
Available on crate feature el3 only.
pub const fn set_ec(&mut self, value: u8)
el3 only.Sets the value of the EC field.
Sourcepub const fn with_ec(self, value: u8) -> Self
Available on crate feature el3 only.
pub const fn with_ec(self, value: u8) -> Self
el3 only.Returns a copy with the EC field set to the given value.
Sourcepub const fn iss2(self) -> u32
Available on crate feature el3 only.
pub const fn iss2(self) -> u32
el3 only.Returns the value of the ISS2 field.