GpccrEl3

Struct GpccrEl3 

pub struct GpccrEl3(/* private fields */);
GPCCR_EL3 system register value.

Implementations

Source

impl GpccrEl3

pub const PPS3: Self

PPS3 bit.

pub const RLPAD: Self

RLPAD bit.

pub const NSPAD: Self

NSPAD bit.

pub const SPAD: Self

SPAD bit.

pub const GPC: Self

GPC bit.

pub const GPCP: Self

GPCP bit.

pub const TBGPCD: Self

TBGPCD bit.

pub const NSO: Self

NSO bit.

pub const APPSAA: Self

APPSAA bit.

pub const SA: Self

SA bit.

pub const NSP: Self

NSP bit.

pub const NA6: Self

NA6 bit.

pub const NA7: Self

NA7 bit.

pub const GPCBW: Self

GPCBW bit.

Source

impl GpccrEl3

pub const fn empty() -> Self

Get a flags value with all bits unset.

pub const fn all() -> Self

Get a flags value with all known bits set.

pub const fn bits(&self) -> u64

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u64) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u64) -> Self

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u64) -> Self

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in this flags value are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Self) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

pub const fn contains(&self, other: Self) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

pub fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in two flags values.

pub fn remove(&mut self, other: Self)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Self)

The bitwise exclusive-or (^) of the bits in two flags values.

pub fn set(&mut self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Self) -> Self

The bitwise and (&) of the bits in two flags values.

pub const fn union(self, other: Self) -> Self

The bitwise or (|) of the bits in two flags values.

pub const fn difference(self, other: Self) -> Self

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in two flags values.

pub const fn complement(self) -> Self

The bitwise negation (!) of the bits in a flags value, truncating the result.

Source

impl GpccrEl3

pub const fn iter(&self) -> Iter<GpccrEl3>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<GpccrEl3>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.

Source

impl GpccrEl3

pub const PPS_SHIFT: u32 = 0

Available on crate feature el3 only.

Offset of the PPS field.

pub const PPS_MASK: u64 = 0b111

Available on crate feature el3 only.

Mask for the PPS field.

pub const PPS3_SHIFT: u32 = 3

Available on crate feature el3 only.

Offset of the PPS3 field.

pub const RLPAD_SHIFT: u32 = 5

Available on crate feature el3 only.

Offset of the RLPAD field.

pub const NSPAD_SHIFT: u32 = 6

Available on crate feature el3 only.

Offset of the NSPAD field.

pub const SPAD_SHIFT: u32 = 7

Available on crate feature el3 only.

Offset of the SPAD field.

pub const IRGN_SHIFT: u32 = 8

Available on crate feature el3 only.

Offset of the IRGN field.

pub const IRGN_MASK: u64 = 0b11

Available on crate feature el3 only.

Mask for the IRGN field.

pub const ORGN_SHIFT: u32 = 10

Available on crate feature el3 only.

Offset of the ORGN field.

pub const ORGN_MASK: u64 = 0b11

Available on crate feature el3 only.

Mask for the ORGN field.

pub const SH_SHIFT: u32 = 12

Available on crate feature el3 only.

Offset of the SH field.

pub const SH_MASK: u64 = 0b11

Available on crate feature el3 only.

Mask for the SH field.

pub const PGS_SHIFT: u32 = 14

Available on crate feature el3 only.

Offset of the PGS field.

pub const PGS_MASK: u64 = 0b11

Available on crate feature el3 only.

Mask for the PGS field.

pub const GPC_SHIFT: u32 = 16

Available on crate feature el3 only.

Offset of the GPC field.

pub const GPCP_SHIFT: u32 = 17

Available on crate feature el3 only.

Offset of the GPCP field.

pub const TBGPCD_SHIFT: u32 = 18

Available on crate feature el3 only.

Offset of the TBGPCD field.

pub const NSO_SHIFT: u32 = 19

Available on crate feature el3 only.

Offset of the NSO field.

pub const L0GPTSZ_SHIFT: u32 = 20

Available on crate feature el3 only.

Offset of the L0GPTSZ field.

pub const L0GPTSZ_MASK: u64 = 0b1111

Available on crate feature el3 only.

Mask for the L0GPTSZ field.

pub const APPSAA_SHIFT: u32 = 24

Available on crate feature el3 only.

Offset of the APPSAA field.

pub const SA_SHIFT: u32 = 25

Available on crate feature el3 only.

Offset of the SA field.

pub const NSP_SHIFT: u32 = 26

Available on crate feature el3 only.

Offset of the NSP field.

pub const NA6_SHIFT: u32 = 27

Available on crate feature el3 only.

Offset of the NA6 field.

pub const NA7_SHIFT: u32 = 28

Available on crate feature el3 only.

Offset of the NA7 field.

pub const GPCBW_SHIFT: u32 = 29

Available on crate feature el3 only.

Offset of the GPCBW field.

pub const fn pps(self) -> u8

Available on crate feature el3 only.

Returns the value of the PPS field.

pub const fn set_pps(&mut self, value: u8)

Available on crate feature el3 only.

Sets the value of the PPS field.

pub const fn with_pps(self, value: u8) -> Self

Available on crate feature el3 only.

Returns a copy with the PPS field set to the given value.

pub fn irgn(self) -> Cacheability

Available on crate feature el3 only.

Returns the value of the IRGN field.

pub fn set_irgn(&mut self, value: Cacheability)

Available on crate feature el3 only.

Sets the value of the IRGN field.

pub fn with_irgn(self, value: Cacheability) -> Self

Available on crate feature el3 only.

Returns a copy with the IRGN field set to the given value.

pub fn orgn(self) -> Cacheability

Available on crate feature el3 only.

Returns the value of the ORGN field.

pub fn set_orgn(&mut self, value: Cacheability)

Available on crate feature el3 only.

Sets the value of the ORGN field.

pub fn with_orgn(self, value: Cacheability) -> Self

Available on crate feature el3 only.

Returns a copy with the ORGN field set to the given value.

pub fn sh(self) -> Shareability

Available on crate feature el3 only.

Returns the value of the SH field.

pub fn set_sh(&mut self, value: Shareability)

Available on crate feature el3 only.

Sets the value of the SH field.

pub fn with_sh(self, value: Shareability) -> Self

Available on crate feature el3 only.

Returns a copy with the SH field set to the given value.

pub const fn pgs(self) -> u8

Available on crate feature el3 only.

Returns the value of the PGS field.

pub const fn set_pgs(&mut self, value: u8)

Available on crate feature el3 only.

Sets the value of the PGS field.

pub const fn with_pgs(self, value: u8) -> Self

Available on crate feature el3 only.

Returns a copy with the PGS field set to the given value.

pub const fn l0gptsz(self) -> u8

Available on crate feature el3 only.

Returns the value of the L0GPTSZ field.

pub const fn set_l0gptsz(&mut self, value: u8)

Available on crate feature el3 only.

Sets the value of the L0GPTSZ field.

pub const fn with_l0gptsz(self, value: u8) -> Self

Available on crate feature el3 only.

Returns a copy with the L0GPTSZ field set to the given value.