Hcr

Struct Hcr 

pub struct Hcr(/* private fields */);
HCR system register value.

Implementations

Source

impl Hcr

pub const VM: Self

VM bit.

pub const SWIO: Self

SWIO bit.

pub const PTW: Self

PTW bit.

pub const FMO: Self

FMO bit.

pub const IMO: Self

IMO bit.

pub const AMO: Self

AMO bit.

pub const VF: Self

VF bit.

pub const VI: Self

VI bit.

pub const VA: Self

VA bit.

pub const FB: Self

FB bit.

pub const DC: Self

DC bit.

pub const TWI: Self

TWI bit.

pub const TWE: Self

TWE bit.

pub const TID0: Self

TID0 bit.

pub const TID1: Self

TID1 bit.

pub const TID2: Self

TID2 bit.

pub const TID3: Self

TID3 bit.

pub const TSC: Self

TSC bit.

pub const TIDCP: Self

TIDCP bit.

pub const TAC: Self

TAC bit.

pub const TSW: Self

TSW bit.

pub const TPC: Self

TPC bit.

pub const TPU: Self

TPU bit.

pub const TTLB: Self

TTLB bit.

pub const TVM: Self

TVM bit.

pub const TGE: Self

TGE bit.

pub const HCD: Self

HCD bit.

pub const TRVM: Self

TRVM bit.

Source

impl Hcr

pub const fn empty() -> Self

Get a flags value with all bits unset.

pub const fn all() -> Self

Get a flags value with all known bits set.

pub const fn bits(&self) -> u32

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u32) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u32) -> Self

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u32) -> Self

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in this flags value are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Self) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

pub const fn contains(&self, other: Self) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

pub fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in two flags values.

pub fn remove(&mut self, other: Self)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Self)

The bitwise exclusive-or (^) of the bits in two flags values.

pub fn set(&mut self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Self) -> Self

The bitwise and (&) of the bits in two flags values.

pub const fn union(self, other: Self) -> Self

The bitwise or (|) of the bits in two flags values.

pub const fn difference(self, other: Self) -> Self

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in two flags values.

pub const fn complement(self) -> Self

The bitwise negation (!) of the bits in a flags value, truncating the result.

Source

impl Hcr

pub const fn iter(&self) -> Iter<Hcr>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<Hcr>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.

Source

impl Hcr

pub const VM_SHIFT: u32 = 0

Offset of the VM field.

pub const SWIO_SHIFT: u32 = 1

Offset of the SWIO field.

pub const PTW_SHIFT: u32 = 2

Offset of the PTW field.

pub const FMO_SHIFT: u32 = 3

Offset of the FMO field.

pub const IMO_SHIFT: u32 = 4

Offset of the IMO field.

pub const AMO_SHIFT: u32 = 5

Offset of the AMO field.

pub const VF_SHIFT: u32 = 6

Offset of the VF field.

pub const VI_SHIFT: u32 = 7

Offset of the VI field.

pub const VA_SHIFT: u32 = 8

Offset of the VA field.

pub const FB_SHIFT: u32 = 9

Offset of the FB field.

pub const BSU_SHIFT: u32 = 10

Offset of the BSU field.

pub const BSU_MASK: u32 = 0b11

Mask for the BSU field.

pub const DC_SHIFT: u32 = 12

Offset of the DC field.

pub const TWI_SHIFT: u32 = 13

Offset of the TWI field.

pub const TWE_SHIFT: u32 = 14

Offset of the TWE field.

pub const TID0_SHIFT: u32 = 15

Offset of the TID0 field.

pub const TID1_SHIFT: u32 = 16

Offset of the TID1 field.

pub const TID2_SHIFT: u32 = 17

Offset of the TID2 field.

pub const TID3_SHIFT: u32 = 18

Offset of the TID3 field.

pub const TSC_SHIFT: u32 = 19

Offset of the TSC field.

pub const TIDCP_SHIFT: u32 = 20

Offset of the TIDCP field.

pub const TAC_SHIFT: u32 = 21

Offset of the TAC field.

pub const TSW_SHIFT: u32 = 22

Offset of the TSW field.

pub const TPC_SHIFT: u32 = 23

Offset of the TPC field.

pub const TPU_SHIFT: u32 = 24

Offset of the TPU field.

pub const TTLB_SHIFT: u32 = 25

Offset of the TTLB field.

pub const TVM_SHIFT: u32 = 26

Offset of the TVM field.

pub const TGE_SHIFT: u32 = 27

Offset of the TGE field.

pub const HCD_SHIFT: u32 = 29

Offset of the HCD field.

pub const TRVM_SHIFT: u32 = 30

Offset of the TRVM field.

pub const fn bsu(self) -> u8

Returns the value of the BSU field.

pub const fn set_bsu(&mut self, value: u8)

Sets the value of the BSU field.

pub const fn with_bsu(self, value: u8) -> Self

Returns a copy with the BSU field set to the given value.