HcrEl2

Struct HcrEl2 

pub struct HcrEl2(/* private fields */);
HCR_EL2 system register value.

Implementations

Source

impl HcrEl2

pub const VM: Self

VM bit.

pub const SWIO: Self

SWIO bit.

pub const PTW: Self

PTW bit.

pub const FMO: Self

FMO bit.

pub const IMO: Self

IMO bit.

pub const AMO: Self

AMO bit.

pub const VF: Self

VF bit.

pub const VI: Self

VI bit.

pub const VSE: Self

VSE bit.

pub const FB: Self

FB bit.

pub const DC: Self

DC bit.

pub const TWI: Self

TWI bit.

pub const TWE: Self

TWE bit.

pub const TID0: Self

TID0 bit.

pub const TID1: Self

TID1 bit.

pub const TID2: Self

TID2 bit.

pub const TID3: Self

TID3 bit.

pub const TSC: Self

TSC bit.

pub const TIDCP: Self

TIDCP bit.

pub const TACR: Self

TACR bit.

pub const TSW: Self

TSW bit.

pub const TPCP: Self

TPCP bit.

pub const TPU: Self

TPU bit.

pub const TTLB: Self

TTLB bit.

pub const TVM: Self

TVM bit.

pub const TGE: Self

Trap general exceptions to EL2.

pub const TDZ: Self

TDZ bit.

pub const HCD: Self

HCD bit.

pub const TRVM: Self

TRVM bit.

pub const RW: Self

RW bit.

pub const CD: Self

CD bit.

pub const ID: Self

ID bit.

pub const E2H: Self

E2H bit.

pub const TLOR: Self

TLOR bit.

pub const TERR: Self

TERR bit.

pub const TEA: Self

TEA bit.

pub const APK: Self

APK bit.

pub const API: Self

API bit.

pub const NV: Self

NV bit.

pub const NV1: Self

NV1 bit.

pub const AT: Self

AT bit.

pub const NV2: Self

NV2 bit.

pub const FWB: Self

FWB bit.

pub const FIEN: Self

FIEN bit.

pub const GPF: Self

GPF bit.

pub const TID4: Self

TID4 bit.

pub const TICAB: Self

TICAB bit.

pub const AMVOFFEN: Self

AMVOFFEN bit.

pub const TOCU: Self

TOCU bit.

pub const ENSCXT: Self

EnSCXT bit.

pub const TTLBIS: Self

TTLBIS bit.

pub const TTLBOS: Self

TTLBOS bit.

pub const ATA: Self

ATA bit.

pub const DCT: Self

DCT bit.

pub const TID5: Self

TID5 bit.

pub const TWEDEN: Self

TWEDEn bit.

Source

impl HcrEl2

pub const fn empty() -> Self

Get a flags value with all bits unset.

pub const fn all() -> Self

Get a flags value with all known bits set.

pub const fn bits(&self) -> u64

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u64) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u64) -> Self

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u64) -> Self

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in this flags value are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Self) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

pub const fn contains(&self, other: Self) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

pub fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in two flags values.

pub fn remove(&mut self, other: Self)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Self)

The bitwise exclusive-or (^) of the bits in two flags values.

pub fn set(&mut self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Self) -> Self

The bitwise and (&) of the bits in two flags values.

pub const fn union(self, other: Self) -> Self

The bitwise or (|) of the bits in two flags values.

pub const fn difference(self, other: Self) -> Self

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in two flags values.

pub const fn complement(self) -> Self

The bitwise negation (!) of the bits in a flags value, truncating the result.

Source

impl HcrEl2

pub const fn iter(&self) -> Iter<HcrEl2>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<HcrEl2>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.

Source

impl HcrEl2

pub const VM_SHIFT: u32 = 0

Available on crate feature el2 only.

Offset of the VM field.

pub const SWIO_SHIFT: u32 = 1

Available on crate feature el2 only.

Offset of the SWIO field.

pub const PTW_SHIFT: u32 = 2

Available on crate feature el2 only.

Offset of the PTW field.

pub const FMO_SHIFT: u32 = 3

Available on crate feature el2 only.

Offset of the FMO field.

pub const IMO_SHIFT: u32 = 4

Available on crate feature el2 only.

Offset of the IMO field.

pub const AMO_SHIFT: u32 = 5

Available on crate feature el2 only.

Offset of the AMO field.

pub const VF_SHIFT: u32 = 6

Available on crate feature el2 only.

Offset of the VF field.

pub const VI_SHIFT: u32 = 7

Available on crate feature el2 only.

Offset of the VI field.

pub const VSE_SHIFT: u32 = 8

Available on crate feature el2 only.

Offset of the VSE field.

pub const FB_SHIFT: u32 = 9

Available on crate feature el2 only.

Offset of the FB field.

pub const BSU_SHIFT: u32 = 10

Available on crate feature el2 only.

Offset of the BSU field.

pub const BSU_MASK: u64 = 0b11

Available on crate feature el2 only.

Mask for the BSU field.

pub const DC_SHIFT: u32 = 12

Available on crate feature el2 only.

Offset of the DC field.

pub const TWI_SHIFT: u32 = 13

Available on crate feature el2 only.

Offset of the TWI field.

pub const TWE_SHIFT: u32 = 14

Available on crate feature el2 only.

Offset of the TWE field.

pub const TID0_SHIFT: u32 = 15

Available on crate feature el2 only.

Offset of the TID0 field.

pub const TID1_SHIFT: u32 = 16

Available on crate feature el2 only.

Offset of the TID1 field.

pub const TID2_SHIFT: u32 = 17

Available on crate feature el2 only.

Offset of the TID2 field.

pub const TID3_SHIFT: u32 = 18

Available on crate feature el2 only.

Offset of the TID3 field.

pub const TSC_SHIFT: u32 = 19

Available on crate feature el2 only.

Offset of the TSC field.

pub const TIDCP_SHIFT: u32 = 20

Available on crate feature el2 only.

Offset of the TIDCP field.

pub const TACR_SHIFT: u32 = 21

Available on crate feature el2 only.

Offset of the TACR field.

pub const TSW_SHIFT: u32 = 22

Available on crate feature el2 only.

Offset of the TSW field.

pub const TPCP_SHIFT: u32 = 23

Available on crate feature el2 only.

Offset of the TPCP field.

pub const TPU_SHIFT: u32 = 24

Available on crate feature el2 only.

Offset of the TPU field.

pub const TTLB_SHIFT: u32 = 25

Available on crate feature el2 only.

Offset of the TTLB field.

pub const TVM_SHIFT: u32 = 26

Available on crate feature el2 only.

Offset of the TVM field.

pub const TGE_SHIFT: u32 = 27

Available on crate feature el2 only.

Offset of the TGE field.

pub const TDZ_SHIFT: u32 = 28

Available on crate feature el2 only.

Offset of the TDZ field.

pub const HCD_SHIFT: u32 = 29

Available on crate feature el2 only.

Offset of the HCD field.

pub const TRVM_SHIFT: u32 = 30

Available on crate feature el2 only.

Offset of the TRVM field.

pub const RW_SHIFT: u32 = 31

Available on crate feature el2 only.

Offset of the RW field.

pub const CD_SHIFT: u32 = 32

Available on crate feature el2 only.

Offset of the CD field.

pub const ID_SHIFT: u32 = 33

Available on crate feature el2 only.

Offset of the ID field.

pub const E2H_SHIFT: u32 = 34

Available on crate feature el2 only.

Offset of the E2H field.

pub const TLOR_SHIFT: u32 = 35

Available on crate feature el2 only.

Offset of the TLOR field.

pub const TERR_SHIFT: u32 = 36

Available on crate feature el2 only.

Offset of the TERR field.

pub const TEA_SHIFT: u32 = 37

Available on crate feature el2 only.

Offset of the TEA field.

pub const APK_SHIFT: u32 = 40

Available on crate feature el2 only.

Offset of the APK field.

pub const API_SHIFT: u32 = 41

Available on crate feature el2 only.

Offset of the API field.

pub const NV_SHIFT: u32 = 42

Available on crate feature el2 only.

Offset of the NV field.

pub const NV1_SHIFT: u32 = 43

Available on crate feature el2 only.

Offset of the NV1 field.

pub const AT_SHIFT: u32 = 44

Available on crate feature el2 only.

Offset of the AT field.

pub const NV2_SHIFT: u32 = 45

Available on crate feature el2 only.

Offset of the NV2 field.

pub const FWB_SHIFT: u32 = 46

Available on crate feature el2 only.

Offset of the FWB field.

pub const FIEN_SHIFT: u32 = 47

Available on crate feature el2 only.

Offset of the FIEN field.

pub const GPF_SHIFT: u32 = 48

Available on crate feature el2 only.

Offset of the GPF field.

pub const TID4_SHIFT: u32 = 49

Available on crate feature el2 only.

Offset of the TID4 field.

pub const TICAB_SHIFT: u32 = 50

Available on crate feature el2 only.

Offset of the TICAB field.

pub const AMVOFFEN_SHIFT: u32 = 51

Available on crate feature el2 only.

Offset of the AMVOFFEN field.

pub const TOCU_SHIFT: u32 = 52

Available on crate feature el2 only.

Offset of the TOCU field.

pub const ENSCXT_SHIFT: u32 = 53

Available on crate feature el2 only.

Offset of the EnSCXT field.

pub const TTLBIS_SHIFT: u32 = 54

Available on crate feature el2 only.

Offset of the TTLBIS field.

pub const TTLBOS_SHIFT: u32 = 55

Available on crate feature el2 only.

Offset of the TTLBOS field.

pub const ATA_SHIFT: u32 = 56

Available on crate feature el2 only.

Offset of the ATA field.

pub const DCT_SHIFT: u32 = 57

Available on crate feature el2 only.

Offset of the DCT field.

pub const TID5_SHIFT: u32 = 58

Available on crate feature el2 only.

Offset of the TID5 field.

pub const TWEDEN_SHIFT: u32 = 59

Available on crate feature el2 only.

Offset of the TWEDEn field.

pub const TWEDEL_SHIFT: u32 = 60

Available on crate feature el2 only.

Offset of the TWEDEL field.

pub const TWEDEL_MASK: u64 = 0b1111

Available on crate feature el2 only.

Mask for the TWEDEL field.

pub const fn bsu(self) -> u8

Available on crate feature el2 only.

Returns the value of the BSU field.

pub const fn set_bsu(&mut self, value: u8)

Available on crate feature el2 only.

Sets the value of the BSU field.

pub const fn with_bsu(self, value: u8) -> Self

Available on crate feature el2 only.

Returns a copy with the BSU field set to the given value.

pub const fn twedel(self) -> u8

Available on crate feature el2 only.

Returns the value of the TWEDEL field.

pub const fn set_twedel(&mut self, value: u8)

Available on crate feature el2 only.

Sets the value of the TWEDEL field.

pub const fn with_twedel(self, value: u8) -> Self

Available on crate feature el2 only.

Returns a copy with the TWEDEL field set to the given value.