HcrxEl2

Struct HcrxEl2 

pub struct HcrxEl2(/* private fields */);
HCRX_EL2 system register value.

Extended Hypervisor Configuration Register.

Implementations

Source

impl HcrxEl2

pub const ENAS0: Self

Do not trap execution of an ST64BV0 instruction at EL0 or EL1 to EL2.

pub const ENALS: Self

Do not trap execution of an LD64B or ST64B instruction at EL0 or EL1 to EL2.

pub const ENASR: Self

Do not trap execution of an ST64BV instruction at EL0 or EL1 to EL2.

pub const FNXS: Self

Determines the behavior of TLBI instructions affected by the XS attribute.

pub const FGTNXS: Self

Determines if the fine-grained traps in HFGITR_EL2 also apply to the corresponding TLBI maintenance instructions with the nXS qualifier.

pub const SMPME: Self

Controls mapping of the value of SMPRI_EL1.Priority for streaming execution priority at EL0 or EL1.

pub const TALLINT: Self

Traps MSR writes of ALLINT at EL1 using AArch64 to EL2.

pub const VINMI: Self

Enables signaling of virtual IRQ interrupts with Superpriority.

pub const VFNMI: Self

Enables signaling of virtual FIQ interrupts with Superpriority.

pub const CMOW: Self

Controls the required permissions for cache maintenance instructions at EL1 or EL0.

pub const MCE2: Self

Controls Memory Copy and Memory Set exceptions generated from EL1.

pub const MSCEN: Self

Enables execution of Memory Set and Memory Copy instructions at EL1 or EL0.

pub const TCR2EN: Self

TCR2En bit.

pub const SCTLR2EN: Self

SCTLR2En bit.

pub const PTTWI: Self

PTTWI bit.

pub const D128EN: Self

D128En bit.

pub const ENSNERR: Self

EnSNERR bit.

pub const TMEA: Self

TMEA bit.

pub const ENSDERR: Self

EnSDERR bit.

pub const ENIDCP128: Self

EnIDCP128 bit.

pub const GCSEN: Self

GCSEn bit.

pub const ENFPM: Self

EnFPM bit.

pub const PACMEN: Self

PACMEn bit.

pub const VTLBIDEN: Self

VTLBIDEn bit.

pub const SRMASKEN: Self

SRMASKEn bit.

pub const NVTGE: Self

NVTGE bit.

pub const POE2EN: Self

POE2En bit.

pub const TPLIMEN: Self

TPLIMEn bit.

pub const FDIT: Self

FDIT bit.

pub const NVNTTLB: Self

NVnTTLB bit.

pub const NVNTTLBIS: Self

NVnTTLBIS bit.

pub const NVNTTLBOS: Self

NVnTTLBOS bit.

pub const VTLBIDOSEN: Self

VTLBIDOSEn bit.

pub const FNB: Self

FNB bit.

pub const VTE: Self

VTE bit.

pub const VTAO: Self

VTAO bit.

pub const VTCO: Self

VTCO bit.

Source

impl HcrxEl2

pub const fn empty() -> Self

Get a flags value with all bits unset.

pub const fn all() -> Self

Get a flags value with all known bits set.

pub const fn bits(&self) -> u64

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u64) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u64) -> Self

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u64) -> Self

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in this flags value are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Self) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

pub const fn contains(&self, other: Self) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

pub fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in two flags values.

pub fn remove(&mut self, other: Self)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Self)

The bitwise exclusive-or (^) of the bits in two flags values.

pub fn set(&mut self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Self) -> Self

The bitwise and (&) of the bits in two flags values.

pub const fn union(self, other: Self) -> Self

The bitwise or (|) of the bits in two flags values.

pub const fn difference(self, other: Self) -> Self

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in two flags values.

pub const fn complement(self) -> Self

The bitwise negation (!) of the bits in a flags value, truncating the result.

Source

impl HcrxEl2

pub const fn iter(&self) -> Iter<HcrxEl2>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<HcrxEl2>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.

Source

impl HcrxEl2

pub const ENAS0_SHIFT: u32 = 0

Available on crate feature el2 only.

Offset of the EnAS0 field.

pub const ENALS_SHIFT: u32 = 1

Available on crate feature el2 only.

Offset of the EnALS field.

pub const ENASR_SHIFT: u32 = 2

Available on crate feature el2 only.

Offset of the EnASR field.

pub const FNXS_SHIFT: u32 = 3

Available on crate feature el2 only.

Offset of the FnXS field.

pub const FGTNXS_SHIFT: u32 = 4

Available on crate feature el2 only.

Offset of the FGTnXS field.

pub const SMPME_SHIFT: u32 = 5

Available on crate feature el2 only.

Offset of the SMPME field.

pub const TALLINT_SHIFT: u32 = 6

Available on crate feature el2 only.

Offset of the TALLINT field.

pub const VINMI_SHIFT: u32 = 7

Available on crate feature el2 only.

Offset of the VINMI field.

pub const VFNMI_SHIFT: u32 = 8

Available on crate feature el2 only.

Offset of the VFNMI field.

pub const CMOW_SHIFT: u32 = 9

Available on crate feature el2 only.

Offset of the CMOW field.

pub const MCE2_SHIFT: u32 = 10

Available on crate feature el2 only.

Offset of the MCE2 field.

pub const MSCEN_SHIFT: u32 = 11

Available on crate feature el2 only.

Offset of the MSCEn field.

pub const TCR2EN_SHIFT: u32 = 14

Available on crate feature el2 only.

Offset of the TCR2En field.

pub const SCTLR2EN_SHIFT: u32 = 15

Available on crate feature el2 only.

Offset of the SCTLR2En field.

pub const PTTWI_SHIFT: u32 = 16

Available on crate feature el2 only.

Offset of the PTTWI field.

pub const D128EN_SHIFT: u32 = 17

Available on crate feature el2 only.

Offset of the D128En field.

pub const ENSNERR_SHIFT: u32 = 18

Available on crate feature el2 only.

Offset of the EnSNERR field.

pub const TMEA_SHIFT: u32 = 19

Available on crate feature el2 only.

Offset of the TMEA field.

pub const ENSDERR_SHIFT: u32 = 20

Available on crate feature el2 only.

Offset of the EnSDERR field.

pub const ENIDCP128_SHIFT: u32 = 21

Available on crate feature el2 only.

Offset of the EnIDCP128 field.

pub const GCSEN_SHIFT: u32 = 22

Available on crate feature el2 only.

Offset of the GCSEn field.

pub const ENFPM_SHIFT: u32 = 23

Available on crate feature el2 only.

Offset of the EnFPM field.

pub const PACMEN_SHIFT: u32 = 24

Available on crate feature el2 only.

Offset of the PACMEn field.

pub const VTLBIDEN_SHIFT: u32 = 25

Available on crate feature el2 only.

Offset of the VTLBIDEn field.

pub const SRMASKEN_SHIFT: u32 = 26

Available on crate feature el2 only.

Offset of the SRMASKEn field.

pub const NVTGE_SHIFT: u32 = 27

Available on crate feature el2 only.

Offset of the NVTGE field.

pub const POE2EN_SHIFT: u32 = 29

Available on crate feature el2 only.

Offset of the POE2En field.

pub const TPLIMEN_SHIFT: u32 = 30

Available on crate feature el2 only.

Offset of the TPLIMEn field.

pub const FDIT_SHIFT: u32 = 31

Available on crate feature el2 only.

Offset of the FDIT field.

pub const NVNTTLB_SHIFT: u32 = 32

Available on crate feature el2 only.

Offset of the NVnTTLB field.

pub const NVNTTLBIS_SHIFT: u32 = 33

Available on crate feature el2 only.

Offset of the NVnTTLBIS field.

pub const NVNTTLBOS_SHIFT: u32 = 34

Available on crate feature el2 only.

Offset of the NVnTTLBOS field.

pub const VTLBIDOSEN_SHIFT: u32 = 35

Available on crate feature el2 only.

Offset of the VTLBIDOSEn field.

pub const FNB_SHIFT: u32 = 36

Available on crate feature el2 only.

Offset of the FNB field.

pub const VTE_SHIFT: u32 = 37

Available on crate feature el2 only.

Offset of the VTE field.

pub const VTAO_SHIFT: u32 = 38

Available on crate feature el2 only.

Offset of the VTAO field.

pub const VTCO_SHIFT: u32 = 39

Available on crate feature el2 only.

Offset of the VTCO field.