HdfgrtrEl2

Struct HdfgrtrEl2 

pub struct HdfgrtrEl2(/* private fields */);
HDFGRTR_EL2 system register value.

Implementations

Source

impl HdfgrtrEl2

pub const DBGBCRN_EL1: Self

DBGBCRn_EL1 bit.

pub const DBGBVRN_EL1: Self

DBGBVRn_EL1 bit.

pub const DBGWCRN_EL1: Self

DBGWCRn_EL1 bit.

pub const DBGWVRN_EL1: Self

DBGWVRn_EL1 bit.

pub const MDSCR_EL1: Self

MDSCR_EL1 bit.

pub const DBGCLAIM: Self

DBGCLAIM bit.

pub const DBGAUTHSTATUS_EL1: Self

DBGAUTHSTATUS_EL1 bit.

pub const DBGPRCR_EL1: Self

DBGPRCR_EL1 bit.

pub const OSLSR_EL1: Self

OSLSR_EL1 bit.

pub const OSECCR_EL1: Self

OSECCR_EL1 bit.

pub const OSDLR_EL1: Self

OSDLR_EL1 bit.

pub const PMEVCNTRN_EL0: Self

PMEVCNTRn_EL0 bit.

pub const PMEVTYPERN_EL0: Self

PMEVTYPERn_EL0 bit.

pub const PMCCFILTR_EL0: Self

PMCCFILTR_EL0 bit.

pub const PMCCNTR_EL0: Self

PMCCNTR_EL0 bit.

pub const PMCNTEN: Self

PMCNTEN bit.

pub const PMINTEN: Self

PMINTEN bit.

pub const PMOVS: Self

PMOVS bit.

pub const PMSELR_EL0: Self

PMSELR_EL0 bit.

pub const PMMIR_EL1: Self

PMMIR_EL1 bit.

pub const PMBLIMITR_EL1: Self

PMBLIMITR_EL1 bit.

pub const PMBPTR_EL1: Self

PMBPTR_EL1 bit.

pub const PMBSR_EL1: Self

PMBSR_EL1 bit.

pub const PMSCR_EL1: Self

PMSCR_EL1 bit.

pub const PMSEVFR_EL1: Self

PMSEVFR_EL1 bit.

pub const PMSFCR_EL1: Self

PMSFCR_EL1 bit.

pub const PMSICR_EL1: Self

PMSICR_EL1 bit.

pub const PMSIDR_EL1: Self

PMSIDR_EL1 bit.

pub const PMSIRR_EL1: Self

PMSIRR_EL1 bit.

pub const PMSLATFR_EL1: Self

PMSLATFR_EL1 bit.

pub const TRC: Self

TRC bit.

pub const TRCAUTHSTATUS: Self

TRCAUTHSTATUS bit.

pub const TRCAUXCTLR: Self

TRCAUXCTLR bit.

pub const TRCCLAIM: Self

TRCCLAIM bit.

pub const TRCCNTVRN: Self

TRCCNTVRn bit.

pub const TRCID: Self

TRCID bit.

pub const TRCIMSPECN: Self

TRCIMSPECn bit.

pub const TRCOSLSR: Self

TRCOSLSR bit.

pub const TRCPRGCTLR: Self

TRCPRGCTLR bit.

pub const TRCSEQSTR: Self

TRCSEQSTR bit.

pub const TRCSSCSRN: Self

TRCSSCSRn bit.

pub const TRCSTATR: Self

TRCSTATR bit.

pub const TRCVICTLR: Self

TRCVICTLR bit.

pub const TRBBASER_EL1: Self

TRBBASER_EL1 bit.

pub const TRBIDR_EL1: Self

TRBIDR_EL1 bit.

pub const TRBLIMITR_EL1: Self

TRBLIMITR_EL1 bit.

pub const TRBMAR_EL1: Self

TRBMAR_EL1 bit.

pub const TRBPTR_EL1: Self

TRBPTR_EL1 bit.

pub const TRBSR_EL1: Self

TRBSR_EL1 bit.

pub const TRBTRG_EL1: Self

TRBTRG_EL1 bit.

pub const PMUSERENR_EL0: Self

PMUSERENR_EL0 bit.

pub const PMCEIDN_EL0: Self

PMCEIDn_EL0 bit.

pub const NBRBIDR: Self

nBRBIDR bit.

pub const NBRBCTL: Self

nBRBCTL bit.

pub const NBRBDATA: Self

nBRBDATA bit.

pub const NPMSNEVFR_EL1: Self

nPMSNEVFR_EL1 bit.

pub const PMBIDR_EL1: Self

PMBIDR_EL1 bit.

Source

impl HdfgrtrEl2

pub const fn empty() -> Self

Get a flags value with all bits unset.

pub const fn all() -> Self

Get a flags value with all known bits set.

pub const fn bits(&self) -> u64

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u64) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u64) -> Self

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u64) -> Self

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in this flags value are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Self) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

pub const fn contains(&self, other: Self) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

pub fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in two flags values.

pub fn remove(&mut self, other: Self)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Self)

The bitwise exclusive-or (^) of the bits in two flags values.

pub fn set(&mut self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Self) -> Self

The bitwise and (&) of the bits in two flags values.

pub const fn union(self, other: Self) -> Self

The bitwise or (|) of the bits in two flags values.

pub const fn difference(self, other: Self) -> Self

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in two flags values.

pub const fn complement(self) -> Self

The bitwise negation (!) of the bits in a flags value, truncating the result.

Source

impl HdfgrtrEl2

pub const fn iter(&self) -> Iter<HdfgrtrEl2>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<HdfgrtrEl2>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.

Source

impl HdfgrtrEl2

pub const DBGBCRN_EL1_SHIFT: u32 = 0

Available on crate feature el2 only.

Offset of the DBGBCRn_EL1 field.

pub const DBGBVRN_EL1_SHIFT: u32 = 1

Available on crate feature el2 only.

Offset of the DBGBVRn_EL1 field.

pub const DBGWCRN_EL1_SHIFT: u32 = 2

Available on crate feature el2 only.

Offset of the DBGWCRn_EL1 field.

pub const DBGWVRN_EL1_SHIFT: u32 = 3

Available on crate feature el2 only.

Offset of the DBGWVRn_EL1 field.

pub const MDSCR_EL1_SHIFT: u32 = 4

Available on crate feature el2 only.

Offset of the MDSCR_EL1 field.

pub const DBGCLAIM_SHIFT: u32 = 5

Available on crate feature el2 only.

Offset of the DBGCLAIM field.

pub const DBGAUTHSTATUS_EL1_SHIFT: u32 = 6

Available on crate feature el2 only.

Offset of the DBGAUTHSTATUS_EL1 field.

pub const DBGPRCR_EL1_SHIFT: u32 = 7

Available on crate feature el2 only.

Offset of the DBGPRCR_EL1 field.

pub const OSLSR_EL1_SHIFT: u32 = 9

Available on crate feature el2 only.

Offset of the OSLSR_EL1 field.

pub const OSECCR_EL1_SHIFT: u32 = 10

Available on crate feature el2 only.

Offset of the OSECCR_EL1 field.

pub const OSDLR_EL1_SHIFT: u32 = 11

Available on crate feature el2 only.

Offset of the OSDLR_EL1 field.

pub const PMEVCNTRN_EL0_SHIFT: u32 = 12

Available on crate feature el2 only.

Offset of the PMEVCNTRn_EL0 field.

pub const PMEVTYPERN_EL0_SHIFT: u32 = 13

Available on crate feature el2 only.

Offset of the PMEVTYPERn_EL0 field.

pub const PMCCFILTR_EL0_SHIFT: u32 = 14

Available on crate feature el2 only.

Offset of the PMCCFILTR_EL0 field.

pub const PMCCNTR_EL0_SHIFT: u32 = 15

Available on crate feature el2 only.

Offset of the PMCCNTR_EL0 field.

pub const PMCNTEN_SHIFT: u32 = 16

Available on crate feature el2 only.

Offset of the PMCNTEN field.

pub const PMINTEN_SHIFT: u32 = 17

Available on crate feature el2 only.

Offset of the PMINTEN field.

pub const PMOVS_SHIFT: u32 = 18

Available on crate feature el2 only.

Offset of the PMOVS field.

pub const PMSELR_EL0_SHIFT: u32 = 19

Available on crate feature el2 only.

Offset of the PMSELR_EL0 field.

pub const PMMIR_EL1_SHIFT: u32 = 22

Available on crate feature el2 only.

Offset of the PMMIR_EL1 field.

pub const PMBLIMITR_EL1_SHIFT: u32 = 23

Available on crate feature el2 only.

Offset of the PMBLIMITR_EL1 field.

pub const PMBPTR_EL1_SHIFT: u32 = 24

Available on crate feature el2 only.

Offset of the PMBPTR_EL1 field.

pub const PMBSR_EL1_SHIFT: u32 = 25

Available on crate feature el2 only.

Offset of the PMBSR_EL1 field.

pub const PMSCR_EL1_SHIFT: u32 = 26

Available on crate feature el2 only.

Offset of the PMSCR_EL1 field.

pub const PMSEVFR_EL1_SHIFT: u32 = 27

Available on crate feature el2 only.

Offset of the PMSEVFR_EL1 field.

pub const PMSFCR_EL1_SHIFT: u32 = 28

Available on crate feature el2 only.

Offset of the PMSFCR_EL1 field.

pub const PMSICR_EL1_SHIFT: u32 = 29

Available on crate feature el2 only.

Offset of the PMSICR_EL1 field.

pub const PMSIDR_EL1_SHIFT: u32 = 30

Available on crate feature el2 only.

Offset of the PMSIDR_EL1 field.

pub const PMSIRR_EL1_SHIFT: u32 = 31

Available on crate feature el2 only.

Offset of the PMSIRR_EL1 field.

pub const PMSLATFR_EL1_SHIFT: u32 = 32

Available on crate feature el2 only.

Offset of the PMSLATFR_EL1 field.

pub const TRC_SHIFT: u32 = 33

Available on crate feature el2 only.

Offset of the TRC field.

pub const TRCAUTHSTATUS_SHIFT: u32 = 34

Available on crate feature el2 only.

Offset of the TRCAUTHSTATUS field.

pub const TRCAUXCTLR_SHIFT: u32 = 35

Available on crate feature el2 only.

Offset of the TRCAUXCTLR field.

pub const TRCCLAIM_SHIFT: u32 = 36

Available on crate feature el2 only.

Offset of the TRCCLAIM field.

pub const TRCCNTVRN_SHIFT: u32 = 37

Available on crate feature el2 only.

Offset of the TRCCNTVRn field.

pub const TRCID_SHIFT: u32 = 40

Available on crate feature el2 only.

Offset of the TRCID field.

pub const TRCIMSPECN_SHIFT: u32 = 41

Available on crate feature el2 only.

Offset of the TRCIMSPECn field.

pub const TRCOSLSR_SHIFT: u32 = 43

Available on crate feature el2 only.

Offset of the TRCOSLSR field.

pub const TRCPRGCTLR_SHIFT: u32 = 44

Available on crate feature el2 only.

Offset of the TRCPRGCTLR field.

pub const TRCSEQSTR_SHIFT: u32 = 45

Available on crate feature el2 only.

Offset of the TRCSEQSTR field.

pub const TRCSSCSRN_SHIFT: u32 = 46

Available on crate feature el2 only.

Offset of the TRCSSCSRn field.

pub const TRCSTATR_SHIFT: u32 = 47

Available on crate feature el2 only.

Offset of the TRCSTATR field.

pub const TRCVICTLR_SHIFT: u32 = 48

Available on crate feature el2 only.

Offset of the TRCVICTLR field.

pub const TRBBASER_EL1_SHIFT: u32 = 50

Available on crate feature el2 only.

Offset of the TRBBASER_EL1 field.

pub const TRBIDR_EL1_SHIFT: u32 = 51

Available on crate feature el2 only.

Offset of the TRBIDR_EL1 field.

pub const TRBLIMITR_EL1_SHIFT: u32 = 52

Available on crate feature el2 only.

Offset of the TRBLIMITR_EL1 field.

pub const TRBMAR_EL1_SHIFT: u32 = 53

Available on crate feature el2 only.

Offset of the TRBMAR_EL1 field.

pub const TRBPTR_EL1_SHIFT: u32 = 54

Available on crate feature el2 only.

Offset of the TRBPTR_EL1 field.

pub const TRBSR_EL1_SHIFT: u32 = 55

Available on crate feature el2 only.

Offset of the TRBSR_EL1 field.

pub const TRBTRG_EL1_SHIFT: u32 = 56

Available on crate feature el2 only.

Offset of the TRBTRG_EL1 field.

pub const PMUSERENR_EL0_SHIFT: u32 = 57

Available on crate feature el2 only.

Offset of the PMUSERENR_EL0 field.

pub const PMCEIDN_EL0_SHIFT: u32 = 58

Available on crate feature el2 only.

Offset of the PMCEIDn_EL0 field.

pub const NBRBIDR_SHIFT: u32 = 59

Available on crate feature el2 only.

Offset of the nBRBIDR field.

pub const NBRBCTL_SHIFT: u32 = 60

Available on crate feature el2 only.

Offset of the nBRBCTL field.

pub const NBRBDATA_SHIFT: u32 = 61

Available on crate feature el2 only.

Offset of the nBRBDATA field.

pub const NPMSNEVFR_EL1_SHIFT: u32 = 62

Available on crate feature el2 only.

Offset of the nPMSNEVFR_EL1 field.

pub const PMBIDR_EL1_SHIFT: u32 = 63

Available on crate feature el2 only.

Offset of the PMBIDR_EL1 field.