pub struct Hdfgwtr2El2(/* private fields */);Expand description
HDFGWTR2_EL2 system register value.
Implementations
Sourceimpl Hdfgwtr2El2
impl Hdfgwtr2El2
Sourcepub const NPMECR_EL1: Self
pub const NPMECR_EL1: Self
nPMECR_EL1 bit.
Sourcepub const NPMIAR_EL1: Self
pub const NPMIAR_EL1: Self
nPMIAR_EL1 bit.
Sourcepub const NPMICNTR_EL0: Self
pub const NPMICNTR_EL0: Self
nPMICNTR_EL0 bit.
Sourcepub const NPMICFILTR_EL0: Self
pub const NPMICFILTR_EL0: Self
nPMICFILTR_EL0 bit.
Sourcepub const NPMUACR_EL1: Self
pub const NPMUACR_EL1: Self
nPMUACR_EL1 bit.
Sourcepub const NMDSELR_EL1: Self
pub const NMDSELR_EL1: Self
nMDSELR_EL1 bit.
Sourcepub const NPMSSCR_EL1: Self
pub const NPMSSCR_EL1: Self
nPMSSCR_EL1 bit.
Sourcepub const NSPMEVCNTRN_EL0: Self
pub const NSPMEVCNTRN_EL0: Self
nSPMEVCNTRn_EL0 bit.
Sourcepub const NSPMEVTYPERN_EL0: Self
pub const NSPMEVTYPERN_EL0: Self
nSPMEVTYPERn_EL0 bit.
Sourcepub const NSPMSELR_EL0: Self
pub const NSPMSELR_EL0: Self
nSPMSELR_EL0 bit.
Sourcepub const NSPMCR_EL0: Self
pub const NSPMCR_EL0: Self
nSPMCR_EL0 bit.
Sourcepub const NSPMACCESSR_EL1: Self
pub const NSPMACCESSR_EL1: Self
nSPMACCESSR_EL1 bit.
Sourcepub const NSPMSCR_EL1: Self
pub const NSPMSCR_EL1: Self
nSPMSCR_EL1 bit.
Sourcepub const NPMSDSFR_EL1: Self
pub const NPMSDSFR_EL1: Self
nPMSDSFR_EL1 bit.
Sourcepub const NTRCITECR_EL1: Self
pub const NTRCITECR_EL1: Self
nTRCITECR_EL1 bit.
Sourcepub const NTRBMPAM_EL1: Self
pub const NTRBMPAM_EL1: Self
nTRBMPAM_EL1 bit.
Sourcepub const NMDSTEPOP_EL1: Self
pub const NMDSTEPOP_EL1: Self
nMDSTEPOP_EL1 bit.
Sourcepub const NPMBMAR_EL1: Self
pub const NPMBMAR_EL1: Self
nPMBMAR_EL1 bit.
Sourceimpl Hdfgwtr2El2
impl Hdfgwtr2El2
Sourcepub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u64) -> Option<Self>
pub const fn from_bits(bits: u64) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u64) -> Self
pub const fn from_bits_truncate(bits: u64) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u64) -> Self
pub const fn from_bits_retain(bits: u64) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl Hdfgwtr2El2
impl Hdfgwtr2El2
Sourcepub const fn iter(&self) -> Iter<Hdfgwtr2El2>
pub const fn iter(&self) -> Iter<Hdfgwtr2El2>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<Hdfgwtr2El2>
pub const fn iter_names(&self) -> IterNames<Hdfgwtr2El2>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl Hdfgwtr2El2
impl Hdfgwtr2El2
Sourcepub const NPMECR_EL1_SHIFT: u32 = 0
Available on crate feature el2 only.
pub const NPMECR_EL1_SHIFT: u32 = 0
el2 only.Offset of the nPMECR_EL1 field.
Sourcepub const NPMIAR_EL1_SHIFT: u32 = 1
Available on crate feature el2 only.
pub const NPMIAR_EL1_SHIFT: u32 = 1
el2 only.Offset of the nPMIAR_EL1 field.
Sourcepub const NPMICNTR_EL0_SHIFT: u32 = 2
Available on crate feature el2 only.
pub const NPMICNTR_EL0_SHIFT: u32 = 2
el2 only.Offset of the nPMICNTR_EL0 field.
Sourcepub const NPMICFILTR_EL0_SHIFT: u32 = 3
Available on crate feature el2 only.
pub const NPMICFILTR_EL0_SHIFT: u32 = 3
el2 only.Offset of the nPMICFILTR_EL0 field.
Sourcepub const NPMUACR_EL1_SHIFT: u32 = 4
Available on crate feature el2 only.
pub const NPMUACR_EL1_SHIFT: u32 = 4
el2 only.Offset of the nPMUACR_EL1 field.
Sourcepub const NMDSELR_EL1_SHIFT: u32 = 5
Available on crate feature el2 only.
pub const NMDSELR_EL1_SHIFT: u32 = 5
el2 only.Offset of the nMDSELR_EL1 field.
Sourcepub const NPMSSCR_EL1_SHIFT: u32 = 7
Available on crate feature el2 only.
pub const NPMSSCR_EL1_SHIFT: u32 = 7
el2 only.Offset of the nPMSSCR_EL1 field.
Sourcepub const NSPMEVCNTRN_EL0_SHIFT: u32 = 8
Available on crate feature el2 only.
pub const NSPMEVCNTRN_EL0_SHIFT: u32 = 8
el2 only.Offset of the nSPMEVCNTRn_EL0 field.
Sourcepub const NSPMEVTYPERN_EL0_SHIFT: u32 = 9
Available on crate feature el2 only.
pub const NSPMEVTYPERN_EL0_SHIFT: u32 = 9
el2 only.Offset of the nSPMEVTYPERn_EL0 field.
Sourcepub const NSPMSELR_EL0_SHIFT: u32 = 10
Available on crate feature el2 only.
pub const NSPMSELR_EL0_SHIFT: u32 = 10
el2 only.Offset of the nSPMSELR_EL0 field.
Sourcepub const NSPMCNTEN_SHIFT: u32 = 11
Available on crate feature el2 only.
pub const NSPMCNTEN_SHIFT: u32 = 11
el2 only.Offset of the nSPMCNTEN field.
Sourcepub const NSPMINTEN_SHIFT: u32 = 12
Available on crate feature el2 only.
pub const NSPMINTEN_SHIFT: u32 = 12
el2 only.Offset of the nSPMINTEN field.
Sourcepub const NSPMOVS_SHIFT: u32 = 13
Available on crate feature el2 only.
pub const NSPMOVS_SHIFT: u32 = 13
el2 only.Offset of the nSPMOVS field.
Sourcepub const NSPMCR_EL0_SHIFT: u32 = 14
Available on crate feature el2 only.
pub const NSPMCR_EL0_SHIFT: u32 = 14
el2 only.Offset of the nSPMCR_EL0 field.
Sourcepub const NSPMACCESSR_EL1_SHIFT: u32 = 15
Available on crate feature el2 only.
pub const NSPMACCESSR_EL1_SHIFT: u32 = 15
el2 only.Offset of the nSPMACCESSR_EL1 field.
Sourcepub const NSPMSCR_EL1_SHIFT: u32 = 16
Available on crate feature el2 only.
pub const NSPMSCR_EL1_SHIFT: u32 = 16
el2 only.Offset of the nSPMSCR_EL1 field.
Sourcepub const NPMSDSFR_EL1_SHIFT: u32 = 19
Available on crate feature el2 only.
pub const NPMSDSFR_EL1_SHIFT: u32 = 19
el2 only.Offset of the nPMSDSFR_EL1 field.
Sourcepub const NTRCITECR_EL1_SHIFT: u32 = 20
Available on crate feature el2 only.
pub const NTRCITECR_EL1_SHIFT: u32 = 20
el2 only.Offset of the nTRCITECR_EL1 field.
Sourcepub const NPMZR_EL0_SHIFT: u32 = 21
Available on crate feature el2 only.
pub const NPMZR_EL0_SHIFT: u32 = 21
el2 only.Offset of the nPMZR_EL0 field.
Sourcepub const NTRBMPAM_EL1_SHIFT: u32 = 22
Available on crate feature el2 only.
pub const NTRBMPAM_EL1_SHIFT: u32 = 22
el2 only.Offset of the nTRBMPAM_EL1 field.
Sourcepub const NMDSTEPOP_EL1_SHIFT: u32 = 23
Available on crate feature el2 only.
pub const NMDSTEPOP_EL1_SHIFT: u32 = 23
el2 only.Offset of the nMDSTEPOP_EL1 field.
Sourcepub const NPMBMAR_EL1_SHIFT: u32 = 24
Available on crate feature el2 only.
pub const NPMBMAR_EL1_SHIFT: u32 = 24
el2 only.Offset of the nPMBMAR_EL1 field.