pub struct Hfgitr2El2(/* private fields */);Expand description
HFGITR2_EL2 system register value.
Implementations
Sourceimpl Hfgitr2El2
impl Hfgitr2El2
Sourcepub const PLBIPERME1OS: Self
pub const PLBIPERME1OS: Self
PLBIPERME1OS bit.
Sourcepub const PLBIASIDE1OS: Self
pub const PLBIASIDE1OS: Self
PLBIASIDE1OS bit.
Sourcepub const PLBIVMALLE1OS: Self
pub const PLBIVMALLE1OS: Self
PLBIVMALLE1OS bit.
Sourcepub const PLBIPERME1IS: Self
pub const PLBIPERME1IS: Self
PLBIPERME1IS bit.
Sourcepub const PLBIASIDE1IS: Self
pub const PLBIASIDE1IS: Self
PLBIASIDE1IS bit.
Sourcepub const PLBIVMALLE1IS: Self
pub const PLBIVMALLE1IS: Self
PLBIVMALLE1IS bit.
Sourcepub const PLBIPERME1: Self
pub const PLBIPERME1: Self
PLBIPERME1 bit.
Sourcepub const PLBIASIDE1: Self
pub const PLBIASIDE1: Self
PLBIASIDE1 bit.
Sourcepub const PLBIVMALLE1: Self
pub const PLBIVMALLE1: Self
PLBIVMALLE1 bit.
Sourcepub const PLBIPERMAE1OS: Self
pub const PLBIPERMAE1OS: Self
PLBIPERMAE1OS bit.
Sourcepub const PLBIPERMAE1IS: Self
pub const PLBIPERMAE1IS: Self
PLBIPERMAE1IS bit.
Sourcepub const PLBIPERMAE1: Self
pub const PLBIPERMAE1: Self
PLBIPERMAE1 bit.
Sourceimpl Hfgitr2El2
impl Hfgitr2El2
Sourcepub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u64) -> Option<Self>
pub const fn from_bits(bits: u64) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u64) -> Self
pub const fn from_bits_truncate(bits: u64) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u64) -> Self
pub const fn from_bits_retain(bits: u64) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl Hfgitr2El2
impl Hfgitr2El2
Sourcepub const fn iter(&self) -> Iter<Hfgitr2El2>
pub const fn iter(&self) -> Iter<Hfgitr2El2>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<Hfgitr2El2>
pub const fn iter_names(&self) -> IterNames<Hfgitr2El2>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl Hfgitr2El2
impl Hfgitr2El2
Sourcepub const TSBCSYNC_SHIFT: u32 = 0
Available on crate feature el2 only.
pub const TSBCSYNC_SHIFT: u32 = 0
el2 only.Offset of the TSBCSYNC field.
Sourcepub const NDCCIVAPS_SHIFT: u32 = 1
Available on crate feature el2 only.
pub const NDCCIVAPS_SHIFT: u32 = 1
el2 only.Offset of the nDCCIVAPS field.
Sourcepub const PLBIPERME1OS_SHIFT: u32 = 2
Available on crate feature el2 only.
pub const PLBIPERME1OS_SHIFT: u32 = 2
el2 only.Offset of the PLBIPERME1OS field.
Sourcepub const PLBIASIDE1OS_SHIFT: u32 = 3
Available on crate feature el2 only.
pub const PLBIASIDE1OS_SHIFT: u32 = 3
el2 only.Offset of the PLBIASIDE1OS field.
Sourcepub const PLBIVMALLE1OS_SHIFT: u32 = 4
Available on crate feature el2 only.
pub const PLBIVMALLE1OS_SHIFT: u32 = 4
el2 only.Offset of the PLBIVMALLE1OS field.
Sourcepub const PLBIPERME1IS_SHIFT: u32 = 5
Available on crate feature el2 only.
pub const PLBIPERME1IS_SHIFT: u32 = 5
el2 only.Offset of the PLBIPERME1IS field.
Sourcepub const PLBIASIDE1IS_SHIFT: u32 = 6
Available on crate feature el2 only.
pub const PLBIASIDE1IS_SHIFT: u32 = 6
el2 only.Offset of the PLBIASIDE1IS field.
Sourcepub const PLBIVMALLE1IS_SHIFT: u32 = 7
Available on crate feature el2 only.
pub const PLBIVMALLE1IS_SHIFT: u32 = 7
el2 only.Offset of the PLBIVMALLE1IS field.
Sourcepub const PLBIPERME1_SHIFT: u32 = 8
Available on crate feature el2 only.
pub const PLBIPERME1_SHIFT: u32 = 8
el2 only.Offset of the PLBIPERME1 field.
Sourcepub const PLBIASIDE1_SHIFT: u32 = 9
Available on crate feature el2 only.
pub const PLBIASIDE1_SHIFT: u32 = 9
el2 only.Offset of the PLBIASIDE1 field.
Sourcepub const PLBIVMALLE1_SHIFT: u32 = 10
Available on crate feature el2 only.
pub const PLBIVMALLE1_SHIFT: u32 = 10
el2 only.Offset of the PLBIVMALLE1 field.
Sourcepub const PLBIPERMAE1OS_SHIFT: u32 = 11
Available on crate feature el2 only.
pub const PLBIPERMAE1OS_SHIFT: u32 = 11
el2 only.Offset of the PLBIPERMAE1OS field.
Sourcepub const PLBIPERMAE1IS_SHIFT: u32 = 12
Available on crate feature el2 only.
pub const PLBIPERMAE1IS_SHIFT: u32 = 12
el2 only.Offset of the PLBIPERMAE1IS field.
Sourcepub const PLBIPERMAE1_SHIFT: u32 = 13
Available on crate feature el2 only.
pub const PLBIPERMAE1_SHIFT: u32 = 13
el2 only.Offset of the PLBIPERMAE1 field.
Sourcepub const DCGBVA_SHIFT: u32 = 14
Available on crate feature el2 only.
pub const DCGBVA_SHIFT: u32 = 14
el2 only.Offset of the DCGBVA field.