HfgitrEl2

Struct HfgitrEl2 

pub struct HfgitrEl2(/* private fields */);
HFGITR_EL2 system register value.

Implementations

Source

impl HfgitrEl2

pub const ICIALLUIS: Self

ICIALLUIS bit.

pub const ICIALLU: Self

ICIALLU bit.

pub const ICIVAU: Self

ICIVAU bit.

pub const DCIVAC: Self

DCIVAC bit.

pub const DCISW: Self

DCISW bit.

pub const DCCSW: Self

DCCSW bit.

pub const DCCISW: Self

DCCISW bit.

pub const DCCVAU: Self

DCCVAU bit.

pub const DCCVAP: Self

DCCVAP bit.

pub const DCCVADP: Self

DCCVADP bit.

pub const DCCIVAC: Self

DCCIVAC bit.

pub const DCZVA: Self

DCZVA bit.

pub const ATS1E1R: Self

ATS1E1R bit.

pub const ATS1E1W: Self

ATS1E1W bit.

pub const ATS1E0R: Self

ATS1E0R bit.

pub const ATS1E0W: Self

ATS1E0W bit.

pub const ATS1E1RP: Self

ATS1E1RP bit.

pub const ATS1E1WP: Self

ATS1E1WP bit.

pub const TLBIVMALLE1OS: Self

TLBIVMALLE1OS bit.

pub const TLBIVAE1OS: Self

TLBIVAE1OS bit.

pub const TLBIASIDE1OS: Self

TLBIASIDE1OS bit.

pub const TLBIVAAE1OS: Self

TLBIVAAE1OS bit.

pub const TLBIVALE1OS: Self

TLBIVALE1OS bit.

pub const TLBIVAALE1OS: Self

TLBIVAALE1OS bit.

pub const TLBIRVAE1OS: Self

TLBIRVAE1OS bit.

pub const TLBIRVAAE1OS: Self

TLBIRVAAE1OS bit.

pub const TLBIRVALE1OS: Self

TLBIRVALE1OS bit.

pub const TLBIRVAALE1OS: Self

TLBIRVAALE1OS bit.

pub const TLBIVMALLE1IS: Self

TLBIVMALLE1IS bit.

pub const TLBIVAE1IS: Self

TLBIVAE1IS bit.

pub const TLBIASIDE1IS: Self

TLBIASIDE1IS bit.

pub const TLBIVAAE1IS: Self

TLBIVAAE1IS bit.

pub const TLBIVALE1IS: Self

TLBIVALE1IS bit.

pub const TLBIVAALE1IS: Self

TLBIVAALE1IS bit.

pub const TLBIRVAE1IS: Self

TLBIRVAE1IS bit.

pub const TLBIRVAAE1IS: Self

TLBIRVAAE1IS bit.

pub const TLBIRVALE1IS: Self

TLBIRVALE1IS bit.

pub const TLBIRVAALE1IS: Self

TLBIRVAALE1IS bit.

pub const TLBIRVAE1: Self

TLBIRVAE1 bit.

pub const TLBIRVAAE1: Self

TLBIRVAAE1 bit.

pub const TLBIRVALE1: Self

TLBIRVALE1 bit.

pub const TLBIRVAALE1: Self

TLBIRVAALE1 bit.

pub const TLBIVMALLE1: Self

TLBIVMALLE1 bit.

pub const TLBIVAE1: Self

TLBIVAE1 bit.

pub const TLBIASIDE1: Self

TLBIASIDE1 bit.

pub const TLBIVAAE1: Self

TLBIVAAE1 bit.

pub const TLBIVALE1: Self

TLBIVALE1 bit.

pub const TLBIVAALE1: Self

TLBIVAALE1 bit.

pub const CFPRCTX: Self

CFPRCTX bit.

pub const DVPRCTX: Self

DVPRCTX bit.

pub const CPPRCTX: Self

CPPRCTX bit.

pub const ERET: Self

ERET bit.

pub const SVC_EL0: Self

SVC_EL0 bit.

pub const SVC_EL1: Self

SVC_EL1 bit.

pub const DCCVAC: Self

DCCVAC bit.

pub const NBRBINJ: Self

nBRBINJ bit.

pub const NBRBIALL: Self

nBRBIALL bit.

pub const NGCSPUSHM_EL1: Self

nGCSPUSHM_EL1 bit.

pub const NGCSSTR_EL1: Self

nGCSSTR_EL1 bit.

pub const NGCSEPP: Self

nGCSEPP bit.

pub const COSPRCTX: Self

COSPRCTX bit.

pub const ATS1E1A: Self

ATS1E1A bit.

pub const PSBCSYNC: Self

PSBCSYNC bit.

Source

impl HfgitrEl2

pub const fn empty() -> Self

Get a flags value with all bits unset.

pub const fn all() -> Self

Get a flags value with all known bits set.

pub const fn bits(&self) -> u64

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u64) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u64) -> Self

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u64) -> Self

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in this flags value are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Self) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

pub const fn contains(&self, other: Self) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

pub fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in two flags values.

pub fn remove(&mut self, other: Self)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Self)

The bitwise exclusive-or (^) of the bits in two flags values.

pub fn set(&mut self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Self) -> Self

The bitwise and (&) of the bits in two flags values.

pub const fn union(self, other: Self) -> Self

The bitwise or (|) of the bits in two flags values.

pub const fn difference(self, other: Self) -> Self

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in two flags values.

pub const fn complement(self) -> Self

The bitwise negation (!) of the bits in a flags value, truncating the result.

Source

impl HfgitrEl2

pub const fn iter(&self) -> Iter<HfgitrEl2>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<HfgitrEl2>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.

Source

impl HfgitrEl2

pub const ICIALLUIS_SHIFT: u32 = 0

Available on crate feature el2 only.

Offset of the ICIALLUIS field.

pub const ICIALLU_SHIFT: u32 = 1

Available on crate feature el2 only.

Offset of the ICIALLU field.

pub const ICIVAU_SHIFT: u32 = 2

Available on crate feature el2 only.

Offset of the ICIVAU field.

pub const DCIVAC_SHIFT: u32 = 3

Available on crate feature el2 only.

Offset of the DCIVAC field.

pub const DCISW_SHIFT: u32 = 4

Available on crate feature el2 only.

Offset of the DCISW field.

pub const DCCSW_SHIFT: u32 = 5

Available on crate feature el2 only.

Offset of the DCCSW field.

pub const DCCISW_SHIFT: u32 = 6

Available on crate feature el2 only.

Offset of the DCCISW field.

pub const DCCVAU_SHIFT: u32 = 7

Available on crate feature el2 only.

Offset of the DCCVAU field.

pub const DCCVAP_SHIFT: u32 = 8

Available on crate feature el2 only.

Offset of the DCCVAP field.

pub const DCCVADP_SHIFT: u32 = 9

Available on crate feature el2 only.

Offset of the DCCVADP field.

pub const DCCIVAC_SHIFT: u32 = 10

Available on crate feature el2 only.

Offset of the DCCIVAC field.

pub const DCZVA_SHIFT: u32 = 11

Available on crate feature el2 only.

Offset of the DCZVA field.

pub const ATS1E1R_SHIFT: u32 = 12

Available on crate feature el2 only.

Offset of the ATS1E1R field.

pub const ATS1E1W_SHIFT: u32 = 13

Available on crate feature el2 only.

Offset of the ATS1E1W field.

pub const ATS1E0R_SHIFT: u32 = 14

Available on crate feature el2 only.

Offset of the ATS1E0R field.

pub const ATS1E0W_SHIFT: u32 = 15

Available on crate feature el2 only.

Offset of the ATS1E0W field.

pub const ATS1E1RP_SHIFT: u32 = 16

Available on crate feature el2 only.

Offset of the ATS1E1RP field.

pub const ATS1E1WP_SHIFT: u32 = 17

Available on crate feature el2 only.

Offset of the ATS1E1WP field.

pub const TLBIVMALLE1OS_SHIFT: u32 = 18

Available on crate feature el2 only.

Offset of the TLBIVMALLE1OS field.

pub const TLBIVAE1OS_SHIFT: u32 = 19

Available on crate feature el2 only.

Offset of the TLBIVAE1OS field.

pub const TLBIASIDE1OS_SHIFT: u32 = 20

Available on crate feature el2 only.

Offset of the TLBIASIDE1OS field.

pub const TLBIVAAE1OS_SHIFT: u32 = 21

Available on crate feature el2 only.

Offset of the TLBIVAAE1OS field.

pub const TLBIVALE1OS_SHIFT: u32 = 22

Available on crate feature el2 only.

Offset of the TLBIVALE1OS field.

pub const TLBIVAALE1OS_SHIFT: u32 = 23

Available on crate feature el2 only.

Offset of the TLBIVAALE1OS field.

pub const TLBIRVAE1OS_SHIFT: u32 = 24

Available on crate feature el2 only.

Offset of the TLBIRVAE1OS field.

pub const TLBIRVAAE1OS_SHIFT: u32 = 25

Available on crate feature el2 only.

Offset of the TLBIRVAAE1OS field.

pub const TLBIRVALE1OS_SHIFT: u32 = 26

Available on crate feature el2 only.

Offset of the TLBIRVALE1OS field.

pub const TLBIRVAALE1OS_SHIFT: u32 = 27

Available on crate feature el2 only.

Offset of the TLBIRVAALE1OS field.

pub const TLBIVMALLE1IS_SHIFT: u32 = 28

Available on crate feature el2 only.

Offset of the TLBIVMALLE1IS field.

pub const TLBIVAE1IS_SHIFT: u32 = 29

Available on crate feature el2 only.

Offset of the TLBIVAE1IS field.

pub const TLBIASIDE1IS_SHIFT: u32 = 30

Available on crate feature el2 only.

Offset of the TLBIASIDE1IS field.

pub const TLBIVAAE1IS_SHIFT: u32 = 31

Available on crate feature el2 only.

Offset of the TLBIVAAE1IS field.

pub const TLBIVALE1IS_SHIFT: u32 = 32

Available on crate feature el2 only.

Offset of the TLBIVALE1IS field.

pub const TLBIVAALE1IS_SHIFT: u32 = 33

Available on crate feature el2 only.

Offset of the TLBIVAALE1IS field.

pub const TLBIRVAE1IS_SHIFT: u32 = 34

Available on crate feature el2 only.

Offset of the TLBIRVAE1IS field.

pub const TLBIRVAAE1IS_SHIFT: u32 = 35

Available on crate feature el2 only.

Offset of the TLBIRVAAE1IS field.

pub const TLBIRVALE1IS_SHIFT: u32 = 36

Available on crate feature el2 only.

Offset of the TLBIRVALE1IS field.

pub const TLBIRVAALE1IS_SHIFT: u32 = 37

Available on crate feature el2 only.

Offset of the TLBIRVAALE1IS field.

pub const TLBIRVAE1_SHIFT: u32 = 38

Available on crate feature el2 only.

Offset of the TLBIRVAE1 field.

pub const TLBIRVAAE1_SHIFT: u32 = 39

Available on crate feature el2 only.

Offset of the TLBIRVAAE1 field.

pub const TLBIRVALE1_SHIFT: u32 = 40

Available on crate feature el2 only.

Offset of the TLBIRVALE1 field.

pub const TLBIRVAALE1_SHIFT: u32 = 41

Available on crate feature el2 only.

Offset of the TLBIRVAALE1 field.

pub const TLBIVMALLE1_SHIFT: u32 = 42

Available on crate feature el2 only.

Offset of the TLBIVMALLE1 field.

pub const TLBIVAE1_SHIFT: u32 = 43

Available on crate feature el2 only.

Offset of the TLBIVAE1 field.

pub const TLBIASIDE1_SHIFT: u32 = 44

Available on crate feature el2 only.

Offset of the TLBIASIDE1 field.

pub const TLBIVAAE1_SHIFT: u32 = 45

Available on crate feature el2 only.

Offset of the TLBIVAAE1 field.

pub const TLBIVALE1_SHIFT: u32 = 46

Available on crate feature el2 only.

Offset of the TLBIVALE1 field.

pub const TLBIVAALE1_SHIFT: u32 = 47

Available on crate feature el2 only.

Offset of the TLBIVAALE1 field.

pub const CFPRCTX_SHIFT: u32 = 48

Available on crate feature el2 only.

Offset of the CFPRCTX field.

pub const DVPRCTX_SHIFT: u32 = 49

Available on crate feature el2 only.

Offset of the DVPRCTX field.

pub const CPPRCTX_SHIFT: u32 = 50

Available on crate feature el2 only.

Offset of the CPPRCTX field.

pub const ERET_SHIFT: u32 = 51

Available on crate feature el2 only.

Offset of the ERET field.

pub const SVC_EL0_SHIFT: u32 = 52

Available on crate feature el2 only.

Offset of the SVC_EL0 field.

pub const SVC_EL1_SHIFT: u32 = 53

Available on crate feature el2 only.

Offset of the SVC_EL1 field.

pub const DCCVAC_SHIFT: u32 = 54

Available on crate feature el2 only.

Offset of the DCCVAC field.

pub const NBRBINJ_SHIFT: u32 = 55

Available on crate feature el2 only.

Offset of the nBRBINJ field.

pub const NBRBIALL_SHIFT: u32 = 56

Available on crate feature el2 only.

Offset of the nBRBIALL field.

pub const NGCSPUSHM_EL1_SHIFT: u32 = 57

Available on crate feature el2 only.

Offset of the nGCSPUSHM_EL1 field.

pub const NGCSSTR_EL1_SHIFT: u32 = 58

Available on crate feature el2 only.

Offset of the nGCSSTR_EL1 field.

pub const NGCSEPP_SHIFT: u32 = 59

Available on crate feature el2 only.

Offset of the nGCSEPP field.

pub const COSPRCTX_SHIFT: u32 = 60

Available on crate feature el2 only.

Offset of the COSPRCTX field.

pub const ATS1E1A_SHIFT: u32 = 62

Available on crate feature el2 only.

Offset of the ATS1E1A field.

pub const PSBCSYNC_SHIFT: u32 = 63

Available on crate feature el2 only.

Offset of the PSBCSYNC field.