Hfgrtr2El2

Struct Hfgrtr2El2 

pub struct Hfgrtr2El2(/* private fields */);
HFGRTR2_EL2 system register value.

Implementations

Source

impl Hfgrtr2El2

pub const NPFAR_EL1: Self

nPFAR_EL1 bit.

pub const NERXGSR_EL1: Self

nERXGSR_EL1 bit.

pub const NRCWSMASK_EL1: Self

nRCWSMASK_EL1 bit.

pub const NCPACRMASK_EL1: Self

nCPACRMASK_EL1 bit.

pub const NSCTLRMASK_EL1: Self

nSCTLRMASK_EL1 bit.

pub const NSCTLR2MASK_EL1: Self

nSCTLR2MASK_EL1 bit.

pub const NTCRMASK_EL1: Self

nTCRMASK_EL1 bit.

pub const NTCR2MASK_EL1: Self

nTCR2MASK_EL1 bit.

pub const NCPACRALIAS_EL1: Self

nCPACRALIAS_EL1 bit.

pub const NSCTLRALIAS_EL1: Self

nSCTLRALIAS_EL1 bit.

pub const NSCTLR2ALIAS_EL1: Self

nSCTLR2ALIAS_EL1 bit.

pub const NTCRALIAS_EL1: Self

nTCRALIAS_EL1 bit.

pub const NTCR2ALIAS_EL1: Self

nTCR2ALIAS_EL1 bit.

pub const NACTLRMASK_EL1: Self

nACTLRMASK_EL1 bit.

pub const NACTLRALIAS_EL1: Self

nACTLRALIAS_EL1 bit.

pub const NTINDEX_EL0: Self

nTINDEX_EL0 bit.

pub const NTINDEX_EL1: Self

nTINDEX_EL1 bit.

pub const NSTINDEX_EL1: Self

nSTINDEX_EL1 bit.

pub const NTTTBRP_EL1: Self

nTTTBRP_EL1 bit.

pub const NTTTBRU_EL1: Self

nTTTBRU_EL1 bit.

pub const NIRTBRP_EL1: Self

nIRTBRP_EL1 bit.

pub const NIRTBRU_EL1: Self

nIRTBRU_EL1 bit.

pub const NDPOTBR1_EL1: Self

nDPOTBR1_EL1 bit.

pub const NDPOTBR0_EL1: Self

nDPOTBR0_EL1 bit.

pub const NTPMIN1_EL1: Self

nTPMIN1_EL1 bit.

pub const NTPMIN0_EL1: Self

nTPMIN0_EL1 bit.

pub const NTPMIN1_EL0: Self

nTPMIN1_EL0 bit.

pub const NTPMIN0_EL0: Self

nTPMIN0_EL0 bit.

pub const NTLBIDIDR_EL1: Self

nTLBIDIDR_EL1 bit.

pub const TFSR_EL1: Self

TFSR_EL1 bit.

pub const RGSR_EL1: Self

RGSR_EL1 bit.

pub const GCR_EL1: Self

GCR_EL1 bit.

pub const NTPIDR3_EL0: Self

nTPIDR3_EL0 bit.

pub const NTPIDR3_EL1: Self

nTPIDR3_EL1 bit.

Source

impl Hfgrtr2El2

pub const fn empty() -> Self

Get a flags value with all bits unset.

pub const fn all() -> Self

Get a flags value with all known bits set.

pub const fn bits(&self) -> u64

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u64) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u64) -> Self

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u64) -> Self

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in this flags value are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Self) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

pub const fn contains(&self, other: Self) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

pub fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in two flags values.

pub fn remove(&mut self, other: Self)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Self)

The bitwise exclusive-or (^) of the bits in two flags values.

pub fn set(&mut self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Self) -> Self

The bitwise and (&) of the bits in two flags values.

pub const fn union(self, other: Self) -> Self

The bitwise or (|) of the bits in two flags values.

pub const fn difference(self, other: Self) -> Self

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in two flags values.

pub const fn complement(self) -> Self

The bitwise negation (!) of the bits in a flags value, truncating the result.

Source

impl Hfgrtr2El2

pub const fn iter(&self) -> Iter<Hfgrtr2El2>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<Hfgrtr2El2>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.

Source

impl Hfgrtr2El2

pub const NPFAR_EL1_SHIFT: u32 = 0

Available on crate feature el2 only.

Offset of the nPFAR_EL1 field.

pub const NERXGSR_EL1_SHIFT: u32 = 1

Available on crate feature el2 only.

Offset of the nERXGSR_EL1 field.

pub const NRCWSMASK_EL1_SHIFT: u32 = 2

Available on crate feature el2 only.

Offset of the nRCWSMASK_EL1 field.

pub const NCPACRMASK_EL1_SHIFT: u32 = 3

Available on crate feature el2 only.

Offset of the nCPACRMASK_EL1 field.

pub const NSCTLRMASK_EL1_SHIFT: u32 = 4

Available on crate feature el2 only.

Offset of the nSCTLRMASK_EL1 field.

pub const NSCTLR2MASK_EL1_SHIFT: u32 = 5

Available on crate feature el2 only.

Offset of the nSCTLR2MASK_EL1 field.

pub const NTCRMASK_EL1_SHIFT: u32 = 6

Available on crate feature el2 only.

Offset of the nTCRMASK_EL1 field.

pub const NTCR2MASK_EL1_SHIFT: u32 = 7

Available on crate feature el2 only.

Offset of the nTCR2MASK_EL1 field.

pub const NCPACRALIAS_EL1_SHIFT: u32 = 8

Available on crate feature el2 only.

Offset of the nCPACRALIAS_EL1 field.

pub const NSCTLRALIAS_EL1_SHIFT: u32 = 9

Available on crate feature el2 only.

Offset of the nSCTLRALIAS_EL1 field.

pub const NSCTLR2ALIAS_EL1_SHIFT: u32 = 10

Available on crate feature el2 only.

Offset of the nSCTLR2ALIAS_EL1 field.

pub const NTCRALIAS_EL1_SHIFT: u32 = 11

Available on crate feature el2 only.

Offset of the nTCRALIAS_EL1 field.

pub const NTCR2ALIAS_EL1_SHIFT: u32 = 12

Available on crate feature el2 only.

Offset of the nTCR2ALIAS_EL1 field.

pub const NACTLRMASK_EL1_SHIFT: u32 = 13

Available on crate feature el2 only.

Offset of the nACTLRMASK_EL1 field.

pub const NACTLRALIAS_EL1_SHIFT: u32 = 14

Available on crate feature el2 only.

Offset of the nACTLRALIAS_EL1 field.

pub const NTINDEX_EL0_SHIFT: u32 = 15

Available on crate feature el2 only.

Offset of the nTINDEX_EL0 field.

pub const NTINDEX_EL1_SHIFT: u32 = 16

Available on crate feature el2 only.

Offset of the nTINDEX_EL1 field.

pub const NSTINDEX_EL1_SHIFT: u32 = 17

Available on crate feature el2 only.

Offset of the nSTINDEX_EL1 field.

pub const NFGDTN_EL1_SHIFT: u32 = 18

Available on crate feature el2 only.

Offset of the nFGDTn_EL1 field.

pub const NFGDTN_EL1_MASK: u64 = 0b11

Available on crate feature el2 only.

Mask for the nFGDTn_EL1 field.

pub const NTTTBRP_EL1_SHIFT: u32 = 20

Available on crate feature el2 only.

Offset of the nTTTBRP_EL1 field.

pub const NTTTBRU_EL1_SHIFT: u32 = 21

Available on crate feature el2 only.

Offset of the nTTTBRU_EL1 field.

pub const NIRTBRP_EL1_SHIFT: u32 = 22

Available on crate feature el2 only.

Offset of the nIRTBRP_EL1 field.

pub const NIRTBRU_EL1_SHIFT: u32 = 23

Available on crate feature el2 only.

Offset of the nIRTBRU_EL1 field.

pub const NDPOTBR1_EL1_SHIFT: u32 = 24

Available on crate feature el2 only.

Offset of the nDPOTBR1_EL1 field.

pub const NDPOTBR0_EL1_SHIFT: u32 = 25

Available on crate feature el2 only.

Offset of the nDPOTBR0_EL1 field.

pub const NTPMIN1_EL1_SHIFT: u32 = 26

Available on crate feature el2 only.

Offset of the nTPMIN1_EL1 field.

pub const NTPMIN0_EL1_SHIFT: u32 = 27

Available on crate feature el2 only.

Offset of the nTPMIN0_EL1 field.

pub const NTPMIN1_EL0_SHIFT: u32 = 28

Available on crate feature el2 only.

Offset of the nTPMIN1_EL0 field.

pub const NTPMIN0_EL0_SHIFT: u32 = 29

Available on crate feature el2 only.

Offset of the nTPMIN0_EL0 field.

pub const NTLBIDIDR_EL1_SHIFT: u32 = 30

Available on crate feature el2 only.

Offset of the nTLBIDIDR_EL1 field.

pub const NAFGDTN_EL1_SHIFT: u32 = 31

Available on crate feature el2 only.

Offset of the nAFGDTn_EL1 field.

pub const NAFGDTN_EL1_MASK: u64 = 0b11

Available on crate feature el2 only.

Mask for the nAFGDTn_EL1 field.

pub const TFSR_EL1_SHIFT: u32 = 33

Available on crate feature el2 only.

Offset of the TFSR_EL1 field.

pub const RGSR_EL1_SHIFT: u32 = 34

Available on crate feature el2 only.

Offset of the RGSR_EL1 field.

pub const GCR_EL1_SHIFT: u32 = 35

Available on crate feature el2 only.

Offset of the GCR_EL1 field.

pub const NTPIDR3_EL0_SHIFT: u32 = 36

Available on crate feature el2 only.

Offset of the nTPIDR3_EL0 field.

pub const NTPIDR3_EL1_SHIFT: u32 = 37

Available on crate feature el2 only.

Offset of the nTPIDR3_EL1 field.

pub const fn nfgdtn_el1(self) -> u8

Available on crate feature el2 only.

Returns the value of the nFGDTn_EL1 field.

pub const fn nafgdtn_el1(self) -> u8

Available on crate feature el2 only.

Returns the value of the nAFGDTn_EL1 field.