pub struct HfgrtrEl2(/* private fields */);Expand description
HFGRTR_EL2 system register value.
Implementations
Sourceimpl HfgrtrEl2
impl HfgrtrEl2
Sourcepub const CCSIDR_EL1: Self
pub const CCSIDR_EL1: Self
CCSIDR_EL1 bit.
Sourcepub const CONTEXTIDR_EL1: Self
pub const CONTEXTIDR_EL1: Self
CONTEXTIDR_EL1 bit.
Sourcepub const CSSELR_EL1: Self
pub const CSSELR_EL1: Self
CSSELR_EL1 bit.
Sourcepub const REVIDR_EL1: Self
pub const REVIDR_EL1: Self
REVIDR_EL1 bit.
Sourcepub const SCXTNUM_EL1: Self
pub const SCXTNUM_EL1: Self
SCXTNUM_EL1 bit.
Sourcepub const SCXTNUM_EL0: Self
pub const SCXTNUM_EL0: Self
SCXTNUM_EL0 bit.
Sourcepub const TPIDRRO_EL0: Self
pub const TPIDRRO_EL0: Self
TPIDRRO_EL0 bit.
Sourcepub const ICC_IGRPENN_EL1: Self
pub const ICC_IGRPENN_EL1: Self
ICC_IGRPENn_EL1 bit.
Sourcepub const ERRIDR_EL1: Self
pub const ERRIDR_EL1: Self
ERRIDR_EL1 bit.
Sourcepub const ERRSELR_EL1: Self
pub const ERRSELR_EL1: Self
ERRSELR_EL1 bit.
Sourcepub const ERXCTLR_EL1: Self
pub const ERXCTLR_EL1: Self
ERXCTLR_EL1 bit.
Sourcepub const ERXSTATUS_EL1: Self
pub const ERXSTATUS_EL1: Self
ERXSTATUS_EL1 bit.
Sourcepub const ERXMISCN_EL1: Self
pub const ERXMISCN_EL1: Self
ERXMISCn_EL1 bit.
Sourcepub const ERXPFGF_EL1: Self
pub const ERXPFGF_EL1: Self
ERXPFGF_EL1 bit.
Sourcepub const ERXPFGCTL_EL1: Self
pub const ERXPFGCTL_EL1: Self
ERXPFGCTL_EL1 bit.
Sourcepub const ERXPFGCDN_EL1: Self
pub const ERXPFGCDN_EL1: Self
ERXPFGCDN_EL1 bit.
Sourcepub const ERXADDR_EL1: Self
pub const ERXADDR_EL1: Self
ERXADDR_EL1 bit.
Sourcepub const NACCDATA_EL1: Self
pub const NACCDATA_EL1: Self
nACCDATA_EL1 bit.
Sourcepub const NSMPRI_EL1: Self
pub const NSMPRI_EL1: Self
nSMPRI_EL1 bit.
Sourcepub const NTPIDR2_EL0: Self
pub const NTPIDR2_EL0: Self
nTPIDR2_EL0 bit.
Sourcepub const NRCWMASK_EL1: Self
pub const NRCWMASK_EL1: Self
nRCWMASK_EL1 bit.
Sourcepub const NPIRE0_EL1: Self
pub const NPIRE0_EL1: Self
nPIRE0_EL1 bit.
Sourcepub const NS2POR_EL1: Self
pub const NS2POR_EL1: Self
nS2POR_EL1 bit.
Sourcepub const NMAIR2_EL1: Self
pub const NMAIR2_EL1: Self
nMAIR2_EL1 bit.
Sourcepub const NAMAIR2_EL1: Self
pub const NAMAIR2_EL1: Self
nAMAIR2_EL1 bit.
Sourceimpl HfgrtrEl2
impl HfgrtrEl2
Sourcepub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u64) -> Option<Self>
pub const fn from_bits(bits: u64) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u64) -> Self
pub const fn from_bits_truncate(bits: u64) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u64) -> Self
pub const fn from_bits_retain(bits: u64) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl HfgrtrEl2
impl HfgrtrEl2
Sourcepub const fn iter(&self) -> Iter<HfgrtrEl2>
pub const fn iter(&self) -> Iter<HfgrtrEl2>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<HfgrtrEl2>
pub const fn iter_names(&self) -> IterNames<HfgrtrEl2>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl HfgrtrEl2
impl HfgrtrEl2
Sourcepub const AFSR0_EL1_SHIFT: u32 = 0
Available on crate feature el2 only.
pub const AFSR0_EL1_SHIFT: u32 = 0
el2 only.Offset of the AFSR0_EL1 field.
Sourcepub const AFSR1_EL1_SHIFT: u32 = 1
Available on crate feature el2 only.
pub const AFSR1_EL1_SHIFT: u32 = 1
el2 only.Offset of the AFSR1_EL1 field.
Sourcepub const AIDR_EL1_SHIFT: u32 = 2
Available on crate feature el2 only.
pub const AIDR_EL1_SHIFT: u32 = 2
el2 only.Offset of the AIDR_EL1 field.
Sourcepub const AMAIR_EL1_SHIFT: u32 = 3
Available on crate feature el2 only.
pub const AMAIR_EL1_SHIFT: u32 = 3
el2 only.Offset of the AMAIR_EL1 field.
Sourcepub const APDAKEY_SHIFT: u32 = 4
Available on crate feature el2 only.
pub const APDAKEY_SHIFT: u32 = 4
el2 only.Offset of the APDAKey field.
Sourcepub const APDBKEY_SHIFT: u32 = 5
Available on crate feature el2 only.
pub const APDBKEY_SHIFT: u32 = 5
el2 only.Offset of the APDBKey field.
Sourcepub const APGAKEY_SHIFT: u32 = 6
Available on crate feature el2 only.
pub const APGAKEY_SHIFT: u32 = 6
el2 only.Offset of the APGAKey field.
Sourcepub const APIAKEY_SHIFT: u32 = 7
Available on crate feature el2 only.
pub const APIAKEY_SHIFT: u32 = 7
el2 only.Offset of the APIAKey field.
Sourcepub const APIBKEY_SHIFT: u32 = 8
Available on crate feature el2 only.
pub const APIBKEY_SHIFT: u32 = 8
el2 only.Offset of the APIBKey field.
Sourcepub const CCSIDR_EL1_SHIFT: u32 = 9
Available on crate feature el2 only.
pub const CCSIDR_EL1_SHIFT: u32 = 9
el2 only.Offset of the CCSIDR_EL1 field.
Sourcepub const CLIDR_EL1_SHIFT: u32 = 10
Available on crate feature el2 only.
pub const CLIDR_EL1_SHIFT: u32 = 10
el2 only.Offset of the CLIDR_EL1 field.
Sourcepub const CONTEXTIDR_EL1_SHIFT: u32 = 11
Available on crate feature el2 only.
pub const CONTEXTIDR_EL1_SHIFT: u32 = 11
el2 only.Offset of the CONTEXTIDR_EL1 field.
Sourcepub const CPACR_EL1_SHIFT: u32 = 12
Available on crate feature el2 only.
pub const CPACR_EL1_SHIFT: u32 = 12
el2 only.Offset of the CPACR_EL1 field.
Sourcepub const CSSELR_EL1_SHIFT: u32 = 13
Available on crate feature el2 only.
pub const CSSELR_EL1_SHIFT: u32 = 13
el2 only.Offset of the CSSELR_EL1 field.
Sourcepub const CTR_EL0_SHIFT: u32 = 14
Available on crate feature el2 only.
pub const CTR_EL0_SHIFT: u32 = 14
el2 only.Offset of the CTR_EL0 field.
Sourcepub const DCZID_EL0_SHIFT: u32 = 15
Available on crate feature el2 only.
pub const DCZID_EL0_SHIFT: u32 = 15
el2 only.Offset of the DCZID_EL0 field.
Sourcepub const ESR_EL1_SHIFT: u32 = 16
Available on crate feature el2 only.
pub const ESR_EL1_SHIFT: u32 = 16
el2 only.Offset of the ESR_EL1 field.
Sourcepub const FAR_EL1_SHIFT: u32 = 17
Available on crate feature el2 only.
pub const FAR_EL1_SHIFT: u32 = 17
el2 only.Offset of the FAR_EL1 field.
Sourcepub const ISR_EL1_SHIFT: u32 = 18
Available on crate feature el2 only.
pub const ISR_EL1_SHIFT: u32 = 18
el2 only.Offset of the ISR_EL1 field.
Sourcepub const LORC_EL1_SHIFT: u32 = 19
Available on crate feature el2 only.
pub const LORC_EL1_SHIFT: u32 = 19
el2 only.Offset of the LORC_EL1 field.
Sourcepub const LOREA_EL1_SHIFT: u32 = 20
Available on crate feature el2 only.
pub const LOREA_EL1_SHIFT: u32 = 20
el2 only.Offset of the LOREA_EL1 field.
Sourcepub const LORID_EL1_SHIFT: u32 = 21
Available on crate feature el2 only.
pub const LORID_EL1_SHIFT: u32 = 21
el2 only.Offset of the LORID_EL1 field.
Sourcepub const LORN_EL1_SHIFT: u32 = 22
Available on crate feature el2 only.
pub const LORN_EL1_SHIFT: u32 = 22
el2 only.Offset of the LORN_EL1 field.
Sourcepub const LORSA_EL1_SHIFT: u32 = 23
Available on crate feature el2 only.
pub const LORSA_EL1_SHIFT: u32 = 23
el2 only.Offset of the LORSA_EL1 field.
Sourcepub const MAIR_EL1_SHIFT: u32 = 24
Available on crate feature el2 only.
pub const MAIR_EL1_SHIFT: u32 = 24
el2 only.Offset of the MAIR_EL1 field.
Sourcepub const MIDR_EL1_SHIFT: u32 = 25
Available on crate feature el2 only.
pub const MIDR_EL1_SHIFT: u32 = 25
el2 only.Offset of the MIDR_EL1 field.
Sourcepub const MPIDR_EL1_SHIFT: u32 = 26
Available on crate feature el2 only.
pub const MPIDR_EL1_SHIFT: u32 = 26
el2 only.Offset of the MPIDR_EL1 field.
Sourcepub const PAR_EL1_SHIFT: u32 = 27
Available on crate feature el2 only.
pub const PAR_EL1_SHIFT: u32 = 27
el2 only.Offset of the PAR_EL1 field.
Sourcepub const REVIDR_EL1_SHIFT: u32 = 28
Available on crate feature el2 only.
pub const REVIDR_EL1_SHIFT: u32 = 28
el2 only.Offset of the REVIDR_EL1 field.
Sourcepub const SCTLR_EL1_SHIFT: u32 = 29
Available on crate feature el2 only.
pub const SCTLR_EL1_SHIFT: u32 = 29
el2 only.Offset of the SCTLR_EL1 field.
Sourcepub const SCXTNUM_EL1_SHIFT: u32 = 30
Available on crate feature el2 only.
pub const SCXTNUM_EL1_SHIFT: u32 = 30
el2 only.Offset of the SCXTNUM_EL1 field.
Sourcepub const SCXTNUM_EL0_SHIFT: u32 = 31
Available on crate feature el2 only.
pub const SCXTNUM_EL0_SHIFT: u32 = 31
el2 only.Offset of the SCXTNUM_EL0 field.
Sourcepub const TCR_EL1_SHIFT: u32 = 32
Available on crate feature el2 only.
pub const TCR_EL1_SHIFT: u32 = 32
el2 only.Offset of the TCR_EL1 field.
Sourcepub const TPIDR_EL1_SHIFT: u32 = 33
Available on crate feature el2 only.
pub const TPIDR_EL1_SHIFT: u32 = 33
el2 only.Offset of the TPIDR_EL1 field.
Sourcepub const TPIDRRO_EL0_SHIFT: u32 = 34
Available on crate feature el2 only.
pub const TPIDRRO_EL0_SHIFT: u32 = 34
el2 only.Offset of the TPIDRRO_EL0 field.
Sourcepub const TPIDR_EL0_SHIFT: u32 = 35
Available on crate feature el2 only.
pub const TPIDR_EL0_SHIFT: u32 = 35
el2 only.Offset of the TPIDR_EL0 field.
Sourcepub const TTBR0_EL1_SHIFT: u32 = 36
Available on crate feature el2 only.
pub const TTBR0_EL1_SHIFT: u32 = 36
el2 only.Offset of the TTBR0_EL1 field.
Sourcepub const TTBR1_EL1_SHIFT: u32 = 37
Available on crate feature el2 only.
pub const TTBR1_EL1_SHIFT: u32 = 37
el2 only.Offset of the TTBR1_EL1 field.
Sourcepub const VBAR_EL1_SHIFT: u32 = 38
Available on crate feature el2 only.
pub const VBAR_EL1_SHIFT: u32 = 38
el2 only.Offset of the VBAR_EL1 field.
Sourcepub const ICC_IGRPENN_EL1_SHIFT: u32 = 39
Available on crate feature el2 only.
pub const ICC_IGRPENN_EL1_SHIFT: u32 = 39
el2 only.Offset of the ICC_IGRPENn_EL1 field.
Sourcepub const ERRIDR_EL1_SHIFT: u32 = 40
Available on crate feature el2 only.
pub const ERRIDR_EL1_SHIFT: u32 = 40
el2 only.Offset of the ERRIDR_EL1 field.
Sourcepub const ERRSELR_EL1_SHIFT: u32 = 41
Available on crate feature el2 only.
pub const ERRSELR_EL1_SHIFT: u32 = 41
el2 only.Offset of the ERRSELR_EL1 field.
Sourcepub const ERXFR_EL1_SHIFT: u32 = 42
Available on crate feature el2 only.
pub const ERXFR_EL1_SHIFT: u32 = 42
el2 only.Offset of the ERXFR_EL1 field.
Sourcepub const ERXCTLR_EL1_SHIFT: u32 = 43
Available on crate feature el2 only.
pub const ERXCTLR_EL1_SHIFT: u32 = 43
el2 only.Offset of the ERXCTLR_EL1 field.
Sourcepub const ERXSTATUS_EL1_SHIFT: u32 = 44
Available on crate feature el2 only.
pub const ERXSTATUS_EL1_SHIFT: u32 = 44
el2 only.Offset of the ERXSTATUS_EL1 field.
Sourcepub const ERXMISCN_EL1_SHIFT: u32 = 45
Available on crate feature el2 only.
pub const ERXMISCN_EL1_SHIFT: u32 = 45
el2 only.Offset of the ERXMISCn_EL1 field.
Sourcepub const ERXPFGF_EL1_SHIFT: u32 = 46
Available on crate feature el2 only.
pub const ERXPFGF_EL1_SHIFT: u32 = 46
el2 only.Offset of the ERXPFGF_EL1 field.
Sourcepub const ERXPFGCTL_EL1_SHIFT: u32 = 47
Available on crate feature el2 only.
pub const ERXPFGCTL_EL1_SHIFT: u32 = 47
el2 only.Offset of the ERXPFGCTL_EL1 field.
Sourcepub const ERXPFGCDN_EL1_SHIFT: u32 = 48
Available on crate feature el2 only.
pub const ERXPFGCDN_EL1_SHIFT: u32 = 48
el2 only.Offset of the ERXPFGCDN_EL1 field.
Sourcepub const ERXADDR_EL1_SHIFT: u32 = 49
Available on crate feature el2 only.
pub const ERXADDR_EL1_SHIFT: u32 = 49
el2 only.Offset of the ERXADDR_EL1 field.
Sourcepub const NACCDATA_EL1_SHIFT: u32 = 50
Available on crate feature el2 only.
pub const NACCDATA_EL1_SHIFT: u32 = 50
el2 only.Offset of the nACCDATA_EL1 field.
Sourcepub const NGCS_EL0_SHIFT: u32 = 52
Available on crate feature el2 only.
pub const NGCS_EL0_SHIFT: u32 = 52
el2 only.Offset of the nGCS_EL0 field.
Sourcepub const NGCS_EL1_SHIFT: u32 = 53
Available on crate feature el2 only.
pub const NGCS_EL1_SHIFT: u32 = 53
el2 only.Offset of the nGCS_EL1 field.
Sourcepub const NSMPRI_EL1_SHIFT: u32 = 54
Available on crate feature el2 only.
pub const NSMPRI_EL1_SHIFT: u32 = 54
el2 only.Offset of the nSMPRI_EL1 field.
Sourcepub const NTPIDR2_EL0_SHIFT: u32 = 55
Available on crate feature el2 only.
pub const NTPIDR2_EL0_SHIFT: u32 = 55
el2 only.Offset of the nTPIDR2_EL0 field.
Sourcepub const NRCWMASK_EL1_SHIFT: u32 = 56
Available on crate feature el2 only.
pub const NRCWMASK_EL1_SHIFT: u32 = 56
el2 only.Offset of the nRCWMASK_EL1 field.
Sourcepub const NPIRE0_EL1_SHIFT: u32 = 57
Available on crate feature el2 only.
pub const NPIRE0_EL1_SHIFT: u32 = 57
el2 only.Offset of the nPIRE0_EL1 field.
Sourcepub const NPIR_EL1_SHIFT: u32 = 58
Available on crate feature el2 only.
pub const NPIR_EL1_SHIFT: u32 = 58
el2 only.Offset of the nPIR_EL1 field.
Sourcepub const NPOR_EL0_SHIFT: u32 = 59
Available on crate feature el2 only.
pub const NPOR_EL0_SHIFT: u32 = 59
el2 only.Offset of the nPOR_EL0 field.
Sourcepub const NPOR_EL1_SHIFT: u32 = 60
Available on crate feature el2 only.
pub const NPOR_EL1_SHIFT: u32 = 60
el2 only.Offset of the nPOR_EL1 field.
Sourcepub const NS2POR_EL1_SHIFT: u32 = 61
Available on crate feature el2 only.
pub const NS2POR_EL1_SHIFT: u32 = 61
el2 only.Offset of the nS2POR_EL1 field.
Sourcepub const NMAIR2_EL1_SHIFT: u32 = 62
Available on crate feature el2 only.
pub const NMAIR2_EL1_SHIFT: u32 = 62
el2 only.Offset of the nMAIR2_EL1 field.
Sourcepub const NAMAIR2_EL1_SHIFT: u32 = 63
Available on crate feature el2 only.
pub const NAMAIR2_EL1_SHIFT: u32 = 63
el2 only.Offset of the nAMAIR2_EL1 field.