pub struct Hfgwtr2El2(/* private fields */);Expand description
HFGWTR2_EL2 system register value.
Implementations
Sourceimpl Hfgwtr2El2
impl Hfgwtr2El2
Sourcepub const NRCWSMASK_EL1: Self
pub const NRCWSMASK_EL1: Self
nRCWSMASK_EL1 bit.
Sourcepub const NCPACRMASK_EL1: Self
pub const NCPACRMASK_EL1: Self
nCPACRMASK_EL1 bit.
Sourcepub const NSCTLRMASK_EL1: Self
pub const NSCTLRMASK_EL1: Self
nSCTLRMASK_EL1 bit.
Sourcepub const NSCTLR2MASK_EL1: Self
pub const NSCTLR2MASK_EL1: Self
nSCTLR2MASK_EL1 bit.
Sourcepub const NTCRMASK_EL1: Self
pub const NTCRMASK_EL1: Self
nTCRMASK_EL1 bit.
Sourcepub const NTCR2MASK_EL1: Self
pub const NTCR2MASK_EL1: Self
nTCR2MASK_EL1 bit.
Sourcepub const NCPACRALIAS_EL1: Self
pub const NCPACRALIAS_EL1: Self
nCPACRALIAS_EL1 bit.
Sourcepub const NSCTLRALIAS_EL1: Self
pub const NSCTLRALIAS_EL1: Self
nSCTLRALIAS_EL1 bit.
Sourcepub const NSCTLR2ALIAS_EL1: Self
pub const NSCTLR2ALIAS_EL1: Self
nSCTLR2ALIAS_EL1 bit.
Sourcepub const NTCRALIAS_EL1: Self
pub const NTCRALIAS_EL1: Self
nTCRALIAS_EL1 bit.
Sourcepub const NTCR2ALIAS_EL1: Self
pub const NTCR2ALIAS_EL1: Self
nTCR2ALIAS_EL1 bit.
Sourcepub const NACTLRMASK_EL1: Self
pub const NACTLRMASK_EL1: Self
nACTLRMASK_EL1 bit.
Sourcepub const NACTLRALIAS_EL1: Self
pub const NACTLRALIAS_EL1: Self
nACTLRALIAS_EL1 bit.
Sourcepub const NTINDEX_EL0: Self
pub const NTINDEX_EL0: Self
nTINDEX_EL0 bit.
Sourcepub const NTINDEX_EL1: Self
pub const NTINDEX_EL1: Self
nTINDEX_EL1 bit.
Sourcepub const NSTINDEX_EL1: Self
pub const NSTINDEX_EL1: Self
nSTINDEX_EL1 bit.
Sourcepub const NTTTBRP_EL1: Self
pub const NTTTBRP_EL1: Self
nTTTBRP_EL1 bit.
Sourcepub const NTTTBRU_EL1: Self
pub const NTTTBRU_EL1: Self
nTTTBRU_EL1 bit.
Sourcepub const NIRTBRP_EL1: Self
pub const NIRTBRP_EL1: Self
nIRTBRP_EL1 bit.
Sourcepub const NIRTBRU_EL1: Self
pub const NIRTBRU_EL1: Self
nIRTBRU_EL1 bit.
Sourcepub const NDPOTBR1_EL1: Self
pub const NDPOTBR1_EL1: Self
nDPOTBR1_EL1 bit.
Sourcepub const NDPOTBR0_EL1: Self
pub const NDPOTBR0_EL1: Self
nDPOTBR0_EL1 bit.
Sourcepub const NTPMIN1_EL1: Self
pub const NTPMIN1_EL1: Self
nTPMIN1_EL1 bit.
Sourcepub const NTPMIN0_EL1: Self
pub const NTPMIN0_EL1: Self
nTPMIN0_EL1 bit.
Sourcepub const NTPMIN1_EL0: Self
pub const NTPMIN1_EL0: Self
nTPMIN1_EL0 bit.
Sourcepub const NTPMIN0_EL0: Self
pub const NTPMIN0_EL0: Self
nTPMIN0_EL0 bit.
Sourcepub const NTPIDR3_EL0: Self
pub const NTPIDR3_EL0: Self
nTPIDR3_EL0 bit.
Sourcepub const NTPIDR3_EL1: Self
pub const NTPIDR3_EL1: Self
nTPIDR3_EL1 bit.
Sourceimpl Hfgwtr2El2
impl Hfgwtr2El2
Sourcepub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u64) -> Option<Self>
pub const fn from_bits(bits: u64) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u64) -> Self
pub const fn from_bits_truncate(bits: u64) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u64) -> Self
pub const fn from_bits_retain(bits: u64) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl Hfgwtr2El2
impl Hfgwtr2El2
Sourcepub const fn iter(&self) -> Iter<Hfgwtr2El2>
pub const fn iter(&self) -> Iter<Hfgwtr2El2>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<Hfgwtr2El2>
pub const fn iter_names(&self) -> IterNames<Hfgwtr2El2>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl Hfgwtr2El2
impl Hfgwtr2El2
Sourcepub const NPFAR_EL1_SHIFT: u32 = 0
Available on crate feature el2 only.
pub const NPFAR_EL1_SHIFT: u32 = 0
el2 only.Offset of the nPFAR_EL1 field.
Sourcepub const NRCWSMASK_EL1_SHIFT: u32 = 2
Available on crate feature el2 only.
pub const NRCWSMASK_EL1_SHIFT: u32 = 2
el2 only.Offset of the nRCWSMASK_EL1 field.
Sourcepub const NCPACRMASK_EL1_SHIFT: u32 = 3
Available on crate feature el2 only.
pub const NCPACRMASK_EL1_SHIFT: u32 = 3
el2 only.Offset of the nCPACRMASK_EL1 field.
Sourcepub const NSCTLRMASK_EL1_SHIFT: u32 = 4
Available on crate feature el2 only.
pub const NSCTLRMASK_EL1_SHIFT: u32 = 4
el2 only.Offset of the nSCTLRMASK_EL1 field.
Sourcepub const NSCTLR2MASK_EL1_SHIFT: u32 = 5
Available on crate feature el2 only.
pub const NSCTLR2MASK_EL1_SHIFT: u32 = 5
el2 only.Offset of the nSCTLR2MASK_EL1 field.
Sourcepub const NTCRMASK_EL1_SHIFT: u32 = 6
Available on crate feature el2 only.
pub const NTCRMASK_EL1_SHIFT: u32 = 6
el2 only.Offset of the nTCRMASK_EL1 field.
Sourcepub const NTCR2MASK_EL1_SHIFT: u32 = 7
Available on crate feature el2 only.
pub const NTCR2MASK_EL1_SHIFT: u32 = 7
el2 only.Offset of the nTCR2MASK_EL1 field.
Sourcepub const NCPACRALIAS_EL1_SHIFT: u32 = 8
Available on crate feature el2 only.
pub const NCPACRALIAS_EL1_SHIFT: u32 = 8
el2 only.Offset of the nCPACRALIAS_EL1 field.
Sourcepub const NSCTLRALIAS_EL1_SHIFT: u32 = 9
Available on crate feature el2 only.
pub const NSCTLRALIAS_EL1_SHIFT: u32 = 9
el2 only.Offset of the nSCTLRALIAS_EL1 field.
Sourcepub const NSCTLR2ALIAS_EL1_SHIFT: u32 = 10
Available on crate feature el2 only.
pub const NSCTLR2ALIAS_EL1_SHIFT: u32 = 10
el2 only.Offset of the nSCTLR2ALIAS_EL1 field.
Sourcepub const NTCRALIAS_EL1_SHIFT: u32 = 11
Available on crate feature el2 only.
pub const NTCRALIAS_EL1_SHIFT: u32 = 11
el2 only.Offset of the nTCRALIAS_EL1 field.
Sourcepub const NTCR2ALIAS_EL1_SHIFT: u32 = 12
Available on crate feature el2 only.
pub const NTCR2ALIAS_EL1_SHIFT: u32 = 12
el2 only.Offset of the nTCR2ALIAS_EL1 field.
Sourcepub const NACTLRMASK_EL1_SHIFT: u32 = 13
Available on crate feature el2 only.
pub const NACTLRMASK_EL1_SHIFT: u32 = 13
el2 only.Offset of the nACTLRMASK_EL1 field.
Sourcepub const NACTLRALIAS_EL1_SHIFT: u32 = 14
Available on crate feature el2 only.
pub const NACTLRALIAS_EL1_SHIFT: u32 = 14
el2 only.Offset of the nACTLRALIAS_EL1 field.
Sourcepub const NTINDEX_EL0_SHIFT: u32 = 15
Available on crate feature el2 only.
pub const NTINDEX_EL0_SHIFT: u32 = 15
el2 only.Offset of the nTINDEX_EL0 field.
Sourcepub const NTINDEX_EL1_SHIFT: u32 = 16
Available on crate feature el2 only.
pub const NTINDEX_EL1_SHIFT: u32 = 16
el2 only.Offset of the nTINDEX_EL1 field.
Sourcepub const NSTINDEX_EL1_SHIFT: u32 = 17
Available on crate feature el2 only.
pub const NSTINDEX_EL1_SHIFT: u32 = 17
el2 only.Offset of the nSTINDEX_EL1 field.
Sourcepub const NFGDTN_EL1_SHIFT: u32 = 18
Available on crate feature el2 only.
pub const NFGDTN_EL1_SHIFT: u32 = 18
el2 only.Offset of the nFGDTn_EL1 field.
Sourcepub const NFGDTN_EL1_MASK: u64 = 0b11
Available on crate feature el2 only.
pub const NFGDTN_EL1_MASK: u64 = 0b11
el2 only.Mask for the nFGDTn_EL1 field.
Sourcepub const NTTTBRP_EL1_SHIFT: u32 = 20
Available on crate feature el2 only.
pub const NTTTBRP_EL1_SHIFT: u32 = 20
el2 only.Offset of the nTTTBRP_EL1 field.
Sourcepub const NTTTBRU_EL1_SHIFT: u32 = 21
Available on crate feature el2 only.
pub const NTTTBRU_EL1_SHIFT: u32 = 21
el2 only.Offset of the nTTTBRU_EL1 field.
Sourcepub const NIRTBRP_EL1_SHIFT: u32 = 22
Available on crate feature el2 only.
pub const NIRTBRP_EL1_SHIFT: u32 = 22
el2 only.Offset of the nIRTBRP_EL1 field.
Sourcepub const NIRTBRU_EL1_SHIFT: u32 = 23
Available on crate feature el2 only.
pub const NIRTBRU_EL1_SHIFT: u32 = 23
el2 only.Offset of the nIRTBRU_EL1 field.
Sourcepub const NDPOTBR1_EL1_SHIFT: u32 = 24
Available on crate feature el2 only.
pub const NDPOTBR1_EL1_SHIFT: u32 = 24
el2 only.Offset of the nDPOTBR1_EL1 field.
Sourcepub const NDPOTBR0_EL1_SHIFT: u32 = 25
Available on crate feature el2 only.
pub const NDPOTBR0_EL1_SHIFT: u32 = 25
el2 only.Offset of the nDPOTBR0_EL1 field.
Sourcepub const NTPMIN1_EL1_SHIFT: u32 = 26
Available on crate feature el2 only.
pub const NTPMIN1_EL1_SHIFT: u32 = 26
el2 only.Offset of the nTPMIN1_EL1 field.
Sourcepub const NTPMIN0_EL1_SHIFT: u32 = 27
Available on crate feature el2 only.
pub const NTPMIN0_EL1_SHIFT: u32 = 27
el2 only.Offset of the nTPMIN0_EL1 field.
Sourcepub const NTPMIN1_EL0_SHIFT: u32 = 28
Available on crate feature el2 only.
pub const NTPMIN1_EL0_SHIFT: u32 = 28
el2 only.Offset of the nTPMIN1_EL0 field.
Sourcepub const NTPMIN0_EL0_SHIFT: u32 = 29
Available on crate feature el2 only.
pub const NTPMIN0_EL0_SHIFT: u32 = 29
el2 only.Offset of the nTPMIN0_EL0 field.
Sourcepub const NAFGDTN_EL1_SHIFT: u32 = 31
Available on crate feature el2 only.
pub const NAFGDTN_EL1_SHIFT: u32 = 31
el2 only.Offset of the nAFGDTn_EL1 field.
Sourcepub const NAFGDTN_EL1_MASK: u64 = 0b11
Available on crate feature el2 only.
pub const NAFGDTN_EL1_MASK: u64 = 0b11
el2 only.Mask for the nAFGDTn_EL1 field.
Sourcepub const TFSR_EL1_SHIFT: u32 = 33
Available on crate feature el2 only.
pub const TFSR_EL1_SHIFT: u32 = 33
el2 only.Offset of the TFSR_EL1 field.
Sourcepub const RGSR_EL1_SHIFT: u32 = 34
Available on crate feature el2 only.
pub const RGSR_EL1_SHIFT: u32 = 34
el2 only.Offset of the RGSR_EL1 field.
Sourcepub const GCR_EL1_SHIFT: u32 = 35
Available on crate feature el2 only.
pub const GCR_EL1_SHIFT: u32 = 35
el2 only.Offset of the GCR_EL1 field.
Sourcepub const NTPIDR3_EL0_SHIFT: u32 = 36
Available on crate feature el2 only.
pub const NTPIDR3_EL0_SHIFT: u32 = 36
el2 only.Offset of the nTPIDR3_EL0 field.
Sourcepub const NTPIDR3_EL1_SHIFT: u32 = 37
Available on crate feature el2 only.
pub const NTPIDR3_EL1_SHIFT: u32 = 37
el2 only.Offset of the nTPIDR3_EL1 field.
Sourcepub const fn nfgdtn_el1(self) -> u8
Available on crate feature el2 only.
pub const fn nfgdtn_el1(self) -> u8
el2 only.Returns the value of the nFGDTn_EL1 field.
Sourcepub const fn set_nfgdtn_el1(&mut self, value: u8)
Available on crate feature el2 only.
pub const fn set_nfgdtn_el1(&mut self, value: u8)
el2 only.Sets the value of the nFGDTn_EL1 field.
Sourcepub const fn with_nfgdtn_el1(self, value: u8) -> Self
Available on crate feature el2 only.
pub const fn with_nfgdtn_el1(self, value: u8) -> Self
el2 only.Returns a copy with the nFGDTn_EL1 field set to the given value.
Sourcepub const fn nafgdtn_el1(self) -> u8
Available on crate feature el2 only.
pub const fn nafgdtn_el1(self) -> u8
el2 only.Returns the value of the nAFGDTn_EL1 field.
Sourcepub const fn set_nafgdtn_el1(&mut self, value: u8)
Available on crate feature el2 only.
pub const fn set_nafgdtn_el1(&mut self, value: u8)
el2 only.Sets the value of the nAFGDTn_EL1 field.
Sourcepub const fn with_nafgdtn_el1(self, value: u8) -> Self
Available on crate feature el2 only.
pub const fn with_nafgdtn_el1(self, value: u8) -> Self
el2 only.Returns a copy with the nAFGDTn_EL1 field set to the given value.