HfgwtrEl2

Struct HfgwtrEl2 

pub struct HfgwtrEl2(/* private fields */);
HFGWTR_EL2 system register value.

Implementations

Source

impl HfgwtrEl2

pub const AFSR0_EL1: Self

AFSR0_EL1 bit.

pub const AFSR1_EL1: Self

AFSR1_EL1 bit.

pub const AMAIR_EL1: Self

AMAIR_EL1 bit.

pub const APDAKEY: Self

APDAKey bit.

pub const APDBKEY: Self

APDBKey bit.

pub const APGAKEY: Self

APGAKey bit.

pub const APIAKEY: Self

APIAKey bit.

pub const APIBKEY: Self

APIBKey bit.

pub const CONTEXTIDR_EL1: Self

CONTEXTIDR_EL1 bit.

pub const CPACR_EL1: Self

CPACR_EL1 bit.

pub const CSSELR_EL1: Self

CSSELR_EL1 bit.

pub const ESR_EL1: Self

ESR_EL1 bit.

pub const FAR_EL1: Self

FAR_EL1 bit.

pub const LORC_EL1: Self

LORC_EL1 bit.

pub const LOREA_EL1: Self

LOREA_EL1 bit.

pub const LORN_EL1: Self

LORN_EL1 bit.

pub const LORSA_EL1: Self

LORSA_EL1 bit.

pub const MAIR_EL1: Self

MAIR_EL1 bit.

pub const PAR_EL1: Self

PAR_EL1 bit.

pub const SCTLR_EL1: Self

SCTLR_EL1 bit.

pub const SCXTNUM_EL1: Self

SCXTNUM_EL1 bit.

pub const SCXTNUM_EL0: Self

SCXTNUM_EL0 bit.

pub const TCR_EL1: Self

TCR_EL1 bit.

pub const TPIDR_EL1: Self

TPIDR_EL1 bit.

pub const TPIDRRO_EL0: Self

TPIDRRO_EL0 bit.

pub const TPIDR_EL0: Self

TPIDR_EL0 bit.

pub const TTBR0_EL1: Self

TTBR0_EL1 bit.

pub const TTBR1_EL1: Self

TTBR1_EL1 bit.

pub const VBAR_EL1: Self

VBAR_EL1 bit.

pub const ICC_IGRPENN_EL1: Self

ICC_IGRPENn_EL1 bit.

pub const ERRSELR_EL1: Self

ERRSELR_EL1 bit.

pub const ERXCTLR_EL1: Self

ERXCTLR_EL1 bit.

pub const ERXSTATUS_EL1: Self

ERXSTATUS_EL1 bit.

pub const ERXMISCN_EL1: Self

ERXMISCn_EL1 bit.

pub const ERXPFGCTL_EL1: Self

ERXPFGCTL_EL1 bit.

pub const ERXPFGCDN_EL1: Self

ERXPFGCDN_EL1 bit.

pub const ERXADDR_EL1: Self

ERXADDR_EL1 bit.

pub const NACCDATA_EL1: Self

nACCDATA_EL1 bit.

pub const NGCS_EL0: Self

nGCS_EL0 bit.

pub const NGCS_EL1: Self

nGCS_EL1 bit.

pub const NSMPRI_EL1: Self

nSMPRI_EL1 bit.

pub const NTPIDR2_EL0: Self

nTPIDR2_EL0 bit.

pub const NRCWMASK_EL1: Self

nRCWMASK_EL1 bit.

pub const NPIRE0_EL1: Self

nPIRE0_EL1 bit.

pub const NPIR_EL1: Self

nPIR_EL1 bit.

pub const NPOR_EL0: Self

nPOR_EL0 bit.

pub const NPOR_EL1: Self

nPOR_EL1 bit.

pub const NS2POR_EL1: Self

nS2POR_EL1 bit.

pub const NMAIR2_EL1: Self

nMAIR2_EL1 bit.

pub const NAMAIR2_EL1: Self

nAMAIR2_EL1 bit.

Source

impl HfgwtrEl2

pub const fn empty() -> Self

Get a flags value with all bits unset.

pub const fn all() -> Self

Get a flags value with all known bits set.

pub const fn bits(&self) -> u64

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u64) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u64) -> Self

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u64) -> Self

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in this flags value are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Self) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

pub const fn contains(&self, other: Self) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

pub fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in two flags values.

pub fn remove(&mut self, other: Self)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Self)

The bitwise exclusive-or (^) of the bits in two flags values.

pub fn set(&mut self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Self) -> Self

The bitwise and (&) of the bits in two flags values.

pub const fn union(self, other: Self) -> Self

The bitwise or (|) of the bits in two flags values.

pub const fn difference(self, other: Self) -> Self

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in two flags values.

pub const fn complement(self) -> Self

The bitwise negation (!) of the bits in a flags value, truncating the result.

Source

impl HfgwtrEl2

pub const fn iter(&self) -> Iter<HfgwtrEl2>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<HfgwtrEl2>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.

Source

impl HfgwtrEl2

pub const AFSR0_EL1_SHIFT: u32 = 0

Available on crate feature el2 only.

Offset of the AFSR0_EL1 field.

pub const AFSR1_EL1_SHIFT: u32 = 1

Available on crate feature el2 only.

Offset of the AFSR1_EL1 field.

pub const AMAIR_EL1_SHIFT: u32 = 3

Available on crate feature el2 only.

Offset of the AMAIR_EL1 field.

pub const APDAKEY_SHIFT: u32 = 4

Available on crate feature el2 only.

Offset of the APDAKey field.

pub const APDBKEY_SHIFT: u32 = 5

Available on crate feature el2 only.

Offset of the APDBKey field.

pub const APGAKEY_SHIFT: u32 = 6

Available on crate feature el2 only.

Offset of the APGAKey field.

pub const APIAKEY_SHIFT: u32 = 7

Available on crate feature el2 only.

Offset of the APIAKey field.

pub const APIBKEY_SHIFT: u32 = 8

Available on crate feature el2 only.

Offset of the APIBKey field.

pub const CONTEXTIDR_EL1_SHIFT: u32 = 11

Available on crate feature el2 only.

Offset of the CONTEXTIDR_EL1 field.

pub const CPACR_EL1_SHIFT: u32 = 12

Available on crate feature el2 only.

Offset of the CPACR_EL1 field.

pub const CSSELR_EL1_SHIFT: u32 = 13

Available on crate feature el2 only.

Offset of the CSSELR_EL1 field.

pub const ESR_EL1_SHIFT: u32 = 16

Available on crate feature el2 only.

Offset of the ESR_EL1 field.

pub const FAR_EL1_SHIFT: u32 = 17

Available on crate feature el2 only.

Offset of the FAR_EL1 field.

pub const LORC_EL1_SHIFT: u32 = 19

Available on crate feature el2 only.

Offset of the LORC_EL1 field.

pub const LOREA_EL1_SHIFT: u32 = 20

Available on crate feature el2 only.

Offset of the LOREA_EL1 field.

pub const LORN_EL1_SHIFT: u32 = 22

Available on crate feature el2 only.

Offset of the LORN_EL1 field.

pub const LORSA_EL1_SHIFT: u32 = 23

Available on crate feature el2 only.

Offset of the LORSA_EL1 field.

pub const MAIR_EL1_SHIFT: u32 = 24

Available on crate feature el2 only.

Offset of the MAIR_EL1 field.

pub const PAR_EL1_SHIFT: u32 = 27

Available on crate feature el2 only.

Offset of the PAR_EL1 field.

pub const SCTLR_EL1_SHIFT: u32 = 29

Available on crate feature el2 only.

Offset of the SCTLR_EL1 field.

pub const SCXTNUM_EL1_SHIFT: u32 = 30

Available on crate feature el2 only.

Offset of the SCXTNUM_EL1 field.

pub const SCXTNUM_EL0_SHIFT: u32 = 31

Available on crate feature el2 only.

Offset of the SCXTNUM_EL0 field.

pub const TCR_EL1_SHIFT: u32 = 32

Available on crate feature el2 only.

Offset of the TCR_EL1 field.

pub const TPIDR_EL1_SHIFT: u32 = 33

Available on crate feature el2 only.

Offset of the TPIDR_EL1 field.

pub const TPIDRRO_EL0_SHIFT: u32 = 34

Available on crate feature el2 only.

Offset of the TPIDRRO_EL0 field.

pub const TPIDR_EL0_SHIFT: u32 = 35

Available on crate feature el2 only.

Offset of the TPIDR_EL0 field.

pub const TTBR0_EL1_SHIFT: u32 = 36

Available on crate feature el2 only.

Offset of the TTBR0_EL1 field.

pub const TTBR1_EL1_SHIFT: u32 = 37

Available on crate feature el2 only.

Offset of the TTBR1_EL1 field.

pub const VBAR_EL1_SHIFT: u32 = 38

Available on crate feature el2 only.

Offset of the VBAR_EL1 field.

pub const ICC_IGRPENN_EL1_SHIFT: u32 = 39

Available on crate feature el2 only.

Offset of the ICC_IGRPENn_EL1 field.

pub const ERRSELR_EL1_SHIFT: u32 = 41

Available on crate feature el2 only.

Offset of the ERRSELR_EL1 field.

pub const ERXCTLR_EL1_SHIFT: u32 = 43

Available on crate feature el2 only.

Offset of the ERXCTLR_EL1 field.

pub const ERXSTATUS_EL1_SHIFT: u32 = 44

Available on crate feature el2 only.

Offset of the ERXSTATUS_EL1 field.

pub const ERXMISCN_EL1_SHIFT: u32 = 45

Available on crate feature el2 only.

Offset of the ERXMISCn_EL1 field.

pub const ERXPFGCTL_EL1_SHIFT: u32 = 47

Available on crate feature el2 only.

Offset of the ERXPFGCTL_EL1 field.

pub const ERXPFGCDN_EL1_SHIFT: u32 = 48

Available on crate feature el2 only.

Offset of the ERXPFGCDN_EL1 field.

pub const ERXADDR_EL1_SHIFT: u32 = 49

Available on crate feature el2 only.

Offset of the ERXADDR_EL1 field.

pub const NACCDATA_EL1_SHIFT: u32 = 50

Available on crate feature el2 only.

Offset of the nACCDATA_EL1 field.

pub const NGCS_EL0_SHIFT: u32 = 52

Available on crate feature el2 only.

Offset of the nGCS_EL0 field.

pub const NGCS_EL1_SHIFT: u32 = 53

Available on crate feature el2 only.

Offset of the nGCS_EL1 field.

pub const NSMPRI_EL1_SHIFT: u32 = 54

Available on crate feature el2 only.

Offset of the nSMPRI_EL1 field.

pub const NTPIDR2_EL0_SHIFT: u32 = 55

Available on crate feature el2 only.

Offset of the nTPIDR2_EL0 field.

pub const NRCWMASK_EL1_SHIFT: u32 = 56

Available on crate feature el2 only.

Offset of the nRCWMASK_EL1 field.

pub const NPIRE0_EL1_SHIFT: u32 = 57

Available on crate feature el2 only.

Offset of the nPIRE0_EL1 field.

pub const NPIR_EL1_SHIFT: u32 = 58

Available on crate feature el2 only.

Offset of the nPIR_EL1 field.

pub const NPOR_EL0_SHIFT: u32 = 59

Available on crate feature el2 only.

Offset of the nPOR_EL0 field.

pub const NPOR_EL1_SHIFT: u32 = 60

Available on crate feature el2 only.

Offset of the nPOR_EL1 field.

pub const NS2POR_EL1_SHIFT: u32 = 61

Available on crate feature el2 only.

Offset of the nS2POR_EL1 field.

pub const NMAIR2_EL1_SHIFT: u32 = 62

Available on crate feature el2 only.

Offset of the nMAIR2_EL1 field.

pub const NAMAIR2_EL1_SHIFT: u32 = 63

Available on crate feature el2 only.

Offset of the nAMAIR2_EL1 field.