pub struct IccCtlr(/* private fields */);Expand description
ICC_CTLR system register value.
Implementations
Sourceimpl IccCtlr
impl IccCtlr
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl IccCtlr
impl IccCtlr
Sourcepub const fn iter(&self) -> Iter<IccCtlr>
pub const fn iter(&self) -> Iter<IccCtlr>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<IccCtlr>
pub const fn iter_names(&self) -> IterNames<IccCtlr>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl IccCtlr
impl IccCtlr
Sourcepub const CBPR_SHIFT: u32 = 0
pub const CBPR_SHIFT: u32 = 0
Offset of the CBPR field.
Sourcepub const EOIMODE_SHIFT: u32 = 1
pub const EOIMODE_SHIFT: u32 = 1
Offset of the EOImode field.
Sourcepub const PMHE_SHIFT: u32 = 6
pub const PMHE_SHIFT: u32 = 6
Offset of the PMHE field.
Sourcepub const PRIBITS_SHIFT: u32 = 8
pub const PRIBITS_SHIFT: u32 = 8
Offset of the PRIbits field.
Sourcepub const PRIBITS_MASK: u32 = 0b111
pub const PRIBITS_MASK: u32 = 0b111
Mask for the PRIbits field.
Sourcepub const IDBITS_SHIFT: u32 = 11
pub const IDBITS_SHIFT: u32 = 11
Offset of the IDbits field.
Sourcepub const IDBITS_MASK: u32 = 0b111
pub const IDBITS_MASK: u32 = 0b111
Mask for the IDbits field.
Sourcepub const SEIS_SHIFT: u32 = 14
pub const SEIS_SHIFT: u32 = 14
Offset of the SEIS field.
Sourcepub const EXTRANGE_SHIFT: u32 = 19
pub const EXTRANGE_SHIFT: u32 = 19
Offset of the ExtRange field.
Sourcepub const fn set_pribits(&mut self, value: u8)
pub const fn set_pribits(&mut self, value: u8)
Sets the value of the PRIbits field.
Sourcepub const fn with_pribits(self, value: u8) -> Self
pub const fn with_pribits(self, value: u8) -> Self
Returns a copy with the PRIbits field set to the given value.
Sourcepub const fn set_idbits(&mut self, value: u8)
pub const fn set_idbits(&mut self, value: u8)
Sets the value of the IDbits field.
Sourcepub const fn with_idbits(self, value: u8) -> Self
pub const fn with_idbits(self, value: u8) -> Self
Returns a copy with the IDbits field set to the given value.