pub struct IdDfr0(/* private fields */);Expand description
ID_DFR0 system register value.
Implementations
Sourceimpl IdDfr0
impl IdDfr0
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl IdDfr0
impl IdDfr0
Sourcepub const fn iter(&self) -> Iter<IdDfr0>
pub const fn iter(&self) -> Iter<IdDfr0>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<IdDfr0>
pub const fn iter_names(&self) -> IterNames<IdDfr0>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl IdDfr0
impl IdDfr0
Sourcepub const COPDBG_SHIFT: u32 = 0
pub const COPDBG_SHIFT: u32 = 0
Offset of the CopDbg field.
Sourcepub const COPDBG_MASK: u32 = 0b1111
pub const COPDBG_MASK: u32 = 0b1111
Mask for the CopDbg field.
Sourcepub const COPSDBG_SHIFT: u32 = 4
pub const COPSDBG_SHIFT: u32 = 4
Offset of the CopSDbg field.
Sourcepub const COPSDBG_MASK: u32 = 0b1111
pub const COPSDBG_MASK: u32 = 0b1111
Mask for the CopSDbg field.
Sourcepub const MMAPDBG_SHIFT: u32 = 8
pub const MMAPDBG_SHIFT: u32 = 8
Offset of the MMapDbg field.
Sourcepub const MMAPDBG_MASK: u32 = 0b1111
pub const MMAPDBG_MASK: u32 = 0b1111
Mask for the MMapDbg field.
Sourcepub const COPTRC_SHIFT: u32 = 12
pub const COPTRC_SHIFT: u32 = 12
Offset of the CopTrc field.
Sourcepub const COPTRC_MASK: u32 = 0b1111
pub const COPTRC_MASK: u32 = 0b1111
Mask for the CopTrc field.
Sourcepub const MMAPTRC_SHIFT: u32 = 16
pub const MMAPTRC_SHIFT: u32 = 16
Offset of the MMapTrc field.
Sourcepub const MMAPTRC_MASK: u32 = 0b1111
pub const MMAPTRC_MASK: u32 = 0b1111
Mask for the MMapTrc field.
Sourcepub const MPROFDBG_SHIFT: u32 = 20
pub const MPROFDBG_SHIFT: u32 = 20
Offset of the MProfDbg field.
Sourcepub const MPROFDBG_MASK: u32 = 0b1111
pub const MPROFDBG_MASK: u32 = 0b1111
Mask for the MProfDbg field.
Sourcepub const PERFMON_SHIFT: u32 = 24
pub const PERFMON_SHIFT: u32 = 24
Offset of the PerfMon field.
Sourcepub const PERFMON_MASK: u32 = 0b1111
pub const PERFMON_MASK: u32 = 0b1111
Mask for the PerfMon field.
Sourcepub const TRACEFILT_SHIFT: u32 = 28
pub const TRACEFILT_SHIFT: u32 = 28
Offset of the TraceFilt field.
Sourcepub const TRACEFILT_MASK: u32 = 0b1111
pub const TRACEFILT_MASK: u32 = 0b1111
Mask for the TraceFilt field.
Sourcepub const fn set_copdbg(&mut self, value: u8)
pub const fn set_copdbg(&mut self, value: u8)
Sets the value of the CopDbg field.
Sourcepub const fn with_copdbg(self, value: u8) -> Self
pub const fn with_copdbg(self, value: u8) -> Self
Returns a copy with the CopDbg field set to the given value.
Sourcepub const fn set_copsdbg(&mut self, value: u8)
pub const fn set_copsdbg(&mut self, value: u8)
Sets the value of the CopSDbg field.
Sourcepub const fn with_copsdbg(self, value: u8) -> Self
pub const fn with_copsdbg(self, value: u8) -> Self
Returns a copy with the CopSDbg field set to the given value.
Sourcepub const fn set_mmapdbg(&mut self, value: u8)
pub const fn set_mmapdbg(&mut self, value: u8)
Sets the value of the MMapDbg field.
Sourcepub const fn with_mmapdbg(self, value: u8) -> Self
pub const fn with_mmapdbg(self, value: u8) -> Self
Returns a copy with the MMapDbg field set to the given value.
Sourcepub const fn set_coptrc(&mut self, value: u8)
pub const fn set_coptrc(&mut self, value: u8)
Sets the value of the CopTrc field.
Sourcepub const fn with_coptrc(self, value: u8) -> Self
pub const fn with_coptrc(self, value: u8) -> Self
Returns a copy with the CopTrc field set to the given value.
Sourcepub const fn set_mmaptrc(&mut self, value: u8)
pub const fn set_mmaptrc(&mut self, value: u8)
Sets the value of the MMapTrc field.
Sourcepub const fn with_mmaptrc(self, value: u8) -> Self
pub const fn with_mmaptrc(self, value: u8) -> Self
Returns a copy with the MMapTrc field set to the given value.
Sourcepub const fn set_mprofdbg(&mut self, value: u8)
pub const fn set_mprofdbg(&mut self, value: u8)
Sets the value of the MProfDbg field.
Sourcepub const fn with_mprofdbg(self, value: u8) -> Self
pub const fn with_mprofdbg(self, value: u8) -> Self
Returns a copy with the MProfDbg field set to the given value.
Sourcepub const fn set_perfmon(&mut self, value: u8)
pub const fn set_perfmon(&mut self, value: u8)
Sets the value of the PerfMon field.
Sourcepub const fn with_perfmon(self, value: u8) -> Self
pub const fn with_perfmon(self, value: u8) -> Self
Returns a copy with the PerfMon field set to the given value.
Sourcepub const fn set_tracefilt(&mut self, value: u8)
pub const fn set_tracefilt(&mut self, value: u8)
Sets the value of the TraceFilt field.
Sourcepub const fn with_tracefilt(self, value: u8) -> Self
pub const fn with_tracefilt(self, value: u8) -> Self
Returns a copy with the TraceFilt field set to the given value.