IdIsar1

Struct IdIsar1 

pub struct IdIsar1(/* private fields */);
ID_ISAR1 system register value.

Implementations

Source

impl IdIsar1

pub const fn empty() -> Self

Get a flags value with all bits unset.

pub const fn all() -> Self

Get a flags value with all known bits set.

pub const fn bits(&self) -> u32

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u32) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u32) -> Self

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u32) -> Self

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in this flags value are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Self) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

pub const fn contains(&self, other: Self) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

pub fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in two flags values.

pub fn remove(&mut self, other: Self)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Self)

The bitwise exclusive-or (^) of the bits in two flags values.

pub fn set(&mut self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Self) -> Self

The bitwise and (&) of the bits in two flags values.

pub const fn union(self, other: Self) -> Self

The bitwise or (|) of the bits in two flags values.

pub const fn difference(self, other: Self) -> Self

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in two flags values.

pub const fn complement(self) -> Self

The bitwise negation (!) of the bits in a flags value, truncating the result.

Source

impl IdIsar1

pub const fn iter(&self) -> Iter<IdIsar1>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<IdIsar1>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.

Source

impl IdIsar1

pub const ENDIAN_SHIFT: u32 = 0

Offset of the Endian field.

pub const ENDIAN_MASK: u32 = 0b1111

Mask for the Endian field.

pub const EXCEPT_SHIFT: u32 = 4

Offset of the Except field.

pub const EXCEPT_MASK: u32 = 0b1111

Mask for the Except field.

pub const EXCEPT_AR_SHIFT: u32 = 8

Offset of the Except_AR field.

pub const EXCEPT_AR_MASK: u32 = 0b1111

Mask for the Except_AR field.

pub const EXTEND_SHIFT: u32 = 12

Offset of the Extend field.

pub const EXTEND_MASK: u32 = 0b1111

Mask for the Extend field.

pub const IFTHEN_SHIFT: u32 = 16

Offset of the IfThen field.

pub const IFTHEN_MASK: u32 = 0b1111

Mask for the IfThen field.

pub const IMMEDIATE_SHIFT: u32 = 20

Offset of the Immediate field.

pub const IMMEDIATE_MASK: u32 = 0b1111

Mask for the Immediate field.

pub const INTERWORK_SHIFT: u32 = 24

Offset of the Interwork field.

pub const INTERWORK_MASK: u32 = 0b1111

Mask for the Interwork field.

pub const JAZELLE_SHIFT: u32 = 28

Offset of the Jazelle field.

pub const JAZELLE_MASK: u32 = 0b1111

Mask for the Jazelle field.

pub const fn endian(self) -> u8

Returns the value of the Endian field.

pub const fn set_endian(&mut self, value: u8)

Sets the value of the Endian field.

pub const fn except(self) -> u8

Returns the value of the Except field.

pub const fn set_except(&mut self, value: u8)

Sets the value of the Except field.

pub const fn except_ar(self) -> u8

Returns the value of the Except_AR field.

pub const fn set_except_ar(&mut self, value: u8)

Sets the value of the Except_AR field.

pub const fn extend_(self) -> u8

Returns the value of the Extend field.

pub const fn set_extend_(&mut self, value: u8)

Sets the value of the Extend field.

pub const fn ifthen(self) -> u8

Returns the value of the IfThen field.

pub const fn set_ifthen(&mut self, value: u8)

Sets the value of the IfThen field.

pub const fn immediate(self) -> u8

Returns the value of the Immediate field.

pub const fn set_immediate(&mut self, value: u8)

Sets the value of the Immediate field.

pub const fn interwork(self) -> u8

Returns the value of the Interwork field.

pub const fn set_interwork(&mut self, value: u8)

Sets the value of the Interwork field.

pub const fn jazelle(self) -> u8

Returns the value of the Jazelle field.

pub const fn set_jazelle(&mut self, value: u8)

Sets the value of the Jazelle field.