pub struct IdIsar2(/* private fields */);Expand description
ID_ISAR2 system register value.
Implementations
Sourceimpl IdIsar2
impl IdIsar2
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl IdIsar2
impl IdIsar2
Sourcepub const fn iter(&self) -> Iter<IdIsar2>
pub const fn iter(&self) -> Iter<IdIsar2>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<IdIsar2>
pub const fn iter_names(&self) -> IterNames<IdIsar2>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl IdIsar2
impl IdIsar2
Sourcepub const LOADSTORE_SHIFT: u32 = 0
pub const LOADSTORE_SHIFT: u32 = 0
Offset of the LoadStore field.
Sourcepub const LOADSTORE_MASK: u32 = 0b1111
pub const LOADSTORE_MASK: u32 = 0b1111
Mask for the LoadStore field.
Sourcepub const MEMHINT_SHIFT: u32 = 4
pub const MEMHINT_SHIFT: u32 = 4
Offset of the MemHint field.
Sourcepub const MEMHINT_MASK: u32 = 0b1111
pub const MEMHINT_MASK: u32 = 0b1111
Mask for the MemHint field.
Sourcepub const MULTIACCESSINT_SHIFT: u32 = 8
pub const MULTIACCESSINT_SHIFT: u32 = 8
Offset of the MultiAccessInt field.
Sourcepub const MULTIACCESSINT_MASK: u32 = 0b1111
pub const MULTIACCESSINT_MASK: u32 = 0b1111
Mask for the MultiAccessInt field.
Sourcepub const MULT_SHIFT: u32 = 12
pub const MULT_SHIFT: u32 = 12
Offset of the Mult field.
Sourcepub const MULTS_SHIFT: u32 = 16
pub const MULTS_SHIFT: u32 = 16
Offset of the MultS field.
Sourcepub const MULTS_MASK: u32 = 0b1111
pub const MULTS_MASK: u32 = 0b1111
Mask for the MultS field.
Sourcepub const MULTU_SHIFT: u32 = 20
pub const MULTU_SHIFT: u32 = 20
Offset of the MultU field.
Sourcepub const MULTU_MASK: u32 = 0b1111
pub const MULTU_MASK: u32 = 0b1111
Mask for the MultU field.
Sourcepub const PSR_AR_SHIFT: u32 = 24
pub const PSR_AR_SHIFT: u32 = 24
Offset of the PSR_AR field.
Sourcepub const PSR_AR_MASK: u32 = 0b1111
pub const PSR_AR_MASK: u32 = 0b1111
Mask for the PSR_AR field.
Sourcepub const REVERSAL_SHIFT: u32 = 28
pub const REVERSAL_SHIFT: u32 = 28
Offset of the Reversal field.
Sourcepub const REVERSAL_MASK: u32 = 0b1111
pub const REVERSAL_MASK: u32 = 0b1111
Mask for the Reversal field.
Sourcepub const fn set_loadstore(&mut self, value: u8)
pub const fn set_loadstore(&mut self, value: u8)
Sets the value of the LoadStore field.
Sourcepub const fn with_loadstore(self, value: u8) -> Self
pub const fn with_loadstore(self, value: u8) -> Self
Returns a copy with the LoadStore field set to the given value.
Sourcepub const fn set_memhint(&mut self, value: u8)
pub const fn set_memhint(&mut self, value: u8)
Sets the value of the MemHint field.
Sourcepub const fn with_memhint(self, value: u8) -> Self
pub const fn with_memhint(self, value: u8) -> Self
Returns a copy with the MemHint field set to the given value.
Sourcepub const fn multiaccessint(self) -> u8
pub const fn multiaccessint(self) -> u8
Returns the value of the MultiAccessInt field.
Sourcepub const fn set_multiaccessint(&mut self, value: u8)
pub const fn set_multiaccessint(&mut self, value: u8)
Sets the value of the MultiAccessInt field.
Sourcepub const fn with_multiaccessint(self, value: u8) -> Self
pub const fn with_multiaccessint(self, value: u8) -> Self
Returns a copy with the MultiAccessInt field set to the given value.
Sourcepub const fn with_mult(self, value: u8) -> Self
pub const fn with_mult(self, value: u8) -> Self
Returns a copy with the Mult field set to the given value.
Sourcepub const fn with_mults(self, value: u8) -> Self
pub const fn with_mults(self, value: u8) -> Self
Returns a copy with the MultS field set to the given value.
Sourcepub const fn with_multu(self, value: u8) -> Self
pub const fn with_multu(self, value: u8) -> Self
Returns a copy with the MultU field set to the given value.
Sourcepub const fn set_psr_ar(&mut self, value: u8)
pub const fn set_psr_ar(&mut self, value: u8)
Sets the value of the PSR_AR field.
Sourcepub const fn with_psr_ar(self, value: u8) -> Self
pub const fn with_psr_ar(self, value: u8) -> Self
Returns a copy with the PSR_AR field set to the given value.
Sourcepub const fn set_reversal(&mut self, value: u8)
pub const fn set_reversal(&mut self, value: u8)
Sets the value of the Reversal field.
Sourcepub const fn with_reversal(self, value: u8) -> Self
pub const fn with_reversal(self, value: u8) -> Self
Returns a copy with the Reversal field set to the given value.