IdIsar3

Struct IdIsar3 

pub struct IdIsar3(/* private fields */);
ID_ISAR3 system register value.

Implementations

Source

impl IdIsar3

pub const fn empty() -> Self

Get a flags value with all bits unset.

pub const fn all() -> Self

Get a flags value with all known bits set.

pub const fn bits(&self) -> u32

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u32) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u32) -> Self

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u32) -> Self

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in this flags value are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Self) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

pub const fn contains(&self, other: Self) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

pub fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in two flags values.

pub fn remove(&mut self, other: Self)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Self)

The bitwise exclusive-or (^) of the bits in two flags values.

pub fn set(&mut self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Self) -> Self

The bitwise and (&) of the bits in two flags values.

pub const fn union(self, other: Self) -> Self

The bitwise or (|) of the bits in two flags values.

pub const fn difference(self, other: Self) -> Self

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in two flags values.

pub const fn complement(self) -> Self

The bitwise negation (!) of the bits in a flags value, truncating the result.

Source

impl IdIsar3

pub const fn iter(&self) -> Iter<IdIsar3>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<IdIsar3>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.

Source

impl IdIsar3

pub const SATURATE_SHIFT: u32 = 0

Offset of the Saturate field.

pub const SATURATE_MASK: u32 = 0b1111

Mask for the Saturate field.

pub const SIMD_SHIFT: u32 = 4

Offset of the SIMD field.

pub const SIMD_MASK: u32 = 0b1111

Mask for the SIMD field.

pub const SVC_SHIFT: u32 = 8

Offset of the SVC field.

pub const SVC_MASK: u32 = 0b1111

Mask for the SVC field.

pub const SYNCHPRIM_SHIFT: u32 = 12

Offset of the SynchPrim field.

pub const SYNCHPRIM_MASK: u32 = 0b1111

Mask for the SynchPrim field.

pub const TABBRANCH_SHIFT: u32 = 16

Offset of the TabBranch field.

pub const TABBRANCH_MASK: u32 = 0b1111

Mask for the TabBranch field.

pub const T32COPY_SHIFT: u32 = 20

Offset of the T32Copy field.

pub const T32COPY_MASK: u32 = 0b1111

Mask for the T32Copy field.

pub const TRUENOP_SHIFT: u32 = 24

Offset of the TrueNOP field.

pub const TRUENOP_MASK: u32 = 0b1111

Mask for the TrueNOP field.

pub const T32EE_SHIFT: u32 = 28

Offset of the T32EE field.

pub const T32EE_MASK: u32 = 0b1111

Mask for the T32EE field.

pub const fn saturate(self) -> u8

Returns the value of the Saturate field.

pub const fn set_saturate(&mut self, value: u8)

Sets the value of the Saturate field.

pub const fn with_saturate(self, value: u8) -> Self

Returns a copy with the Saturate field set to the given value.

pub const fn simd(self) -> u8

Returns the value of the SIMD field.

pub const fn set_simd(&mut self, value: u8)

Sets the value of the SIMD field.

pub const fn with_simd(self, value: u8) -> Self

Returns a copy with the SIMD field set to the given value.

pub const fn svc(self) -> u8

Returns the value of the SVC field.

pub const fn set_svc(&mut self, value: u8)

Sets the value of the SVC field.

pub const fn with_svc(self, value: u8) -> Self

Returns a copy with the SVC field set to the given value.

pub const fn synchprim(self) -> u8

Returns the value of the SynchPrim field.

pub const fn set_synchprim(&mut self, value: u8)

Sets the value of the SynchPrim field.

pub const fn with_synchprim(self, value: u8) -> Self

Returns a copy with the SynchPrim field set to the given value.

pub const fn tabbranch(self) -> u8

Returns the value of the TabBranch field.

pub const fn set_tabbranch(&mut self, value: u8)

Sets the value of the TabBranch field.

pub const fn with_tabbranch(self, value: u8) -> Self

Returns a copy with the TabBranch field set to the given value.

pub const fn t32copy(self) -> u8

Returns the value of the T32Copy field.

pub const fn set_t32copy(&mut self, value: u8)

Sets the value of the T32Copy field.

pub const fn with_t32copy(self, value: u8) -> Self

Returns a copy with the T32Copy field set to the given value.

pub const fn truenop(self) -> u8

Returns the value of the TrueNOP field.

pub const fn set_truenop(&mut self, value: u8)

Sets the value of the TrueNOP field.

pub const fn with_truenop(self, value: u8) -> Self

Returns a copy with the TrueNOP field set to the given value.

pub const fn t32ee(self) -> u8

Returns the value of the T32EE field.

pub const fn set_t32ee(&mut self, value: u8)

Sets the value of the T32EE field.

pub const fn with_t32ee(self, value: u8) -> Self

Returns a copy with the T32EE field set to the given value.