pub struct IdIsar4(/* private fields */);Expand description
ID_ISAR4 system register value.
Implementations
Sourceimpl IdIsar4
impl IdIsar4
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl IdIsar4
impl IdIsar4
Sourcepub const fn iter(&self) -> Iter<IdIsar4>
pub const fn iter(&self) -> Iter<IdIsar4>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<IdIsar4>
pub const fn iter_names(&self) -> IterNames<IdIsar4>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl IdIsar4
impl IdIsar4
Sourcepub const UNPRIV_SHIFT: u32 = 0
pub const UNPRIV_SHIFT: u32 = 0
Offset of the Unpriv field.
Sourcepub const UNPRIV_MASK: u32 = 0b1111
pub const UNPRIV_MASK: u32 = 0b1111
Mask for the Unpriv field.
Sourcepub const WITHSHIFTS_SHIFT: u32 = 4
pub const WITHSHIFTS_SHIFT: u32 = 4
Offset of the WithShifts field.
Sourcepub const WITHSHIFTS_MASK: u32 = 0b1111
pub const WITHSHIFTS_MASK: u32 = 0b1111
Mask for the WithShifts field.
Sourcepub const WRITEBACK_SHIFT: u32 = 8
pub const WRITEBACK_SHIFT: u32 = 8
Offset of the Writeback field.
Sourcepub const WRITEBACK_MASK: u32 = 0b1111
pub const WRITEBACK_MASK: u32 = 0b1111
Mask for the Writeback field.
Sourcepub const BARRIER_SHIFT: u32 = 16
pub const BARRIER_SHIFT: u32 = 16
Offset of the Barrier field.
Sourcepub const BARRIER_MASK: u32 = 0b1111
pub const BARRIER_MASK: u32 = 0b1111
Mask for the Barrier field.
Sourcepub const SYNCHPRIM_FRAC_SHIFT: u32 = 20
pub const SYNCHPRIM_FRAC_SHIFT: u32 = 20
Offset of the SynchPrim_frac field.
Sourcepub const SYNCHPRIM_FRAC_MASK: u32 = 0b1111
pub const SYNCHPRIM_FRAC_MASK: u32 = 0b1111
Mask for the SynchPrim_frac field.
Sourcepub const PSR_M_SHIFT: u32 = 24
pub const PSR_M_SHIFT: u32 = 24
Offset of the PSR_M field.
Sourcepub const PSR_M_MASK: u32 = 0b1111
pub const PSR_M_MASK: u32 = 0b1111
Mask for the PSR_M field.
Sourcepub const SWP_FRAC_SHIFT: u32 = 28
pub const SWP_FRAC_SHIFT: u32 = 28
Offset of the SWP_frac field.
Sourcepub const SWP_FRAC_MASK: u32 = 0b1111
pub const SWP_FRAC_MASK: u32 = 0b1111
Mask for the SWP_frac field.
Sourcepub const fn set_unpriv(&mut self, value: u8)
pub const fn set_unpriv(&mut self, value: u8)
Sets the value of the Unpriv field.
Sourcepub const fn with_unpriv(self, value: u8) -> Self
pub const fn with_unpriv(self, value: u8) -> Self
Returns a copy with the Unpriv field set to the given value.
Sourcepub const fn withshifts(self) -> u8
pub const fn withshifts(self) -> u8
Returns the value of the WithShifts field.
Sourcepub const fn set_withshifts(&mut self, value: u8)
pub const fn set_withshifts(&mut self, value: u8)
Sets the value of the WithShifts field.
Sourcepub const fn with_withshifts(self, value: u8) -> Self
pub const fn with_withshifts(self, value: u8) -> Self
Returns a copy with the WithShifts field set to the given value.
Sourcepub const fn set_writeback(&mut self, value: u8)
pub const fn set_writeback(&mut self, value: u8)
Sets the value of the Writeback field.
Sourcepub const fn with_writeback(self, value: u8) -> Self
pub const fn with_writeback(self, value: u8) -> Self
Returns a copy with the Writeback field set to the given value.
Sourcepub const fn with_smc(self, value: u8) -> Self
pub const fn with_smc(self, value: u8) -> Self
Returns a copy with the SMC field set to the given value.
Sourcepub const fn set_barrier(&mut self, value: u8)
pub const fn set_barrier(&mut self, value: u8)
Sets the value of the Barrier field.
Sourcepub const fn with_barrier(self, value: u8) -> Self
pub const fn with_barrier(self, value: u8) -> Self
Returns a copy with the Barrier field set to the given value.
Sourcepub const fn synchprim_frac(self) -> u8
pub const fn synchprim_frac(self) -> u8
Returns the value of the SynchPrim_frac field.
Sourcepub const fn set_synchprim_frac(&mut self, value: u8)
pub const fn set_synchprim_frac(&mut self, value: u8)
Sets the value of the SynchPrim_frac field.
Sourcepub const fn with_synchprim_frac(self, value: u8) -> Self
pub const fn with_synchprim_frac(self, value: u8) -> Self
Returns a copy with the SynchPrim_frac field set to the given value.
Sourcepub const fn with_psr_m(self, value: u8) -> Self
pub const fn with_psr_m(self, value: u8) -> Self
Returns a copy with the PSR_M field set to the given value.
Sourcepub const fn set_swp_frac(&mut self, value: u8)
pub const fn set_swp_frac(&mut self, value: u8)
Sets the value of the SWP_frac field.
Sourcepub const fn with_swp_frac(self, value: u8) -> Self
pub const fn with_swp_frac(self, value: u8) -> Self
Returns a copy with the SWP_frac field set to the given value.