pub struct IdIsar5(/* private fields */);Expand description
ID_ISAR5 system register value.
Implementations
Sourceimpl IdIsar5
impl IdIsar5
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl IdIsar5
impl IdIsar5
Sourcepub const fn iter(&self) -> Iter<IdIsar5>
pub const fn iter(&self) -> Iter<IdIsar5>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<IdIsar5>
pub const fn iter_names(&self) -> IterNames<IdIsar5>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl IdIsar5
impl IdIsar5
Sourcepub const SEVL_SHIFT: u32 = 0
pub const SEVL_SHIFT: u32 = 0
Offset of the SEVL field.
Sourcepub const SHA1_SHIFT: u32 = 8
pub const SHA1_SHIFT: u32 = 8
Offset of the SHA1 field.
Sourcepub const SHA2_SHIFT: u32 = 12
pub const SHA2_SHIFT: u32 = 12
Offset of the SHA2 field.
Sourcepub const CRC32_SHIFT: u32 = 16
pub const CRC32_SHIFT: u32 = 16
Offset of the CRC32 field.
Sourcepub const CRC32_MASK: u32 = 0b1111
pub const CRC32_MASK: u32 = 0b1111
Mask for the CRC32 field.
Sourcepub const VCMA_SHIFT: u32 = 28
pub const VCMA_SHIFT: u32 = 28
Offset of the VCMA field.
Sourcepub const fn with_sevl(self, value: u8) -> Self
pub const fn with_sevl(self, value: u8) -> Self
Returns a copy with the SEVL field set to the given value.
Sourcepub const fn with_aes(self, value: u8) -> Self
pub const fn with_aes(self, value: u8) -> Self
Returns a copy with the AES field set to the given value.
Sourcepub const fn with_sha1(self, value: u8) -> Self
pub const fn with_sha1(self, value: u8) -> Self
Returns a copy with the SHA1 field set to the given value.
Sourcepub const fn with_sha2(self, value: u8) -> Self
pub const fn with_sha2(self, value: u8) -> Self
Returns a copy with the SHA2 field set to the given value.
Sourcepub const fn with_crc32(self, value: u8) -> Self
pub const fn with_crc32(self, value: u8) -> Self
Returns a copy with the CRC32 field set to the given value.