pub struct IdIsar6(/* private fields */);Expand description
ID_ISAR6 system register value.
Implementations
Sourceimpl IdIsar6
impl IdIsar6
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl IdIsar6
impl IdIsar6
Sourcepub const fn iter(&self) -> Iter<IdIsar6>
pub const fn iter(&self) -> Iter<IdIsar6>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<IdIsar6>
pub const fn iter_names(&self) -> IterNames<IdIsar6>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl IdIsar6
impl IdIsar6
Sourcepub const JSCVT_SHIFT: u32 = 0
pub const JSCVT_SHIFT: u32 = 0
Offset of the JSCVT field.
Sourcepub const JSCVT_MASK: u32 = 0b1111
pub const JSCVT_MASK: u32 = 0b1111
Mask for the JSCVT field.
Sourcepub const SPECRES_SHIFT: u32 = 16
pub const SPECRES_SHIFT: u32 = 16
Offset of the SPECRES field.
Sourcepub const SPECRES_MASK: u32 = 0b1111
pub const SPECRES_MASK: u32 = 0b1111
Mask for the SPECRES field.
Sourcepub const BF16_SHIFT: u32 = 20
pub const BF16_SHIFT: u32 = 20
Offset of the BF16 field.
Sourcepub const I8MM_SHIFT: u32 = 24
pub const I8MM_SHIFT: u32 = 24
Offset of the I8MM field.
Sourcepub const CLRBHB_SHIFT: u32 = 28
pub const CLRBHB_SHIFT: u32 = 28
Offset of the CLRBHB field.
Sourcepub const CLRBHB_MASK: u32 = 0b1111
pub const CLRBHB_MASK: u32 = 0b1111
Mask for the CLRBHB field.
Sourcepub const fn with_jscvt(self, value: u8) -> Self
pub const fn with_jscvt(self, value: u8) -> Self
Returns a copy with the JSCVT field set to the given value.
Sourcepub const fn with_dp(self, value: u8) -> Self
pub const fn with_dp(self, value: u8) -> Self
Returns a copy with the DP field set to the given value.
Sourcepub const fn with_fhm(self, value: u8) -> Self
pub const fn with_fhm(self, value: u8) -> Self
Returns a copy with the FHM field set to the given value.
Sourcepub const fn with_sb(self, value: u8) -> Self
pub const fn with_sb(self, value: u8) -> Self
Returns a copy with the SB field set to the given value.
Sourcepub const fn set_specres(&mut self, value: u8)
pub const fn set_specres(&mut self, value: u8)
Sets the value of the SPECRES field.
Sourcepub const fn with_specres(self, value: u8) -> Self
pub const fn with_specres(self, value: u8) -> Self
Returns a copy with the SPECRES field set to the given value.
Sourcepub const fn with_bf16(self, value: u8) -> Self
pub const fn with_bf16(self, value: u8) -> Self
Returns a copy with the BF16 field set to the given value.
Sourcepub const fn with_i8mm(self, value: u8) -> Self
pub const fn with_i8mm(self, value: u8) -> Self
Returns a copy with the I8MM field set to the given value.
Sourcepub const fn set_clrbhb(&mut self, value: u8)
pub const fn set_clrbhb(&mut self, value: u8)
Sets the value of the CLRBHB field.
Sourcepub const fn with_clrbhb(self, value: u8) -> Self
pub const fn with_clrbhb(self, value: u8) -> Self
Returns a copy with the CLRBHB field set to the given value.