pub struct IdMmfr0(/* private fields */);Expand description
ID_MMFR0 system register value.
Implementations
Sourceimpl IdMmfr0
impl IdMmfr0
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl IdMmfr0
impl IdMmfr0
Sourcepub const fn iter(&self) -> Iter<IdMmfr0>
pub const fn iter(&self) -> Iter<IdMmfr0>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<IdMmfr0>
pub const fn iter_names(&self) -> IterNames<IdMmfr0>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl IdMmfr0
impl IdMmfr0
Sourcepub const VMSA_SHIFT: u32 = 0
pub const VMSA_SHIFT: u32 = 0
Offset of the VMSA field.
Sourcepub const PMSA_SHIFT: u32 = 4
pub const PMSA_SHIFT: u32 = 4
Offset of the PMSA field.
Sourcepub const OUTERSHR_SHIFT: u32 = 8
pub const OUTERSHR_SHIFT: u32 = 8
Offset of the OuterShr field.
Sourcepub const OUTERSHR_MASK: u32 = 0b1111
pub const OUTERSHR_MASK: u32 = 0b1111
Mask for the OuterShr field.
Sourcepub const SHARELVL_SHIFT: u32 = 12
pub const SHARELVL_SHIFT: u32 = 12
Offset of the ShareLvl field.
Sourcepub const SHARELVL_MASK: u32 = 0b1111
pub const SHARELVL_MASK: u32 = 0b1111
Mask for the ShareLvl field.
Sourcepub const AUXREG_SHIFT: u32 = 20
pub const AUXREG_SHIFT: u32 = 20
Offset of the AuxReg field.
Sourcepub const AUXREG_MASK: u32 = 0b1111
pub const AUXREG_MASK: u32 = 0b1111
Mask for the AuxReg field.
Sourcepub const FCSE_SHIFT: u32 = 24
pub const FCSE_SHIFT: u32 = 24
Offset of the FCSE field.
Sourcepub const INNERSHR_SHIFT: u32 = 28
pub const INNERSHR_SHIFT: u32 = 28
Offset of the InnerShr field.
Sourcepub const INNERSHR_MASK: u32 = 0b1111
pub const INNERSHR_MASK: u32 = 0b1111
Mask for the InnerShr field.
Sourcepub const fn with_vmsa(self, value: u8) -> Self
pub const fn with_vmsa(self, value: u8) -> Self
Returns a copy with the VMSA field set to the given value.
Sourcepub const fn with_pmsa(self, value: u8) -> Self
pub const fn with_pmsa(self, value: u8) -> Self
Returns a copy with the PMSA field set to the given value.
Sourcepub const fn set_outershr(&mut self, value: u8)
pub const fn set_outershr(&mut self, value: u8)
Sets the value of the OuterShr field.
Sourcepub const fn with_outershr(self, value: u8) -> Self
pub const fn with_outershr(self, value: u8) -> Self
Returns a copy with the OuterShr field set to the given value.
Returns the value of the ShareLvl field.
Sets the value of the ShareLvl field.
Returns a copy with the ShareLvl field set to the given value.
Sourcepub const fn with_tcm(self, value: u8) -> Self
pub const fn with_tcm(self, value: u8) -> Self
Returns a copy with the TCM field set to the given value.
Sourcepub const fn set_auxreg(&mut self, value: u8)
pub const fn set_auxreg(&mut self, value: u8)
Sets the value of the AuxReg field.
Sourcepub const fn with_auxreg(self, value: u8) -> Self
pub const fn with_auxreg(self, value: u8) -> Self
Returns a copy with the AuxReg field set to the given value.
Sourcepub const fn with_fcse(self, value: u8) -> Self
pub const fn with_fcse(self, value: u8) -> Self
Returns a copy with the FCSE field set to the given value.
Sourcepub const fn set_innershr(&mut self, value: u8)
pub const fn set_innershr(&mut self, value: u8)
Sets the value of the InnerShr field.
Sourcepub const fn with_innershr(self, value: u8) -> Self
pub const fn with_innershr(self, value: u8) -> Self
Returns a copy with the InnerShr field set to the given value.