pub struct IdMmfr1(/* private fields */);Expand description
ID_MMFR1 system register value.
Implementations
Sourceimpl IdMmfr1
impl IdMmfr1
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl IdMmfr1
impl IdMmfr1
Sourcepub const fn iter(&self) -> Iter<IdMmfr1>
pub const fn iter(&self) -> Iter<IdMmfr1>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<IdMmfr1>
pub const fn iter_names(&self) -> IterNames<IdMmfr1>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl IdMmfr1
impl IdMmfr1
Sourcepub const L1HVDVA_SHIFT: u32 = 0
pub const L1HVDVA_SHIFT: u32 = 0
Offset of the L1HvdVA field.
Sourcepub const L1HVDVA_MASK: u32 = 0b1111
pub const L1HVDVA_MASK: u32 = 0b1111
Mask for the L1HvdVA field.
Sourcepub const L1UNIVA_SHIFT: u32 = 4
pub const L1UNIVA_SHIFT: u32 = 4
Offset of the L1UniVA field.
Sourcepub const L1UNIVA_MASK: u32 = 0b1111
pub const L1UNIVA_MASK: u32 = 0b1111
Mask for the L1UniVA field.
Sourcepub const L1HVDSW_SHIFT: u32 = 8
pub const L1HVDSW_SHIFT: u32 = 8
Offset of the L1HvdSW field.
Sourcepub const L1HVDSW_MASK: u32 = 0b1111
pub const L1HVDSW_MASK: u32 = 0b1111
Mask for the L1HvdSW field.
Sourcepub const L1UNISW_SHIFT: u32 = 12
pub const L1UNISW_SHIFT: u32 = 12
Offset of the L1UniSW field.
Sourcepub const L1UNISW_MASK: u32 = 0b1111
pub const L1UNISW_MASK: u32 = 0b1111
Mask for the L1UniSW field.
Sourcepub const L1HVD_SHIFT: u32 = 16
pub const L1HVD_SHIFT: u32 = 16
Offset of the L1Hvd field.
Sourcepub const L1HVD_MASK: u32 = 0b1111
pub const L1HVD_MASK: u32 = 0b1111
Mask for the L1Hvd field.
Sourcepub const L1UNI_SHIFT: u32 = 20
pub const L1UNI_SHIFT: u32 = 20
Offset of the L1Uni field.
Sourcepub const L1UNI_MASK: u32 = 0b1111
pub const L1UNI_MASK: u32 = 0b1111
Mask for the L1Uni field.
Sourcepub const L1TSTCLN_SHIFT: u32 = 24
pub const L1TSTCLN_SHIFT: u32 = 24
Offset of the L1TstCln field.
Sourcepub const L1TSTCLN_MASK: u32 = 0b1111
pub const L1TSTCLN_MASK: u32 = 0b1111
Mask for the L1TstCln field.
Sourcepub const BPRED_SHIFT: u32 = 28
pub const BPRED_SHIFT: u32 = 28
Offset of the BPred field.
Sourcepub const BPRED_MASK: u32 = 0b1111
pub const BPRED_MASK: u32 = 0b1111
Mask for the BPred field.
Sourcepub const fn set_l1hvdva(&mut self, value: u8)
pub const fn set_l1hvdva(&mut self, value: u8)
Sets the value of the L1HvdVA field.
Sourcepub const fn with_l1hvdva(self, value: u8) -> Self
pub const fn with_l1hvdva(self, value: u8) -> Self
Returns a copy with the L1HvdVA field set to the given value.
Sourcepub const fn set_l1univa(&mut self, value: u8)
pub const fn set_l1univa(&mut self, value: u8)
Sets the value of the L1UniVA field.
Sourcepub const fn with_l1univa(self, value: u8) -> Self
pub const fn with_l1univa(self, value: u8) -> Self
Returns a copy with the L1UniVA field set to the given value.
Sourcepub const fn set_l1hvdsw(&mut self, value: u8)
pub const fn set_l1hvdsw(&mut self, value: u8)
Sets the value of the L1HvdSW field.
Sourcepub const fn with_l1hvdsw(self, value: u8) -> Self
pub const fn with_l1hvdsw(self, value: u8) -> Self
Returns a copy with the L1HvdSW field set to the given value.
Sourcepub const fn set_l1unisw(&mut self, value: u8)
pub const fn set_l1unisw(&mut self, value: u8)
Sets the value of the L1UniSW field.
Sourcepub const fn with_l1unisw(self, value: u8) -> Self
pub const fn with_l1unisw(self, value: u8) -> Self
Returns a copy with the L1UniSW field set to the given value.
Sourcepub const fn with_l1hvd(self, value: u8) -> Self
pub const fn with_l1hvd(self, value: u8) -> Self
Returns a copy with the L1Hvd field set to the given value.
Sourcepub const fn with_l1uni(self, value: u8) -> Self
pub const fn with_l1uni(self, value: u8) -> Self
Returns a copy with the L1Uni field set to the given value.
Sourcepub const fn set_l1tstcln(&mut self, value: u8)
pub const fn set_l1tstcln(&mut self, value: u8)
Sets the value of the L1TstCln field.
Sourcepub const fn with_l1tstcln(self, value: u8) -> Self
pub const fn with_l1tstcln(self, value: u8) -> Self
Returns a copy with the L1TstCln field set to the given value.
Sourcepub const fn with_bpred(self, value: u8) -> Self
pub const fn with_bpred(self, value: u8) -> Self
Returns a copy with the BPred field set to the given value.