pub struct IdMmfr2(/* private fields */);Expand description
ID_MMFR2 system register value.
Implementations
Sourceimpl IdMmfr2
impl IdMmfr2
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl IdMmfr2
impl IdMmfr2
Sourcepub const fn iter(&self) -> Iter<IdMmfr2>
pub const fn iter(&self) -> Iter<IdMmfr2>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<IdMmfr2>
pub const fn iter_names(&self) -> IterNames<IdMmfr2>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl IdMmfr2
impl IdMmfr2
Sourcepub const L1HVDFG_SHIFT: u32 = 0
pub const L1HVDFG_SHIFT: u32 = 0
Offset of the L1HvdFG field.
Sourcepub const L1HVDFG_MASK: u32 = 0b1111
pub const L1HVDFG_MASK: u32 = 0b1111
Mask for the L1HvdFG field.
Sourcepub const L1HVDBG_SHIFT: u32 = 4
pub const L1HVDBG_SHIFT: u32 = 4
Offset of the L1HvdBG field.
Sourcepub const L1HVDBG_MASK: u32 = 0b1111
pub const L1HVDBG_MASK: u32 = 0b1111
Mask for the L1HvdBG field.
Sourcepub const L1HVDRNG_SHIFT: u32 = 8
pub const L1HVDRNG_SHIFT: u32 = 8
Offset of the L1HvdRng field.
Sourcepub const L1HVDRNG_MASK: u32 = 0b1111
pub const L1HVDRNG_MASK: u32 = 0b1111
Mask for the L1HvdRng field.
Sourcepub const HVDTLB_SHIFT: u32 = 12
pub const HVDTLB_SHIFT: u32 = 12
Offset of the HvdTLB field.
Sourcepub const HVDTLB_MASK: u32 = 0b1111
pub const HVDTLB_MASK: u32 = 0b1111
Mask for the HvdTLB field.
Sourcepub const UNITLB_SHIFT: u32 = 16
pub const UNITLB_SHIFT: u32 = 16
Offset of the UniTLB field.
Sourcepub const UNITLB_MASK: u32 = 0b1111
pub const UNITLB_MASK: u32 = 0b1111
Mask for the UniTLB field.
Sourcepub const MEMBARR_SHIFT: u32 = 20
pub const MEMBARR_SHIFT: u32 = 20
Offset of the MemBarr field.
Sourcepub const MEMBARR_MASK: u32 = 0b1111
pub const MEMBARR_MASK: u32 = 0b1111
Mask for the MemBarr field.
Sourcepub const WFISTALL_SHIFT: u32 = 24
pub const WFISTALL_SHIFT: u32 = 24
Offset of the WFIStall field.
Sourcepub const WFISTALL_MASK: u32 = 0b1111
pub const WFISTALL_MASK: u32 = 0b1111
Mask for the WFIStall field.
Sourcepub const HWACCFLG_SHIFT: u32 = 28
pub const HWACCFLG_SHIFT: u32 = 28
Offset of the HWAccFlg field.
Sourcepub const HWACCFLG_MASK: u32 = 0b1111
pub const HWACCFLG_MASK: u32 = 0b1111
Mask for the HWAccFlg field.
Sourcepub const fn set_l1hvdfg(&mut self, value: u8)
pub const fn set_l1hvdfg(&mut self, value: u8)
Sets the value of the L1HvdFG field.
Sourcepub const fn with_l1hvdfg(self, value: u8) -> Self
pub const fn with_l1hvdfg(self, value: u8) -> Self
Returns a copy with the L1HvdFG field set to the given value.
Sourcepub const fn set_l1hvdbg(&mut self, value: u8)
pub const fn set_l1hvdbg(&mut self, value: u8)
Sets the value of the L1HvdBG field.
Sourcepub const fn with_l1hvdbg(self, value: u8) -> Self
pub const fn with_l1hvdbg(self, value: u8) -> Self
Returns a copy with the L1HvdBG field set to the given value.
Sourcepub const fn set_l1hvdrng(&mut self, value: u8)
pub const fn set_l1hvdrng(&mut self, value: u8)
Sets the value of the L1HvdRng field.
Sourcepub const fn with_l1hvdrng(self, value: u8) -> Self
pub const fn with_l1hvdrng(self, value: u8) -> Self
Returns a copy with the L1HvdRng field set to the given value.
Sourcepub const fn set_hvdtlb(&mut self, value: u8)
pub const fn set_hvdtlb(&mut self, value: u8)
Sets the value of the HvdTLB field.
Sourcepub const fn with_hvdtlb(self, value: u8) -> Self
pub const fn with_hvdtlb(self, value: u8) -> Self
Returns a copy with the HvdTLB field set to the given value.
Sourcepub const fn set_unitlb(&mut self, value: u8)
pub const fn set_unitlb(&mut self, value: u8)
Sets the value of the UniTLB field.
Sourcepub const fn with_unitlb(self, value: u8) -> Self
pub const fn with_unitlb(self, value: u8) -> Self
Returns a copy with the UniTLB field set to the given value.
Sourcepub const fn set_membarr(&mut self, value: u8)
pub const fn set_membarr(&mut self, value: u8)
Sets the value of the MemBarr field.
Sourcepub const fn with_membarr(self, value: u8) -> Self
pub const fn with_membarr(self, value: u8) -> Self
Returns a copy with the MemBarr field set to the given value.
Sourcepub const fn set_wfistall(&mut self, value: u8)
pub const fn set_wfistall(&mut self, value: u8)
Sets the value of the WFIStall field.
Sourcepub const fn with_wfistall(self, value: u8) -> Self
pub const fn with_wfistall(self, value: u8) -> Self
Returns a copy with the WFIStall field set to the given value.
Sourcepub const fn set_hwaccflg(&mut self, value: u8)
pub const fn set_hwaccflg(&mut self, value: u8)
Sets the value of the HWAccFlg field.
Sourcepub const fn with_hwaccflg(self, value: u8) -> Self
pub const fn with_hwaccflg(self, value: u8) -> Self
Returns a copy with the HWAccFlg field set to the given value.