pub struct IdMmfr3(/* private fields */);Expand description
ID_MMFR3 system register value.
Implementations
Sourceimpl IdMmfr3
impl IdMmfr3
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl IdMmfr3
impl IdMmfr3
Sourcepub const fn iter(&self) -> Iter<IdMmfr3>
pub const fn iter(&self) -> Iter<IdMmfr3>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<IdMmfr3>
pub const fn iter_names(&self) -> IterNames<IdMmfr3>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl IdMmfr3
impl IdMmfr3
Sourcepub const CMAINTVA_SHIFT: u32 = 0
pub const CMAINTVA_SHIFT: u32 = 0
Offset of the CMaintVA field.
Sourcepub const CMAINTVA_MASK: u32 = 0b1111
pub const CMAINTVA_MASK: u32 = 0b1111
Mask for the CMaintVA field.
Sourcepub const CMAINTSW_SHIFT: u32 = 4
pub const CMAINTSW_SHIFT: u32 = 4
Offset of the CMaintSW field.
Sourcepub const CMAINTSW_MASK: u32 = 0b1111
pub const CMAINTSW_MASK: u32 = 0b1111
Mask for the CMaintSW field.
Sourcepub const BPMAINT_SHIFT: u32 = 8
pub const BPMAINT_SHIFT: u32 = 8
Offset of the BPMaint field.
Sourcepub const BPMAINT_MASK: u32 = 0b1111
pub const BPMAINT_MASK: u32 = 0b1111
Mask for the BPMaint field.
Sourcepub const MAINTBCST_SHIFT: u32 = 12
pub const MAINTBCST_SHIFT: u32 = 12
Offset of the MaintBcst field.
Sourcepub const MAINTBCST_MASK: u32 = 0b1111
pub const MAINTBCST_MASK: u32 = 0b1111
Mask for the MaintBcst field.
Sourcepub const COHWALK_SHIFT: u32 = 20
pub const COHWALK_SHIFT: u32 = 20
Offset of the CohWalk field.
Sourcepub const COHWALK_MASK: u32 = 0b1111
pub const COHWALK_MASK: u32 = 0b1111
Mask for the CohWalk field.
Sourcepub const CMEMSZ_SHIFT: u32 = 24
pub const CMEMSZ_SHIFT: u32 = 24
Offset of the CMemSz field.
Sourcepub const CMEMSZ_MASK: u32 = 0b1111
pub const CMEMSZ_MASK: u32 = 0b1111
Mask for the CMemSz field.
Sourcepub const SUPERSEC_SHIFT: u32 = 28
pub const SUPERSEC_SHIFT: u32 = 28
Offset of the Supersec field.
Sourcepub const SUPERSEC_MASK: u32 = 0b1111
pub const SUPERSEC_MASK: u32 = 0b1111
Mask for the Supersec field.
Sourcepub const fn set_cmaintva(&mut self, value: u8)
pub const fn set_cmaintva(&mut self, value: u8)
Sets the value of the CMaintVA field.
Sourcepub const fn with_cmaintva(self, value: u8) -> Self
pub const fn with_cmaintva(self, value: u8) -> Self
Returns a copy with the CMaintVA field set to the given value.
Sourcepub const fn set_cmaintsw(&mut self, value: u8)
pub const fn set_cmaintsw(&mut self, value: u8)
Sets the value of the CMaintSW field.
Sourcepub const fn with_cmaintsw(self, value: u8) -> Self
pub const fn with_cmaintsw(self, value: u8) -> Self
Returns a copy with the CMaintSW field set to the given value.
Sourcepub const fn set_bpmaint(&mut self, value: u8)
pub const fn set_bpmaint(&mut self, value: u8)
Sets the value of the BPMaint field.
Sourcepub const fn with_bpmaint(self, value: u8) -> Self
pub const fn with_bpmaint(self, value: u8) -> Self
Returns a copy with the BPMaint field set to the given value.
Sourcepub const fn set_maintbcst(&mut self, value: u8)
pub const fn set_maintbcst(&mut self, value: u8)
Sets the value of the MaintBcst field.
Sourcepub const fn with_maintbcst(self, value: u8) -> Self
pub const fn with_maintbcst(self, value: u8) -> Self
Returns a copy with the MaintBcst field set to the given value.
Sourcepub const fn with_pan(self, value: u8) -> Self
pub const fn with_pan(self, value: u8) -> Self
Returns a copy with the PAN field set to the given value.
Sourcepub const fn set_cohwalk(&mut self, value: u8)
pub const fn set_cohwalk(&mut self, value: u8)
Sets the value of the CohWalk field.
Sourcepub const fn with_cohwalk(self, value: u8) -> Self
pub const fn with_cohwalk(self, value: u8) -> Self
Returns a copy with the CohWalk field set to the given value.
Sourcepub const fn set_cmemsz(&mut self, value: u8)
pub const fn set_cmemsz(&mut self, value: u8)
Sets the value of the CMemSz field.
Sourcepub const fn with_cmemsz(self, value: u8) -> Self
pub const fn with_cmemsz(self, value: u8) -> Self
Returns a copy with the CMemSz field set to the given value.
Sourcepub const fn set_supersec(&mut self, value: u8)
pub const fn set_supersec(&mut self, value: u8)
Sets the value of the Supersec field.
Sourcepub const fn with_supersec(self, value: u8) -> Self
pub const fn with_supersec(self, value: u8) -> Self
Returns a copy with the Supersec field set to the given value.