IdMmfr4

Struct IdMmfr4 

pub struct IdMmfr4(/* private fields */);
ID_MMFR4 system register value.

Implementations

Source

impl IdMmfr4

pub const fn empty() -> Self

Get a flags value with all bits unset.

pub const fn all() -> Self

Get a flags value with all known bits set.

pub const fn bits(&self) -> u32

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u32) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u32) -> Self

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u32) -> Self

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in this flags value are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Self) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

pub const fn contains(&self, other: Self) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

pub fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in two flags values.

pub fn remove(&mut self, other: Self)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Self)

The bitwise exclusive-or (^) of the bits in two flags values.

pub fn set(&mut self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Self) -> Self

The bitwise and (&) of the bits in two flags values.

pub const fn union(self, other: Self) -> Self

The bitwise or (|) of the bits in two flags values.

pub const fn difference(self, other: Self) -> Self

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in two flags values.

pub const fn complement(self) -> Self

The bitwise negation (!) of the bits in a flags value, truncating the result.

Source

impl IdMmfr4

pub const fn iter(&self) -> Iter<IdMmfr4>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<IdMmfr4>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.

Source

impl IdMmfr4

pub const SPECSEI_SHIFT: u32 = 0

Offset of the SpecSEI field.

pub const SPECSEI_MASK: u32 = 0b1111

Mask for the SpecSEI field.

pub const AC2_SHIFT: u32 = 4

Offset of the AC2 field.

pub const AC2_MASK: u32 = 0b1111

Mask for the AC2 field.

pub const XNX_SHIFT: u32 = 8

Offset of the XNX field.

pub const XNX_MASK: u32 = 0b1111

Mask for the XNX field.

pub const CNP_SHIFT: u32 = 12

Offset of the CnP field.

pub const CNP_MASK: u32 = 0b1111

Mask for the CnP field.

pub const HPDS_SHIFT: u32 = 16

Offset of the HPDS field.

pub const HPDS_MASK: u32 = 0b1111

Mask for the HPDS field.

pub const LSM_SHIFT: u32 = 20

Offset of the LSM field.

pub const LSM_MASK: u32 = 0b1111

Mask for the LSM field.

pub const CCIDX_SHIFT: u32 = 24

Offset of the CCIDX field.

pub const CCIDX_MASK: u32 = 0b1111

Mask for the CCIDX field.

pub const EVT_SHIFT: u32 = 28

Offset of the EVT field.

pub const EVT_MASK: u32 = 0b1111

Mask for the EVT field.

pub const fn specsei(self) -> u8

Returns the value of the SpecSEI field.

pub const fn ac2(self) -> u8

Returns the value of the AC2 field.

pub const fn xnx(self) -> u8

Returns the value of the XNX field.

pub const fn cnp(self) -> u8

Returns the value of the CnP field.

pub const fn hpds(self) -> u8

Returns the value of the HPDS field.

pub const fn lsm(self) -> u8

Returns the value of the LSM field.

pub const fn ccidx(self) -> u8

Returns the value of the CCIDX field.

pub const fn evt(self) -> u8

Returns the value of the EVT field.