pub struct IdPfr0(/* private fields */);Expand description
ID_PFR0 system register value.
Implementations
Sourceimpl IdPfr0
impl IdPfr0
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl IdPfr0
impl IdPfr0
Sourcepub const fn iter(&self) -> Iter<IdPfr0>
pub const fn iter(&self) -> Iter<IdPfr0>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<IdPfr0>
pub const fn iter_names(&self) -> IterNames<IdPfr0>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl IdPfr0
impl IdPfr0
Sourcepub const STATE0_SHIFT: u32 = 0
pub const STATE0_SHIFT: u32 = 0
Offset of the State0 field.
Sourcepub const STATE0_MASK: u32 = 0b1111
pub const STATE0_MASK: u32 = 0b1111
Mask for the State0 field.
Sourcepub const STATE1_SHIFT: u32 = 4
pub const STATE1_SHIFT: u32 = 4
Offset of the State1 field.
Sourcepub const STATE1_MASK: u32 = 0b1111
pub const STATE1_MASK: u32 = 0b1111
Mask for the State1 field.
Sourcepub const STATE2_SHIFT: u32 = 8
pub const STATE2_SHIFT: u32 = 8
Offset of the State2 field.
Sourcepub const STATE2_MASK: u32 = 0b1111
pub const STATE2_MASK: u32 = 0b1111
Mask for the State2 field.
Sourcepub const STATE3_SHIFT: u32 = 12
pub const STATE3_SHIFT: u32 = 12
Offset of the State3 field.
Sourcepub const STATE3_MASK: u32 = 0b1111
pub const STATE3_MASK: u32 = 0b1111
Mask for the State3 field.
Sourcepub const CSV2_SHIFT: u32 = 16
pub const CSV2_SHIFT: u32 = 16
Offset of the CSV2 field.
Sourcepub const fn set_state0(&mut self, value: u8)
pub const fn set_state0(&mut self, value: u8)
Sets the value of the State0 field.
Sourcepub const fn with_state0(self, value: u8) -> Self
pub const fn with_state0(self, value: u8) -> Self
Returns a copy with the State0 field set to the given value.
Sourcepub const fn set_state1(&mut self, value: u8)
pub const fn set_state1(&mut self, value: u8)
Sets the value of the State1 field.
Sourcepub const fn with_state1(self, value: u8) -> Self
pub const fn with_state1(self, value: u8) -> Self
Returns a copy with the State1 field set to the given value.
Sourcepub const fn set_state2(&mut self, value: u8)
pub const fn set_state2(&mut self, value: u8)
Sets the value of the State2 field.
Sourcepub const fn with_state2(self, value: u8) -> Self
pub const fn with_state2(self, value: u8) -> Self
Returns a copy with the State2 field set to the given value.
Sourcepub const fn set_state3(&mut self, value: u8)
pub const fn set_state3(&mut self, value: u8)
Sets the value of the State3 field.
Sourcepub const fn with_state3(self, value: u8) -> Self
pub const fn with_state3(self, value: u8) -> Self
Returns a copy with the State3 field set to the given value.
Sourcepub const fn with_csv2(self, value: u8) -> Self
pub const fn with_csv2(self, value: u8) -> Self
Returns a copy with the CSV2 field set to the given value.
Sourcepub const fn with_amu(self, value: u8) -> Self
pub const fn with_amu(self, value: u8) -> Self
Returns a copy with the AMU field set to the given value.