pub struct IdPfr1(/* private fields */);Expand description
ID_PFR1 system register value.
Implementations
Sourceimpl IdPfr1
impl IdPfr1
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl IdPfr1
impl IdPfr1
Sourcepub const fn iter(&self) -> Iter<IdPfr1>
pub const fn iter(&self) -> Iter<IdPfr1>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<IdPfr1>
pub const fn iter_names(&self) -> IterNames<IdPfr1>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl IdPfr1
impl IdPfr1
Sourcepub const PROGMOD_SHIFT: u32 = 0
pub const PROGMOD_SHIFT: u32 = 0
Offset of the ProgMod field.
Sourcepub const PROGMOD_MASK: u32 = 0b1111
pub const PROGMOD_MASK: u32 = 0b1111
Mask for the ProgMod field.
Sourcepub const SECURITY_SHIFT: u32 = 4
pub const SECURITY_SHIFT: u32 = 4
Offset of the Security field.
Sourcepub const SECURITY_MASK: u32 = 0b1111
pub const SECURITY_MASK: u32 = 0b1111
Mask for the Security field.
Sourcepub const MPROGMOD_SHIFT: u32 = 8
pub const MPROGMOD_SHIFT: u32 = 8
Offset of the MProgMod field.
Sourcepub const MPROGMOD_MASK: u32 = 0b1111
pub const MPROGMOD_MASK: u32 = 0b1111
Mask for the MProgMod field.
Sourcepub const VIRTUALIZATION_SHIFT: u32 = 12
pub const VIRTUALIZATION_SHIFT: u32 = 12
Offset of the Virtualization field.
Sourcepub const VIRTUALIZATION_MASK: u32 = 0b1111
pub const VIRTUALIZATION_MASK: u32 = 0b1111
Mask for the Virtualization field.
Sourcepub const GENTIMER_SHIFT: u32 = 16
pub const GENTIMER_SHIFT: u32 = 16
Offset of the GenTimer field.
Sourcepub const GENTIMER_MASK: u32 = 0b1111
pub const GENTIMER_MASK: u32 = 0b1111
Mask for the GenTimer field.
Sourcepub const SEC_FRAC_SHIFT: u32 = 20
pub const SEC_FRAC_SHIFT: u32 = 20
Offset of the Sec_frac field.
Sourcepub const SEC_FRAC_MASK: u32 = 0b1111
pub const SEC_FRAC_MASK: u32 = 0b1111
Mask for the Sec_frac field.
Sourcepub const VIRT_FRAC_SHIFT: u32 = 24
pub const VIRT_FRAC_SHIFT: u32 = 24
Offset of the Virt_frac field.
Sourcepub const VIRT_FRAC_MASK: u32 = 0b1111
pub const VIRT_FRAC_MASK: u32 = 0b1111
Mask for the Virt_frac field.
Sourcepub const fn set_progmod(&mut self, value: u8)
pub const fn set_progmod(&mut self, value: u8)
Sets the value of the ProgMod field.
Sourcepub const fn with_progmod(self, value: u8) -> Self
pub const fn with_progmod(self, value: u8) -> Self
Returns a copy with the ProgMod field set to the given value.
Sourcepub const fn set_security(&mut self, value: u8)
pub const fn set_security(&mut self, value: u8)
Sets the value of the Security field.
Sourcepub const fn with_security(self, value: u8) -> Self
pub const fn with_security(self, value: u8) -> Self
Returns a copy with the Security field set to the given value.
Sourcepub const fn set_mprogmod(&mut self, value: u8)
pub const fn set_mprogmod(&mut self, value: u8)
Sets the value of the MProgMod field.
Sourcepub const fn with_mprogmod(self, value: u8) -> Self
pub const fn with_mprogmod(self, value: u8) -> Self
Returns a copy with the MProgMod field set to the given value.
Sourcepub const fn virtualization(self) -> u8
pub const fn virtualization(self) -> u8
Returns the value of the Virtualization field.
Sourcepub const fn set_virtualization(&mut self, value: u8)
pub const fn set_virtualization(&mut self, value: u8)
Sets the value of the Virtualization field.
Sourcepub const fn with_virtualization(self, value: u8) -> Self
pub const fn with_virtualization(self, value: u8) -> Self
Returns a copy with the Virtualization field set to the given value.
Sourcepub const fn set_gentimer(&mut self, value: u8)
pub const fn set_gentimer(&mut self, value: u8)
Sets the value of the GenTimer field.
Sourcepub const fn with_gentimer(self, value: u8) -> Self
pub const fn with_gentimer(self, value: u8) -> Self
Returns a copy with the GenTimer field set to the given value.
Sourcepub const fn set_sec_frac(&mut self, value: u8)
pub const fn set_sec_frac(&mut self, value: u8)
Sets the value of the Sec_frac field.
Sourcepub const fn with_sec_frac(self, value: u8) -> Self
pub const fn with_sec_frac(self, value: u8) -> Self
Returns a copy with the Sec_frac field set to the given value.
Sourcepub const fn set_virt_frac(&mut self, value: u8)
pub const fn set_virt_frac(&mut self, value: u8)
Sets the value of the Virt_frac field.
Sourcepub const fn with_virt_frac(self, value: u8) -> Self
pub const fn with_virt_frac(self, value: u8) -> Self
Returns a copy with the Virt_frac field set to the given value.