IdPfr2

Struct IdPfr2 

pub struct IdPfr2(/* private fields */);
ID_PFR2 system register value.

Implementations

Source

impl IdPfr2

pub const fn empty() -> Self

Get a flags value with all bits unset.

pub const fn all() -> Self

Get a flags value with all known bits set.

pub const fn bits(&self) -> u32

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u32) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u32) -> Self

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u32) -> Self

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in this flags value are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Self) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

pub const fn contains(&self, other: Self) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

pub fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in two flags values.

pub fn remove(&mut self, other: Self)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Self)

The bitwise exclusive-or (^) of the bits in two flags values.

pub fn set(&mut self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Self) -> Self

The bitwise and (&) of the bits in two flags values.

pub const fn union(self, other: Self) -> Self

The bitwise or (|) of the bits in two flags values.

pub const fn difference(self, other: Self) -> Self

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in two flags values.

pub const fn complement(self) -> Self

The bitwise negation (!) of the bits in a flags value, truncating the result.

Source

impl IdPfr2

pub const fn iter(&self) -> Iter<IdPfr2>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<IdPfr2>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.

Source

impl IdPfr2

pub const CSV3_SHIFT: u32 = 0

Offset of the CSV3 field.

pub const CSV3_MASK: u32 = 0b1111

Mask for the CSV3 field.

pub const SSBS_SHIFT: u32 = 4

Offset of the SSBS field.

pub const SSBS_MASK: u32 = 0b1111

Mask for the SSBS field.

pub const RAS_FRAC_SHIFT: u32 = 8

Offset of the RAS_frac field.

pub const RAS_FRAC_MASK: u32 = 0b1111

Mask for the RAS_frac field.

pub const fn csv3(self) -> u8

Returns the value of the CSV3 field.

pub const fn set_csv3(&mut self, value: u8)

Sets the value of the CSV3 field.

pub const fn with_csv3(self, value: u8) -> Self

Returns a copy with the CSV3 field set to the given value.

pub const fn ssbs(self) -> u8

Returns the value of the SSBS field.

pub const fn set_ssbs(&mut self, value: u8)

Sets the value of the SSBS field.

pub const fn with_ssbs(self, value: u8) -> Self

Returns a copy with the SSBS field set to the given value.

pub const fn ras_frac(self) -> u8

Returns the value of the RAS_frac field.

pub const fn set_ras_frac(&mut self, value: u8)

Sets the value of the RAS_frac field.

pub const fn with_ras_frac(self, value: u8) -> Self

Returns a copy with the RAS_frac field set to the given value.