MdcrEl2

Struct MdcrEl2 

pub struct MdcrEl2(/* private fields */);
MDCR_EL2 system register value.

Implementations

Source

impl MdcrEl2

pub const TPMCR: Self

TPMCR bit.

pub const TPM: Self

TPM bit.

pub const HPME: Self

HPME bit.

pub const TDE: Self

TDE bit.

pub const TDA: Self

TDA bit.

pub const TDOSA: Self

TDOSA bit.

pub const TDRA: Self

TDRA bit.

pub const TPMS: Self

TPMS bit.

pub const ENSPM: Self

EnSPM bit.

pub const HPMD: Self

HPMD bit.

pub const TTRF: Self

TTRF bit.

pub const HCCD: Self

HCCD bit.

pub const HLP: Self

HLP bit.

pub const TDCC: Self

TDCC bit.

pub const MTPME: Self

MTPME bit.

pub const HPMFZO: Self

HPMFZO bit.

pub const HPMFZS: Self

HPMFZS bit.

pub const EBWE: Self

EBWE bit.

pub const ENSTEPOP: Self

EnSTEPOP bit.

Source

impl MdcrEl2

pub const fn empty() -> Self

Get a flags value with all bits unset.

pub const fn all() -> Self

Get a flags value with all known bits set.

pub const fn bits(&self) -> u64

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u64) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u64) -> Self

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u64) -> Self

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in this flags value are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Self) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

pub const fn contains(&self, other: Self) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

pub fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in two flags values.

pub fn remove(&mut self, other: Self)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Self)

The bitwise exclusive-or (^) of the bits in two flags values.

pub fn set(&mut self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Self) -> Self

The bitwise and (&) of the bits in two flags values.

pub const fn union(self, other: Self) -> Self

The bitwise or (|) of the bits in two flags values.

pub const fn difference(self, other: Self) -> Self

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in two flags values.

pub const fn complement(self) -> Self

The bitwise negation (!) of the bits in a flags value, truncating the result.

Source

impl MdcrEl2

pub const fn iter(&self) -> Iter<MdcrEl2>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<MdcrEl2>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.

Source

impl MdcrEl2

pub const HPMN_SHIFT: u32 = 0

Available on crate feature el2 only.

Offset of the HPMN field.

pub const HPMN_MASK: u64 = 0b11111

Available on crate feature el2 only.

Mask for the HPMN field.

pub const TPMCR_SHIFT: u32 = 5

Available on crate feature el2 only.

Offset of the TPMCR field.

pub const TPM_SHIFT: u32 = 6

Available on crate feature el2 only.

Offset of the TPM field.

pub const HPME_SHIFT: u32 = 7

Available on crate feature el2 only.

Offset of the HPME field.

pub const TDE_SHIFT: u32 = 8

Available on crate feature el2 only.

Offset of the TDE field.

pub const TDA_SHIFT: u32 = 9

Available on crate feature el2 only.

Offset of the TDA field.

pub const TDOSA_SHIFT: u32 = 10

Available on crate feature el2 only.

Offset of the TDOSA field.

pub const TDRA_SHIFT: u32 = 11

Available on crate feature el2 only.

Offset of the TDRA field.

pub const E2PB_SHIFT: u32 = 12

Available on crate feature el2 only.

Offset of the E2PB field.

pub const E2PB_MASK: u64 = 0b11

Available on crate feature el2 only.

Mask for the E2PB field.

pub const TPMS_SHIFT: u32 = 14

Available on crate feature el2 only.

Offset of the TPMS field.

pub const ENSPM_SHIFT: u32 = 15

Available on crate feature el2 only.

Offset of the EnSPM field.

pub const HPMD_SHIFT: u32 = 17

Available on crate feature el2 only.

Offset of the HPMD field.

pub const TTRF_SHIFT: u32 = 19

Available on crate feature el2 only.

Offset of the TTRF field.

pub const HCCD_SHIFT: u32 = 23

Available on crate feature el2 only.

Offset of the HCCD field.

pub const E2TB_SHIFT: u32 = 24

Available on crate feature el2 only.

Offset of the E2TB field.

pub const E2TB_MASK: u64 = 0b11

Available on crate feature el2 only.

Mask for the E2TB field.

pub const HLP_SHIFT: u32 = 26

Available on crate feature el2 only.

Offset of the HLP field.

pub const TDCC_SHIFT: u32 = 27

Available on crate feature el2 only.

Offset of the TDCC field.

pub const MTPME_SHIFT: u32 = 28

Available on crate feature el2 only.

Offset of the MTPME field.

pub const HPMFZO_SHIFT: u32 = 29

Available on crate feature el2 only.

Offset of the HPMFZO field.

pub const PMSSE_SHIFT: u32 = 30

Available on crate feature el2 only.

Offset of the PMSSE field.

pub const PMSSE_MASK: u64 = 0b11

Available on crate feature el2 only.

Mask for the PMSSE field.

pub const HPMFZS_SHIFT: u32 = 36

Available on crate feature el2 only.

Offset of the HPMFZS field.

pub const PMEE_SHIFT: u32 = 40

Available on crate feature el2 only.

Offset of the PMEE field.

pub const PMEE_MASK: u64 = 0b11

Available on crate feature el2 only.

Mask for the PMEE field.

pub const EBWE_SHIFT: u32 = 43

Available on crate feature el2 only.

Offset of the EBWE field.

pub const ENSTEPOP_SHIFT: u32 = 50

Available on crate feature el2 only.

Offset of the EnSTEPOP field.

pub const fn hpmn(self) -> u8

Available on crate feature el2 only.

Returns the value of the HPMN field.

pub const fn set_hpmn(&mut self, value: u8)

Available on crate feature el2 only.

Sets the value of the HPMN field.

pub const fn with_hpmn(self, value: u8) -> Self

Available on crate feature el2 only.

Returns a copy with the HPMN field set to the given value.

pub const fn e2pb(self) -> u8

Available on crate feature el2 only.

Returns the value of the E2PB field.

pub const fn set_e2pb(&mut self, value: u8)

Available on crate feature el2 only.

Sets the value of the E2PB field.

pub const fn with_e2pb(self, value: u8) -> Self

Available on crate feature el2 only.

Returns a copy with the E2PB field set to the given value.

pub const fn e2tb(self) -> u8

Available on crate feature el2 only.

Returns the value of the E2TB field.

pub const fn set_e2tb(&mut self, value: u8)

Available on crate feature el2 only.

Sets the value of the E2TB field.

pub const fn with_e2tb(self, value: u8) -> Self

Available on crate feature el2 only.

Returns a copy with the E2TB field set to the given value.

pub const fn pmsse(self) -> u8

Available on crate feature el2 only.

Returns the value of the PMSSE field.

pub const fn set_pmsse(&mut self, value: u8)

Available on crate feature el2 only.

Sets the value of the PMSSE field.

pub const fn with_pmsse(self, value: u8) -> Self

Available on crate feature el2 only.

Returns a copy with the PMSSE field set to the given value.

pub const fn pmee(self) -> u8

Available on crate feature el2 only.

Returns the value of the PMEE field.

pub const fn set_pmee(&mut self, value: u8)

Available on crate feature el2 only.

Sets the value of the PMEE field.

pub const fn with_pmee(self, value: u8) -> Self

Available on crate feature el2 only.

Returns a copy with the PMEE field set to the given value.