MdcrEl3

Struct MdcrEl3 

pub struct MdcrEl3(/* private fields */);
MDCR_EL3 system register value.

Implementations

Source

impl MdcrEl3

pub const SPD32: Self

Available on crate feature el3 only.

Set to 0b10 to disable AArch32 Secure self-hosted privileged debug from S-EL1.

pub const NSPB_NS: Self

Available on crate feature el3 only.

Non-secure state owns the Profiling Buffer. Profiling is disabled in Secure and Realm states.

pub const NSTB_EN: Self

Available on crate feature el3 only.

Enable TRBE register access for the security state that owns the buffer.

pub const NSTB_SS: Self

Available on crate feature el3 only.

Together with MDCR_EL3.NSTBE determines which security state owns the trace buffer

Source

impl MdcrEl3

pub const RLTE: Self

Realm Trace enable. Enables tracing in Realm state.

pub const EPMADE: Self

EPMADE bit.

pub const ETADE: Self

ETADE bit.

pub const EDADE: Self

EDADE bit.

pub const TPM: Self

Trap Performance Monitor register accesses

pub const ENPM2: Self

Do not trap various PMUv3p9 related system register accesses to EL3.

pub const TDA: Self

TDA bit.

pub const TDOSA: Self

TDOSA bit.

pub const NSPBE: Self

Non-secure Profiling Buffer Extended. Together with MDCR_EL3.NSPB, controls the Profiling Buffer owning Security state and accesses to Statistical Profiling and Profiling Buffer System registers from EL2 and EL1.

pub const SDD: Self

Set to one to disable AArch64 Secure self-hosted debug. Debug exceptions, other than Breakpoint Instruction exceptions, are disabled from all ELs in Secure state.

pub const SPME: Self

Secure Performance Monitors Enable. Controls event counting in Secure state and EL3.

pub const STE: Self

Secure Trace enable. Enables tracing in Secure state.

pub const TTRF: Self

Trap Trace Filter controls. Traps use of the Trace Filter control registers at EL2 and EL1 to EL3.

pub const EDAD: Self

EDAD bit.

pub const EPMAD: Self

EPMAD bit.

pub const ETAD: Self

ETAD bit.

pub const SCCD: Self

Secure Cycle Counter Disable. Prohibits PMCCNTR_EL0 from counting in Secure state.

pub const NSTBE: Self

Non-secure Trace Buffer Extended. Together with MDCR_EL3.NSTB, controls the trace buffer owning Security state and accesses to trace buffer System registers from EL2 and EL1.

pub const TDCC: Self

TDCC bit.

pub const MTPME: Self

Multi-threaded PMU Enable. Enables use of the PMEVTYPER_EL0.MT bits.

pub const MCCD: Self

Monitor Cycle Counter Disable. Prohibits the Cycle Counter, PMCCNTR_EL0, from counting at EL3.

pub const MPMX: Self

Monitor Performance Monitors Extended control. In conjunction with MDCR_EL3.SPME, controls when event counters are enabled at EL3 and in other Secure Exception levels.

pub const ENPMSN: Self

Trap accesses to PMSNEVFR_EL1. Controls access to Statistical Profiling PMSNEVFR_EL1 System register from EL2 and EL1.

pub const E3BREW: Self

E3BREW bit.

pub const E3BREC: Self

E3BREC bit.

pub const ENTB2: Self

EnTB2 bit.

pub const ENPMS3: Self

Enable access to SPE registers. When disabled, accesses to SPE registers generate a trap to EL3.

pub const EBWE: Self

EBWE bit.

pub const ENPMSS: Self

EnPMSS bit.

pub const ENITE: Self

EnITE bit.

pub const ENSTEPOP: Self

EnSTEPOP bit.

pub const ENPMS4: Self

EnPMS4 bit.

Source

impl MdcrEl3

pub const fn empty() -> Self

Get a flags value with all bits unset.

pub const fn all() -> Self

Get a flags value with all known bits set.

pub const fn bits(&self) -> u64

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u64) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u64) -> Self

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u64) -> Self

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in this flags value are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Self) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

pub const fn contains(&self, other: Self) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

pub fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in two flags values.

pub fn remove(&mut self, other: Self)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Self)

The bitwise exclusive-or (^) of the bits in two flags values.

pub fn set(&mut self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Self) -> Self

The bitwise and (&) of the bits in two flags values.

pub const fn union(self, other: Self) -> Self

The bitwise or (|) of the bits in two flags values.

pub const fn difference(self, other: Self) -> Self

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in two flags values.

pub const fn complement(self) -> Self

The bitwise negation (!) of the bits in a flags value, truncating the result.

Source

impl MdcrEl3

pub const fn iter(&self) -> Iter<MdcrEl3>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<MdcrEl3>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.

Source

impl MdcrEl3

pub const RLTE_SHIFT: u32 = 0

Available on crate feature el3 only.

Offset of the RLTE field.

pub const EPMADE_SHIFT: u32 = 2

Available on crate feature el3 only.

Offset of the EPMADE field.

pub const ETADE_SHIFT: u32 = 3

Available on crate feature el3 only.

Offset of the ETADE field.

pub const EDADE_SHIFT: u32 = 4

Available on crate feature el3 only.

Offset of the EDADE field.

pub const TPM_SHIFT: u32 = 6

Available on crate feature el3 only.

Offset of the TPM field.

pub const ENPM2_SHIFT: u32 = 7

Available on crate feature el3 only.

Offset of the EnPM2 field.

pub const TDA_SHIFT: u32 = 9

Available on crate feature el3 only.

Offset of the TDA field.

pub const TDOSA_SHIFT: u32 = 10

Available on crate feature el3 only.

Offset of the TDOSA field.

pub const NSPBE_SHIFT: u32 = 11

Available on crate feature el3 only.

Offset of the NSPBE field.

pub const NSPB_SHIFT: u32 = 12

Available on crate feature el3 only.

Offset of the NSPB field.

pub const NSPB_MASK: u64 = 0b11

Available on crate feature el3 only.

Mask for the NSPB field.

pub const SPD32_SHIFT: u32 = 14

Available on crate feature el3 only.

Offset of the SPD32 field.

pub const SPD32_MASK: u64 = 0b11

Available on crate feature el3 only.

Mask for the SPD32 field.

pub const SDD_SHIFT: u32 = 16

Available on crate feature el3 only.

Offset of the SDD field.

pub const SPME_SHIFT: u32 = 17

Available on crate feature el3 only.

Offset of the SPME field.

pub const STE_SHIFT: u32 = 18

Available on crate feature el3 only.

Offset of the STE field.

pub const TTRF_SHIFT: u32 = 19

Available on crate feature el3 only.

Offset of the TTRF field.

pub const EDAD_SHIFT: u32 = 20

Available on crate feature el3 only.

Offset of the EDAD field.

pub const EPMAD_SHIFT: u32 = 21

Available on crate feature el3 only.

Offset of the EPMAD field.

pub const ETAD_SHIFT: u32 = 22

Available on crate feature el3 only.

Offset of the ETAD field.

pub const SCCD_SHIFT: u32 = 23

Available on crate feature el3 only.

Offset of the SCCD field.

pub const NSTB_SHIFT: u32 = 24

Available on crate feature el3 only.

Offset of the NSTB field.

pub const NSTB_MASK: u64 = 0b11

Available on crate feature el3 only.

Mask for the NSTB field.

pub const NSTBE_SHIFT: u32 = 26

Available on crate feature el3 only.

Offset of the NSTBE field.

pub const TDCC_SHIFT: u32 = 27

Available on crate feature el3 only.

Offset of the TDCC field.

pub const MTPME_SHIFT: u32 = 28

Available on crate feature el3 only.

Offset of the MTPME field.

pub const PMSSE_SHIFT: u32 = 30

Available on crate feature el3 only.

Offset of the PMSSE field.

pub const PMSSE_MASK: u64 = 0b11

Available on crate feature el3 only.

Mask for the PMSSE field.

pub const SBRBE_SHIFT: u32 = 32

Available on crate feature el3 only.

Offset of the SBRBE field.

pub const SBRBE_MASK: u64 = 0b11

Available on crate feature el3 only.

Mask for the SBRBE field.

pub const MCCD_SHIFT: u32 = 34

Available on crate feature el3 only.

Offset of the MCCD field.

pub const MPMX_SHIFT: u32 = 35

Available on crate feature el3 only.

Offset of the MPMX field.

pub const ENPMSN_SHIFT: u32 = 36

Available on crate feature el3 only.

Offset of the EnPMSN field.

pub const E3BREW_SHIFT: u32 = 37

Available on crate feature el3 only.

Offset of the E3BREW field.

pub const E3BREC_SHIFT: u32 = 38

Available on crate feature el3 only.

Offset of the E3BREC field.

pub const ENTB2_SHIFT: u32 = 39

Available on crate feature el3 only.

Offset of the EnTB2 field.

pub const PMEE_SHIFT: u32 = 40

Available on crate feature el3 only.

Offset of the PMEE field.

pub const PMEE_MASK: u64 = 0b11

Available on crate feature el3 only.

Mask for the PMEE field.

pub const ENPMS3_SHIFT: u32 = 42

Available on crate feature el3 only.

Offset of the EnPMS3 field.

pub const EBWE_SHIFT: u32 = 43

Available on crate feature el3 only.

Offset of the EBWE field.

pub const ENPMSS_SHIFT: u32 = 44

Available on crate feature el3 only.

Offset of the EnPMSS field.

pub const EPMSSAD_SHIFT: u32 = 45

Available on crate feature el3 only.

Offset of the EPMSSAD field.

pub const EPMSSAD_MASK: u64 = 0b11

Available on crate feature el3 only.

Mask for the EPMSSAD field.

pub const ENITE_SHIFT: u32 = 47

Available on crate feature el3 only.

Offset of the EnITE field.

pub const ETBAD_SHIFT: u32 = 48

Available on crate feature el3 only.

Offset of the ETBAD field.

pub const ETBAD_MASK: u64 = 0b11

Available on crate feature el3 only.

Mask for the ETBAD field.

pub const ENSTEPOP_SHIFT: u32 = 50

Available on crate feature el3 only.

Offset of the EnSTEPOP field.

pub const PMSEE_SHIFT: u32 = 51

Available on crate feature el3 only.

Offset of the PMSEE field.

pub const PMSEE_MASK: u64 = 0b11

Available on crate feature el3 only.

Mask for the PMSEE field.

pub const TRBEE_SHIFT: u32 = 53

Available on crate feature el3 only.

Offset of the TRBEE field.

pub const TRBEE_MASK: u64 = 0b11

Available on crate feature el3 only.

Mask for the TRBEE field.

pub const ENPMS4_SHIFT: u32 = 55

Available on crate feature el3 only.

Offset of the EnPMS4 field.

pub const fn nspb(self) -> u8

Available on crate feature el3 only.

Returns the value of the NSPB field.

pub const fn set_nspb(&mut self, value: u8)

Available on crate feature el3 only.

Sets the value of the NSPB field.

pub const fn with_nspb(self, value: u8) -> Self

Available on crate feature el3 only.

Returns a copy with the NSPB field set to the given value.

pub const fn spd32(self) -> u8

Available on crate feature el3 only.

Returns the value of the SPD32 field.

pub const fn set_spd32(&mut self, value: u8)

Available on crate feature el3 only.

Sets the value of the SPD32 field.

pub const fn with_spd32(self, value: u8) -> Self

Available on crate feature el3 only.

Returns a copy with the SPD32 field set to the given value.

pub const fn nstb(self) -> u8

Available on crate feature el3 only.

Returns the value of the NSTB field.

pub const fn set_nstb(&mut self, value: u8)

Available on crate feature el3 only.

Sets the value of the NSTB field.

pub const fn with_nstb(self, value: u8) -> Self

Available on crate feature el3 only.

Returns a copy with the NSTB field set to the given value.

pub const fn pmsse(self) -> u8

Available on crate feature el3 only.

Returns the value of the PMSSE field.

pub const fn set_pmsse(&mut self, value: u8)

Available on crate feature el3 only.

Sets the value of the PMSSE field.

pub const fn with_pmsse(self, value: u8) -> Self

Available on crate feature el3 only.

Returns a copy with the PMSSE field set to the given value.

pub const fn sbrbe(self) -> u8

Available on crate feature el3 only.

Returns the value of the SBRBE field.

pub const fn set_sbrbe(&mut self, value: u8)

Available on crate feature el3 only.

Sets the value of the SBRBE field.

pub const fn with_sbrbe(self, value: u8) -> Self

Available on crate feature el3 only.

Returns a copy with the SBRBE field set to the given value.

pub const fn pmee(self) -> u8

Available on crate feature el3 only.

Returns the value of the PMEE field.

pub const fn set_pmee(&mut self, value: u8)

Available on crate feature el3 only.

Sets the value of the PMEE field.

pub const fn with_pmee(self, value: u8) -> Self

Available on crate feature el3 only.

Returns a copy with the PMEE field set to the given value.

pub const fn epmssad(self) -> u8

Available on crate feature el3 only.

Returns the value of the EPMSSAD field.

pub const fn set_epmssad(&mut self, value: u8)

Available on crate feature el3 only.

Sets the value of the EPMSSAD field.

pub const fn with_epmssad(self, value: u8) -> Self

Available on crate feature el3 only.

Returns a copy with the EPMSSAD field set to the given value.

pub const fn etbad(self) -> u8

Available on crate feature el3 only.

Returns the value of the ETBAD field.

pub const fn set_etbad(&mut self, value: u8)

Available on crate feature el3 only.

Sets the value of the ETBAD field.

pub const fn with_etbad(self, value: u8) -> Self

Available on crate feature el3 only.

Returns a copy with the ETBAD field set to the given value.

pub const fn pmsee(self) -> u8

Available on crate feature el3 only.

Returns the value of the PMSEE field.

pub const fn set_pmsee(&mut self, value: u8)

Available on crate feature el3 only.

Sets the value of the PMSEE field.

pub const fn with_pmsee(self, value: u8) -> Self

Available on crate feature el3 only.

Returns a copy with the PMSEE field set to the given value.

pub const fn trbee(self) -> u8

Available on crate feature el3 only.

Returns the value of the TRBEE field.

pub const fn set_trbee(&mut self, value: u8)

Available on crate feature el3 only.

Sets the value of the TRBEE field.

pub const fn with_trbee(self, value: u8) -> Self

Available on crate feature el3 only.

Returns a copy with the TRBEE field set to the given value.