pub struct Midr(/* private fields */);Expand description
MIDR system register value.
Implementations
Sourceimpl Midr
impl Midr
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl Midr
impl Midr
Sourcepub const fn iter(&self) -> Iter<Midr>
pub const fn iter(&self) -> Iter<Midr>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<Midr>
pub const fn iter_names(&self) -> IterNames<Midr>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl Midr
impl Midr
Sourcepub const REVISION_SHIFT: u32 = 0
pub const REVISION_SHIFT: u32 = 0
Offset of the Revision field.
Sourcepub const REVISION_MASK: u32 = 0b1111
pub const REVISION_MASK: u32 = 0b1111
Mask for the Revision field.
Sourcepub const PARTNUM_SHIFT: u32 = 4
pub const PARTNUM_SHIFT: u32 = 4
Offset of the PartNum field.
Sourcepub const PARTNUM_MASK: u32 = 0b111111111111
pub const PARTNUM_MASK: u32 = 0b111111111111
Mask for the PartNum field.
Sourcepub const ARCHITECTURE_SHIFT: u32 = 16
pub const ARCHITECTURE_SHIFT: u32 = 16
Offset of the Architecture field.
Sourcepub const ARCHITECTURE_MASK: u32 = 0b1111
pub const ARCHITECTURE_MASK: u32 = 0b1111
Mask for the Architecture field.
Sourcepub const VARIANT_SHIFT: u32 = 20
pub const VARIANT_SHIFT: u32 = 20
Offset of the Variant field.
Sourcepub const VARIANT_MASK: u32 = 0b1111
pub const VARIANT_MASK: u32 = 0b1111
Mask for the Variant field.
Sourcepub const IMPLEMENTER_SHIFT: u32 = 24
pub const IMPLEMENTER_SHIFT: u32 = 24
Offset of the Implementer field.
Sourcepub const IMPLEMENTER_MASK: u32 = 0b11111111
pub const IMPLEMENTER_MASK: u32 = 0b11111111
Mask for the Implementer field.
Sourcepub const fn set_revision(&mut self, value: u8)
pub const fn set_revision(&mut self, value: u8)
Sets the value of the Revision field.
Sourcepub const fn with_revision(self, value: u8) -> Self
pub const fn with_revision(self, value: u8) -> Self
Returns a copy with the Revision field set to the given value.
Sourcepub const fn set_partnum(&mut self, value: u16)
pub const fn set_partnum(&mut self, value: u16)
Sets the value of the PartNum field.
Sourcepub const fn with_partnum(self, value: u16) -> Self
pub const fn with_partnum(self, value: u16) -> Self
Returns a copy with the PartNum field set to the given value.
Sourcepub const fn architecture(self) -> u8
pub const fn architecture(self) -> u8
Returns the value of the Architecture field.
Sourcepub const fn set_architecture(&mut self, value: u8)
pub const fn set_architecture(&mut self, value: u8)
Sets the value of the Architecture field.
Sourcepub const fn with_architecture(self, value: u8) -> Self
pub const fn with_architecture(self, value: u8) -> Self
Returns a copy with the Architecture field set to the given value.
Sourcepub const fn set_variant(&mut self, value: u8)
pub const fn set_variant(&mut self, value: u8)
Sets the value of the Variant field.
Sourcepub const fn with_variant(self, value: u8) -> Self
pub const fn with_variant(self, value: u8) -> Self
Returns a copy with the Variant field set to the given value.
Sourcepub const fn implementer(self) -> u8
pub const fn implementer(self) -> u8
Returns the value of the Implementer field.
Sourcepub const fn set_implementer(&mut self, value: u8)
pub const fn set_implementer(&mut self, value: u8)
Sets the value of the Implementer field.
Sourcepub const fn with_implementer(self, value: u8) -> Self
pub const fn with_implementer(self, value: u8) -> Self
Returns a copy with the Implementer field set to the given value.