MidrEl1

Struct MidrEl1 

pub struct MidrEl1(/* private fields */);
MIDR_EL1 system register value.

Implementations

Source

impl MidrEl1

pub const fn empty() -> Self

Get a flags value with all bits unset.

pub const fn all() -> Self

Get a flags value with all known bits set.

pub const fn bits(&self) -> u64

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u64) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u64) -> Self

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u64) -> Self

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in this flags value are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Self) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

pub const fn contains(&self, other: Self) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

pub fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in two flags values.

pub fn remove(&mut self, other: Self)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Self)

The bitwise exclusive-or (^) of the bits in two flags values.

pub fn set(&mut self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Self) -> Self

The bitwise and (&) of the bits in two flags values.

pub const fn union(self, other: Self) -> Self

The bitwise or (|) of the bits in two flags values.

pub const fn difference(self, other: Self) -> Self

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in two flags values.

pub const fn complement(self) -> Self

The bitwise negation (!) of the bits in a flags value, truncating the result.

Source

impl MidrEl1

pub const fn iter(&self) -> Iter<MidrEl1>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<MidrEl1>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.

Source

impl MidrEl1

pub const REVISION_SHIFT: u32 = 0

Available on crate feature el1 only.

Offset of the Revision field.

pub const REVISION_MASK: u64 = 0b1111

Available on crate feature el1 only.

Mask for the Revision field.

pub const PARTNUM_SHIFT: u32 = 4

Available on crate feature el1 only.

Offset of the PartNum field.

pub const PARTNUM_MASK: u64 = 0b111111111111

Available on crate feature el1 only.

Mask for the PartNum field.

pub const ARCHITECTURE_SHIFT: u32 = 16

Available on crate feature el1 only.

Offset of the Architecture field.

pub const ARCHITECTURE_MASK: u64 = 0b1111

Available on crate feature el1 only.

Mask for the Architecture field.

pub const VARIANT_SHIFT: u32 = 20

Available on crate feature el1 only.

Offset of the Variant field.

pub const VARIANT_MASK: u64 = 0b1111

Available on crate feature el1 only.

Mask for the Variant field.

pub const IMPLEMENTER_SHIFT: u32 = 24

Available on crate feature el1 only.

Offset of the Implementer field.

pub const IMPLEMENTER_MASK: u64 = 0b11111111

Available on crate feature el1 only.

Mask for the Implementer field.

pub const fn revision(self) -> u8

Available on crate feature el1 only.

Returns the value of the Revision field.

pub const fn set_revision(&mut self, value: u8)

Available on crate feature el1 only.

Sets the value of the Revision field.

pub const fn with_revision(self, value: u8) -> Self

Available on crate feature el1 only.

Returns a copy with the Revision field set to the given value.

pub const fn partnum(self) -> u16

Available on crate feature el1 only.

Returns the value of the PartNum field.

pub const fn set_partnum(&mut self, value: u16)

Available on crate feature el1 only.

Sets the value of the PartNum field.

pub const fn with_partnum(self, value: u16) -> Self

Available on crate feature el1 only.

Returns a copy with the PartNum field set to the given value.

pub const fn architecture(self) -> u8

Available on crate feature el1 only.

Returns the value of the Architecture field.

pub const fn set_architecture(&mut self, value: u8)

Available on crate feature el1 only.

Sets the value of the Architecture field.

pub const fn with_architecture(self, value: u8) -> Self

Available on crate feature el1 only.

Returns a copy with the Architecture field set to the given value.

pub const fn variant(self) -> u8

Available on crate feature el1 only.

Returns the value of the Variant field.

pub const fn set_variant(&mut self, value: u8)

Available on crate feature el1 only.

Sets the value of the Variant field.

pub const fn with_variant(self, value: u8) -> Self

Available on crate feature el1 only.

Returns a copy with the Variant field set to the given value.

pub const fn implementer(self) -> u8

Available on crate feature el1 only.

Returns the value of the Implementer field.

pub const fn set_implementer(&mut self, value: u8)

Available on crate feature el1 only.

Sets the value of the Implementer field.

pub const fn with_implementer(self, value: u8) -> Self

Available on crate feature el1 only.

Returns a copy with the Implementer field set to the given value.