pub struct Mpam2El2(/* private fields */);Expand description
MPAM2_EL2 system register value.
Implementations
Sourceimpl Mpam2El2
impl Mpam2El2
Sourcepub const TRAPMPAM1EL1: Self
pub const TRAPMPAM1EL1: Self
TRAPMPAM1EL1 bit.
Sourcepub const TRAPMPAM0EL1: Self
pub const TRAPMPAM0EL1: Self
TRAPMPAM0EL1 bit.
Sourcepub const ALTSP_FRCD: Self
pub const ALTSP_FRCD: Self
ALTSP_FRCD bit.
Sourceimpl Mpam2El2
impl Mpam2El2
Sourcepub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u64) -> Option<Self>
pub const fn from_bits(bits: u64) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u64) -> Self
pub const fn from_bits_truncate(bits: u64) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u64) -> Self
pub const fn from_bits_retain(bits: u64) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl Mpam2El2
impl Mpam2El2
Sourcepub const fn iter(&self) -> Iter<Mpam2El2>
pub const fn iter(&self) -> Iter<Mpam2El2>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<Mpam2El2>
pub const fn iter_names(&self) -> IterNames<Mpam2El2>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl Mpam2El2
impl Mpam2El2
Sourcepub const PARTID_SHIFT: u32 = 0
Available on crate feature el2 only.
pub const PARTID_SHIFT: u32 = 0
el2 only.Offset of the PARTID field.
Sourcepub const PARTID_MASK: u64 = 0b1111111111111111
Available on crate feature el2 only.
pub const PARTID_MASK: u64 = 0b1111111111111111
el2 only.Mask for the PARTID field.
Sourcepub const PARTID_I_SHIFT: u32 = 0
Available on crate feature el2 only.
pub const PARTID_I_SHIFT: u32 = 0
el2 only.Offset of the PARTID_I field.
Sourcepub const PARTID_I_MASK: u64 = 0b1111111111111111
Available on crate feature el2 only.
pub const PARTID_I_MASK: u64 = 0b1111111111111111
el2 only.Mask for the PARTID_I field.
Sourcepub const PARTID_D_SHIFT: u32 = 16
Available on crate feature el2 only.
pub const PARTID_D_SHIFT: u32 = 16
el2 only.Offset of the PARTID_D field.
Sourcepub const PARTID_D_MASK: u64 = 0b1111111111111111
Available on crate feature el2 only.
pub const PARTID_D_MASK: u64 = 0b1111111111111111
el2 only.Mask for the PARTID_D field.
Sourcepub const ALTPARTID_SHIFT: u32 = 16
Available on crate feature el2 only.
pub const ALTPARTID_SHIFT: u32 = 16
el2 only.Offset of the altPARTID field.
Sourcepub const ALTPARTID_MASK: u64 = 0b1111111111111111
Available on crate feature el2 only.
pub const ALTPARTID_MASK: u64 = 0b1111111111111111
el2 only.Mask for the altPARTID field.
Sourcepub const PMG_MASK: u64 = 0b1111111111111111
Available on crate feature el2 only.
pub const PMG_MASK: u64 = 0b1111111111111111
el2 only.Mask for the PMG field.
Sourcepub const PMG_I_SHIFT: u32 = 32
Available on crate feature el2 only.
pub const PMG_I_SHIFT: u32 = 32
el2 only.Offset of the PMG_I field.
Sourcepub const PMG_I_MASK: u64 = 0b11111111
Available on crate feature el2 only.
pub const PMG_I_MASK: u64 = 0b11111111
el2 only.Mask for the PMG_I field.
Sourcepub const PMG_D_SHIFT: u32 = 40
Available on crate feature el2 only.
pub const PMG_D_SHIFT: u32 = 40
el2 only.Offset of the PMG_D field.
Sourcepub const PMG_D_MASK: u64 = 0b11111111
Available on crate feature el2 only.
pub const PMG_D_MASK: u64 = 0b11111111
el2 only.Mask for the PMG_D field.
Sourcepub const TRAPMPAM1EL1_SHIFT: u32 = 48
Available on crate feature el2 only.
pub const TRAPMPAM1EL1_SHIFT: u32 = 48
el2 only.Offset of the TRAPMPAM1EL1 field.
Sourcepub const ALTPMG_SHIFT: u32 = 48
Available on crate feature el2 only.
pub const ALTPMG_SHIFT: u32 = 48
el2 only.Offset of the altPMG field.
Sourcepub const ALTPMG_MASK: u64 = 0b1111111111111111
Available on crate feature el2 only.
pub const ALTPMG_MASK: u64 = 0b1111111111111111
el2 only.Mask for the altPMG field.
Sourcepub const TRAPMPAM0EL1_SHIFT: u32 = 49
Available on crate feature el2 only.
pub const TRAPMPAM0EL1_SHIFT: u32 = 49
el2 only.Offset of the TRAPMPAM0EL1 field.
Sourcepub const ENMPAMSM_SHIFT: u32 = 50
Available on crate feature el2 only.
pub const ENMPAMSM_SHIFT: u32 = 50
el2 only.Offset of the EnMPAMSM field.
Sourcepub const ALTSP_FRCD_SHIFT: u32 = 54
Available on crate feature el2 only.
pub const ALTSP_FRCD_SHIFT: u32 = 54
el2 only.Offset of the ALTSP_FRCD field.
Sourcepub const ALTSP_EL2_SHIFT: u32 = 55
Available on crate feature el2 only.
pub const ALTSP_EL2_SHIFT: u32 = 55
el2 only.Offset of the ALTSP_EL2 field.
Sourcepub const ALTSP_HFC_SHIFT: u32 = 56
Available on crate feature el2 only.
pub const ALTSP_HFC_SHIFT: u32 = 56
el2 only.Offset of the ALTSP_HFC field.
Sourcepub const TIDR_SHIFT: u32 = 58
Available on crate feature el2 only.
pub const TIDR_SHIFT: u32 = 58
el2 only.Offset of the TIDR field.
Sourcepub const MPAMEN_SHIFT: u32 = 63
Available on crate feature el2 only.
pub const MPAMEN_SHIFT: u32 = 63
el2 only.Offset of the MPAMEN field.
Sourcepub const fn partid(self) -> u16
Available on crate feature el2 only.
pub const fn partid(self) -> u16
el2 only.Returns the value of the PARTID field.
Sourcepub const fn set_partid(&mut self, value: u16)
Available on crate feature el2 only.
pub const fn set_partid(&mut self, value: u16)
el2 only.Sets the value of the PARTID field.
Sourcepub const fn with_partid(self, value: u16) -> Self
Available on crate feature el2 only.
pub const fn with_partid(self, value: u16) -> Self
el2 only.Returns a copy with the PARTID field set to the given value.
Sourcepub const fn partid_i(self) -> u16
Available on crate feature el2 only.
pub const fn partid_i(self) -> u16
el2 only.Returns the value of the PARTID_I field.
Sourcepub const fn set_partid_i(&mut self, value: u16)
Available on crate feature el2 only.
pub const fn set_partid_i(&mut self, value: u16)
el2 only.Sets the value of the PARTID_I field.
Sourcepub const fn with_partid_i(self, value: u16) -> Self
Available on crate feature el2 only.
pub const fn with_partid_i(self, value: u16) -> Self
el2 only.Returns a copy with the PARTID_I field set to the given value.
Sourcepub const fn partid_d(self) -> u16
Available on crate feature el2 only.
pub const fn partid_d(self) -> u16
el2 only.Returns the value of the PARTID_D field.
Sourcepub const fn set_partid_d(&mut self, value: u16)
Available on crate feature el2 only.
pub const fn set_partid_d(&mut self, value: u16)
el2 only.Sets the value of the PARTID_D field.
Sourcepub const fn with_partid_d(self, value: u16) -> Self
Available on crate feature el2 only.
pub const fn with_partid_d(self, value: u16) -> Self
el2 only.Returns a copy with the PARTID_D field set to the given value.
Sourcepub const fn altpartid(self) -> u16
Available on crate feature el2 only.
pub const fn altpartid(self) -> u16
el2 only.Returns the value of the altPARTID field.
Sourcepub const fn set_altpartid(&mut self, value: u16)
Available on crate feature el2 only.
pub const fn set_altpartid(&mut self, value: u16)
el2 only.Sets the value of the altPARTID field.
Sourcepub const fn with_altpartid(self, value: u16) -> Self
Available on crate feature el2 only.
pub const fn with_altpartid(self, value: u16) -> Self
el2 only.Returns a copy with the altPARTID field set to the given value.
Sourcepub const fn pmg(self) -> u16
Available on crate feature el2 only.
pub const fn pmg(self) -> u16
el2 only.Returns the value of the PMG field.
Sourcepub const fn set_pmg(&mut self, value: u16)
Available on crate feature el2 only.
pub const fn set_pmg(&mut self, value: u16)
el2 only.Sets the value of the PMG field.
Sourcepub const fn with_pmg(self, value: u16) -> Self
Available on crate feature el2 only.
pub const fn with_pmg(self, value: u16) -> Self
el2 only.Returns a copy with the PMG field set to the given value.
Sourcepub const fn pmg_i(self) -> u8
Available on crate feature el2 only.
pub const fn pmg_i(self) -> u8
el2 only.Returns the value of the PMG_I field.
Sourcepub const fn set_pmg_i(&mut self, value: u8)
Available on crate feature el2 only.
pub const fn set_pmg_i(&mut self, value: u8)
el2 only.Sets the value of the PMG_I field.
Sourcepub const fn with_pmg_i(self, value: u8) -> Self
Available on crate feature el2 only.
pub const fn with_pmg_i(self, value: u8) -> Self
el2 only.Returns a copy with the PMG_I field set to the given value.
Sourcepub const fn pmg_d(self) -> u8
Available on crate feature el2 only.
pub const fn pmg_d(self) -> u8
el2 only.Returns the value of the PMG_D field.
Sourcepub const fn set_pmg_d(&mut self, value: u8)
Available on crate feature el2 only.
pub const fn set_pmg_d(&mut self, value: u8)
el2 only.Sets the value of the PMG_D field.
Sourcepub const fn with_pmg_d(self, value: u8) -> Self
Available on crate feature el2 only.
pub const fn with_pmg_d(self, value: u8) -> Self
el2 only.Returns a copy with the PMG_D field set to the given value.
Sourcepub const fn altpmg(self) -> u16
Available on crate feature el2 only.
pub const fn altpmg(self) -> u16
el2 only.Returns the value of the altPMG field.
Sourcepub const fn set_altpmg(&mut self, value: u16)
Available on crate feature el2 only.
pub const fn set_altpmg(&mut self, value: u16)
el2 only.Sets the value of the altPMG field.
Sourcepub const fn with_altpmg(self, value: u16) -> Self
Available on crate feature el2 only.
pub const fn with_altpmg(self, value: u16) -> Self
el2 only.Returns a copy with the altPMG field set to the given value.