Mpam3El3

Struct Mpam3El3 

pub struct Mpam3El3(/* private fields */);
MPAM3_EL3 system register value.

Holds information to generate MPAM labels for memory requests when executing at EL3.

Implementations

Source

impl Mpam3El3

pub const RT_ALTSP_NS: Self

RT_ALTSP_NS bit.

pub const ALTSP_EL3: Self

ALTSP_EL3 bit.

pub const ALTSP_HFC: Self

ALTSP_HFC bit.

pub const ALTSP_HEN: Self

ALTSP_HEN bit.

pub const FORCE_NS: Self

FORCE_NS bit.

pub const SDEFLT: Self

SDEFLT bit.

pub const TRAPLOWER: Self

Trap direct accesses to MPAM System registers that are not UNDEFINED from all ELn lower than EL3.

pub const MPAMEN: Self

MPAM Enable. If set, MPAM information is output based on the MPAMn_ELx register for ELn according the MPAM configuration. If not set, the default PARTID and default PMG are output in MPAM information when executing at any ELn.

Source

impl Mpam3El3

pub const fn empty() -> Self

Get a flags value with all bits unset.

pub const fn all() -> Self

Get a flags value with all known bits set.

pub const fn bits(&self) -> u64

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u64) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u64) -> Self

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u64) -> Self

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in this flags value are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Self) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

pub const fn contains(&self, other: Self) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

pub fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in two flags values.

pub fn remove(&mut self, other: Self)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Self)

The bitwise exclusive-or (^) of the bits in two flags values.

pub fn set(&mut self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Self) -> Self

The bitwise and (&) of the bits in two flags values.

pub const fn union(self, other: Self) -> Self

The bitwise or (|) of the bits in two flags values.

pub const fn difference(self, other: Self) -> Self

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in two flags values.

pub const fn complement(self) -> Self

The bitwise negation (!) of the bits in a flags value, truncating the result.

Source

impl Mpam3El3

pub const fn iter(&self) -> Iter<Mpam3El3>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<Mpam3El3>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.

Source

impl Mpam3El3

pub const PARTID_SHIFT: u32 = 0

Available on crate feature el3 only.

Offset of the PARTID field.

pub const PARTID_MASK: u64 = 0b1111111111111111

Available on crate feature el3 only.

Mask for the PARTID field.

pub const PARTID_I_SHIFT: u32 = 0

Available on crate feature el3 only.

Offset of the PARTID_I field.

pub const PARTID_I_MASK: u64 = 0b1111111111111111

Available on crate feature el3 only.

Mask for the PARTID_I field.

pub const PARTID_D_SHIFT: u32 = 16

Available on crate feature el3 only.

Offset of the PARTID_D field.

pub const PARTID_D_MASK: u64 = 0b1111111111111111

Available on crate feature el3 only.

Mask for the PARTID_D field.

pub const ALTPARTID_SHIFT: u32 = 16

Available on crate feature el3 only.

Offset of the altPARTID field.

pub const ALTPARTID_MASK: u64 = 0b1111111111111111

Available on crate feature el3 only.

Mask for the altPARTID field.

pub const PMG_SHIFT: u32 = 32

Available on crate feature el3 only.

Offset of the PMG field.

pub const PMG_MASK: u64 = 0b1111111111111111

Available on crate feature el3 only.

Mask for the PMG field.

pub const PMG_I_SHIFT: u32 = 32

Available on crate feature el3 only.

Offset of the PMG_I field.

pub const PMG_I_MASK: u64 = 0b11111111

Available on crate feature el3 only.

Mask for the PMG_I field.

pub const PMG_D_SHIFT: u32 = 40

Available on crate feature el3 only.

Offset of the PMG_D field.

pub const PMG_D_MASK: u64 = 0b11111111

Available on crate feature el3 only.

Mask for the PMG_D field.

pub const ALTPMG_SHIFT: u32 = 48

Available on crate feature el3 only.

Offset of the altPMG field.

pub const ALTPMG_MASK: u64 = 0b1111111111111111

Available on crate feature el3 only.

Mask for the altPMG field.

pub const RT_ALTSP_NS_SHIFT: u32 = 52

Available on crate feature el3 only.

Offset of the RT_ALTSP_NS field.

pub const ALTSP_EL3_SHIFT: u32 = 55

Available on crate feature el3 only.

Offset of the ALTSP_EL3 field.

pub const ALTSP_HFC_SHIFT: u32 = 56

Available on crate feature el3 only.

Offset of the ALTSP_HFC field.

pub const ALTSP_HEN_SHIFT: u32 = 57

Available on crate feature el3 only.

Offset of the ALTSP_HEN field.

pub const FORCE_NS_SHIFT: u32 = 60

Available on crate feature el3 only.

Offset of the FORCE_NS field.

pub const SDEFLT_SHIFT: u32 = 61

Available on crate feature el3 only.

Offset of the SDEFLT field.

pub const TRAPLOWER_SHIFT: u32 = 62

Available on crate feature el3 only.

Offset of the TRAPLOWER field.

pub const MPAMEN_SHIFT: u32 = 63

Available on crate feature el3 only.

Offset of the MPAMEN field.

pub const fn partid(self) -> u16

Available on crate feature el3 only.

Returns the value of the PARTID field.

pub const fn set_partid(&mut self, value: u16)

Available on crate feature el3 only.

Sets the value of the PARTID field.

pub const fn with_partid(self, value: u16) -> Self

Available on crate feature el3 only.

Returns a copy with the PARTID field set to the given value.

pub const fn partid_i(self) -> u16

Available on crate feature el3 only.

Returns the value of the PARTID_I field.

pub const fn set_partid_i(&mut self, value: u16)

Available on crate feature el3 only.

Sets the value of the PARTID_I field.

pub const fn with_partid_i(self, value: u16) -> Self

Available on crate feature el3 only.

Returns a copy with the PARTID_I field set to the given value.

pub const fn partid_d(self) -> u16

Available on crate feature el3 only.

Returns the value of the PARTID_D field.

pub const fn set_partid_d(&mut self, value: u16)

Available on crate feature el3 only.

Sets the value of the PARTID_D field.

pub const fn with_partid_d(self, value: u16) -> Self

Available on crate feature el3 only.

Returns a copy with the PARTID_D field set to the given value.

pub const fn altpartid(self) -> u16

Available on crate feature el3 only.

Returns the value of the altPARTID field.

pub const fn set_altpartid(&mut self, value: u16)

Available on crate feature el3 only.

Sets the value of the altPARTID field.

pub const fn with_altpartid(self, value: u16) -> Self

Available on crate feature el3 only.

Returns a copy with the altPARTID field set to the given value.

pub const fn pmg(self) -> u16

Available on crate feature el3 only.

Returns the value of the PMG field.

pub const fn set_pmg(&mut self, value: u16)

Available on crate feature el3 only.

Sets the value of the PMG field.

pub const fn with_pmg(self, value: u16) -> Self

Available on crate feature el3 only.

Returns a copy with the PMG field set to the given value.

pub const fn pmg_i(self) -> u8

Available on crate feature el3 only.

Returns the value of the PMG_I field.

pub const fn set_pmg_i(&mut self, value: u8)

Available on crate feature el3 only.

Sets the value of the PMG_I field.

pub const fn with_pmg_i(self, value: u8) -> Self

Available on crate feature el3 only.

Returns a copy with the PMG_I field set to the given value.

pub const fn pmg_d(self) -> u8

Available on crate feature el3 only.

Returns the value of the PMG_D field.

pub const fn set_pmg_d(&mut self, value: u8)

Available on crate feature el3 only.

Sets the value of the PMG_D field.

pub const fn with_pmg_d(self, value: u8) -> Self

Available on crate feature el3 only.

Returns a copy with the PMG_D field set to the given value.

pub const fn altpmg(self) -> u16

Available on crate feature el3 only.

Returns the value of the altPMG field.

pub const fn set_altpmg(&mut self, value: u16)

Available on crate feature el3 only.

Sets the value of the altPMG field.

pub const fn with_altpmg(self, value: u16) -> Self

Available on crate feature el3 only.

Returns a copy with the altPMG field set to the given value.