pub struct Par(/* private fields */);Expand description
PAR system register value.
Implementations
Sourceimpl Par
impl Par
Sourcepub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u64) -> Option<Self>
pub const fn from_bits(bits: u64) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u64) -> Self
pub const fn from_bits_truncate(bits: u64) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u64) -> Self
pub const fn from_bits_retain(bits: u64) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl Par
impl Par
Sourcepub const fn iter(&self) -> Iter<Par>
pub const fn iter(&self) -> Iter<Par>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<Par>
pub const fn iter_names(&self) -> IterNames<Par>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl Par
impl Par
Sourcepub const FS_4_0_SHIFT: u32 = 1
pub const FS_4_0_SHIFT: u32 = 1
Offset of the FS[4:0] field.
Sourcepub const FS_4_0_MASK: u64 = 0b11111
pub const FS_4_0_MASK: u64 = 0b11111
Mask for the FS[4:0] field.
Sourcepub const OUTER_1_0_SHIFT: u32 = 2
pub const OUTER_1_0_SHIFT: u32 = 2
Offset of the Outer[1:0] field.
Sourcepub const OUTER_1_0_MASK: u64 = 0b11
pub const OUTER_1_0_MASK: u64 = 0b11
Mask for the Outer[1:0] field.
Sourcepub const INNER_2_0_SHIFT: u32 = 4
pub const INNER_2_0_SHIFT: u32 = 4
Offset of the Inner[2:0] field.
Sourcepub const INNER_2_0_MASK: u64 = 0b111
pub const INNER_2_0_MASK: u64 = 0b111
Mask for the Inner[2:0] field.
Sourcepub const FS_5_SHIFT: u32 = 6
pub const FS_5_SHIFT: u32 = 6
Offset of the FS[5] field.
Sourcepub const S2WLK_SHIFT: u32 = 8
pub const S2WLK_SHIFT: u32 = 8
Offset of the S2WLK field.
Sourcepub const FSTAGE_SHIFT: u32 = 9
pub const FSTAGE_SHIFT: u32 = 9
Offset of the FSTAGE field.
Sourcepub const LPAE_SHIFT: u32 = 11
pub const LPAE_SHIFT: u32 = 11
Offset of the LPAE field.
Sourcepub const ATTR_SHIFT: u32 = 56
pub const ATTR_SHIFT: u32 = 56
Offset of the ATTR field.
Sourcepub const fn with_fst(self, value: u8) -> Self
pub const fn with_fst(self, value: u8) -> Self
Returns a copy with the FST field set to the given value.
Sourcepub const fn set_fs_4_0(&mut self, value: u8)
pub const fn set_fs_4_0(&mut self, value: u8)
Sets the value of the FS[4:0] field.
Sourcepub const fn with_fs_4_0(self, value: u8) -> Self
pub const fn with_fs_4_0(self, value: u8) -> Self
Returns a copy with the FS[4:0] field set to the given value.
Sourcepub const fn set_outer_1_0(&mut self, value: u8)
pub const fn set_outer_1_0(&mut self, value: u8)
Sets the value of the Outer[1:0] field.
Sourcepub const fn with_outer_1_0(self, value: u8) -> Self
pub const fn with_outer_1_0(self, value: u8) -> Self
Returns a copy with the Outer[1:0] field set to the given value.
Sourcepub const fn set_inner_2_0(&mut self, value: u8)
pub const fn set_inner_2_0(&mut self, value: u8)
Sets the value of the Inner[2:0] field.
Sourcepub const fn with_inner_2_0(self, value: u8) -> Self
pub const fn with_inner_2_0(self, value: u8) -> Self
Returns a copy with the Inner[2:0] field set to the given value.