ParEl1

Struct ParEl1 

pub struct ParEl1(/* private fields */);
PAR_EL1 system register value.

Implementations

Source

impl ParEl1

pub const RES1: Self

RES1 bits in the PAR_EL1 register.

pub const F: Self

F bit.

pub const PTW: Self

PTW bit.

pub const NS: Self

NS bit.

pub const S: Self

S bit.

pub const NSE: Self

NSE bit.

pub const ASSUREDONLY: Self

AssuredOnly bit.

pub const TOPLEVEL: Self

TopLevel bit.

pub const OVERLAY: Self

Overlay bit.

pub const DIRTYBIT: Self

DirtyBit bit.

Source

impl ParEl1

pub const fn empty() -> Self

Get a flags value with all bits unset.

pub const fn all() -> Self

Get a flags value with all known bits set.

pub const fn bits(&self) -> u64

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u64) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u64) -> Self

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u64) -> Self

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in this flags value are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Self) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

pub const fn contains(&self, other: Self) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

pub fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in two flags values.

pub fn remove(&mut self, other: Self)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Self)

The bitwise exclusive-or (^) of the bits in two flags values.

pub fn set(&mut self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Self) -> Self

The bitwise and (&) of the bits in two flags values.

pub const fn union(self, other: Self) -> Self

The bitwise or (|) of the bits in two flags values.

pub const fn difference(self, other: Self) -> Self

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in two flags values.

pub const fn complement(self) -> Self

The bitwise negation (!) of the bits in a flags value, truncating the result.

Source

impl ParEl1

pub const fn iter(&self) -> Iter<ParEl1>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<ParEl1>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.

Source

impl ParEl1

pub const F_SHIFT: u32 = 0

Available on crate feature el1 only.

Offset of the F field.

pub const FST_SHIFT: u32 = 1

Available on crate feature el1 only.

Offset of the FST field.

pub const FST_MASK: u64 = 0b111111

Available on crate feature el1 only.

Mask for the FST field.

pub const SH_SHIFT: u32 = 7

Available on crate feature el1 only.

Offset of the SH field.

pub const SH_MASK: u64 = 0b11

Available on crate feature el1 only.

Mask for the SH field.

pub const PTW_SHIFT: u32 = 8

Available on crate feature el1 only.

Offset of the PTW field.

pub const NS_SHIFT: u32 = 9

Available on crate feature el1 only.

Offset of the NS field.

pub const S_SHIFT: u32 = 9

Available on crate feature el1 only.

Offset of the S field.

pub const NSE_SHIFT: u32 = 11

Available on crate feature el1 only.

Offset of the NSE field.

pub const ASSUREDONLY_SHIFT: u32 = 12

Available on crate feature el1 only.

Offset of the AssuredOnly field.

pub const PA_47_12_SHIFT: u32 = 12

Available on crate feature el1 only.

Offset of the PA[47:12] field.

pub const PA_47_12_MASK: u64 = 0b111111111111111111111111111111111111

Available on crate feature el1 only.

Mask for the PA[47:12] field.

pub const TOPLEVEL_SHIFT: u32 = 13

Available on crate feature el1 only.

Offset of the TopLevel field.

pub const OVERLAY_SHIFT: u32 = 14

Available on crate feature el1 only.

Offset of the Overlay field.

pub const DIRTYBIT_SHIFT: u32 = 15

Available on crate feature el1 only.

Offset of the DirtyBit field.

pub const PA_51_48_SHIFT: u32 = 48

Available on crate feature el1 only.

Offset of the PA[51:48] field.

pub const PA_51_48_MASK: u64 = 0b1111

Available on crate feature el1 only.

Mask for the PA[51:48] field.

pub const ATTR_SHIFT: u32 = 56

Available on crate feature el1 only.

Offset of the ATTR field.

pub const ATTR_MASK: u64 = 0b11111111

Available on crate feature el1 only.

Mask for the ATTR field.

pub const fn fst(self) -> u8

Available on crate feature el1 only.

Returns the value of the FST field.

pub const fn set_fst(&mut self, value: u8)

Available on crate feature el1 only.

Sets the value of the FST field.

pub const fn with_fst(self, value: u8) -> Self

Available on crate feature el1 only.

Returns a copy with the FST field set to the given value.

pub const fn sh(self) -> u8

Available on crate feature el1 only.

Returns the value of the SH field.

pub const fn set_sh(&mut self, value: u8)

Available on crate feature el1 only.

Sets the value of the SH field.

pub const fn with_sh(self, value: u8) -> Self

Available on crate feature el1 only.

Returns a copy with the SH field set to the given value.

pub const fn pa_47_12(self) -> u64

Available on crate feature el1 only.

Returns the value of the PA[47:12] field.

pub const fn set_pa_47_12(&mut self, value: u64)

Available on crate feature el1 only.

Sets the value of the PA[47:12] field.

pub const fn with_pa_47_12(self, value: u64) -> Self

Available on crate feature el1 only.

Returns a copy with the PA[47:12] field set to the given value.

pub const fn pa_51_48(self) -> u8

Available on crate feature el1 only.

Returns the value of the PA[51:48] field.

pub const fn set_pa_51_48(&mut self, value: u8)

Available on crate feature el1 only.

Sets the value of the PA[51:48] field.

pub const fn with_pa_51_48(self, value: u8) -> Self

Available on crate feature el1 only.

Returns a copy with the PA[51:48] field set to the given value.

pub const fn attr(self) -> u8

Available on crate feature el1 only.

Returns the value of the ATTR field.

pub const fn set_attr(&mut self, value: u8)

Available on crate feature el1 only.

Sets the value of the ATTR field.

pub const fn with_attr(self, value: u8) -> Self

Available on crate feature el1 only.

Returns a copy with the ATTR field set to the given value.