Pmceid1

Struct Pmceid1 

pub struct Pmceid1(/* private fields */);
PMCEID1 system register value.

Implementations

Source

impl Pmceid1

pub const ID0: Self

ID<n> bit 0.

pub const ID1: Self

ID<n> bit 1.

pub const ID2: Self

ID<n> bit 2.

pub const ID3: Self

ID<n> bit 3.

pub const ID4: Self

ID<n> bit 4.

pub const ID5: Self

ID<n> bit 5.

pub const ID6: Self

ID<n> bit 6.

pub const ID7: Self

ID<n> bit 7.

pub const ID8: Self

ID<n> bit 8.

pub const ID9: Self

ID<n> bit 9.

pub const ID10: Self

ID<n> bit 10.

pub const ID11: Self

ID<n> bit 11.

pub const ID12: Self

ID<n> bit 12.

pub const ID13: Self

ID<n> bit 13.

pub const ID14: Self

ID<n> bit 14.

pub const ID15: Self

ID<n> bit 15.

pub const ID16: Self

ID<n> bit 16.

pub const ID17: Self

ID<n> bit 17.

pub const ID18: Self

ID<n> bit 18.

pub const ID19: Self

ID<n> bit 19.

pub const ID20: Self

ID<n> bit 20.

pub const ID21: Self

ID<n> bit 21.

pub const ID22: Self

ID<n> bit 22.

pub const ID23: Self

ID<n> bit 23.

pub const ID24: Self

ID<n> bit 24.

pub const ID25: Self

ID<n> bit 25.

pub const ID26: Self

ID<n> bit 26.

pub const ID27: Self

ID<n> bit 27.

pub const ID28: Self

ID<n> bit 28.

pub const ID29: Self

ID<n> bit 29.

pub const ID30: Self

ID<n> bit 30.

pub const ID31: Self

ID<n> bit 31.

Source

impl Pmceid1

pub const fn empty() -> Self

Get a flags value with all bits unset.

pub const fn all() -> Self

Get a flags value with all known bits set.

pub const fn bits(&self) -> u32

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u32) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u32) -> Self

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u32) -> Self

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in this flags value are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Self) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

pub const fn contains(&self, other: Self) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

pub fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in two flags values.

pub fn remove(&mut self, other: Self)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Self)

The bitwise exclusive-or (^) of the bits in two flags values.

pub fn set(&mut self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Self) -> Self

The bitwise and (&) of the bits in two flags values.

pub const fn union(self, other: Self) -> Self

The bitwise or (|) of the bits in two flags values.

pub const fn difference(self, other: Self) -> Self

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in two flags values.

pub const fn complement(self) -> Self

The bitwise negation (!) of the bits in a flags value, truncating the result.

Source

impl Pmceid1

pub const fn iter(&self) -> Iter<Pmceid1>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<Pmceid1>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.

Source

impl Pmceid1

pub const ID_SHIFT: u32 = 0

Offset of the ID<n> field.