Pmcntenset

Struct Pmcntenset 

pub struct Pmcntenset(/* private fields */);
PMCNTENSET system register value.

Implementations

Source

impl Pmcntenset

pub const P0: Self

P<m> bit 0.

pub const P1: Self

P<m> bit 1.

pub const P2: Self

P<m> bit 2.

pub const P3: Self

P<m> bit 3.

pub const P4: Self

P<m> bit 4.

pub const P5: Self

P<m> bit 5.

pub const P6: Self

P<m> bit 6.

pub const P7: Self

P<m> bit 7.

pub const P8: Self

P<m> bit 8.

pub const P9: Self

P<m> bit 9.

pub const P10: Self

P<m> bit 10.

pub const P11: Self

P<m> bit 11.

pub const P12: Self

P<m> bit 12.

pub const P13: Self

P<m> bit 13.

pub const P14: Self

P<m> bit 14.

pub const P15: Self

P<m> bit 15.

pub const P16: Self

P<m> bit 16.

pub const P17: Self

P<m> bit 17.

pub const P18: Self

P<m> bit 18.

pub const P19: Self

P<m> bit 19.

pub const P20: Self

P<m> bit 20.

pub const P21: Self

P<m> bit 21.

pub const P22: Self

P<m> bit 22.

pub const P23: Self

P<m> bit 23.

pub const P24: Self

P<m> bit 24.

pub const P25: Self

P<m> bit 25.

pub const P26: Self

P<m> bit 26.

pub const P27: Self

P<m> bit 27.

pub const P28: Self

P<m> bit 28.

pub const P29: Self

P<m> bit 29.

pub const P30: Self

P<m> bit 30.

pub const C: Self

C bit.

Source

impl Pmcntenset

pub const fn empty() -> Self

Get a flags value with all bits unset.

pub const fn all() -> Self

Get a flags value with all known bits set.

pub const fn bits(&self) -> u32

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u32) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u32) -> Self

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u32) -> Self

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in this flags value are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Self) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

pub const fn contains(&self, other: Self) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

pub fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in two flags values.

pub fn remove(&mut self, other: Self)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Self)

The bitwise exclusive-or (^) of the bits in two flags values.

pub fn set(&mut self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Self) -> Self

The bitwise and (&) of the bits in two flags values.

pub const fn union(self, other: Self) -> Self

The bitwise or (|) of the bits in two flags values.

pub const fn difference(self, other: Self) -> Self

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in two flags values.

pub const fn complement(self) -> Self

The bitwise negation (!) of the bits in a flags value, truncating the result.

Source

impl Pmcntenset

pub const fn iter(&self) -> Iter<Pmcntenset>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<Pmcntenset>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.

Source

impl Pmcntenset

pub const P_SHIFT: u32 = 0

Offset of the P<m> field.

pub const C_SHIFT: u32 = 31

Offset of the C field.