PmcrEl0

Struct PmcrEl0 

pub struct PmcrEl0(/* private fields */);
PMCR_EL0 system register value.

Implementations

Source

impl PmcrEl0

pub const E: Self

Enable. Affected counters are enabled by PMCNTENSET_EL0.

pub const P: Self

Event counter reset. Reset all affected event counters PMEVCNTR_EL0 to zero.

pub const C: Self

Cycle counter reset. Reset PMCCNTR_EL0 to zero.

pub const D: Self

Clock divider. If set PMCCNTR_EL0 counts once every 64 clock cycles.

pub const X: Self

Enable export of events in an IMPLEMENTATION DEFINED PMU event export bus. If set, export events where not prohibited.

pub const DP: Self

If set, cycle counting by PMCCNTR_EL0 is disabled in prohibited regions.

pub const LC: Self

LC bit.

pub const LP: Self

LP bit.

pub const FZO: Self

FZO bit.

pub const FZS: Self

FZS bit.

Source

impl PmcrEl0

pub const fn empty() -> Self

Get a flags value with all bits unset.

pub const fn all() -> Self

Get a flags value with all known bits set.

pub const fn bits(&self) -> u64

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u64) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u64) -> Self

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u64) -> Self

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in this flags value are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Self) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

pub const fn contains(&self, other: Self) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

pub fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in two flags values.

pub fn remove(&mut self, other: Self)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Self)

The bitwise exclusive-or (^) of the bits in two flags values.

pub fn set(&mut self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Self) -> Self

The bitwise and (&) of the bits in two flags values.

pub const fn union(self, other: Self) -> Self

The bitwise or (|) of the bits in two flags values.

pub const fn difference(self, other: Self) -> Self

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in two flags values.

pub const fn complement(self) -> Self

The bitwise negation (!) of the bits in a flags value, truncating the result.

Source

impl PmcrEl0

pub const fn iter(&self) -> Iter<PmcrEl0>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<PmcrEl0>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.

Source

impl PmcrEl0

pub const E_SHIFT: u32 = 0

Offset of the E field.

pub const P_SHIFT: u32 = 1

Offset of the P field.

pub const C_SHIFT: u32 = 2

Offset of the C field.

pub const D_SHIFT: u32 = 3

Offset of the D field.

pub const X_SHIFT: u32 = 4

Offset of the X field.

pub const DP_SHIFT: u32 = 5

Offset of the DP field.

pub const LC_SHIFT: u32 = 6

Offset of the LC field.

pub const LP_SHIFT: u32 = 7

Offset of the LP field.

pub const FZO_SHIFT: u32 = 9

Offset of the FZO field.

pub const N_SHIFT: u32 = 11

Offset of the N field.

pub const N_MASK: u64 = 0b11111

Mask for the N field.

pub const IDCODE_SHIFT: u32 = 16

Offset of the IDCODE field.

pub const IDCODE_MASK: u64 = 0b11111111

Mask for the IDCODE field.

pub const IMP_SHIFT: u32 = 24

Offset of the IMP field.

pub const IMP_MASK: u64 = 0b11111111

Mask for the IMP field.

pub const FZS_SHIFT: u32 = 32

Offset of the FZS field.

pub const fn n(self) -> u8

Returns the value of the N field.

pub const fn set_n(&mut self, value: u8)

Sets the value of the N field.

pub const fn with_n(self, value: u8) -> Self

Returns a copy with the N field set to the given value.

pub const fn idcode(self) -> u8

Returns the value of the IDCODE field.

pub const fn set_idcode(&mut self, value: u8)

Sets the value of the IDCODE field.

pub const fn with_idcode(self, value: u8) -> Self

Returns a copy with the IDCODE field set to the given value.

pub const fn imp(self) -> u8

Returns the value of the IMP field.

pub const fn set_imp(&mut self, value: u8)

Sets the value of the IMP field.

pub const fn with_imp(self, value: u8) -> Self

Returns a copy with the IMP field set to the given value.