pub struct Pmmir(/* private fields */);Expand description
PMMIR system register value.
Implementations
Sourceimpl Pmmir
impl Pmmir
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl Pmmir
impl Pmmir
Sourcepub const fn iter(&self) -> Iter<Pmmir>
pub const fn iter(&self) -> Iter<Pmmir>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<Pmmir>
pub const fn iter_names(&self) -> IterNames<Pmmir>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl Pmmir
impl Pmmir
Sourcepub const SLOTS_SHIFT: u32 = 0
pub const SLOTS_SHIFT: u32 = 0
Offset of the SLOTS field.
Sourcepub const SLOTS_MASK: u32 = 0b11111111
pub const SLOTS_MASK: u32 = 0b11111111
Mask for the SLOTS field.
Sourcepub const BUS_SLOTS_SHIFT: u32 = 8
pub const BUS_SLOTS_SHIFT: u32 = 8
Offset of the BUS_SLOTS field.
Sourcepub const BUS_SLOTS_MASK: u32 = 0b11111111
pub const BUS_SLOTS_MASK: u32 = 0b11111111
Mask for the BUS_SLOTS field.
Sourcepub const BUS_WIDTH_SHIFT: u32 = 16
pub const BUS_WIDTH_SHIFT: u32 = 16
Offset of the BUS_WIDTH field.
Sourcepub const BUS_WIDTH_MASK: u32 = 0b1111
pub const BUS_WIDTH_MASK: u32 = 0b1111
Mask for the BUS_WIDTH field.
Sourcepub const THWIDTH_SHIFT: u32 = 20
pub const THWIDTH_SHIFT: u32 = 20
Offset of the THWIDTH field.
Sourcepub const THWIDTH_MASK: u32 = 0b1111
pub const THWIDTH_MASK: u32 = 0b1111
Mask for the THWIDTH field.
Sourcepub const EDGE_SHIFT: u32 = 24
pub const EDGE_SHIFT: u32 = 24
Offset of the EDGE field.
Sourcepub const fn with_slots(self, value: u8) -> Self
pub const fn with_slots(self, value: u8) -> Self
Returns a copy with the SLOTS field set to the given value.
Sourcepub const fn set_bus_slots(&mut self, value: u8)
pub const fn set_bus_slots(&mut self, value: u8)
Sets the value of the BUS_SLOTS field.
Sourcepub const fn with_bus_slots(self, value: u8) -> Self
pub const fn with_bus_slots(self, value: u8) -> Self
Returns a copy with the BUS_SLOTS field set to the given value.
Sourcepub const fn set_bus_width(&mut self, value: u8)
pub const fn set_bus_width(&mut self, value: u8)
Sets the value of the BUS_WIDTH field.
Sourcepub const fn with_bus_width(self, value: u8) -> Self
pub const fn with_bus_width(self, value: u8) -> Self
Returns a copy with the BUS_WIDTH field set to the given value.
Sourcepub const fn set_thwidth(&mut self, value: u8)
pub const fn set_thwidth(&mut self, value: u8)
Sets the value of the THWIDTH field.
Sourcepub const fn with_thwidth(self, value: u8) -> Self
pub const fn with_thwidth(self, value: u8) -> Self
Returns a copy with the THWIDTH field set to the given value.