SctlrEl2

Struct SctlrEl2 

pub struct SctlrEl2(/* private fields */);
SCTLR_EL2 system register value.

Implementations

Source

impl SctlrEl2

pub const M: Self

M bit.

pub const A: Self

A bit.

pub const C: Self

C bit.

pub const SA: Self

SA bit.

pub const SA0: Self

SA0 bit.

pub const CP15BEN: Self

CP15BEN bit.

pub const NAA: Self

nAA bit.

pub const SED: Self

SED bit.

pub const UMA: Self

UMA bit.

pub const ENRCTX: Self

EnRCTX bit.

pub const EOS: Self

EOS bit.

pub const I: Self

I bit.

pub const ENDB: Self

EnDB bit.

pub const DZE: Self

DZE bit.

pub const UCT: Self

UCT bit.

pub const NTWI: Self

nTWI bit.

pub const NTWE: Self

nTWE bit.

pub const WXN: Self

WXN bit.

pub const IESB: Self

IESB bit.

pub const EIS: Self

EIS bit.

pub const SPAN: Self

Do not set Privileged Access Never, on taking an exception to EL2.

pub const UCI: Self

UCI bit.

pub const ENDA: Self

EnDA bit.

pub const NTLSMD: Self

nTLSMD bit.

pub const LSMAOE: Self

LSMAOE bit.

pub const ENIB: Self

Enable pointer authentication using APIBKey_EL1.

pub const ENIA: Self

Enable pointer authentication using APIAKey_EL1.

pub const CMOW: Self

CMOW bit.

pub const MSCEN: Self

MSCEn bit.

pub const ENFPM: Self

EnFPM bit.

pub const BT0: Self

BT0 bit.

pub const BT: Self

BT bit.

pub const ITFSB: Self

ITFSB bit.

pub const ATA0: Self

ATA0 bit.

pub const ATA: Self

ATA bit.

pub const DSSBS: Self

Default PSTATE.SSBS value on Exception Entry.

pub const TWEDEN: Self

TWEDEn bit.

pub const ENASR: Self

EnASR bit.

pub const ENAS0: Self

EnAS0 bit.

pub const ENALS: Self

EnALS bit.

pub const EPAN: Self

EPAN bit.

pub const TCSO0: Self

TCSO0 bit.

pub const TCSO: Self

TCSO bit.

pub const ENTP2: Self

EnTP2 bit.

pub const NMI: Self

NMI bit.

pub const SPINTMASK: Self

SP Interrupt Mask enable.

pub const TIDCP: Self

TIDCP bit.

Source

impl SctlrEl2

pub const fn empty() -> Self

Get a flags value with all bits unset.

pub const fn all() -> Self

Get a flags value with all known bits set.

pub const fn bits(&self) -> u64

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u64) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u64) -> Self

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u64) -> Self

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in this flags value are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Self) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

pub const fn contains(&self, other: Self) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

pub fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in two flags values.

pub fn remove(&mut self, other: Self)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Self)

The bitwise exclusive-or (^) of the bits in two flags values.

pub fn set(&mut self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Self) -> Self

The bitwise and (&) of the bits in two flags values.

pub const fn union(self, other: Self) -> Self

The bitwise or (|) of the bits in two flags values.

pub const fn difference(self, other: Self) -> Self

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in two flags values.

pub const fn complement(self) -> Self

The bitwise negation (!) of the bits in a flags value, truncating the result.

Source

impl SctlrEl2

pub const fn iter(&self) -> Iter<SctlrEl2>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<SctlrEl2>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.

Source

impl SctlrEl2

pub const M_SHIFT: u32 = 0

Available on crate feature el2 only.

Offset of the M field.

pub const A_SHIFT: u32 = 1

Available on crate feature el2 only.

Offset of the A field.

pub const C_SHIFT: u32 = 2

Available on crate feature el2 only.

Offset of the C field.

pub const SA_SHIFT: u32 = 3

Available on crate feature el2 only.

Offset of the SA field.

pub const SA0_SHIFT: u32 = 4

Available on crate feature el2 only.

Offset of the SA0 field.

pub const CP15BEN_SHIFT: u32 = 5

Available on crate feature el2 only.

Offset of the CP15BEN field.

pub const NAA_SHIFT: u32 = 6

Available on crate feature el2 only.

Offset of the nAA field.

pub const SED_SHIFT: u32 = 8

Available on crate feature el2 only.

Offset of the SED field.

pub const UMA_SHIFT: u32 = 9

Available on crate feature el2 only.

Offset of the UMA field.

pub const ENRCTX_SHIFT: u32 = 10

Available on crate feature el2 only.

Offset of the EnRCTX field.

pub const EOS_SHIFT: u32 = 11

Available on crate feature el2 only.

Offset of the EOS field.

pub const I_SHIFT: u32 = 12

Available on crate feature el2 only.

Offset of the I field.

pub const ENDB_SHIFT: u32 = 13

Available on crate feature el2 only.

Offset of the EnDB field.

pub const DZE_SHIFT: u32 = 14

Available on crate feature el2 only.

Offset of the DZE field.

pub const UCT_SHIFT: u32 = 15

Available on crate feature el2 only.

Offset of the UCT field.

pub const NTWI_SHIFT: u32 = 16

Available on crate feature el2 only.

Offset of the nTWI field.

pub const NTWE_SHIFT: u32 = 18

Available on crate feature el2 only.

Offset of the nTWE field.

pub const WXN_SHIFT: u32 = 19

Available on crate feature el2 only.

Offset of the WXN field.

pub const IESB_SHIFT: u32 = 21

Available on crate feature el2 only.

Offset of the IESB field.

pub const EIS_SHIFT: u32 = 22

Available on crate feature el2 only.

Offset of the EIS field.

pub const SPAN_SHIFT: u32 = 23

Available on crate feature el2 only.

Offset of the SPAN field.

pub const UCI_SHIFT: u32 = 26

Available on crate feature el2 only.

Offset of the UCI field.

pub const ENDA_SHIFT: u32 = 27

Available on crate feature el2 only.

Offset of the EnDA field.

pub const NTLSMD_SHIFT: u32 = 28

Available on crate feature el2 only.

Offset of the nTLSMD field.

pub const LSMAOE_SHIFT: u32 = 29

Available on crate feature el2 only.

Offset of the LSMAOE field.

pub const ENIB_SHIFT: u32 = 30

Available on crate feature el2 only.

Offset of the EnIB field.

pub const ENIA_SHIFT: u32 = 31

Available on crate feature el2 only.

Offset of the EnIA field.

pub const CMOW_SHIFT: u32 = 32

Available on crate feature el2 only.

Offset of the CMOW field.

pub const MSCEN_SHIFT: u32 = 33

Available on crate feature el2 only.

Offset of the MSCEn field.

pub const ENFPM_SHIFT: u32 = 34

Available on crate feature el2 only.

Offset of the EnFPM field.

pub const BT0_SHIFT: u32 = 35

Available on crate feature el2 only.

Offset of the BT0 field.

pub const BT_SHIFT: u32 = 36

Available on crate feature el2 only.

Offset of the BT field.

pub const ITFSB_SHIFT: u32 = 37

Available on crate feature el2 only.

Offset of the ITFSB field.

pub const TCF0_SHIFT: u32 = 38

Available on crate feature el2 only.

Offset of the TCF0 field.

pub const TCF0_MASK: u64 = 0b11

Available on crate feature el2 only.

Mask for the TCF0 field.

pub const TCF_SHIFT: u32 = 40

Available on crate feature el2 only.

Offset of the TCF field.

pub const TCF_MASK: u64 = 0b11

Available on crate feature el2 only.

Mask for the TCF field.

pub const ATA0_SHIFT: u32 = 42

Available on crate feature el2 only.

Offset of the ATA0 field.

pub const ATA_SHIFT: u32 = 43

Available on crate feature el2 only.

Offset of the ATA field.

pub const DSSBS_SHIFT: u32 = 44

Available on crate feature el2 only.

Offset of the DSSBS field.

pub const TWEDEN_SHIFT: u32 = 45

Available on crate feature el2 only.

Offset of the TWEDEn field.

pub const TWEDEL_SHIFT: u32 = 46

Available on crate feature el2 only.

Offset of the TWEDEL field.

pub const TWEDEL_MASK: u64 = 0b1111

Available on crate feature el2 only.

Mask for the TWEDEL field.

pub const ENASR_SHIFT: u32 = 54

Available on crate feature el2 only.

Offset of the EnASR field.

pub const ENAS0_SHIFT: u32 = 55

Available on crate feature el2 only.

Offset of the EnAS0 field.

pub const ENALS_SHIFT: u32 = 56

Available on crate feature el2 only.

Offset of the EnALS field.

pub const EPAN_SHIFT: u32 = 57

Available on crate feature el2 only.

Offset of the EPAN field.

pub const TCSO0_SHIFT: u32 = 58

Available on crate feature el2 only.

Offset of the TCSO0 field.

pub const TCSO_SHIFT: u32 = 59

Available on crate feature el2 only.

Offset of the TCSO field.

pub const ENTP2_SHIFT: u32 = 60

Available on crate feature el2 only.

Offset of the EnTP2 field.

pub const NMI_SHIFT: u32 = 61

Available on crate feature el2 only.

Offset of the NMI field.

pub const SPINTMASK_SHIFT: u32 = 62

Available on crate feature el2 only.

Offset of the SPINTMASK field.

pub const TIDCP_SHIFT: u32 = 63

Available on crate feature el2 only.

Offset of the TIDCP field.

pub const fn tcf0(self) -> u8

Available on crate feature el2 only.

Returns the value of the TCF0 field.

pub const fn set_tcf0(&mut self, value: u8)

Available on crate feature el2 only.

Sets the value of the TCF0 field.

pub const fn with_tcf0(self, value: u8) -> Self

Available on crate feature el2 only.

Returns a copy with the TCF0 field set to the given value.

pub const fn tcf(self) -> u8

Available on crate feature el2 only.

Returns the value of the TCF field.

pub const fn set_tcf(&mut self, value: u8)

Available on crate feature el2 only.

Sets the value of the TCF field.

pub const fn with_tcf(self, value: u8) -> Self

Available on crate feature el2 only.

Returns a copy with the TCF field set to the given value.

pub const fn twedel(self) -> u8

Available on crate feature el2 only.

Returns the value of the TWEDEL field.

pub const fn set_twedel(&mut self, value: u8)

Available on crate feature el2 only.

Sets the value of the TWEDEL field.

pub const fn with_twedel(self, value: u8) -> Self

Available on crate feature el2 only.

Returns a copy with the TWEDEL field set to the given value.