SpsrEl3

Struct SpsrEl3 

pub struct SpsrEl3(/* private fields */);
SPSR_EL3 system register value.

Implementations

Source

impl SpsrEl3

pub const M_AARCH64_EL0: Self

Available on crate feature el3 only.

AArch64 execution state, EL0.

pub const M_AARCH64_EL1T: Self

Available on crate feature el3 only.

AArch64 execution state, EL1 with SP_EL0.

pub const M_AARCH64_EL1H: Self

Available on crate feature el3 only.

AArch64 execution state, EL1 with SP_EL1.

pub const M_AARCH64_EL2T: Self

Available on crate feature el3 only.

AArch64 execution state, EL2 with SP_EL0.

pub const M_AARCH64_EL2H: Self

Available on crate feature el3 only.

AArch64 execution state, EL2 with SP_EL2.

pub const M_AARCH64_EL3T: Self

Available on crate feature el3 only.

AArch64 execution state, EL3 with SP_EL0.

pub const M_AARCH64_EL3H: Self

Available on crate feature el3 only.

AArch64 execution state, EL3 with SP_EL3.

pub const SP_EL0: Self

Available on crate feature el3 only.

Exception was taken with PSTATE.SP set to SP_EL0.

pub const SP_ELX: Self

Available on crate feature el3 only.

Exception was taken with PSTATE.SP set to SP_ELx.

pub const NZCV: Self

Available on crate feature el3 only.

All of the N, Z, C and V bits.

pub const SSBS: Self

Available on crate feature el3 only.

Speculative Store Bypass Safe.

pub const fn exception_level(self) -> ExceptionLevel

Available on crate feature el3 only.

Returns the value of the EL field.

pub const fn stack_pointer(self) -> StackPointer

Available on crate feature el3 only.

Returns the value of the SP field.

Source

impl SpsrEl3

pub const M_4: Self

M[4] bit.

pub const T: Self

T bit.

pub const F: Self

F bit.

pub const I: Self

I bit.

pub const A: Self

A bit.

pub const D: Self

D bit.

pub const E: Self

E bit.

pub const ALLINT: Self

ALLINT bit.

pub const BTYPE2: Self

BTYPE2 bit.

pub const IL: Self

IL bit.

pub const SS: Self

SS bit.

pub const PAN: Self

PAN bit.

pub const UAO: Self

UAO bit.

pub const DIT: Self

DIT bit.

pub const TCO: Self

TCO bit.

pub const Q: Self

Q bit.

pub const V: Self

V bit.

pub const C: Self

C bit.

pub const Z: Self

Z bit.

pub const N: Self

N bit.

pub const PM: Self

PM bit.

pub const PPEND: Self

PPEND bit.

pub const EXLOCK: Self

EXLOCK bit.

pub const PACM: Self

PACM bit.

pub const UINJ: Self

UINJ bit.

Source

impl SpsrEl3

pub const fn empty() -> Self

Get a flags value with all bits unset.

pub const fn all() -> Self

Get a flags value with all known bits set.

pub const fn bits(&self) -> u64

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u64) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u64) -> Self

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u64) -> Self

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in this flags value are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Self) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

pub const fn contains(&self, other: Self) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

pub fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in two flags values.

pub fn remove(&mut self, other: Self)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Self)

The bitwise exclusive-or (^) of the bits in two flags values.

pub fn set(&mut self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Self) -> Self

The bitwise and (&) of the bits in two flags values.

pub const fn union(self, other: Self) -> Self

The bitwise or (|) of the bits in two flags values.

pub const fn difference(self, other: Self) -> Self

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in two flags values.

pub const fn complement(self) -> Self

The bitwise negation (!) of the bits in a flags value, truncating the result.

Source

impl SpsrEl3

pub const fn iter(&self) -> Iter<SpsrEl3>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<SpsrEl3>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.

Source

impl SpsrEl3

pub const M_3_0_SHIFT: u32 = 0

Available on crate feature el3 only.

Offset of the M[3:0] field.

pub const M_3_0_MASK: u64 = 0b1111

Available on crate feature el3 only.

Mask for the M[3:0] field.

pub const M_4_SHIFT: u32 = 4

Available on crate feature el3 only.

Offset of the M[4] field.

pub const T_SHIFT: u32 = 5

Available on crate feature el3 only.

Offset of the T field.

pub const F_SHIFT: u32 = 6

Available on crate feature el3 only.

Offset of the F field.

pub const I_SHIFT: u32 = 7

Available on crate feature el3 only.

Offset of the I field.

pub const A_SHIFT: u32 = 8

Available on crate feature el3 only.

Offset of the A field.

pub const D_SHIFT: u32 = 9

Available on crate feature el3 only.

Offset of the D field.

pub const E_SHIFT: u32 = 9

Available on crate feature el3 only.

Offset of the E field.

pub const BTYPE_SHIFT: u32 = 10

Available on crate feature el3 only.

Offset of the BTYPE field.

pub const BTYPE_MASK: u64 = 0b11

Available on crate feature el3 only.

Mask for the BTYPE field.

pub const ALLINT_SHIFT: u32 = 13

Available on crate feature el3 only.

Offset of the ALLINT field.

pub const BTYPE2_SHIFT: u32 = 14

Available on crate feature el3 only.

Offset of the BTYPE2 field.

pub const GE_SHIFT: u32 = 16

Available on crate feature el3 only.

Offset of the GE field.

pub const GE_MASK: u64 = 0b1111

Available on crate feature el3 only.

Mask for the GE field.

pub const IL_SHIFT: u32 = 20

Available on crate feature el3 only.

Offset of the IL field.

pub const SS_SHIFT: u32 = 21

Available on crate feature el3 only.

Offset of the SS field.

pub const PAN_SHIFT: u32 = 22

Available on crate feature el3 only.

Offset of the PAN field.

pub const UAO_SHIFT: u32 = 23

Available on crate feature el3 only.

Offset of the UAO field.

pub const DIT_SHIFT: u32 = 24

Available on crate feature el3 only.

Offset of the DIT field.

pub const TCO_SHIFT: u32 = 25

Available on crate feature el3 only.

Offset of the TCO field.

pub const Q_SHIFT: u32 = 27

Available on crate feature el3 only.

Offset of the Q field.

pub const V_SHIFT: u32 = 28

Available on crate feature el3 only.

Offset of the V field.

pub const C_SHIFT: u32 = 29

Available on crate feature el3 only.

Offset of the C field.

pub const Z_SHIFT: u32 = 30

Available on crate feature el3 only.

Offset of the Z field.

pub const N_SHIFT: u32 = 31

Available on crate feature el3 only.

Offset of the N field.

pub const PM_SHIFT: u32 = 32

Available on crate feature el3 only.

Offset of the PM field.

pub const PPEND_SHIFT: u32 = 33

Available on crate feature el3 only.

Offset of the PPEND field.

pub const EXLOCK_SHIFT: u32 = 34

Available on crate feature el3 only.

Offset of the EXLOCK field.

pub const PACM_SHIFT: u32 = 35

Available on crate feature el3 only.

Offset of the PACM field.

pub const UINJ_SHIFT: u32 = 36

Available on crate feature el3 only.

Offset of the UINJ field.

pub const fn m_3_0(self) -> u8

Available on crate feature el3 only.

Returns the value of the M[3:0] field.

pub const fn set_m_3_0(&mut self, value: u8)

Available on crate feature el3 only.

Sets the value of the M[3:0] field.

pub const fn with_m_3_0(self, value: u8) -> Self

Available on crate feature el3 only.

Returns a copy with the M[3:0] field set to the given value.

pub const fn btype(self) -> u8

Available on crate feature el3 only.

Returns the value of the BTYPE field.

pub const fn set_btype(&mut self, value: u8)

Available on crate feature el3 only.

Sets the value of the BTYPE field.

pub const fn with_btype(self, value: u8) -> Self

Available on crate feature el3 only.

Returns a copy with the BTYPE field set to the given value.

pub const fn ge(self) -> u8

Available on crate feature el3 only.

Returns the value of the GE field.

pub const fn set_ge(&mut self, value: u8)

Available on crate feature el3 only.

Sets the value of the GE field.

pub const fn with_ge(self, value: u8) -> Self

Available on crate feature el3 only.

Returns a copy with the GE field set to the given value.