pub struct Tcr2El1(/* private fields */);Expand description
TCR2_EL1 system register value.
Implementations
Sourceimpl Tcr2El1
impl Tcr2El1
Sourcepub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u64) -> Option<Self>
pub const fn from_bits(bits: u64) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u64) -> Self
pub const fn from_bits_truncate(bits: u64) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u64) -> Self
pub const fn from_bits_retain(bits: u64) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl Tcr2El1
impl Tcr2El1
Sourcepub const fn iter(&self) -> Iter<Tcr2El1>
pub const fn iter(&self) -> Iter<Tcr2El1>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<Tcr2El1>
pub const fn iter_names(&self) -> IterNames<Tcr2El1>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl Tcr2El1
impl Tcr2El1
Sourcepub const PNCH_SHIFT: u32 = 0
Available on crate feature el1 only.
pub const PNCH_SHIFT: u32 = 0
el1 only.Offset of the PnCH field.
Sourcepub const E0POE_SHIFT: u32 = 2
Available on crate feature el1 only.
pub const E0POE_SHIFT: u32 = 2
el1 only.Offset of the E0POE field.
Sourcepub const D128_SHIFT: u32 = 5
Available on crate feature el1 only.
pub const D128_SHIFT: u32 = 5
el1 only.Offset of the D128 field.
Sourcepub const PTTWI_SHIFT: u32 = 10
Available on crate feature el1 only.
pub const PTTWI_SHIFT: u32 = 10
el1 only.Offset of the PTTWI field.
Sourcepub const HAFT_SHIFT: u32 = 11
Available on crate feature el1 only.
pub const HAFT_SHIFT: u32 = 11
el1 only.Offset of the HAFT field.
Sourcepub const DISCH0_SHIFT: u32 = 14
Available on crate feature el1 only.
pub const DISCH0_SHIFT: u32 = 14
el1 only.Offset of the DisCH0 field.
Sourcepub const DISCH1_SHIFT: u32 = 15
Available on crate feature el1 only.
pub const DISCH1_SHIFT: u32 = 15
el1 only.Offset of the DisCH1 field.
Sourcepub const FNG0_SHIFT: u32 = 17
Available on crate feature el1 only.
pub const FNG0_SHIFT: u32 = 17
el1 only.Offset of the FNG0 field.
Sourcepub const FNG1_SHIFT: u32 = 18
Available on crate feature el1 only.
pub const FNG1_SHIFT: u32 = 18
el1 only.Offset of the FNG1 field.
Sourcepub const POE2F_SHIFT: u32 = 19
Available on crate feature el1 only.
pub const POE2F_SHIFT: u32 = 19
el1 only.Offset of the POE2F field.
Sourcepub const FNGNA0_SHIFT: u32 = 20
Available on crate feature el1 only.
pub const FNGNA0_SHIFT: u32 = 20
el1 only.Offset of the FNGNA0 field.
Sourcepub const FNGNA1_SHIFT: u32 = 21
Available on crate feature el1 only.
pub const FNGNA1_SHIFT: u32 = 21
el1 only.Offset of the FNGNA1 field.
Sourcepub const POIW_SHIFT: u32 = 22
Available on crate feature el1 only.
pub const POIW_SHIFT: u32 = 22
el1 only.Offset of the POIW field.
Sourcepub const VTB0_SHIFT: u32 = 25
Available on crate feature el1 only.
pub const VTB0_SHIFT: u32 = 25
el1 only.Offset of the VTB0 field.
Sourcepub const VTB0_MASK: u64 = 0b11111
Available on crate feature el1 only.
pub const VTB0_MASK: u64 = 0b11111
el1 only.Mask for the VTB0 field.
Sourcepub const VTB1_SHIFT: u32 = 30
Available on crate feature el1 only.
pub const VTB1_SHIFT: u32 = 30
el1 only.Offset of the VTB1 field.
Sourcepub const VTB1_MASK: u64 = 0b11111
Available on crate feature el1 only.
pub const VTB1_MASK: u64 = 0b11111
el1 only.Mask for the VTB1 field.
Sourcepub const TVAD0_SHIFT: u32 = 35
Available on crate feature el1 only.
pub const TVAD0_SHIFT: u32 = 35
el1 only.Offset of the TVAD0 field.
Sourcepub const TVAD1_SHIFT: u32 = 36
Available on crate feature el1 only.
pub const TVAD1_SHIFT: u32 = 36
el1 only.Offset of the TVAD1 field.
Sourcepub const fn poiw(self) -> u8
Available on crate feature el1 only.
pub const fn poiw(self) -> u8
el1 only.Returns the value of the POIW field.
Sourcepub const fn set_poiw(&mut self, value: u8)
Available on crate feature el1 only.
pub const fn set_poiw(&mut self, value: u8)
el1 only.Sets the value of the POIW field.
Sourcepub const fn with_poiw(self, value: u8) -> Self
Available on crate feature el1 only.
pub const fn with_poiw(self, value: u8) -> Self
el1 only.Returns a copy with the POIW field set to the given value.
Sourcepub const fn vtb0(self) -> u8
Available on crate feature el1 only.
pub const fn vtb0(self) -> u8
el1 only.Returns the value of the VTB0 field.
Sourcepub const fn set_vtb0(&mut self, value: u8)
Available on crate feature el1 only.
pub const fn set_vtb0(&mut self, value: u8)
el1 only.Sets the value of the VTB0 field.
Sourcepub const fn with_vtb0(self, value: u8) -> Self
Available on crate feature el1 only.
pub const fn with_vtb0(self, value: u8) -> Self
el1 only.Returns a copy with the VTB0 field set to the given value.
Sourcepub const fn vtb1(self) -> u8
Available on crate feature el1 only.
pub const fn vtb1(self) -> u8
el1 only.Returns the value of the VTB1 field.