Tcr2El2

Struct Tcr2El2 

pub struct Tcr2El2(/* private fields */);
TCR2_EL2 system register value.

Implementations

Source

impl Tcr2El2

pub const PNCH: Self

PnCH bit.

pub const PIE: Self

PIE bit.

pub const E0POE: Self

E0POE bit.

pub const POE: Self

POE bit.

pub const AIE: Self

AIE bit.

pub const D128: Self

D128 bit.

pub const PTTWI: Self

PTTWI bit.

pub const HAFT: Self

HAFT bit.

pub const AMEC0: Self

AMEC0 bit.

pub const AMEC1: Self

AMEC1 bit.

pub const DISCH0: Self

DisCH0 bit.

pub const DISCH1: Self

DisCH1 bit.

pub const A2: Self

A2 bit.

pub const FNG0: Self

FNG0 bit.

pub const FNG1: Self

FNG1 bit.

pub const POE2F: Self

POE2F bit.

pub const TVAD0: Self

TVAD0 bit.

pub const TVAD1: Self

TVAD1 bit.

Source

impl Tcr2El2

pub const fn empty() -> Self

Get a flags value with all bits unset.

pub const fn all() -> Self

Get a flags value with all known bits set.

pub const fn bits(&self) -> u64

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u64) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u64) -> Self

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u64) -> Self

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in this flags value are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Self) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

pub const fn contains(&self, other: Self) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

pub fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in two flags values.

pub fn remove(&mut self, other: Self)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Self)

The bitwise exclusive-or (^) of the bits in two flags values.

pub fn set(&mut self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Self) -> Self

The bitwise and (&) of the bits in two flags values.

pub const fn union(self, other: Self) -> Self

The bitwise or (|) of the bits in two flags values.

pub const fn difference(self, other: Self) -> Self

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in two flags values.

pub const fn complement(self) -> Self

The bitwise negation (!) of the bits in a flags value, truncating the result.

Source

impl Tcr2El2

pub const fn iter(&self) -> Iter<Tcr2El2>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<Tcr2El2>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.

Source

impl Tcr2El2

pub const PNCH_SHIFT: u32 = 0

Available on crate feature el2 only.

Offset of the PnCH field.

pub const PIE_SHIFT: u32 = 1

Available on crate feature el2 only.

Offset of the PIE field.

pub const E0POE_SHIFT: u32 = 2

Available on crate feature el2 only.

Offset of the E0POE field.

pub const POE_SHIFT: u32 = 3

Available on crate feature el2 only.

Offset of the POE field.

pub const AIE_SHIFT: u32 = 4

Available on crate feature el2 only.

Offset of the AIE field.

pub const D128_SHIFT: u32 = 5

Available on crate feature el2 only.

Offset of the D128 field.

pub const PTTWI_SHIFT: u32 = 10

Available on crate feature el2 only.

Offset of the PTTWI field.

pub const HAFT_SHIFT: u32 = 11

Available on crate feature el2 only.

Offset of the HAFT field.

pub const AMEC0_SHIFT: u32 = 12

Available on crate feature el2 only.

Offset of the AMEC0 field.

pub const AMEC1_SHIFT: u32 = 13

Available on crate feature el2 only.

Offset of the AMEC1 field.

pub const DISCH0_SHIFT: u32 = 14

Available on crate feature el2 only.

Offset of the DisCH0 field.

pub const DISCH1_SHIFT: u32 = 15

Available on crate feature el2 only.

Offset of the DisCH1 field.

pub const A2_SHIFT: u32 = 16

Available on crate feature el2 only.

Offset of the A2 field.

pub const FNG0_SHIFT: u32 = 17

Available on crate feature el2 only.

Offset of the FNG0 field.

pub const FNG1_SHIFT: u32 = 18

Available on crate feature el2 only.

Offset of the FNG1 field.

pub const POE2F_SHIFT: u32 = 19

Available on crate feature el2 only.

Offset of the POE2F field.

pub const POIW_SHIFT: u32 = 22

Available on crate feature el2 only.

Offset of the POIW field.

pub const POIW_MASK: u64 = 0b111

Available on crate feature el2 only.

Mask for the POIW field.

pub const VTB0_SHIFT: u32 = 25

Available on crate feature el2 only.

Offset of the VTB0 field.

pub const VTB0_MASK: u64 = 0b11111

Available on crate feature el2 only.

Mask for the VTB0 field.

pub const VTB1_SHIFT: u32 = 30

Available on crate feature el2 only.

Offset of the VTB1 field.

pub const VTB1_MASK: u64 = 0b11111

Available on crate feature el2 only.

Mask for the VTB1 field.

pub const TVAD0_SHIFT: u32 = 35

Available on crate feature el2 only.

Offset of the TVAD0 field.

pub const TVAD1_SHIFT: u32 = 36

Available on crate feature el2 only.

Offset of the TVAD1 field.

pub const fn poiw(self) -> u8

Available on crate feature el2 only.

Returns the value of the POIW field.

pub const fn set_poiw(&mut self, value: u8)

Available on crate feature el2 only.

Sets the value of the POIW field.

pub const fn with_poiw(self, value: u8) -> Self

Available on crate feature el2 only.

Returns a copy with the POIW field set to the given value.

pub const fn vtb0(self) -> u8

Available on crate feature el2 only.

Returns the value of the VTB0 field.

pub const fn set_vtb0(&mut self, value: u8)

Available on crate feature el2 only.

Sets the value of the VTB0 field.

pub const fn with_vtb0(self, value: u8) -> Self

Available on crate feature el2 only.

Returns a copy with the VTB0 field set to the given value.

pub const fn vtb1(self) -> u8

Available on crate feature el2 only.

Returns the value of the VTB1 field.

pub const fn set_vtb1(&mut self, value: u8)

Available on crate feature el2 only.

Sets the value of the VTB1 field.

pub const fn with_vtb1(self, value: u8) -> Self

Available on crate feature el2 only.

Returns a copy with the VTB1 field set to the given value.