TcrEl1

Struct TcrEl1 

pub struct TcrEl1(/* private fields */);
TCR_EL1 system register value.

Implementations

Source

impl TcrEl1

pub const EPD0: Self

EPD0 bit.

pub const A1: Self

A1 bit.

pub const EPD1: Self

EPD1 bit.

pub const AS: Self

AS bit.

pub const TBI0: Self

TBI0 bit.

pub const TBI1: Self

TBI1 bit.

pub const HA: Self

HA bit.

pub const HD: Self

HD bit.

pub const HPD0: Self

HPD0 bit.

pub const HPD1: Self

HPD1 bit.

pub const HWU059: Self

HWU059 bit.

pub const HWU060: Self

HWU060 bit.

pub const HWU061: Self

HWU061 bit.

pub const HWU062: Self

HWU062 bit.

pub const HWU159: Self

HWU159 bit.

pub const HWU160: Self

HWU160 bit.

pub const HWU161: Self

HWU161 bit.

pub const HWU162: Self

HWU162 bit.

pub const TBID0: Self

TBID0 bit.

pub const TBID1: Self

TBID1 bit.

pub const NFD0: Self

NFD0 bit.

pub const NFD1: Self

NFD1 bit.

pub const E0PD0: Self

E0PD0 bit.

pub const E0PD1: Self

E0PD1 bit.

pub const TCMA0: Self

TCMA0 bit.

pub const TCMA1: Self

TCMA1 bit.

pub const DS: Self

DS bit.

pub const MTX0: Self

MTX0 bit.

pub const MTX1: Self

MTX1 bit.

Source

impl TcrEl1

pub const fn empty() -> Self

Get a flags value with all bits unset.

pub const fn all() -> Self

Get a flags value with all known bits set.

pub const fn bits(&self) -> u64

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u64) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u64) -> Self

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u64) -> Self

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in this flags value are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Self) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

pub const fn contains(&self, other: Self) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

pub fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in two flags values.

pub fn remove(&mut self, other: Self)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Self)

The bitwise exclusive-or (^) of the bits in two flags values.

pub fn set(&mut self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Self) -> Self

The bitwise and (&) of the bits in two flags values.

pub const fn union(self, other: Self) -> Self

The bitwise or (|) of the bits in two flags values.

pub const fn difference(self, other: Self) -> Self

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in two flags values.

pub const fn complement(self) -> Self

The bitwise negation (!) of the bits in a flags value, truncating the result.

Source

impl TcrEl1

pub const fn iter(&self) -> Iter<TcrEl1>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<TcrEl1>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.

Source

impl TcrEl1

pub const T0SZ_SHIFT: u32 = 0

Available on crate feature el1 only.

Offset of the T0SZ field.

pub const T0SZ_MASK: u64 = 0b111111

Available on crate feature el1 only.

Mask for the T0SZ field.

pub const EPD0_SHIFT: u32 = 7

Available on crate feature el1 only.

Offset of the EPD0 field.

pub const IRGN0_SHIFT: u32 = 8

Available on crate feature el1 only.

Offset of the IRGN0 field.

pub const IRGN0_MASK: u64 = 0b11

Available on crate feature el1 only.

Mask for the IRGN0 field.

pub const ORGN0_SHIFT: u32 = 10

Available on crate feature el1 only.

Offset of the ORGN0 field.

pub const ORGN0_MASK: u64 = 0b11

Available on crate feature el1 only.

Mask for the ORGN0 field.

pub const SH0_SHIFT: u32 = 12

Available on crate feature el1 only.

Offset of the SH0 field.

pub const SH0_MASK: u64 = 0b11

Available on crate feature el1 only.

Mask for the SH0 field.

pub const TG0_SHIFT: u32 = 14

Available on crate feature el1 only.

Offset of the TG0 field.

pub const TG0_MASK: u64 = 0b11

Available on crate feature el1 only.

Mask for the TG0 field.

pub const T1SZ_SHIFT: u32 = 16

Available on crate feature el1 only.

Offset of the T1SZ field.

pub const T1SZ_MASK: u64 = 0b111111

Available on crate feature el1 only.

Mask for the T1SZ field.

pub const A1_SHIFT: u32 = 22

Available on crate feature el1 only.

Offset of the A1 field.

pub const EPD1_SHIFT: u32 = 23

Available on crate feature el1 only.

Offset of the EPD1 field.

pub const IRGN1_SHIFT: u32 = 24

Available on crate feature el1 only.

Offset of the IRGN1 field.

pub const IRGN1_MASK: u64 = 0b11

Available on crate feature el1 only.

Mask for the IRGN1 field.

pub const ORGN1_SHIFT: u32 = 26

Available on crate feature el1 only.

Offset of the ORGN1 field.

pub const ORGN1_MASK: u64 = 0b11

Available on crate feature el1 only.

Mask for the ORGN1 field.

pub const SH1_SHIFT: u32 = 28

Available on crate feature el1 only.

Offset of the SH1 field.

pub const SH1_MASK: u64 = 0b11

Available on crate feature el1 only.

Mask for the SH1 field.

pub const TG1_SHIFT: u32 = 30

Available on crate feature el1 only.

Offset of the TG1 field.

pub const TG1_MASK: u64 = 0b11

Available on crate feature el1 only.

Mask for the TG1 field.

pub const IPS_SHIFT: u32 = 32

Available on crate feature el1 only.

Offset of the IPS field.

pub const IPS_MASK: u64 = 0b111

Available on crate feature el1 only.

Mask for the IPS field.

pub const AS_SHIFT: u32 = 36

Available on crate feature el1 only.

Offset of the AS field.

pub const TBI0_SHIFT: u32 = 37

Available on crate feature el1 only.

Offset of the TBI0 field.

pub const TBI1_SHIFT: u32 = 38

Available on crate feature el1 only.

Offset of the TBI1 field.

pub const HA_SHIFT: u32 = 39

Available on crate feature el1 only.

Offset of the HA field.

pub const HD_SHIFT: u32 = 40

Available on crate feature el1 only.

Offset of the HD field.

pub const HPD0_SHIFT: u32 = 41

Available on crate feature el1 only.

Offset of the HPD0 field.

pub const HPD1_SHIFT: u32 = 42

Available on crate feature el1 only.

Offset of the HPD1 field.

pub const HWU059_SHIFT: u32 = 43

Available on crate feature el1 only.

Offset of the HWU059 field.

pub const HWU060_SHIFT: u32 = 44

Available on crate feature el1 only.

Offset of the HWU060 field.

pub const HWU061_SHIFT: u32 = 45

Available on crate feature el1 only.

Offset of the HWU061 field.

pub const HWU062_SHIFT: u32 = 46

Available on crate feature el1 only.

Offset of the HWU062 field.

pub const HWU159_SHIFT: u32 = 47

Available on crate feature el1 only.

Offset of the HWU159 field.

pub const HWU160_SHIFT: u32 = 48

Available on crate feature el1 only.

Offset of the HWU160 field.

pub const HWU161_SHIFT: u32 = 49

Available on crate feature el1 only.

Offset of the HWU161 field.

pub const HWU162_SHIFT: u32 = 50

Available on crate feature el1 only.

Offset of the HWU162 field.

pub const TBID0_SHIFT: u32 = 51

Available on crate feature el1 only.

Offset of the TBID0 field.

pub const TBID1_SHIFT: u32 = 52

Available on crate feature el1 only.

Offset of the TBID1 field.

pub const NFD0_SHIFT: u32 = 53

Available on crate feature el1 only.

Offset of the NFD0 field.

pub const NFD1_SHIFT: u32 = 54

Available on crate feature el1 only.

Offset of the NFD1 field.

pub const E0PD0_SHIFT: u32 = 55

Available on crate feature el1 only.

Offset of the E0PD0 field.

pub const E0PD1_SHIFT: u32 = 56

Available on crate feature el1 only.

Offset of the E0PD1 field.

pub const TCMA0_SHIFT: u32 = 57

Available on crate feature el1 only.

Offset of the TCMA0 field.

pub const TCMA1_SHIFT: u32 = 58

Available on crate feature el1 only.

Offset of the TCMA1 field.

pub const DS_SHIFT: u32 = 59

Available on crate feature el1 only.

Offset of the DS field.

pub const MTX0_SHIFT: u32 = 60

Available on crate feature el1 only.

Offset of the MTX0 field.

pub const MTX1_SHIFT: u32 = 61

Available on crate feature el1 only.

Offset of the MTX1 field.

pub const fn t0sz(self) -> u8

Available on crate feature el1 only.

Returns the value of the T0SZ field.

pub const fn set_t0sz(&mut self, value: u8)

Available on crate feature el1 only.

Sets the value of the T0SZ field.

pub const fn with_t0sz(self, value: u8) -> Self

Available on crate feature el1 only.

Returns a copy with the T0SZ field set to the given value.

pub const fn irgn0(self) -> u8

Available on crate feature el1 only.

Returns the value of the IRGN0 field.

pub const fn set_irgn0(&mut self, value: u8)

Available on crate feature el1 only.

Sets the value of the IRGN0 field.

pub const fn with_irgn0(self, value: u8) -> Self

Available on crate feature el1 only.

Returns a copy with the IRGN0 field set to the given value.

pub const fn orgn0(self) -> u8

Available on crate feature el1 only.

Returns the value of the ORGN0 field.

pub const fn set_orgn0(&mut self, value: u8)

Available on crate feature el1 only.

Sets the value of the ORGN0 field.

pub const fn with_orgn0(self, value: u8) -> Self

Available on crate feature el1 only.

Returns a copy with the ORGN0 field set to the given value.

pub const fn sh0(self) -> u8

Available on crate feature el1 only.

Returns the value of the SH0 field.

pub const fn set_sh0(&mut self, value: u8)

Available on crate feature el1 only.

Sets the value of the SH0 field.

pub const fn with_sh0(self, value: u8) -> Self

Available on crate feature el1 only.

Returns a copy with the SH0 field set to the given value.

pub const fn tg0(self) -> u8

Available on crate feature el1 only.

Returns the value of the TG0 field.

pub const fn set_tg0(&mut self, value: u8)

Available on crate feature el1 only.

Sets the value of the TG0 field.

pub const fn with_tg0(self, value: u8) -> Self

Available on crate feature el1 only.

Returns a copy with the TG0 field set to the given value.

pub const fn t1sz(self) -> u8

Available on crate feature el1 only.

Returns the value of the T1SZ field.

pub const fn set_t1sz(&mut self, value: u8)

Available on crate feature el1 only.

Sets the value of the T1SZ field.

pub const fn with_t1sz(self, value: u8) -> Self

Available on crate feature el1 only.

Returns a copy with the T1SZ field set to the given value.

pub const fn irgn1(self) -> u8

Available on crate feature el1 only.

Returns the value of the IRGN1 field.

pub const fn set_irgn1(&mut self, value: u8)

Available on crate feature el1 only.

Sets the value of the IRGN1 field.

pub const fn with_irgn1(self, value: u8) -> Self

Available on crate feature el1 only.

Returns a copy with the IRGN1 field set to the given value.

pub const fn orgn1(self) -> u8

Available on crate feature el1 only.

Returns the value of the ORGN1 field.

pub const fn set_orgn1(&mut self, value: u8)

Available on crate feature el1 only.

Sets the value of the ORGN1 field.

pub const fn with_orgn1(self, value: u8) -> Self

Available on crate feature el1 only.

Returns a copy with the ORGN1 field set to the given value.

pub const fn sh1(self) -> u8

Available on crate feature el1 only.

Returns the value of the SH1 field.

pub const fn set_sh1(&mut self, value: u8)

Available on crate feature el1 only.

Sets the value of the SH1 field.

pub const fn with_sh1(self, value: u8) -> Self

Available on crate feature el1 only.

Returns a copy with the SH1 field set to the given value.

pub const fn tg1(self) -> u8

Available on crate feature el1 only.

Returns the value of the TG1 field.

pub const fn set_tg1(&mut self, value: u8)

Available on crate feature el1 only.

Sets the value of the TG1 field.

pub const fn with_tg1(self, value: u8) -> Self

Available on crate feature el1 only.

Returns a copy with the TG1 field set to the given value.

pub const fn ips(self) -> u8

Available on crate feature el1 only.

Returns the value of the IPS field.

pub const fn set_ips(&mut self, value: u8)

Available on crate feature el1 only.

Sets the value of the IPS field.

pub const fn with_ips(self, value: u8) -> Self

Available on crate feature el1 only.

Returns a copy with the IPS field set to the given value.