TcrEl3

Struct TcrEl3 

pub struct TcrEl3(/* private fields */);
TCR_EL3 system register value.

Implementations

Source

impl TcrEl3

pub const RES1: Self

RES1 bits in the TCR_EL3 register.

pub const TBI: Self

TBI bit.

pub const HA: Self

HA bit.

pub const HD: Self

HD bit.

pub const HPD: Self

HPD bit.

pub const HWU59: Self

HWU59 bit.

pub const HWU60: Self

HWU60 bit.

pub const HWU61: Self

HWU61 bit.

pub const HWU62: Self

HWU62 bit.

pub const TBID: Self

TBID bit.

pub const TCMA: Self

TCMA bit.

pub const DS: Self

DS bit.

pub const MTX: Self

MTX bit.

pub const PNCH: Self

PnCH bit.

pub const PIE: Self

PIE bit.

pub const POE: Self

POE bit.

pub const AIE: Self

AIE bit.

pub const D128: Self

D128 bit.

pub const PTTWI: Self

PTTWI bit.

pub const HAFT: Self

HAFT bit.

pub const DISCH0: Self

DisCH0 bit.

pub const POE2F: Self

POE2F bit.

pub const TVAD: Self

TVAD bit.

Source

impl TcrEl3

pub const fn empty() -> Self

Get a flags value with all bits unset.

pub const fn all() -> Self

Get a flags value with all known bits set.

pub const fn bits(&self) -> u64

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u64) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u64) -> Self

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u64) -> Self

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in this flags value are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Self) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

pub const fn contains(&self, other: Self) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

pub fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in two flags values.

pub fn remove(&mut self, other: Self)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Self)

The bitwise exclusive-or (^) of the bits in two flags values.

pub fn set(&mut self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Self) -> Self

The bitwise and (&) of the bits in two flags values.

pub const fn union(self, other: Self) -> Self

The bitwise or (|) of the bits in two flags values.

pub const fn difference(self, other: Self) -> Self

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in two flags values.

pub const fn complement(self) -> Self

The bitwise negation (!) of the bits in a flags value, truncating the result.

Source

impl TcrEl3

pub const fn iter(&self) -> Iter<TcrEl3>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<TcrEl3>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.

Source

impl TcrEl3

pub const T0SZ_SHIFT: u32 = 0

Available on crate feature el3 only.

Offset of the T0SZ field.

pub const T0SZ_MASK: u64 = 0b111111

Available on crate feature el3 only.

Mask for the T0SZ field.

pub const IRGN0_SHIFT: u32 = 8

Available on crate feature el3 only.

Offset of the IRGN0 field.

pub const IRGN0_MASK: u64 = 0b11

Available on crate feature el3 only.

Mask for the IRGN0 field.

pub const ORGN0_SHIFT: u32 = 10

Available on crate feature el3 only.

Offset of the ORGN0 field.

pub const ORGN0_MASK: u64 = 0b11

Available on crate feature el3 only.

Mask for the ORGN0 field.

pub const SH0_SHIFT: u32 = 12

Available on crate feature el3 only.

Offset of the SH0 field.

pub const SH0_MASK: u64 = 0b11

Available on crate feature el3 only.

Mask for the SH0 field.

pub const TG0_SHIFT: u32 = 14

Available on crate feature el3 only.

Offset of the TG0 field.

pub const TG0_MASK: u64 = 0b11

Available on crate feature el3 only.

Mask for the TG0 field.

pub const PS_SHIFT: u32 = 16

Available on crate feature el3 only.

Offset of the PS field.

pub const PS_MASK: u64 = 0b111

Available on crate feature el3 only.

Mask for the PS field.

pub const TBI_SHIFT: u32 = 20

Available on crate feature el3 only.

Offset of the TBI field.

pub const HA_SHIFT: u32 = 21

Available on crate feature el3 only.

Offset of the HA field.

pub const HD_SHIFT: u32 = 22

Available on crate feature el3 only.

Offset of the HD field.

pub const HPD_SHIFT: u32 = 24

Available on crate feature el3 only.

Offset of the HPD field.

pub const HWU59_SHIFT: u32 = 25

Available on crate feature el3 only.

Offset of the HWU59 field.

pub const HWU60_SHIFT: u32 = 26

Available on crate feature el3 only.

Offset of the HWU60 field.

pub const HWU61_SHIFT: u32 = 27

Available on crate feature el3 only.

Offset of the HWU61 field.

pub const HWU62_SHIFT: u32 = 28

Available on crate feature el3 only.

Offset of the HWU62 field.

pub const TBID_SHIFT: u32 = 29

Available on crate feature el3 only.

Offset of the TBID field.

pub const TCMA_SHIFT: u32 = 30

Available on crate feature el3 only.

Offset of the TCMA field.

pub const DS_SHIFT: u32 = 32

Available on crate feature el3 only.

Offset of the DS field.

pub const MTX_SHIFT: u32 = 33

Available on crate feature el3 only.

Offset of the MTX field.

pub const PNCH_SHIFT: u32 = 34

Available on crate feature el3 only.

Offset of the PnCH field.

pub const PIE_SHIFT: u32 = 35

Available on crate feature el3 only.

Offset of the PIE field.

pub const POE_SHIFT: u32 = 36

Available on crate feature el3 only.

Offset of the POE field.

pub const AIE_SHIFT: u32 = 37

Available on crate feature el3 only.

Offset of the AIE field.

pub const D128_SHIFT: u32 = 38

Available on crate feature el3 only.

Offset of the D128 field.

pub const PTTWI_SHIFT: u32 = 41

Available on crate feature el3 only.

Offset of the PTTWI field.

pub const HAFT_SHIFT: u32 = 42

Available on crate feature el3 only.

Offset of the HAFT field.

pub const DISCH0_SHIFT: u32 = 43

Available on crate feature el3 only.

Offset of the DisCH0 field.

pub const POE2F_SHIFT: u32 = 44

Available on crate feature el3 only.

Offset of the POE2F field.

pub const POIW_SHIFT: u32 = 45

Available on crate feature el3 only.

Offset of the POIW field.

pub const POIW_MASK: u64 = 0b111

Available on crate feature el3 only.

Mask for the POIW field.

pub const VTB_SHIFT: u32 = 48

Available on crate feature el3 only.

Offset of the VTB field.

pub const VTB_MASK: u64 = 0b11111

Available on crate feature el3 only.

Mask for the VTB field.

pub const TVAD_SHIFT: u32 = 53

Available on crate feature el3 only.

Offset of the TVAD field.

pub const fn t0sz(self) -> u8

Available on crate feature el3 only.

Returns the value of the T0SZ field.

pub const fn set_t0sz(&mut self, value: u8)

Available on crate feature el3 only.

Sets the value of the T0SZ field.

pub const fn with_t0sz(self, value: u8) -> Self

Available on crate feature el3 only.

Returns a copy with the T0SZ field set to the given value.

pub const fn irgn0(self) -> u8

Available on crate feature el3 only.

Returns the value of the IRGN0 field.

pub const fn set_irgn0(&mut self, value: u8)

Available on crate feature el3 only.

Sets the value of the IRGN0 field.

pub const fn with_irgn0(self, value: u8) -> Self

Available on crate feature el3 only.

Returns a copy with the IRGN0 field set to the given value.

pub const fn orgn0(self) -> u8

Available on crate feature el3 only.

Returns the value of the ORGN0 field.

pub const fn set_orgn0(&mut self, value: u8)

Available on crate feature el3 only.

Sets the value of the ORGN0 field.

pub const fn with_orgn0(self, value: u8) -> Self

Available on crate feature el3 only.

Returns a copy with the ORGN0 field set to the given value.

pub const fn sh0(self) -> u8

Available on crate feature el3 only.

Returns the value of the SH0 field.

pub const fn set_sh0(&mut self, value: u8)

Available on crate feature el3 only.

Sets the value of the SH0 field.

pub const fn with_sh0(self, value: u8) -> Self

Available on crate feature el3 only.

Returns a copy with the SH0 field set to the given value.

pub const fn tg0(self) -> u8

Available on crate feature el3 only.

Returns the value of the TG0 field.

pub const fn set_tg0(&mut self, value: u8)

Available on crate feature el3 only.

Sets the value of the TG0 field.

pub const fn with_tg0(self, value: u8) -> Self

Available on crate feature el3 only.

Returns a copy with the TG0 field set to the given value.

pub const fn ps(self) -> u8

Available on crate feature el3 only.

Returns the value of the PS field.

pub const fn set_ps(&mut self, value: u8)

Available on crate feature el3 only.

Sets the value of the PS field.

pub const fn with_ps(self, value: u8) -> Self

Available on crate feature el3 only.

Returns a copy with the PS field set to the given value.

pub const fn poiw(self) -> u8

Available on crate feature el3 only.

Returns the value of the POIW field.

pub const fn set_poiw(&mut self, value: u8)

Available on crate feature el3 only.

Sets the value of the POIW field.

pub const fn with_poiw(self, value: u8) -> Self

Available on crate feature el3 only.

Returns a copy with the POIW field set to the given value.

pub const fn vtb(self) -> u8

Available on crate feature el3 only.

Returns the value of the VTB field.

pub const fn set_vtb(&mut self, value: u8)

Available on crate feature el3 only.

Sets the value of the VTB field.

pub const fn with_vtb(self, value: u8) -> Self

Available on crate feature el3 only.

Returns a copy with the VTB field set to the given value.