Ttbcr

Struct Ttbcr 

pub struct Ttbcr(/* private fields */);
TTBCR system register value.

Implementations

Source

impl Ttbcr

pub const PD0: Self

PD0 bit.

pub const PD1: Self

PD1 bit.

pub const T2E: Self

T2E bit.

pub const EPD0: Self

EPD0 bit.

pub const A1: Self

A1 bit.

pub const EPD1: Self

EPD1 bit.

pub const EAE: Self

EAE bit.

Source

impl Ttbcr

pub const fn empty() -> Self

Get a flags value with all bits unset.

pub const fn all() -> Self

Get a flags value with all known bits set.

pub const fn bits(&self) -> u32

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u32) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u32) -> Self

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u32) -> Self

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in this flags value are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Self) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

pub const fn contains(&self, other: Self) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

pub fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in two flags values.

pub fn remove(&mut self, other: Self)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Self)

The bitwise exclusive-or (^) of the bits in two flags values.

pub fn set(&mut self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Self) -> Self

The bitwise and (&) of the bits in two flags values.

pub const fn union(self, other: Self) -> Self

The bitwise or (|) of the bits in two flags values.

pub const fn difference(self, other: Self) -> Self

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in two flags values.

pub const fn complement(self) -> Self

The bitwise negation (!) of the bits in a flags value, truncating the result.

Source

impl Ttbcr

pub const fn iter(&self) -> Iter<Ttbcr>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<Ttbcr>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.

Source

impl Ttbcr

pub const N_SHIFT: u32 = 0

Offset of the N field.

pub const N_MASK: u32 = 0b111

Mask for the N field.

pub const T0SZ_SHIFT: u32 = 0

Offset of the T0SZ field.

pub const T0SZ_MASK: u32 = 0b111

Mask for the T0SZ field.

pub const PD0_SHIFT: u32 = 4

Offset of the PD0 field.

pub const PD1_SHIFT: u32 = 5

Offset of the PD1 field.

pub const T2E_SHIFT: u32 = 6

Offset of the T2E field.

pub const EPD0_SHIFT: u32 = 7

Offset of the EPD0 field.

pub const IRGN0_SHIFT: u32 = 8

Offset of the IRGN0 field.

pub const IRGN0_MASK: u32 = 0b11

Mask for the IRGN0 field.

pub const ORGN0_SHIFT: u32 = 10

Offset of the ORGN0 field.

pub const ORGN0_MASK: u32 = 0b11

Mask for the ORGN0 field.

pub const SH0_SHIFT: u32 = 12

Offset of the SH0 field.

pub const SH0_MASK: u32 = 0b11

Mask for the SH0 field.

pub const T1SZ_SHIFT: u32 = 16

Offset of the T1SZ field.

pub const T1SZ_MASK: u32 = 0b111

Mask for the T1SZ field.

pub const A1_SHIFT: u32 = 22

Offset of the A1 field.

pub const EPD1_SHIFT: u32 = 23

Offset of the EPD1 field.

pub const IRGN1_SHIFT: u32 = 24

Offset of the IRGN1 field.

pub const IRGN1_MASK: u32 = 0b11

Mask for the IRGN1 field.

pub const ORGN1_SHIFT: u32 = 26

Offset of the ORGN1 field.

pub const ORGN1_MASK: u32 = 0b11

Mask for the ORGN1 field.

pub const SH1_SHIFT: u32 = 28

Offset of the SH1 field.

pub const SH1_MASK: u32 = 0b11

Mask for the SH1 field.

pub const EAE_SHIFT: u32 = 31

Offset of the EAE field.

pub const fn n(self) -> u8

Returns the value of the N field.

pub const fn set_n(&mut self, value: u8)

Sets the value of the N field.

pub const fn with_n(self, value: u8) -> Self

Returns a copy with the N field set to the given value.

pub const fn t0sz(self) -> u8

Returns the value of the T0SZ field.

pub const fn set_t0sz(&mut self, value: u8)

Sets the value of the T0SZ field.

pub const fn with_t0sz(self, value: u8) -> Self

Returns a copy with the T0SZ field set to the given value.

pub const fn irgn0(self) -> u8

Returns the value of the IRGN0 field.

pub const fn set_irgn0(&mut self, value: u8)

Sets the value of the IRGN0 field.

pub const fn with_irgn0(self, value: u8) -> Self

Returns a copy with the IRGN0 field set to the given value.

pub const fn orgn0(self) -> u8

Returns the value of the ORGN0 field.

pub const fn set_orgn0(&mut self, value: u8)

Sets the value of the ORGN0 field.

pub const fn with_orgn0(self, value: u8) -> Self

Returns a copy with the ORGN0 field set to the given value.

pub const fn sh0(self) -> u8

Returns the value of the SH0 field.

pub const fn set_sh0(&mut self, value: u8)

Sets the value of the SH0 field.

pub const fn with_sh0(self, value: u8) -> Self

Returns a copy with the SH0 field set to the given value.

pub const fn t1sz(self) -> u8

Returns the value of the T1SZ field.

pub const fn set_t1sz(&mut self, value: u8)

Sets the value of the T1SZ field.

pub const fn with_t1sz(self, value: u8) -> Self

Returns a copy with the T1SZ field set to the given value.

pub const fn irgn1(self) -> u8

Returns the value of the IRGN1 field.

pub const fn set_irgn1(&mut self, value: u8)

Sets the value of the IRGN1 field.

pub const fn with_irgn1(self, value: u8) -> Self

Returns a copy with the IRGN1 field set to the given value.

pub const fn orgn1(self) -> u8

Returns the value of the ORGN1 field.

pub const fn set_orgn1(&mut self, value: u8)

Sets the value of the ORGN1 field.

pub const fn with_orgn1(self, value: u8) -> Self

Returns a copy with the ORGN1 field set to the given value.

pub const fn sh1(self) -> u8

Returns the value of the SH1 field.

pub const fn set_sh1(&mut self, value: u8)

Sets the value of the SH1 field.

pub const fn with_sh1(self, value: u8) -> Self

Returns a copy with the SH1 field set to the given value.