pub struct Ttbr0El2(/* private fields */);Expand description
TTBR0_EL2 system register value.
Implementations
Sourceimpl Ttbr0El2
impl Ttbr0El2
Sourcepub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u64) -> Option<Self>
pub const fn from_bits(bits: u64) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u64) -> Self
pub const fn from_bits_truncate(bits: u64) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u64) -> Self
pub const fn from_bits_retain(bits: u64) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl Ttbr0El2
impl Ttbr0El2
Sourcepub const fn iter(&self) -> Iter<Ttbr0El2>
pub const fn iter(&self) -> Iter<Ttbr0El2>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<Ttbr0El2>
pub const fn iter_names(&self) -> IterNames<Ttbr0El2>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl Ttbr0El2
impl Ttbr0El2
Sourcepub const BADDR_47_1_SHIFT: u32 = 1
Available on crate feature el2 only.
pub const BADDR_47_1_SHIFT: u32 = 1
el2 only.Offset of the BADDR[47:1] field.
Sourcepub const BADDR_47_1_MASK: u64 = 0b11111111111111111111111111111111111111111111111
Available on crate feature el2 only.
pub const BADDR_47_1_MASK: u64 = 0b11111111111111111111111111111111111111111111111
el2 only.Mask for the BADDR[47:1] field.
Sourcepub const ASID_SHIFT: u32 = 48
Available on crate feature el2 only.
pub const ASID_SHIFT: u32 = 48
el2 only.Offset of the ASID field.
Sourcepub const ASID_MASK: u64 = 0b1111111111111111
Available on crate feature el2 only.
pub const ASID_MASK: u64 = 0b1111111111111111
el2 only.Mask for the ASID field.
Sourcepub const fn baddr_47_1(self) -> u64
Available on crate feature el2 only.
pub const fn baddr_47_1(self) -> u64
el2 only.Returns the value of the BADDR[47:1] field.
Sourcepub const fn set_baddr_47_1(&mut self, value: u64)
Available on crate feature el2 only.
pub const fn set_baddr_47_1(&mut self, value: u64)
el2 only.Sets the value of the BADDR[47:1] field.
Sourcepub const fn with_baddr_47_1(self, value: u64) -> Self
Available on crate feature el2 only.
pub const fn with_baddr_47_1(self, value: u64) -> Self
el2 only.Returns a copy with the BADDR[47:1] field set to the given value.
Sourcepub const fn skl(self) -> u8
Available on crate feature el2 only.
pub const fn skl(self) -> u8
el2 only.Returns the value of the SKL field.
Sourcepub const fn set_skl(&mut self, value: u8)
Available on crate feature el2 only.
pub const fn set_skl(&mut self, value: u8)
el2 only.Sets the value of the SKL field.
Sourcepub const fn with_skl(self, value: u8) -> Self
Available on crate feature el2 only.
pub const fn with_skl(self, value: u8) -> Self
el2 only.Returns a copy with the SKL field set to the given value.
Sourcepub const fn asid(self) -> u16
Available on crate feature el2 only.
pub const fn asid(self) -> u16
el2 only.Returns the value of the ASID field.