pub struct Vtcr(/* private fields */);Expand description
VTCR system register value.
Implementations
Sourceimpl Vtcr
impl Vtcr
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl Vtcr
impl Vtcr
Sourcepub const fn iter(&self) -> Iter<Vtcr>
pub const fn iter(&self) -> Iter<Vtcr>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<Vtcr>
pub const fn iter_names(&self) -> IterNames<Vtcr>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl Vtcr
impl Vtcr
Sourcepub const T0SZ_SHIFT: u32 = 0
pub const T0SZ_SHIFT: u32 = 0
Offset of the T0SZ field.
Sourcepub const IRGN0_SHIFT: u32 = 8
pub const IRGN0_SHIFT: u32 = 8
Offset of the IRGN0 field.
Sourcepub const IRGN0_MASK: u32 = 0b11
pub const IRGN0_MASK: u32 = 0b11
Mask for the IRGN0 field.
Sourcepub const ORGN0_SHIFT: u32 = 10
pub const ORGN0_SHIFT: u32 = 10
Offset of the ORGN0 field.
Sourcepub const ORGN0_MASK: u32 = 0b11
pub const ORGN0_MASK: u32 = 0b11
Mask for the ORGN0 field.
Sourcepub const HWU59_SHIFT: u32 = 25
pub const HWU59_SHIFT: u32 = 25
Offset of the HWU59 field.
Sourcepub const HWU60_SHIFT: u32 = 26
pub const HWU60_SHIFT: u32 = 26
Offset of the HWU60 field.
Sourcepub const HWU61_SHIFT: u32 = 27
pub const HWU61_SHIFT: u32 = 27
Offset of the HWU61 field.
Sourcepub const HWU62_SHIFT: u32 = 28
pub const HWU62_SHIFT: u32 = 28
Offset of the HWU62 field.
Sourcepub const fn with_t0sz(self, value: u8) -> Self
pub const fn with_t0sz(self, value: u8) -> Self
Returns a copy with the T0SZ field set to the given value.
Sourcepub const fn with_sl0(self, value: u8) -> Self
pub const fn with_sl0(self, value: u8) -> Self
Returns a copy with the SL0 field set to the given value.
Sourcepub const fn with_irgn0(self, value: u8) -> Self
pub const fn with_irgn0(self, value: u8) -> Self
Returns a copy with the IRGN0 field set to the given value.
Sourcepub const fn with_orgn0(self, value: u8) -> Self
pub const fn with_orgn0(self, value: u8) -> Self
Returns a copy with the ORGN0 field set to the given value.