VtcrEl2

Struct VtcrEl2 

pub struct VtcrEl2(/* private fields */);
VTCR_EL2 system register value.

Implementations

Source

impl VtcrEl2

pub const RES1: Self

RES1 bits in the VTCR_EL2 register.

pub const VS: Self

VS bit.

pub const HA: Self

HA bit.

pub const HD: Self

HD bit.

pub const HWU59: Self

HWU59 bit.

pub const HWU60: Self

HWU60 bit.

pub const HWU61: Self

HWU61 bit.

pub const HWU62: Self

HWU62 bit.

pub const NSW: Self

NSW bit.

pub const NSA: Self

NSA bit.

pub const DS: Self

DS bit.

pub const SL2: Self

SL2 bit.

pub const ASSUREDONLY: Self

AssuredOnly bit.

pub const TL1: Self

TL1 bit.

pub const S2PIE: Self

S2PIE bit.

pub const S2POE: Self

S2POE bit.

pub const D128: Self

D128 bit.

pub const GCSH: Self

GCSH bit.

pub const TL0: Self

TL0 bit.

pub const HAFT: Self

HAFT bit.

pub const HDBSS: Self

HDBSS bit.

Source

impl VtcrEl2

pub const fn empty() -> Self

Get a flags value with all bits unset.

pub const fn all() -> Self

Get a flags value with all known bits set.

pub const fn bits(&self) -> u64

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u64) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u64) -> Self

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u64) -> Self

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in this flags value are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Self) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

pub const fn contains(&self, other: Self) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

pub fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in two flags values.

pub fn remove(&mut self, other: Self)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Self)

The bitwise exclusive-or (^) of the bits in two flags values.

pub fn set(&mut self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Self) -> Self

The bitwise and (&) of the bits in two flags values.

pub const fn union(self, other: Self) -> Self

The bitwise or (|) of the bits in two flags values.

pub const fn difference(self, other: Self) -> Self

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in two flags values.

pub const fn complement(self) -> Self

The bitwise negation (!) of the bits in a flags value, truncating the result.

Source

impl VtcrEl2

pub const fn iter(&self) -> Iter<VtcrEl2>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<VtcrEl2>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.

Source

impl VtcrEl2

pub const T0SZ_SHIFT: u32 = 0

Available on crate feature el2 only.

Offset of the T0SZ field.

pub const T0SZ_MASK: u64 = 0b111111

Available on crate feature el2 only.

Mask for the T0SZ field.

pub const SL0_SHIFT: u32 = 6

Available on crate feature el2 only.

Offset of the SL0 field.

pub const SL0_MASK: u64 = 0b11

Available on crate feature el2 only.

Mask for the SL0 field.

pub const IRGN0_SHIFT: u32 = 8

Available on crate feature el2 only.

Offset of the IRGN0 field.

pub const IRGN0_MASK: u64 = 0b11

Available on crate feature el2 only.

Mask for the IRGN0 field.

pub const ORGN0_SHIFT: u32 = 10

Available on crate feature el2 only.

Offset of the ORGN0 field.

pub const ORGN0_MASK: u64 = 0b11

Available on crate feature el2 only.

Mask for the ORGN0 field.

pub const SH0_SHIFT: u32 = 12

Available on crate feature el2 only.

Offset of the SH0 field.

pub const SH0_MASK: u64 = 0b11

Available on crate feature el2 only.

Mask for the SH0 field.

pub const TG0_SHIFT: u32 = 14

Available on crate feature el2 only.

Offset of the TG0 field.

pub const TG0_MASK: u64 = 0b11

Available on crate feature el2 only.

Mask for the TG0 field.

pub const PS_SHIFT: u32 = 16

Available on crate feature el2 only.

Offset of the PS field.

pub const PS_MASK: u64 = 0b111

Available on crate feature el2 only.

Mask for the PS field.

pub const VS_SHIFT: u32 = 19

Available on crate feature el2 only.

Offset of the VS field.

pub const HA_SHIFT: u32 = 21

Available on crate feature el2 only.

Offset of the HA field.

pub const HD_SHIFT: u32 = 22

Available on crate feature el2 only.

Offset of the HD field.

pub const HWU59_SHIFT: u32 = 25

Available on crate feature el2 only.

Offset of the HWU59 field.

pub const HWU60_SHIFT: u32 = 26

Available on crate feature el2 only.

Offset of the HWU60 field.

pub const HWU61_SHIFT: u32 = 27

Available on crate feature el2 only.

Offset of the HWU61 field.

pub const HWU62_SHIFT: u32 = 28

Available on crate feature el2 only.

Offset of the HWU62 field.

pub const NSW_SHIFT: u32 = 29

Available on crate feature el2 only.

Offset of the NSW field.

pub const NSA_SHIFT: u32 = 30

Available on crate feature el2 only.

Offset of the NSA field.

pub const DS_SHIFT: u32 = 32

Available on crate feature el2 only.

Offset of the DS field.

pub const SL2_SHIFT: u32 = 33

Available on crate feature el2 only.

Offset of the SL2 field.

pub const ASSUREDONLY_SHIFT: u32 = 34

Available on crate feature el2 only.

Offset of the AssuredOnly field.

pub const TL1_SHIFT: u32 = 35

Available on crate feature el2 only.

Offset of the TL1 field.

pub const S2PIE_SHIFT: u32 = 36

Available on crate feature el2 only.

Offset of the S2PIE field.

pub const S2POE_SHIFT: u32 = 37

Available on crate feature el2 only.

Offset of the S2POE field.

pub const D128_SHIFT: u32 = 38

Available on crate feature el2 only.

Offset of the D128 field.

pub const GCSH_SHIFT: u32 = 40

Available on crate feature el2 only.

Offset of the GCSH field.

pub const TL0_SHIFT: u32 = 41

Available on crate feature el2 only.

Offset of the TL0 field.

pub const HAFT_SHIFT: u32 = 44

Available on crate feature el2 only.

Offset of the HAFT field.

pub const HDBSS_SHIFT: u32 = 45

Available on crate feature el2 only.

Offset of the HDBSS field.

pub const fn t0sz(self) -> u8

Available on crate feature el2 only.

Returns the value of the T0SZ field.

pub const fn set_t0sz(&mut self, value: u8)

Available on crate feature el2 only.

Sets the value of the T0SZ field.

pub const fn with_t0sz(self, value: u8) -> Self

Available on crate feature el2 only.

Returns a copy with the T0SZ field set to the given value.

pub const fn sl0(self) -> u8

Available on crate feature el2 only.

Returns the value of the SL0 field.

pub const fn set_sl0(&mut self, value: u8)

Available on crate feature el2 only.

Sets the value of the SL0 field.

pub const fn with_sl0(self, value: u8) -> Self

Available on crate feature el2 only.

Returns a copy with the SL0 field set to the given value.

pub const fn irgn0(self) -> u8

Available on crate feature el2 only.

Returns the value of the IRGN0 field.

pub const fn set_irgn0(&mut self, value: u8)

Available on crate feature el2 only.

Sets the value of the IRGN0 field.

pub const fn with_irgn0(self, value: u8) -> Self

Available on crate feature el2 only.

Returns a copy with the IRGN0 field set to the given value.

pub const fn orgn0(self) -> u8

Available on crate feature el2 only.

Returns the value of the ORGN0 field.

pub const fn set_orgn0(&mut self, value: u8)

Available on crate feature el2 only.

Sets the value of the ORGN0 field.

pub const fn with_orgn0(self, value: u8) -> Self

Available on crate feature el2 only.

Returns a copy with the ORGN0 field set to the given value.

pub const fn sh0(self) -> u8

Available on crate feature el2 only.

Returns the value of the SH0 field.

pub const fn set_sh0(&mut self, value: u8)

Available on crate feature el2 only.

Sets the value of the SH0 field.

pub const fn with_sh0(self, value: u8) -> Self

Available on crate feature el2 only.

Returns a copy with the SH0 field set to the given value.

pub const fn tg0(self) -> u8

Available on crate feature el2 only.

Returns the value of the TG0 field.

pub const fn set_tg0(&mut self, value: u8)

Available on crate feature el2 only.

Sets the value of the TG0 field.

pub const fn with_tg0(self, value: u8) -> Self

Available on crate feature el2 only.

Returns a copy with the TG0 field set to the given value.

pub const fn ps(self) -> u8

Available on crate feature el2 only.

Returns the value of the PS field.

pub const fn set_ps(&mut self, value: u8)

Available on crate feature el2 only.

Sets the value of the PS field.

pub const fn with_ps(self, value: u8) -> Self

Available on crate feature el2 only.

Returns a copy with the PS field set to the given value.