pub struct CtrEl0(/* private fields */);Expand description
CTR_EL0 system register value.
Cache Type Register.
Implementations
Sourceimpl CtrEl0
impl CtrEl0
Sourcepub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u64) -> Option<Self>
pub const fn from_bits(bits: u64) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u64) -> Self
pub const fn from_bits_truncate(bits: u64) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u64) -> Self
pub const fn from_bits_retain(bits: u64) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl CtrEl0
impl CtrEl0
Sourcepub const fn iter(&self) -> Iter<CtrEl0>
pub const fn iter(&self) -> Iter<CtrEl0>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<CtrEl0>
pub const fn iter_names(&self) -> IterNames<CtrEl0>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl CtrEl0
impl CtrEl0
Sourcepub const IMINLINE_SHIFT: u32 = 0
pub const IMINLINE_SHIFT: u32 = 0
Offset of the IminLine field.
Sourcepub const IMINLINE_MASK: u64 = 0b1111
pub const IMINLINE_MASK: u64 = 0b1111
Mask for the IminLine field.
Sourcepub const L1IP_SHIFT: u32 = 14
pub const L1IP_SHIFT: u32 = 14
Offset of the L1Ip field.
Sourcepub const DMINLINE_SHIFT: u32 = 16
pub const DMINLINE_SHIFT: u32 = 16
Offset of the DminLine field.
Sourcepub const DMINLINE_MASK: u64 = 0b1111
pub const DMINLINE_MASK: u64 = 0b1111
Mask for the DminLine field.
Sourcepub const TMINLINE_SHIFT: u32 = 32
pub const TMINLINE_SHIFT: u32 = 32
Offset of the TminLine field.
Sourcepub const TMINLINE_MASK: u64 = 0b111111
pub const TMINLINE_MASK: u64 = 0b111111
Mask for the TminLine field.
Sourcepub const fn set_iminline(&mut self, value: u8)
pub const fn set_iminline(&mut self, value: u8)
Sets the value of the IminLine field.
Sourcepub const fn with_iminline(self, value: u8) -> Self
pub const fn with_iminline(self, value: u8) -> Self
Returns a copy with the IminLine field set to the given value.
Sourcepub const fn with_l1ip(self, value: u8) -> Self
pub const fn with_l1ip(self, value: u8) -> Self
Returns a copy with the L1Ip field set to the given value.
Sourcepub const fn dminline(self) -> u8
pub const fn dminline(self) -> u8
Returns the value of the DminLine field.
Log2 of the number of words in the smallest cache line of all the data caches and unified caches that are controlled by the PE.
Sourcepub const fn set_dminline(&mut self, value: u8)
pub const fn set_dminline(&mut self, value: u8)
Sets the value of the DminLine field.
Log2 of the number of words in the smallest cache line of all the data caches and unified caches that are controlled by the PE.
Sourcepub const fn with_dminline(self, value: u8) -> Self
pub const fn with_dminline(self, value: u8) -> Self
Returns a copy with the DminLine field set to the given value.
Log2 of the number of words in the smallest cache line of all the data caches and unified caches that are controlled by the PE.
Sourcepub const fn with_erg(self, value: u8) -> Self
pub const fn with_erg(self, value: u8) -> Self
Returns a copy with the ERG field set to the given value.
Sourcepub const fn with_cwg(self, value: u8) -> Self
pub const fn with_cwg(self, value: u8) -> Self
Returns a copy with the CWG field set to the given value.
Sourcepub const fn set_tminline(&mut self, value: u8)
pub const fn set_tminline(&mut self, value: u8)
Sets the value of the TminLine field.
Sourcepub const fn with_tminline(self, value: u8) -> Self
pub const fn with_tminline(self, value: u8) -> Self
Returns a copy with the TminLine field set to the given value.