pub struct Dbgdevid(/* private fields */);Expand description
DBGDEVID system register value.
Implementations
Sourceimpl Dbgdevid
impl Dbgdevid
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl Dbgdevid
impl Dbgdevid
Sourcepub const fn iter(&self) -> Iter<Dbgdevid>
pub const fn iter(&self) -> Iter<Dbgdevid>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<Dbgdevid>
pub const fn iter_names(&self) -> IterNames<Dbgdevid>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl Dbgdevid
impl Dbgdevid
Sourcepub const PCSAMPLE_SHIFT: u32 = 0
pub const PCSAMPLE_SHIFT: u32 = 0
Offset of the PCSample field.
Sourcepub const PCSAMPLE_MASK: u32 = 0b1111
pub const PCSAMPLE_MASK: u32 = 0b1111
Mask for the PCSample field.
Sourcepub const WPADDRMASK_SHIFT: u32 = 4
pub const WPADDRMASK_SHIFT: u32 = 4
Offset of the WPAddrMask field.
Sourcepub const WPADDRMASK_MASK: u32 = 0b1111
pub const WPADDRMASK_MASK: u32 = 0b1111
Mask for the WPAddrMask field.
Sourcepub const BPADDRMASK_SHIFT: u32 = 8
pub const BPADDRMASK_SHIFT: u32 = 8
Offset of the BPAddrMask field.
Sourcepub const BPADDRMASK_MASK: u32 = 0b1111
pub const BPADDRMASK_MASK: u32 = 0b1111
Mask for the BPAddrMask field.
Sourcepub const VECTORCATCH_SHIFT: u32 = 12
pub const VECTORCATCH_SHIFT: u32 = 12
Offset of the VectorCatch field.
Sourcepub const VECTORCATCH_MASK: u32 = 0b1111
pub const VECTORCATCH_MASK: u32 = 0b1111
Mask for the VectorCatch field.
Sourcepub const VIRTEXTNS_SHIFT: u32 = 16
pub const VIRTEXTNS_SHIFT: u32 = 16
Offset of the VirtExtns field.
Sourcepub const VIRTEXTNS_MASK: u32 = 0b1111
pub const VIRTEXTNS_MASK: u32 = 0b1111
Mask for the VirtExtns field.
Sourcepub const DOUBLELOCK_SHIFT: u32 = 20
pub const DOUBLELOCK_SHIFT: u32 = 20
Offset of the DoubleLock field.
Sourcepub const DOUBLELOCK_MASK: u32 = 0b1111
pub const DOUBLELOCK_MASK: u32 = 0b1111
Mask for the DoubleLock field.
Sourcepub const AUXREGS_SHIFT: u32 = 24
pub const AUXREGS_SHIFT: u32 = 24
Offset of the AuxRegs field.
Sourcepub const AUXREGS_MASK: u32 = 0b1111
pub const AUXREGS_MASK: u32 = 0b1111
Mask for the AuxRegs field.
Sourcepub const CIDMASK_SHIFT: u32 = 28
pub const CIDMASK_SHIFT: u32 = 28
Offset of the CIDMask field.
Sourcepub const CIDMASK_MASK: u32 = 0b1111
pub const CIDMASK_MASK: u32 = 0b1111
Mask for the CIDMask field.
Sourcepub const fn set_pcsample(&mut self, value: u8)
pub const fn set_pcsample(&mut self, value: u8)
Sets the value of the PCSample field.
Sourcepub const fn with_pcsample(self, value: u8) -> Self
pub const fn with_pcsample(self, value: u8) -> Self
Returns a copy with the PCSample field set to the given value.
Sourcepub const fn wpaddrmask(self) -> u8
pub const fn wpaddrmask(self) -> u8
Returns the value of the WPAddrMask field.
Sourcepub const fn set_wpaddrmask(&mut self, value: u8)
pub const fn set_wpaddrmask(&mut self, value: u8)
Sets the value of the WPAddrMask field.
Sourcepub const fn with_wpaddrmask(self, value: u8) -> Self
pub const fn with_wpaddrmask(self, value: u8) -> Self
Returns a copy with the WPAddrMask field set to the given value.
Sourcepub const fn bpaddrmask(self) -> u8
pub const fn bpaddrmask(self) -> u8
Returns the value of the BPAddrMask field.
Sourcepub const fn set_bpaddrmask(&mut self, value: u8)
pub const fn set_bpaddrmask(&mut self, value: u8)
Sets the value of the BPAddrMask field.
Sourcepub const fn with_bpaddrmask(self, value: u8) -> Self
pub const fn with_bpaddrmask(self, value: u8) -> Self
Returns a copy with the BPAddrMask field set to the given value.
Sourcepub const fn vectorcatch(self) -> u8
pub const fn vectorcatch(self) -> u8
Returns the value of the VectorCatch field.
Sourcepub const fn set_vectorcatch(&mut self, value: u8)
pub const fn set_vectorcatch(&mut self, value: u8)
Sets the value of the VectorCatch field.
Sourcepub const fn with_vectorcatch(self, value: u8) -> Self
pub const fn with_vectorcatch(self, value: u8) -> Self
Returns a copy with the VectorCatch field set to the given value.
Sourcepub const fn set_virtextns(&mut self, value: u8)
pub const fn set_virtextns(&mut self, value: u8)
Sets the value of the VirtExtns field.
Sourcepub const fn with_virtextns(self, value: u8) -> Self
pub const fn with_virtextns(self, value: u8) -> Self
Returns a copy with the VirtExtns field set to the given value.
Sourcepub const fn doublelock(self) -> u8
pub const fn doublelock(self) -> u8
Returns the value of the DoubleLock field.
Sourcepub const fn set_doublelock(&mut self, value: u8)
pub const fn set_doublelock(&mut self, value: u8)
Sets the value of the DoubleLock field.
Sourcepub const fn with_doublelock(self, value: u8) -> Self
pub const fn with_doublelock(self, value: u8) -> Self
Returns a copy with the DoubleLock field set to the given value.
Sourcepub const fn set_auxregs(&mut self, value: u8)
pub const fn set_auxregs(&mut self, value: u8)
Sets the value of the AuxRegs field.
Sourcepub const fn with_auxregs(self, value: u8) -> Self
pub const fn with_auxregs(self, value: u8) -> Self
Returns a copy with the AuxRegs field set to the given value.
Sourcepub const fn set_cidmask(&mut self, value: u8)
pub const fn set_cidmask(&mut self, value: u8)
Sets the value of the CIDMask field.
Sourcepub const fn with_cidmask(self, value: u8) -> Self
pub const fn with_cidmask(self, value: u8) -> Self
Returns a copy with the CIDMask field set to the given value.