pub struct DisrEl1(/* private fields */);Expand description
DISR_EL1 system register value.
Implementations
Sourceimpl DisrEl1
impl DisrEl1
Sourcepub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u64) -> Option<Self>
pub const fn from_bits(bits: u64) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u64) -> Self
pub const fn from_bits_truncate(bits: u64) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u64) -> Self
pub const fn from_bits_retain(bits: u64) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl DisrEl1
impl DisrEl1
Sourcepub const fn iter(&self) -> Iter<DisrEl1>
pub const fn iter(&self) -> Iter<DisrEl1>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<DisrEl1>
pub const fn iter_names(&self) -> IterNames<DisrEl1>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl DisrEl1
impl DisrEl1
Sourcepub const DFSC_SHIFT: u32 = 0
Available on crate feature el1 only.
pub const DFSC_SHIFT: u32 = 0
el1 only.Offset of the DFSC field.
Sourcepub const DFSC_MASK: u64 = 0b111111
Available on crate feature el1 only.
pub const DFSC_MASK: u64 = 0b111111
el1 only.Mask for the DFSC field.
Sourcepub const WNRV_SHIFT: u32 = 7
Available on crate feature el1 only.
pub const WNRV_SHIFT: u32 = 7
el1 only.Offset of the WnRV field.
Sourcepub const fn dfsc(self) -> u8
Available on crate feature el1 only.
pub const fn dfsc(self) -> u8
el1 only.Returns the value of the DFSC field.
Sourcepub const fn set_dfsc(&mut self, value: u8)
Available on crate feature el1 only.
pub const fn set_dfsc(&mut self, value: u8)
el1 only.Sets the value of the DFSC field.
Sourcepub const fn with_dfsc(self, value: u8) -> Self
Available on crate feature el1 only.
pub const fn with_dfsc(self, value: u8) -> Self
el1 only.Returns a copy with the DFSC field set to the given value.
Sourcepub const fn aet(self) -> u8
Available on crate feature el1 only.
pub const fn aet(self) -> u8
el1 only.Returns the value of the AET field.
Sourcepub const fn set_aet(&mut self, value: u8)
Available on crate feature el1 only.
pub const fn set_aet(&mut self, value: u8)
el1 only.Sets the value of the AET field.
Sourcepub const fn with_aet(self, value: u8) -> Self
Available on crate feature el1 only.
pub const fn with_aet(self, value: u8) -> Self
el1 only.Returns a copy with the AET field set to the given value.
Sourcepub const fn wu(self) -> u8
Available on crate feature el1 only.
pub const fn wu(self) -> u8
el1 only.Returns the value of the WU field.