pub struct GpccrEl3(/* private fields */);Expand description
GPCCR_EL3 system register value.
Implementations
Sourceimpl GpccrEl3
impl GpccrEl3
Sourcepub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u64) -> Option<Self>
pub const fn from_bits(bits: u64) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u64) -> Self
pub const fn from_bits_truncate(bits: u64) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u64) -> Self
pub const fn from_bits_retain(bits: u64) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl GpccrEl3
impl GpccrEl3
Sourcepub const fn iter(&self) -> Iter<GpccrEl3>
pub const fn iter(&self) -> Iter<GpccrEl3>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<GpccrEl3>
pub const fn iter_names(&self) -> IterNames<GpccrEl3>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl GpccrEl3
impl GpccrEl3
Sourcepub const PPS3_SHIFT: u32 = 3
Available on crate feature el3 only.
pub const PPS3_SHIFT: u32 = 3
el3 only.Offset of the PPS3 field.
Sourcepub const RLPAD_SHIFT: u32 = 5
Available on crate feature el3 only.
pub const RLPAD_SHIFT: u32 = 5
el3 only.Offset of the RLPAD field.
Sourcepub const NSPAD_SHIFT: u32 = 6
Available on crate feature el3 only.
pub const NSPAD_SHIFT: u32 = 6
el3 only.Offset of the NSPAD field.
Sourcepub const SPAD_SHIFT: u32 = 7
Available on crate feature el3 only.
pub const SPAD_SHIFT: u32 = 7
el3 only.Offset of the SPAD field.
Sourcepub const IRGN_SHIFT: u32 = 8
Available on crate feature el3 only.
pub const IRGN_SHIFT: u32 = 8
el3 only.Offset of the IRGN field.
Sourcepub const ORGN_SHIFT: u32 = 10
Available on crate feature el3 only.
pub const ORGN_SHIFT: u32 = 10
el3 only.Offset of the ORGN field.
Sourcepub const GPCP_SHIFT: u32 = 17
Available on crate feature el3 only.
pub const GPCP_SHIFT: u32 = 17
el3 only.Offset of the GPCP field.
Sourcepub const TBGPCD_SHIFT: u32 = 18
Available on crate feature el3 only.
pub const TBGPCD_SHIFT: u32 = 18
el3 only.Offset of the TBGPCD field.
Sourcepub const L0GPTSZ_SHIFT: u32 = 20
Available on crate feature el3 only.
pub const L0GPTSZ_SHIFT: u32 = 20
el3 only.Offset of the L0GPTSZ field.
Sourcepub const L0GPTSZ_MASK: u64 = 0b1111
Available on crate feature el3 only.
pub const L0GPTSZ_MASK: u64 = 0b1111
el3 only.Mask for the L0GPTSZ field.
Sourcepub const APPSAA_SHIFT: u32 = 24
Available on crate feature el3 only.
pub const APPSAA_SHIFT: u32 = 24
el3 only.Offset of the APPSAA field.
Sourcepub const GPCBW_SHIFT: u32 = 29
Available on crate feature el3 only.
pub const GPCBW_SHIFT: u32 = 29
el3 only.Offset of the GPCBW field.
Sourcepub const fn pps(self) -> u8
Available on crate feature el3 only.
pub const fn pps(self) -> u8
el3 only.Returns the value of the PPS field.
Sourcepub const fn set_pps(&mut self, value: u8)
Available on crate feature el3 only.
pub const fn set_pps(&mut self, value: u8)
el3 only.Sets the value of the PPS field.
Sourcepub const fn with_pps(self, value: u8) -> Self
Available on crate feature el3 only.
pub const fn with_pps(self, value: u8) -> Self
el3 only.Returns a copy with the PPS field set to the given value.
Sourcepub fn irgn(self) -> Cacheability
Available on crate feature el3 only.
pub fn irgn(self) -> Cacheability
el3 only.Returns the value of the IRGN field.
Sourcepub fn set_irgn(&mut self, value: Cacheability)
Available on crate feature el3 only.
pub fn set_irgn(&mut self, value: Cacheability)
el3 only.Sets the value of the IRGN field.
Sourcepub fn with_irgn(self, value: Cacheability) -> Self
Available on crate feature el3 only.
pub fn with_irgn(self, value: Cacheability) -> Self
el3 only.Returns a copy with the IRGN field set to the given value.
Sourcepub fn orgn(self) -> Cacheability
Available on crate feature el3 only.
pub fn orgn(self) -> Cacheability
el3 only.Returns the value of the ORGN field.
Sourcepub fn set_orgn(&mut self, value: Cacheability)
Available on crate feature el3 only.
pub fn set_orgn(&mut self, value: Cacheability)
el3 only.Sets the value of the ORGN field.
Sourcepub fn with_orgn(self, value: Cacheability) -> Self
Available on crate feature el3 only.
pub fn with_orgn(self, value: Cacheability) -> Self
el3 only.Returns a copy with the ORGN field set to the given value.
Sourcepub fn sh(self) -> Shareability
Available on crate feature el3 only.
pub fn sh(self) -> Shareability
el3 only.Returns the value of the SH field.
Sourcepub fn set_sh(&mut self, value: Shareability)
Available on crate feature el3 only.
pub fn set_sh(&mut self, value: Shareability)
el3 only.Sets the value of the SH field.
Sourcepub fn with_sh(self, value: Shareability) -> Self
Available on crate feature el3 only.
pub fn with_sh(self, value: Shareability) -> Self
el3 only.Returns a copy with the SH field set to the given value.
Sourcepub const fn pgs(self) -> u8
Available on crate feature el3 only.
pub const fn pgs(self) -> u8
el3 only.Returns the value of the PGS field.
Sourcepub const fn set_pgs(&mut self, value: u8)
Available on crate feature el3 only.
pub const fn set_pgs(&mut self, value: u8)
el3 only.Sets the value of the PGS field.
Sourcepub const fn with_pgs(self, value: u8) -> Self
Available on crate feature el3 only.
pub const fn with_pgs(self, value: u8) -> Self
el3 only.Returns a copy with the PGS field set to the given value.
Sourcepub const fn l0gptsz(self) -> u8
Available on crate feature el3 only.
pub const fn l0gptsz(self) -> u8
el3 only.Returns the value of the L0GPTSZ field.
Sourcepub const fn set_l0gptsz(&mut self, value: u8)
Available on crate feature el3 only.
pub const fn set_l0gptsz(&mut self, value: u8)
el3 only.Sets the value of the L0GPTSZ field.
Sourcepub const fn with_l0gptsz(self, value: u8) -> Self
Available on crate feature el3 only.
pub const fn with_l0gptsz(self, value: u8) -> Self
el3 only.Returns a copy with the L0GPTSZ field set to the given value.