pub struct Hcr(/* private fields */);Expand description
HCR system register value.
Implementations
Sourceimpl Hcr
impl Hcr
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl Hcr
impl Hcr
Sourcepub const fn iter(&self) -> Iter<Hcr>
pub const fn iter(&self) -> Iter<Hcr>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<Hcr>
pub const fn iter_names(&self) -> IterNames<Hcr>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl Hcr
impl Hcr
Sourcepub const SWIO_SHIFT: u32 = 1
pub const SWIO_SHIFT: u32 = 1
Offset of the SWIO field.
Sourcepub const TID0_SHIFT: u32 = 15
pub const TID0_SHIFT: u32 = 15
Offset of the TID0 field.
Sourcepub const TID1_SHIFT: u32 = 16
pub const TID1_SHIFT: u32 = 16
Offset of the TID1 field.
Sourcepub const TID2_SHIFT: u32 = 17
pub const TID2_SHIFT: u32 = 17
Offset of the TID2 field.
Sourcepub const TID3_SHIFT: u32 = 18
pub const TID3_SHIFT: u32 = 18
Offset of the TID3 field.
Sourcepub const TIDCP_SHIFT: u32 = 20
pub const TIDCP_SHIFT: u32 = 20
Offset of the TIDCP field.
Sourcepub const TTLB_SHIFT: u32 = 25
pub const TTLB_SHIFT: u32 = 25
Offset of the TTLB field.
Sourcepub const TRVM_SHIFT: u32 = 30
pub const TRVM_SHIFT: u32 = 30
Offset of the TRVM field.