pub struct HcrxEl2(/* private fields */);Expand description
HCRX_EL2 system register value.
Extended Hypervisor Configuration Register.
Implementations
Sourceimpl HcrxEl2
impl HcrxEl2
Sourcepub const ENALS: Self
pub const ENALS: Self
Do not trap execution of an LD64B or ST64B instruction at EL0 or EL1 to EL2.
Sourcepub const FNXS: Self
pub const FNXS: Self
Determines the behavior of TLBI instructions affected by the XS attribute.
Sourcepub const FGTNXS: Self
pub const FGTNXS: Self
Determines if the fine-grained traps in HFGITR_EL2 also apply to the corresponding TLBI maintenance instructions with the nXS qualifier.
Sourcepub const SMPME: Self
pub const SMPME: Self
Controls mapping of the value of SMPRI_EL1.Priority for streaming execution priority at EL0 or EL1.
Sourcepub const CMOW: Self
pub const CMOW: Self
Controls the required permissions for cache maintenance instructions at EL1 or EL0.
Sourcepub const MSCEN: Self
pub const MSCEN: Self
Enables execution of Memory Set and Memory Copy instructions at EL1 or EL0.
Sourcepub const VTLBIDOSEN: Self
pub const VTLBIDOSEN: Self
VTLBIDOSEn bit.
Sourceimpl HcrxEl2
impl HcrxEl2
Sourcepub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u64) -> Option<Self>
pub const fn from_bits(bits: u64) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u64) -> Self
pub const fn from_bits_truncate(bits: u64) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u64) -> Self
pub const fn from_bits_retain(bits: u64) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl HcrxEl2
impl HcrxEl2
Sourcepub const fn iter(&self) -> Iter<HcrxEl2>
pub const fn iter(&self) -> Iter<HcrxEl2>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<HcrxEl2>
pub const fn iter_names(&self) -> IterNames<HcrxEl2>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl HcrxEl2
impl HcrxEl2
Sourcepub const ENAS0_SHIFT: u32 = 0
Available on crate feature el2 only.
pub const ENAS0_SHIFT: u32 = 0
el2 only.Offset of the EnAS0 field.
Sourcepub const ENALS_SHIFT: u32 = 1
Available on crate feature el2 only.
pub const ENALS_SHIFT: u32 = 1
el2 only.Offset of the EnALS field.
Sourcepub const ENASR_SHIFT: u32 = 2
Available on crate feature el2 only.
pub const ENASR_SHIFT: u32 = 2
el2 only.Offset of the EnASR field.
Sourcepub const FNXS_SHIFT: u32 = 3
Available on crate feature el2 only.
pub const FNXS_SHIFT: u32 = 3
el2 only.Offset of the FnXS field.
Sourcepub const FGTNXS_SHIFT: u32 = 4
Available on crate feature el2 only.
pub const FGTNXS_SHIFT: u32 = 4
el2 only.Offset of the FGTnXS field.
Sourcepub const SMPME_SHIFT: u32 = 5
Available on crate feature el2 only.
pub const SMPME_SHIFT: u32 = 5
el2 only.Offset of the SMPME field.
Sourcepub const TALLINT_SHIFT: u32 = 6
Available on crate feature el2 only.
pub const TALLINT_SHIFT: u32 = 6
el2 only.Offset of the TALLINT field.
Sourcepub const VINMI_SHIFT: u32 = 7
Available on crate feature el2 only.
pub const VINMI_SHIFT: u32 = 7
el2 only.Offset of the VINMI field.
Sourcepub const VFNMI_SHIFT: u32 = 8
Available on crate feature el2 only.
pub const VFNMI_SHIFT: u32 = 8
el2 only.Offset of the VFNMI field.
Sourcepub const CMOW_SHIFT: u32 = 9
Available on crate feature el2 only.
pub const CMOW_SHIFT: u32 = 9
el2 only.Offset of the CMOW field.
Sourcepub const MCE2_SHIFT: u32 = 10
Available on crate feature el2 only.
pub const MCE2_SHIFT: u32 = 10
el2 only.Offset of the MCE2 field.
Sourcepub const MSCEN_SHIFT: u32 = 11
Available on crate feature el2 only.
pub const MSCEN_SHIFT: u32 = 11
el2 only.Offset of the MSCEn field.
Sourcepub const TCR2EN_SHIFT: u32 = 14
Available on crate feature el2 only.
pub const TCR2EN_SHIFT: u32 = 14
el2 only.Offset of the TCR2En field.
Sourcepub const SCTLR2EN_SHIFT: u32 = 15
Available on crate feature el2 only.
pub const SCTLR2EN_SHIFT: u32 = 15
el2 only.Offset of the SCTLR2En field.
Sourcepub const PTTWI_SHIFT: u32 = 16
Available on crate feature el2 only.
pub const PTTWI_SHIFT: u32 = 16
el2 only.Offset of the PTTWI field.
Sourcepub const D128EN_SHIFT: u32 = 17
Available on crate feature el2 only.
pub const D128EN_SHIFT: u32 = 17
el2 only.Offset of the D128En field.
Sourcepub const ENSNERR_SHIFT: u32 = 18
Available on crate feature el2 only.
pub const ENSNERR_SHIFT: u32 = 18
el2 only.Offset of the EnSNERR field.
Sourcepub const TMEA_SHIFT: u32 = 19
Available on crate feature el2 only.
pub const TMEA_SHIFT: u32 = 19
el2 only.Offset of the TMEA field.
Sourcepub const ENSDERR_SHIFT: u32 = 20
Available on crate feature el2 only.
pub const ENSDERR_SHIFT: u32 = 20
el2 only.Offset of the EnSDERR field.
Sourcepub const ENIDCP128_SHIFT: u32 = 21
Available on crate feature el2 only.
pub const ENIDCP128_SHIFT: u32 = 21
el2 only.Offset of the EnIDCP128 field.
Sourcepub const GCSEN_SHIFT: u32 = 22
Available on crate feature el2 only.
pub const GCSEN_SHIFT: u32 = 22
el2 only.Offset of the GCSEn field.
Sourcepub const ENFPM_SHIFT: u32 = 23
Available on crate feature el2 only.
pub const ENFPM_SHIFT: u32 = 23
el2 only.Offset of the EnFPM field.
Sourcepub const PACMEN_SHIFT: u32 = 24
Available on crate feature el2 only.
pub const PACMEN_SHIFT: u32 = 24
el2 only.Offset of the PACMEn field.
Sourcepub const VTLBIDEN_SHIFT: u32 = 25
Available on crate feature el2 only.
pub const VTLBIDEN_SHIFT: u32 = 25
el2 only.Offset of the VTLBIDEn field.
Sourcepub const SRMASKEN_SHIFT: u32 = 26
Available on crate feature el2 only.
pub const SRMASKEN_SHIFT: u32 = 26
el2 only.Offset of the SRMASKEn field.
Sourcepub const NVTGE_SHIFT: u32 = 27
Available on crate feature el2 only.
pub const NVTGE_SHIFT: u32 = 27
el2 only.Offset of the NVTGE field.
Sourcepub const POE2EN_SHIFT: u32 = 29
Available on crate feature el2 only.
pub const POE2EN_SHIFT: u32 = 29
el2 only.Offset of the POE2En field.
Sourcepub const TPLIMEN_SHIFT: u32 = 30
Available on crate feature el2 only.
pub const TPLIMEN_SHIFT: u32 = 30
el2 only.Offset of the TPLIMEn field.
Sourcepub const FDIT_SHIFT: u32 = 31
Available on crate feature el2 only.
pub const FDIT_SHIFT: u32 = 31
el2 only.Offset of the FDIT field.
Sourcepub const NVNTTLB_SHIFT: u32 = 32
Available on crate feature el2 only.
pub const NVNTTLB_SHIFT: u32 = 32
el2 only.Offset of the NVnTTLB field.
Sourcepub const NVNTTLBIS_SHIFT: u32 = 33
Available on crate feature el2 only.
pub const NVNTTLBIS_SHIFT: u32 = 33
el2 only.Offset of the NVnTTLBIS field.
Sourcepub const NVNTTLBOS_SHIFT: u32 = 34
Available on crate feature el2 only.
pub const NVNTTLBOS_SHIFT: u32 = 34
el2 only.Offset of the NVnTTLBOS field.
Sourcepub const VTLBIDOSEN_SHIFT: u32 = 35
Available on crate feature el2 only.
pub const VTLBIDOSEN_SHIFT: u32 = 35
el2 only.Offset of the VTLBIDOSEn field.
Sourcepub const VTAO_SHIFT: u32 = 38
Available on crate feature el2 only.
pub const VTAO_SHIFT: u32 = 38
el2 only.Offset of the VTAO field.
Sourcepub const VTCO_SHIFT: u32 = 39
Available on crate feature el2 only.
pub const VTCO_SHIFT: u32 = 39
el2 only.Offset of the VTCO field.