pub struct HdfgrtrEl2(/* private fields */);Expand description
HDFGRTR_EL2 system register value.
Implementations
Sourceimpl HdfgrtrEl2
impl HdfgrtrEl2
Sourcepub const DBGBCRN_EL1: Self
pub const DBGBCRN_EL1: Self
DBGBCRn_EL1 bit.
Sourcepub const DBGBVRN_EL1: Self
pub const DBGBVRN_EL1: Self
DBGBVRn_EL1 bit.
Sourcepub const DBGWCRN_EL1: Self
pub const DBGWCRN_EL1: Self
DBGWCRn_EL1 bit.
Sourcepub const DBGWVRN_EL1: Self
pub const DBGWVRN_EL1: Self
DBGWVRn_EL1 bit.
Sourcepub const DBGAUTHSTATUS_EL1: Self
pub const DBGAUTHSTATUS_EL1: Self
DBGAUTHSTATUS_EL1 bit.
Sourcepub const DBGPRCR_EL1: Self
pub const DBGPRCR_EL1: Self
DBGPRCR_EL1 bit.
Sourcepub const OSECCR_EL1: Self
pub const OSECCR_EL1: Self
OSECCR_EL1 bit.
Sourcepub const PMEVCNTRN_EL0: Self
pub const PMEVCNTRN_EL0: Self
PMEVCNTRn_EL0 bit.
Sourcepub const PMEVTYPERN_EL0: Self
pub const PMEVTYPERN_EL0: Self
PMEVTYPERn_EL0 bit.
Sourcepub const PMCCFILTR_EL0: Self
pub const PMCCFILTR_EL0: Self
PMCCFILTR_EL0 bit.
Sourcepub const PMCCNTR_EL0: Self
pub const PMCCNTR_EL0: Self
PMCCNTR_EL0 bit.
Sourcepub const PMSELR_EL0: Self
pub const PMSELR_EL0: Self
PMSELR_EL0 bit.
Sourcepub const PMBLIMITR_EL1: Self
pub const PMBLIMITR_EL1: Self
PMBLIMITR_EL1 bit.
Sourcepub const PMBPTR_EL1: Self
pub const PMBPTR_EL1: Self
PMBPTR_EL1 bit.
Sourcepub const PMSEVFR_EL1: Self
pub const PMSEVFR_EL1: Self
PMSEVFR_EL1 bit.
Sourcepub const PMSFCR_EL1: Self
pub const PMSFCR_EL1: Self
PMSFCR_EL1 bit.
Sourcepub const PMSICR_EL1: Self
pub const PMSICR_EL1: Self
PMSICR_EL1 bit.
Sourcepub const PMSIDR_EL1: Self
pub const PMSIDR_EL1: Self
PMSIDR_EL1 bit.
Sourcepub const PMSIRR_EL1: Self
pub const PMSIRR_EL1: Self
PMSIRR_EL1 bit.
Sourcepub const PMSLATFR_EL1: Self
pub const PMSLATFR_EL1: Self
PMSLATFR_EL1 bit.
Sourcepub const TRCAUTHSTATUS: Self
pub const TRCAUTHSTATUS: Self
TRCAUTHSTATUS bit.
Sourcepub const TRCAUXCTLR: Self
pub const TRCAUXCTLR: Self
TRCAUXCTLR bit.
Sourcepub const TRCIMSPECN: Self
pub const TRCIMSPECN: Self
TRCIMSPECn bit.
Sourcepub const TRCPRGCTLR: Self
pub const TRCPRGCTLR: Self
TRCPRGCTLR bit.
Sourcepub const TRBBASER_EL1: Self
pub const TRBBASER_EL1: Self
TRBBASER_EL1 bit.
Sourcepub const TRBIDR_EL1: Self
pub const TRBIDR_EL1: Self
TRBIDR_EL1 bit.
Sourcepub const TRBLIMITR_EL1: Self
pub const TRBLIMITR_EL1: Self
TRBLIMITR_EL1 bit.
Sourcepub const TRBMAR_EL1: Self
pub const TRBMAR_EL1: Self
TRBMAR_EL1 bit.
Sourcepub const TRBPTR_EL1: Self
pub const TRBPTR_EL1: Self
TRBPTR_EL1 bit.
Sourcepub const TRBTRG_EL1: Self
pub const TRBTRG_EL1: Self
TRBTRG_EL1 bit.
Sourcepub const PMUSERENR_EL0: Self
pub const PMUSERENR_EL0: Self
PMUSERENR_EL0 bit.
Sourcepub const PMCEIDN_EL0: Self
pub const PMCEIDN_EL0: Self
PMCEIDn_EL0 bit.
Sourcepub const NPMSNEVFR_EL1: Self
pub const NPMSNEVFR_EL1: Self
nPMSNEVFR_EL1 bit.
Sourcepub const PMBIDR_EL1: Self
pub const PMBIDR_EL1: Self
PMBIDR_EL1 bit.
Sourceimpl HdfgrtrEl2
impl HdfgrtrEl2
Sourcepub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u64) -> Option<Self>
pub const fn from_bits(bits: u64) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u64) -> Self
pub const fn from_bits_truncate(bits: u64) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u64) -> Self
pub const fn from_bits_retain(bits: u64) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl HdfgrtrEl2
impl HdfgrtrEl2
Sourcepub const fn iter(&self) -> Iter<HdfgrtrEl2>
pub const fn iter(&self) -> Iter<HdfgrtrEl2>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<HdfgrtrEl2>
pub const fn iter_names(&self) -> IterNames<HdfgrtrEl2>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl HdfgrtrEl2
impl HdfgrtrEl2
Sourcepub const DBGBCRN_EL1_SHIFT: u32 = 0
Available on crate feature el2 only.
pub const DBGBCRN_EL1_SHIFT: u32 = 0
el2 only.Offset of the DBGBCRn_EL1 field.
Sourcepub const DBGBVRN_EL1_SHIFT: u32 = 1
Available on crate feature el2 only.
pub const DBGBVRN_EL1_SHIFT: u32 = 1
el2 only.Offset of the DBGBVRn_EL1 field.
Sourcepub const DBGWCRN_EL1_SHIFT: u32 = 2
Available on crate feature el2 only.
pub const DBGWCRN_EL1_SHIFT: u32 = 2
el2 only.Offset of the DBGWCRn_EL1 field.
Sourcepub const DBGWVRN_EL1_SHIFT: u32 = 3
Available on crate feature el2 only.
pub const DBGWVRN_EL1_SHIFT: u32 = 3
el2 only.Offset of the DBGWVRn_EL1 field.
Sourcepub const MDSCR_EL1_SHIFT: u32 = 4
Available on crate feature el2 only.
pub const MDSCR_EL1_SHIFT: u32 = 4
el2 only.Offset of the MDSCR_EL1 field.
Sourcepub const DBGCLAIM_SHIFT: u32 = 5
Available on crate feature el2 only.
pub const DBGCLAIM_SHIFT: u32 = 5
el2 only.Offset of the DBGCLAIM field.
Sourcepub const DBGAUTHSTATUS_EL1_SHIFT: u32 = 6
Available on crate feature el2 only.
pub const DBGAUTHSTATUS_EL1_SHIFT: u32 = 6
el2 only.Offset of the DBGAUTHSTATUS_EL1 field.
Sourcepub const DBGPRCR_EL1_SHIFT: u32 = 7
Available on crate feature el2 only.
pub const DBGPRCR_EL1_SHIFT: u32 = 7
el2 only.Offset of the DBGPRCR_EL1 field.
Sourcepub const OSLSR_EL1_SHIFT: u32 = 9
Available on crate feature el2 only.
pub const OSLSR_EL1_SHIFT: u32 = 9
el2 only.Offset of the OSLSR_EL1 field.
Sourcepub const OSECCR_EL1_SHIFT: u32 = 10
Available on crate feature el2 only.
pub const OSECCR_EL1_SHIFT: u32 = 10
el2 only.Offset of the OSECCR_EL1 field.
Sourcepub const OSDLR_EL1_SHIFT: u32 = 11
Available on crate feature el2 only.
pub const OSDLR_EL1_SHIFT: u32 = 11
el2 only.Offset of the OSDLR_EL1 field.
Sourcepub const PMEVCNTRN_EL0_SHIFT: u32 = 12
Available on crate feature el2 only.
pub const PMEVCNTRN_EL0_SHIFT: u32 = 12
el2 only.Offset of the PMEVCNTRn_EL0 field.
Sourcepub const PMEVTYPERN_EL0_SHIFT: u32 = 13
Available on crate feature el2 only.
pub const PMEVTYPERN_EL0_SHIFT: u32 = 13
el2 only.Offset of the PMEVTYPERn_EL0 field.
Sourcepub const PMCCFILTR_EL0_SHIFT: u32 = 14
Available on crate feature el2 only.
pub const PMCCFILTR_EL0_SHIFT: u32 = 14
el2 only.Offset of the PMCCFILTR_EL0 field.
Sourcepub const PMCCNTR_EL0_SHIFT: u32 = 15
Available on crate feature el2 only.
pub const PMCCNTR_EL0_SHIFT: u32 = 15
el2 only.Offset of the PMCCNTR_EL0 field.
Sourcepub const PMCNTEN_SHIFT: u32 = 16
Available on crate feature el2 only.
pub const PMCNTEN_SHIFT: u32 = 16
el2 only.Offset of the PMCNTEN field.
Sourcepub const PMINTEN_SHIFT: u32 = 17
Available on crate feature el2 only.
pub const PMINTEN_SHIFT: u32 = 17
el2 only.Offset of the PMINTEN field.
Sourcepub const PMOVS_SHIFT: u32 = 18
Available on crate feature el2 only.
pub const PMOVS_SHIFT: u32 = 18
el2 only.Offset of the PMOVS field.
Sourcepub const PMSELR_EL0_SHIFT: u32 = 19
Available on crate feature el2 only.
pub const PMSELR_EL0_SHIFT: u32 = 19
el2 only.Offset of the PMSELR_EL0 field.
Sourcepub const PMMIR_EL1_SHIFT: u32 = 22
Available on crate feature el2 only.
pub const PMMIR_EL1_SHIFT: u32 = 22
el2 only.Offset of the PMMIR_EL1 field.
Sourcepub const PMBLIMITR_EL1_SHIFT: u32 = 23
Available on crate feature el2 only.
pub const PMBLIMITR_EL1_SHIFT: u32 = 23
el2 only.Offset of the PMBLIMITR_EL1 field.
Sourcepub const PMBPTR_EL1_SHIFT: u32 = 24
Available on crate feature el2 only.
pub const PMBPTR_EL1_SHIFT: u32 = 24
el2 only.Offset of the PMBPTR_EL1 field.
Sourcepub const PMBSR_EL1_SHIFT: u32 = 25
Available on crate feature el2 only.
pub const PMBSR_EL1_SHIFT: u32 = 25
el2 only.Offset of the PMBSR_EL1 field.
Sourcepub const PMSCR_EL1_SHIFT: u32 = 26
Available on crate feature el2 only.
pub const PMSCR_EL1_SHIFT: u32 = 26
el2 only.Offset of the PMSCR_EL1 field.
Sourcepub const PMSEVFR_EL1_SHIFT: u32 = 27
Available on crate feature el2 only.
pub const PMSEVFR_EL1_SHIFT: u32 = 27
el2 only.Offset of the PMSEVFR_EL1 field.
Sourcepub const PMSFCR_EL1_SHIFT: u32 = 28
Available on crate feature el2 only.
pub const PMSFCR_EL1_SHIFT: u32 = 28
el2 only.Offset of the PMSFCR_EL1 field.
Sourcepub const PMSICR_EL1_SHIFT: u32 = 29
Available on crate feature el2 only.
pub const PMSICR_EL1_SHIFT: u32 = 29
el2 only.Offset of the PMSICR_EL1 field.
Sourcepub const PMSIDR_EL1_SHIFT: u32 = 30
Available on crate feature el2 only.
pub const PMSIDR_EL1_SHIFT: u32 = 30
el2 only.Offset of the PMSIDR_EL1 field.
Sourcepub const PMSIRR_EL1_SHIFT: u32 = 31
Available on crate feature el2 only.
pub const PMSIRR_EL1_SHIFT: u32 = 31
el2 only.Offset of the PMSIRR_EL1 field.
Sourcepub const PMSLATFR_EL1_SHIFT: u32 = 32
Available on crate feature el2 only.
pub const PMSLATFR_EL1_SHIFT: u32 = 32
el2 only.Offset of the PMSLATFR_EL1 field.
Sourcepub const TRCAUTHSTATUS_SHIFT: u32 = 34
Available on crate feature el2 only.
pub const TRCAUTHSTATUS_SHIFT: u32 = 34
el2 only.Offset of the TRCAUTHSTATUS field.
Sourcepub const TRCAUXCTLR_SHIFT: u32 = 35
Available on crate feature el2 only.
pub const TRCAUXCTLR_SHIFT: u32 = 35
el2 only.Offset of the TRCAUXCTLR field.
Sourcepub const TRCCLAIM_SHIFT: u32 = 36
Available on crate feature el2 only.
pub const TRCCLAIM_SHIFT: u32 = 36
el2 only.Offset of the TRCCLAIM field.
Sourcepub const TRCCNTVRN_SHIFT: u32 = 37
Available on crate feature el2 only.
pub const TRCCNTVRN_SHIFT: u32 = 37
el2 only.Offset of the TRCCNTVRn field.
Sourcepub const TRCID_SHIFT: u32 = 40
Available on crate feature el2 only.
pub const TRCID_SHIFT: u32 = 40
el2 only.Offset of the TRCID field.
Sourcepub const TRCIMSPECN_SHIFT: u32 = 41
Available on crate feature el2 only.
pub const TRCIMSPECN_SHIFT: u32 = 41
el2 only.Offset of the TRCIMSPECn field.
Sourcepub const TRCOSLSR_SHIFT: u32 = 43
Available on crate feature el2 only.
pub const TRCOSLSR_SHIFT: u32 = 43
el2 only.Offset of the TRCOSLSR field.
Sourcepub const TRCPRGCTLR_SHIFT: u32 = 44
Available on crate feature el2 only.
pub const TRCPRGCTLR_SHIFT: u32 = 44
el2 only.Offset of the TRCPRGCTLR field.
Sourcepub const TRCSEQSTR_SHIFT: u32 = 45
Available on crate feature el2 only.
pub const TRCSEQSTR_SHIFT: u32 = 45
el2 only.Offset of the TRCSEQSTR field.
Sourcepub const TRCSSCSRN_SHIFT: u32 = 46
Available on crate feature el2 only.
pub const TRCSSCSRN_SHIFT: u32 = 46
el2 only.Offset of the TRCSSCSRn field.
Sourcepub const TRCSTATR_SHIFT: u32 = 47
Available on crate feature el2 only.
pub const TRCSTATR_SHIFT: u32 = 47
el2 only.Offset of the TRCSTATR field.
Sourcepub const TRCVICTLR_SHIFT: u32 = 48
Available on crate feature el2 only.
pub const TRCVICTLR_SHIFT: u32 = 48
el2 only.Offset of the TRCVICTLR field.
Sourcepub const TRBBASER_EL1_SHIFT: u32 = 50
Available on crate feature el2 only.
pub const TRBBASER_EL1_SHIFT: u32 = 50
el2 only.Offset of the TRBBASER_EL1 field.
Sourcepub const TRBIDR_EL1_SHIFT: u32 = 51
Available on crate feature el2 only.
pub const TRBIDR_EL1_SHIFT: u32 = 51
el2 only.Offset of the TRBIDR_EL1 field.
Sourcepub const TRBLIMITR_EL1_SHIFT: u32 = 52
Available on crate feature el2 only.
pub const TRBLIMITR_EL1_SHIFT: u32 = 52
el2 only.Offset of the TRBLIMITR_EL1 field.
Sourcepub const TRBMAR_EL1_SHIFT: u32 = 53
Available on crate feature el2 only.
pub const TRBMAR_EL1_SHIFT: u32 = 53
el2 only.Offset of the TRBMAR_EL1 field.
Sourcepub const TRBPTR_EL1_SHIFT: u32 = 54
Available on crate feature el2 only.
pub const TRBPTR_EL1_SHIFT: u32 = 54
el2 only.Offset of the TRBPTR_EL1 field.
Sourcepub const TRBSR_EL1_SHIFT: u32 = 55
Available on crate feature el2 only.
pub const TRBSR_EL1_SHIFT: u32 = 55
el2 only.Offset of the TRBSR_EL1 field.
Sourcepub const TRBTRG_EL1_SHIFT: u32 = 56
Available on crate feature el2 only.
pub const TRBTRG_EL1_SHIFT: u32 = 56
el2 only.Offset of the TRBTRG_EL1 field.
Sourcepub const PMUSERENR_EL0_SHIFT: u32 = 57
Available on crate feature el2 only.
pub const PMUSERENR_EL0_SHIFT: u32 = 57
el2 only.Offset of the PMUSERENR_EL0 field.
Sourcepub const PMCEIDN_EL0_SHIFT: u32 = 58
Available on crate feature el2 only.
pub const PMCEIDN_EL0_SHIFT: u32 = 58
el2 only.Offset of the PMCEIDn_EL0 field.
Sourcepub const NBRBIDR_SHIFT: u32 = 59
Available on crate feature el2 only.
pub const NBRBIDR_SHIFT: u32 = 59
el2 only.Offset of the nBRBIDR field.
Sourcepub const NBRBCTL_SHIFT: u32 = 60
Available on crate feature el2 only.
pub const NBRBCTL_SHIFT: u32 = 60
el2 only.Offset of the nBRBCTL field.
Sourcepub const NBRBDATA_SHIFT: u32 = 61
Available on crate feature el2 only.
pub const NBRBDATA_SHIFT: u32 = 61
el2 only.Offset of the nBRBDATA field.
Sourcepub const NPMSNEVFR_EL1_SHIFT: u32 = 62
Available on crate feature el2 only.
pub const NPMSNEVFR_EL1_SHIFT: u32 = 62
el2 only.Offset of the nPMSNEVFR_EL1 field.
Sourcepub const PMBIDR_EL1_SHIFT: u32 = 63
Available on crate feature el2 only.
pub const PMBIDR_EL1_SHIFT: u32 = 63
el2 only.Offset of the PMBIDR_EL1 field.