pub struct HfgitrEl2(/* private fields */);Expand description
HFGITR_EL2 system register value.
Implementations
Sourceimpl HfgitrEl2
impl HfgitrEl2
Sourcepub const TLBIVMALLE1OS: Self
pub const TLBIVMALLE1OS: Self
TLBIVMALLE1OS bit.
Sourcepub const TLBIVAE1OS: Self
pub const TLBIVAE1OS: Self
TLBIVAE1OS bit.
Sourcepub const TLBIASIDE1OS: Self
pub const TLBIASIDE1OS: Self
TLBIASIDE1OS bit.
Sourcepub const TLBIVAAE1OS: Self
pub const TLBIVAAE1OS: Self
TLBIVAAE1OS bit.
Sourcepub const TLBIVALE1OS: Self
pub const TLBIVALE1OS: Self
TLBIVALE1OS bit.
Sourcepub const TLBIVAALE1OS: Self
pub const TLBIVAALE1OS: Self
TLBIVAALE1OS bit.
Sourcepub const TLBIRVAE1OS: Self
pub const TLBIRVAE1OS: Self
TLBIRVAE1OS bit.
Sourcepub const TLBIRVAAE1OS: Self
pub const TLBIRVAAE1OS: Self
TLBIRVAAE1OS bit.
Sourcepub const TLBIRVALE1OS: Self
pub const TLBIRVALE1OS: Self
TLBIRVALE1OS bit.
Sourcepub const TLBIRVAALE1OS: Self
pub const TLBIRVAALE1OS: Self
TLBIRVAALE1OS bit.
Sourcepub const TLBIVMALLE1IS: Self
pub const TLBIVMALLE1IS: Self
TLBIVMALLE1IS bit.
Sourcepub const TLBIVAE1IS: Self
pub const TLBIVAE1IS: Self
TLBIVAE1IS bit.
Sourcepub const TLBIASIDE1IS: Self
pub const TLBIASIDE1IS: Self
TLBIASIDE1IS bit.
Sourcepub const TLBIVAAE1IS: Self
pub const TLBIVAAE1IS: Self
TLBIVAAE1IS bit.
Sourcepub const TLBIVALE1IS: Self
pub const TLBIVALE1IS: Self
TLBIVALE1IS bit.
Sourcepub const TLBIVAALE1IS: Self
pub const TLBIVAALE1IS: Self
TLBIVAALE1IS bit.
Sourcepub const TLBIRVAE1IS: Self
pub const TLBIRVAE1IS: Self
TLBIRVAE1IS bit.
Sourcepub const TLBIRVAAE1IS: Self
pub const TLBIRVAAE1IS: Self
TLBIRVAAE1IS bit.
Sourcepub const TLBIRVALE1IS: Self
pub const TLBIRVALE1IS: Self
TLBIRVALE1IS bit.
Sourcepub const TLBIRVAALE1IS: Self
pub const TLBIRVAALE1IS: Self
TLBIRVAALE1IS bit.
Sourcepub const TLBIRVAAE1: Self
pub const TLBIRVAAE1: Self
TLBIRVAAE1 bit.
Sourcepub const TLBIRVALE1: Self
pub const TLBIRVALE1: Self
TLBIRVALE1 bit.
Sourcepub const TLBIRVAALE1: Self
pub const TLBIRVAALE1: Self
TLBIRVAALE1 bit.
Sourcepub const TLBIVMALLE1: Self
pub const TLBIVMALLE1: Self
TLBIVMALLE1 bit.
Sourcepub const TLBIASIDE1: Self
pub const TLBIASIDE1: Self
TLBIASIDE1 bit.
Sourcepub const TLBIVAALE1: Self
pub const TLBIVAALE1: Self
TLBIVAALE1 bit.
Sourcepub const NGCSPUSHM_EL1: Self
pub const NGCSPUSHM_EL1: Self
nGCSPUSHM_EL1 bit.
Sourcepub const NGCSSTR_EL1: Self
pub const NGCSSTR_EL1: Self
nGCSSTR_EL1 bit.
Sourceimpl HfgitrEl2
impl HfgitrEl2
Sourcepub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u64) -> Option<Self>
pub const fn from_bits(bits: u64) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u64) -> Self
pub const fn from_bits_truncate(bits: u64) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u64) -> Self
pub const fn from_bits_retain(bits: u64) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl HfgitrEl2
impl HfgitrEl2
Sourcepub const fn iter(&self) -> Iter<HfgitrEl2>
pub const fn iter(&self) -> Iter<HfgitrEl2>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<HfgitrEl2>
pub const fn iter_names(&self) -> IterNames<HfgitrEl2>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl HfgitrEl2
impl HfgitrEl2
Sourcepub const ICIALLUIS_SHIFT: u32 = 0
Available on crate feature el2 only.
pub const ICIALLUIS_SHIFT: u32 = 0
el2 only.Offset of the ICIALLUIS field.
Sourcepub const ICIALLU_SHIFT: u32 = 1
Available on crate feature el2 only.
pub const ICIALLU_SHIFT: u32 = 1
el2 only.Offset of the ICIALLU field.
Sourcepub const ICIVAU_SHIFT: u32 = 2
Available on crate feature el2 only.
pub const ICIVAU_SHIFT: u32 = 2
el2 only.Offset of the ICIVAU field.
Sourcepub const DCIVAC_SHIFT: u32 = 3
Available on crate feature el2 only.
pub const DCIVAC_SHIFT: u32 = 3
el2 only.Offset of the DCIVAC field.
Sourcepub const DCISW_SHIFT: u32 = 4
Available on crate feature el2 only.
pub const DCISW_SHIFT: u32 = 4
el2 only.Offset of the DCISW field.
Sourcepub const DCCSW_SHIFT: u32 = 5
Available on crate feature el2 only.
pub const DCCSW_SHIFT: u32 = 5
el2 only.Offset of the DCCSW field.
Sourcepub const DCCISW_SHIFT: u32 = 6
Available on crate feature el2 only.
pub const DCCISW_SHIFT: u32 = 6
el2 only.Offset of the DCCISW field.
Sourcepub const DCCVAU_SHIFT: u32 = 7
Available on crate feature el2 only.
pub const DCCVAU_SHIFT: u32 = 7
el2 only.Offset of the DCCVAU field.
Sourcepub const DCCVAP_SHIFT: u32 = 8
Available on crate feature el2 only.
pub const DCCVAP_SHIFT: u32 = 8
el2 only.Offset of the DCCVAP field.
Sourcepub const DCCVADP_SHIFT: u32 = 9
Available on crate feature el2 only.
pub const DCCVADP_SHIFT: u32 = 9
el2 only.Offset of the DCCVADP field.
Sourcepub const DCCIVAC_SHIFT: u32 = 10
Available on crate feature el2 only.
pub const DCCIVAC_SHIFT: u32 = 10
el2 only.Offset of the DCCIVAC field.
Sourcepub const DCZVA_SHIFT: u32 = 11
Available on crate feature el2 only.
pub const DCZVA_SHIFT: u32 = 11
el2 only.Offset of the DCZVA field.
Sourcepub const ATS1E1R_SHIFT: u32 = 12
Available on crate feature el2 only.
pub const ATS1E1R_SHIFT: u32 = 12
el2 only.Offset of the ATS1E1R field.
Sourcepub const ATS1E1W_SHIFT: u32 = 13
Available on crate feature el2 only.
pub const ATS1E1W_SHIFT: u32 = 13
el2 only.Offset of the ATS1E1W field.
Sourcepub const ATS1E0R_SHIFT: u32 = 14
Available on crate feature el2 only.
pub const ATS1E0R_SHIFT: u32 = 14
el2 only.Offset of the ATS1E0R field.
Sourcepub const ATS1E0W_SHIFT: u32 = 15
Available on crate feature el2 only.
pub const ATS1E0W_SHIFT: u32 = 15
el2 only.Offset of the ATS1E0W field.
Sourcepub const ATS1E1RP_SHIFT: u32 = 16
Available on crate feature el2 only.
pub const ATS1E1RP_SHIFT: u32 = 16
el2 only.Offset of the ATS1E1RP field.
Sourcepub const ATS1E1WP_SHIFT: u32 = 17
Available on crate feature el2 only.
pub const ATS1E1WP_SHIFT: u32 = 17
el2 only.Offset of the ATS1E1WP field.
Sourcepub const TLBIVMALLE1OS_SHIFT: u32 = 18
Available on crate feature el2 only.
pub const TLBIVMALLE1OS_SHIFT: u32 = 18
el2 only.Offset of the TLBIVMALLE1OS field.
Sourcepub const TLBIVAE1OS_SHIFT: u32 = 19
Available on crate feature el2 only.
pub const TLBIVAE1OS_SHIFT: u32 = 19
el2 only.Offset of the TLBIVAE1OS field.
Sourcepub const TLBIASIDE1OS_SHIFT: u32 = 20
Available on crate feature el2 only.
pub const TLBIASIDE1OS_SHIFT: u32 = 20
el2 only.Offset of the TLBIASIDE1OS field.
Sourcepub const TLBIVAAE1OS_SHIFT: u32 = 21
Available on crate feature el2 only.
pub const TLBIVAAE1OS_SHIFT: u32 = 21
el2 only.Offset of the TLBIVAAE1OS field.
Sourcepub const TLBIVALE1OS_SHIFT: u32 = 22
Available on crate feature el2 only.
pub const TLBIVALE1OS_SHIFT: u32 = 22
el2 only.Offset of the TLBIVALE1OS field.
Sourcepub const TLBIVAALE1OS_SHIFT: u32 = 23
Available on crate feature el2 only.
pub const TLBIVAALE1OS_SHIFT: u32 = 23
el2 only.Offset of the TLBIVAALE1OS field.
Sourcepub const TLBIRVAE1OS_SHIFT: u32 = 24
Available on crate feature el2 only.
pub const TLBIRVAE1OS_SHIFT: u32 = 24
el2 only.Offset of the TLBIRVAE1OS field.
Sourcepub const TLBIRVAAE1OS_SHIFT: u32 = 25
Available on crate feature el2 only.
pub const TLBIRVAAE1OS_SHIFT: u32 = 25
el2 only.Offset of the TLBIRVAAE1OS field.
Sourcepub const TLBIRVALE1OS_SHIFT: u32 = 26
Available on crate feature el2 only.
pub const TLBIRVALE1OS_SHIFT: u32 = 26
el2 only.Offset of the TLBIRVALE1OS field.
Sourcepub const TLBIRVAALE1OS_SHIFT: u32 = 27
Available on crate feature el2 only.
pub const TLBIRVAALE1OS_SHIFT: u32 = 27
el2 only.Offset of the TLBIRVAALE1OS field.
Sourcepub const TLBIVMALLE1IS_SHIFT: u32 = 28
Available on crate feature el2 only.
pub const TLBIVMALLE1IS_SHIFT: u32 = 28
el2 only.Offset of the TLBIVMALLE1IS field.
Sourcepub const TLBIVAE1IS_SHIFT: u32 = 29
Available on crate feature el2 only.
pub const TLBIVAE1IS_SHIFT: u32 = 29
el2 only.Offset of the TLBIVAE1IS field.
Sourcepub const TLBIASIDE1IS_SHIFT: u32 = 30
Available on crate feature el2 only.
pub const TLBIASIDE1IS_SHIFT: u32 = 30
el2 only.Offset of the TLBIASIDE1IS field.
Sourcepub const TLBIVAAE1IS_SHIFT: u32 = 31
Available on crate feature el2 only.
pub const TLBIVAAE1IS_SHIFT: u32 = 31
el2 only.Offset of the TLBIVAAE1IS field.
Sourcepub const TLBIVALE1IS_SHIFT: u32 = 32
Available on crate feature el2 only.
pub const TLBIVALE1IS_SHIFT: u32 = 32
el2 only.Offset of the TLBIVALE1IS field.
Sourcepub const TLBIVAALE1IS_SHIFT: u32 = 33
Available on crate feature el2 only.
pub const TLBIVAALE1IS_SHIFT: u32 = 33
el2 only.Offset of the TLBIVAALE1IS field.
Sourcepub const TLBIRVAE1IS_SHIFT: u32 = 34
Available on crate feature el2 only.
pub const TLBIRVAE1IS_SHIFT: u32 = 34
el2 only.Offset of the TLBIRVAE1IS field.
Sourcepub const TLBIRVAAE1IS_SHIFT: u32 = 35
Available on crate feature el2 only.
pub const TLBIRVAAE1IS_SHIFT: u32 = 35
el2 only.Offset of the TLBIRVAAE1IS field.
Sourcepub const TLBIRVALE1IS_SHIFT: u32 = 36
Available on crate feature el2 only.
pub const TLBIRVALE1IS_SHIFT: u32 = 36
el2 only.Offset of the TLBIRVALE1IS field.
Sourcepub const TLBIRVAALE1IS_SHIFT: u32 = 37
Available on crate feature el2 only.
pub const TLBIRVAALE1IS_SHIFT: u32 = 37
el2 only.Offset of the TLBIRVAALE1IS field.
Sourcepub const TLBIRVAE1_SHIFT: u32 = 38
Available on crate feature el2 only.
pub const TLBIRVAE1_SHIFT: u32 = 38
el2 only.Offset of the TLBIRVAE1 field.
Sourcepub const TLBIRVAAE1_SHIFT: u32 = 39
Available on crate feature el2 only.
pub const TLBIRVAAE1_SHIFT: u32 = 39
el2 only.Offset of the TLBIRVAAE1 field.
Sourcepub const TLBIRVALE1_SHIFT: u32 = 40
Available on crate feature el2 only.
pub const TLBIRVALE1_SHIFT: u32 = 40
el2 only.Offset of the TLBIRVALE1 field.
Sourcepub const TLBIRVAALE1_SHIFT: u32 = 41
Available on crate feature el2 only.
pub const TLBIRVAALE1_SHIFT: u32 = 41
el2 only.Offset of the TLBIRVAALE1 field.
Sourcepub const TLBIVMALLE1_SHIFT: u32 = 42
Available on crate feature el2 only.
pub const TLBIVMALLE1_SHIFT: u32 = 42
el2 only.Offset of the TLBIVMALLE1 field.
Sourcepub const TLBIVAE1_SHIFT: u32 = 43
Available on crate feature el2 only.
pub const TLBIVAE1_SHIFT: u32 = 43
el2 only.Offset of the TLBIVAE1 field.
Sourcepub const TLBIASIDE1_SHIFT: u32 = 44
Available on crate feature el2 only.
pub const TLBIASIDE1_SHIFT: u32 = 44
el2 only.Offset of the TLBIASIDE1 field.
Sourcepub const TLBIVAAE1_SHIFT: u32 = 45
Available on crate feature el2 only.
pub const TLBIVAAE1_SHIFT: u32 = 45
el2 only.Offset of the TLBIVAAE1 field.
Sourcepub const TLBIVALE1_SHIFT: u32 = 46
Available on crate feature el2 only.
pub const TLBIVALE1_SHIFT: u32 = 46
el2 only.Offset of the TLBIVALE1 field.
Sourcepub const TLBIVAALE1_SHIFT: u32 = 47
Available on crate feature el2 only.
pub const TLBIVAALE1_SHIFT: u32 = 47
el2 only.Offset of the TLBIVAALE1 field.
Sourcepub const CFPRCTX_SHIFT: u32 = 48
Available on crate feature el2 only.
pub const CFPRCTX_SHIFT: u32 = 48
el2 only.Offset of the CFPRCTX field.
Sourcepub const DVPRCTX_SHIFT: u32 = 49
Available on crate feature el2 only.
pub const DVPRCTX_SHIFT: u32 = 49
el2 only.Offset of the DVPRCTX field.
Sourcepub const CPPRCTX_SHIFT: u32 = 50
Available on crate feature el2 only.
pub const CPPRCTX_SHIFT: u32 = 50
el2 only.Offset of the CPPRCTX field.
Sourcepub const ERET_SHIFT: u32 = 51
Available on crate feature el2 only.
pub const ERET_SHIFT: u32 = 51
el2 only.Offset of the ERET field.
Sourcepub const SVC_EL0_SHIFT: u32 = 52
Available on crate feature el2 only.
pub const SVC_EL0_SHIFT: u32 = 52
el2 only.Offset of the SVC_EL0 field.
Sourcepub const SVC_EL1_SHIFT: u32 = 53
Available on crate feature el2 only.
pub const SVC_EL1_SHIFT: u32 = 53
el2 only.Offset of the SVC_EL1 field.
Sourcepub const DCCVAC_SHIFT: u32 = 54
Available on crate feature el2 only.
pub const DCCVAC_SHIFT: u32 = 54
el2 only.Offset of the DCCVAC field.
Sourcepub const NBRBINJ_SHIFT: u32 = 55
Available on crate feature el2 only.
pub const NBRBINJ_SHIFT: u32 = 55
el2 only.Offset of the nBRBINJ field.
Sourcepub const NBRBIALL_SHIFT: u32 = 56
Available on crate feature el2 only.
pub const NBRBIALL_SHIFT: u32 = 56
el2 only.Offset of the nBRBIALL field.
Sourcepub const NGCSPUSHM_EL1_SHIFT: u32 = 57
Available on crate feature el2 only.
pub const NGCSPUSHM_EL1_SHIFT: u32 = 57
el2 only.Offset of the nGCSPUSHM_EL1 field.
Sourcepub const NGCSSTR_EL1_SHIFT: u32 = 58
Available on crate feature el2 only.
pub const NGCSSTR_EL1_SHIFT: u32 = 58
el2 only.Offset of the nGCSSTR_EL1 field.
Sourcepub const NGCSEPP_SHIFT: u32 = 59
Available on crate feature el2 only.
pub const NGCSEPP_SHIFT: u32 = 59
el2 only.Offset of the nGCSEPP field.
Sourcepub const COSPRCTX_SHIFT: u32 = 60
Available on crate feature el2 only.
pub const COSPRCTX_SHIFT: u32 = 60
el2 only.Offset of the COSPRCTX field.
Sourcepub const ATS1E1A_SHIFT: u32 = 62
Available on crate feature el2 only.
pub const ATS1E1A_SHIFT: u32 = 62
el2 only.Offset of the ATS1E1A field.
Sourcepub const PSBCSYNC_SHIFT: u32 = 63
Available on crate feature el2 only.
pub const PSBCSYNC_SHIFT: u32 = 63
el2 only.Offset of the PSBCSYNC field.