pub struct IdIsar1(/* private fields */);Expand description
ID_ISAR1 system register value.
Implementations
Sourceimpl IdIsar1
impl IdIsar1
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl IdIsar1
impl IdIsar1
Sourcepub const fn iter(&self) -> Iter<IdIsar1>
pub const fn iter(&self) -> Iter<IdIsar1>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<IdIsar1>
pub const fn iter_names(&self) -> IterNames<IdIsar1>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl IdIsar1
impl IdIsar1
Sourcepub const ENDIAN_SHIFT: u32 = 0
pub const ENDIAN_SHIFT: u32 = 0
Offset of the Endian field.
Sourcepub const ENDIAN_MASK: u32 = 0b1111
pub const ENDIAN_MASK: u32 = 0b1111
Mask for the Endian field.
Sourcepub const EXCEPT_SHIFT: u32 = 4
pub const EXCEPT_SHIFT: u32 = 4
Offset of the Except field.
Sourcepub const EXCEPT_MASK: u32 = 0b1111
pub const EXCEPT_MASK: u32 = 0b1111
Mask for the Except field.
Sourcepub const EXCEPT_AR_SHIFT: u32 = 8
pub const EXCEPT_AR_SHIFT: u32 = 8
Offset of the Except_AR field.
Sourcepub const EXCEPT_AR_MASK: u32 = 0b1111
pub const EXCEPT_AR_MASK: u32 = 0b1111
Mask for the Except_AR field.
Sourcepub const EXTEND_SHIFT: u32 = 12
pub const EXTEND_SHIFT: u32 = 12
Offset of the Extend field.
Sourcepub const EXTEND_MASK: u32 = 0b1111
pub const EXTEND_MASK: u32 = 0b1111
Mask for the Extend field.
Sourcepub const IFTHEN_SHIFT: u32 = 16
pub const IFTHEN_SHIFT: u32 = 16
Offset of the IfThen field.
Sourcepub const IFTHEN_MASK: u32 = 0b1111
pub const IFTHEN_MASK: u32 = 0b1111
Mask for the IfThen field.
Sourcepub const IMMEDIATE_SHIFT: u32 = 20
pub const IMMEDIATE_SHIFT: u32 = 20
Offset of the Immediate field.
Sourcepub const IMMEDIATE_MASK: u32 = 0b1111
pub const IMMEDIATE_MASK: u32 = 0b1111
Mask for the Immediate field.
Sourcepub const INTERWORK_SHIFT: u32 = 24
pub const INTERWORK_SHIFT: u32 = 24
Offset of the Interwork field.
Sourcepub const INTERWORK_MASK: u32 = 0b1111
pub const INTERWORK_MASK: u32 = 0b1111
Mask for the Interwork field.
Sourcepub const JAZELLE_SHIFT: u32 = 28
pub const JAZELLE_SHIFT: u32 = 28
Offset of the Jazelle field.
Sourcepub const JAZELLE_MASK: u32 = 0b1111
pub const JAZELLE_MASK: u32 = 0b1111
Mask for the Jazelle field.
Sourcepub const fn set_endian(&mut self, value: u8)
pub const fn set_endian(&mut self, value: u8)
Sets the value of the Endian field.
Sourcepub const fn set_except(&mut self, value: u8)
pub const fn set_except(&mut self, value: u8)
Sets the value of the Except field.
Sourcepub const fn set_except_ar(&mut self, value: u8)
pub const fn set_except_ar(&mut self, value: u8)
Sets the value of the Except_AR field.
Sourcepub const fn set_extend_(&mut self, value: u8)
pub const fn set_extend_(&mut self, value: u8)
Sets the value of the Extend field.
Sourcepub const fn set_ifthen(&mut self, value: u8)
pub const fn set_ifthen(&mut self, value: u8)
Sets the value of the IfThen field.
Sourcepub const fn set_immediate(&mut self, value: u8)
pub const fn set_immediate(&mut self, value: u8)
Sets the value of the Immediate field.
Sourcepub const fn set_interwork(&mut self, value: u8)
pub const fn set_interwork(&mut self, value: u8)
Sets the value of the Interwork field.
Sourcepub const fn set_jazelle(&mut self, value: u8)
pub const fn set_jazelle(&mut self, value: u8)
Sets the value of the Jazelle field.