pub struct IdIsar3(/* private fields */);Expand description
ID_ISAR3 system register value.
Implementations
Sourceimpl IdIsar3
impl IdIsar3
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl IdIsar3
impl IdIsar3
Sourcepub const fn iter(&self) -> Iter<IdIsar3>
pub const fn iter(&self) -> Iter<IdIsar3>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<IdIsar3>
pub const fn iter_names(&self) -> IterNames<IdIsar3>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl IdIsar3
impl IdIsar3
Sourcepub const SATURATE_SHIFT: u32 = 0
pub const SATURATE_SHIFT: u32 = 0
Offset of the Saturate field.
Sourcepub const SATURATE_MASK: u32 = 0b1111
pub const SATURATE_MASK: u32 = 0b1111
Mask for the Saturate field.
Sourcepub const SIMD_SHIFT: u32 = 4
pub const SIMD_SHIFT: u32 = 4
Offset of the SIMD field.
Sourcepub const SYNCHPRIM_SHIFT: u32 = 12
pub const SYNCHPRIM_SHIFT: u32 = 12
Offset of the SynchPrim field.
Sourcepub const SYNCHPRIM_MASK: u32 = 0b1111
pub const SYNCHPRIM_MASK: u32 = 0b1111
Mask for the SynchPrim field.
Sourcepub const TABBRANCH_SHIFT: u32 = 16
pub const TABBRANCH_SHIFT: u32 = 16
Offset of the TabBranch field.
Sourcepub const TABBRANCH_MASK: u32 = 0b1111
pub const TABBRANCH_MASK: u32 = 0b1111
Mask for the TabBranch field.
Sourcepub const T32COPY_SHIFT: u32 = 20
pub const T32COPY_SHIFT: u32 = 20
Offset of the T32Copy field.
Sourcepub const T32COPY_MASK: u32 = 0b1111
pub const T32COPY_MASK: u32 = 0b1111
Mask for the T32Copy field.
Sourcepub const TRUENOP_SHIFT: u32 = 24
pub const TRUENOP_SHIFT: u32 = 24
Offset of the TrueNOP field.
Sourcepub const TRUENOP_MASK: u32 = 0b1111
pub const TRUENOP_MASK: u32 = 0b1111
Mask for the TrueNOP field.
Sourcepub const T32EE_SHIFT: u32 = 28
pub const T32EE_SHIFT: u32 = 28
Offset of the T32EE field.
Sourcepub const T32EE_MASK: u32 = 0b1111
pub const T32EE_MASK: u32 = 0b1111
Mask for the T32EE field.
Sourcepub const fn set_saturate(&mut self, value: u8)
pub const fn set_saturate(&mut self, value: u8)
Sets the value of the Saturate field.
Sourcepub const fn with_saturate(self, value: u8) -> Self
pub const fn with_saturate(self, value: u8) -> Self
Returns a copy with the Saturate field set to the given value.
Sourcepub const fn with_simd(self, value: u8) -> Self
pub const fn with_simd(self, value: u8) -> Self
Returns a copy with the SIMD field set to the given value.
Sourcepub const fn with_svc(self, value: u8) -> Self
pub const fn with_svc(self, value: u8) -> Self
Returns a copy with the SVC field set to the given value.
Sourcepub const fn set_synchprim(&mut self, value: u8)
pub const fn set_synchprim(&mut self, value: u8)
Sets the value of the SynchPrim field.
Sourcepub const fn with_synchprim(self, value: u8) -> Self
pub const fn with_synchprim(self, value: u8) -> Self
Returns a copy with the SynchPrim field set to the given value.
Sourcepub const fn set_tabbranch(&mut self, value: u8)
pub const fn set_tabbranch(&mut self, value: u8)
Sets the value of the TabBranch field.
Sourcepub const fn with_tabbranch(self, value: u8) -> Self
pub const fn with_tabbranch(self, value: u8) -> Self
Returns a copy with the TabBranch field set to the given value.
Sourcepub const fn set_t32copy(&mut self, value: u8)
pub const fn set_t32copy(&mut self, value: u8)
Sets the value of the T32Copy field.
Sourcepub const fn with_t32copy(self, value: u8) -> Self
pub const fn with_t32copy(self, value: u8) -> Self
Returns a copy with the T32Copy field set to the given value.
Sourcepub const fn set_truenop(&mut self, value: u8)
pub const fn set_truenop(&mut self, value: u8)
Sets the value of the TrueNOP field.
Sourcepub const fn with_truenop(self, value: u8) -> Self
pub const fn with_truenop(self, value: u8) -> Self
Returns a copy with the TrueNOP field set to the given value.
Sourcepub const fn with_t32ee(self, value: u8) -> Self
pub const fn with_t32ee(self, value: u8) -> Self
Returns a copy with the T32EE field set to the given value.