IdIsar6

Struct IdIsar6 

pub struct IdIsar6(/* private fields */);
ID_ISAR6 system register value.

Implementations

Source

impl IdIsar6

pub const fn empty() -> Self

Get a flags value with all bits unset.

pub const fn all() -> Self

Get a flags value with all known bits set.

pub const fn bits(&self) -> u32

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u32) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u32) -> Self

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u32) -> Self

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in this flags value are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Self) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

pub const fn contains(&self, other: Self) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

pub fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in two flags values.

pub fn remove(&mut self, other: Self)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Self)

The bitwise exclusive-or (^) of the bits in two flags values.

pub fn set(&mut self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Self) -> Self

The bitwise and (&) of the bits in two flags values.

pub const fn union(self, other: Self) -> Self

The bitwise or (|) of the bits in two flags values.

pub const fn difference(self, other: Self) -> Self

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in two flags values.

pub const fn complement(self) -> Self

The bitwise negation (!) of the bits in a flags value, truncating the result.

Source

impl IdIsar6

pub const fn iter(&self) -> Iter<IdIsar6>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<IdIsar6>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.

Source

impl IdIsar6

pub const JSCVT_SHIFT: u32 = 0

Offset of the JSCVT field.

pub const JSCVT_MASK: u32 = 0b1111

Mask for the JSCVT field.

pub const DP_SHIFT: u32 = 4

Offset of the DP field.

pub const DP_MASK: u32 = 0b1111

Mask for the DP field.

pub const FHM_SHIFT: u32 = 8

Offset of the FHM field.

pub const FHM_MASK: u32 = 0b1111

Mask for the FHM field.

pub const SB_SHIFT: u32 = 12

Offset of the SB field.

pub const SB_MASK: u32 = 0b1111

Mask for the SB field.

pub const SPECRES_SHIFT: u32 = 16

Offset of the SPECRES field.

pub const SPECRES_MASK: u32 = 0b1111

Mask for the SPECRES field.

pub const BF16_SHIFT: u32 = 20

Offset of the BF16 field.

pub const BF16_MASK: u32 = 0b1111

Mask for the BF16 field.

pub const I8MM_SHIFT: u32 = 24

Offset of the I8MM field.

pub const I8MM_MASK: u32 = 0b1111

Mask for the I8MM field.

pub const CLRBHB_SHIFT: u32 = 28

Offset of the CLRBHB field.

pub const CLRBHB_MASK: u32 = 0b1111

Mask for the CLRBHB field.

pub const fn jscvt(self) -> u8

Returns the value of the JSCVT field.

pub const fn dp(self) -> u8

Returns the value of the DP field.

pub const fn fhm(self) -> u8

Returns the value of the FHM field.

pub const fn sb(self) -> u8

Returns the value of the SB field.

pub const fn specres(self) -> u8

Returns the value of the SPECRES field.

pub const fn bf16(self) -> u8

Returns the value of the BF16 field.

pub const fn i8mm(self) -> u8

Returns the value of the I8MM field.

pub const fn clrbhb(self) -> u8

Returns the value of the CLRBHB field.