pub struct MdcrEl2(/* private fields */);Expand description
MDCR_EL2 system register value.
Implementations
Sourceimpl MdcrEl2
impl MdcrEl2
Sourcepub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u64) -> Option<Self>
pub const fn from_bits(bits: u64) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u64) -> Self
pub const fn from_bits_truncate(bits: u64) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u64) -> Self
pub const fn from_bits_retain(bits: u64) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl MdcrEl2
impl MdcrEl2
Sourcepub const fn iter(&self) -> Iter<MdcrEl2>
pub const fn iter(&self) -> Iter<MdcrEl2>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<MdcrEl2>
pub const fn iter_names(&self) -> IterNames<MdcrEl2>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl MdcrEl2
impl MdcrEl2
Sourcepub const HPMN_SHIFT: u32 = 0
Available on crate feature el2 only.
pub const HPMN_SHIFT: u32 = 0
el2 only.Offset of the HPMN field.
Sourcepub const HPMN_MASK: u64 = 0b11111
Available on crate feature el2 only.
pub const HPMN_MASK: u64 = 0b11111
el2 only.Mask for the HPMN field.
Sourcepub const TPMCR_SHIFT: u32 = 5
Available on crate feature el2 only.
pub const TPMCR_SHIFT: u32 = 5
el2 only.Offset of the TPMCR field.
Sourcepub const HPME_SHIFT: u32 = 7
Available on crate feature el2 only.
pub const HPME_SHIFT: u32 = 7
el2 only.Offset of the HPME field.
Sourcepub const TDOSA_SHIFT: u32 = 10
Available on crate feature el2 only.
pub const TDOSA_SHIFT: u32 = 10
el2 only.Offset of the TDOSA field.
Sourcepub const TDRA_SHIFT: u32 = 11
Available on crate feature el2 only.
pub const TDRA_SHIFT: u32 = 11
el2 only.Offset of the TDRA field.
Sourcepub const E2PB_SHIFT: u32 = 12
Available on crate feature el2 only.
pub const E2PB_SHIFT: u32 = 12
el2 only.Offset of the E2PB field.
Sourcepub const TPMS_SHIFT: u32 = 14
Available on crate feature el2 only.
pub const TPMS_SHIFT: u32 = 14
el2 only.Offset of the TPMS field.
Sourcepub const ENSPM_SHIFT: u32 = 15
Available on crate feature el2 only.
pub const ENSPM_SHIFT: u32 = 15
el2 only.Offset of the EnSPM field.
Sourcepub const HPMD_SHIFT: u32 = 17
Available on crate feature el2 only.
pub const HPMD_SHIFT: u32 = 17
el2 only.Offset of the HPMD field.
Sourcepub const TTRF_SHIFT: u32 = 19
Available on crate feature el2 only.
pub const TTRF_SHIFT: u32 = 19
el2 only.Offset of the TTRF field.
Sourcepub const HCCD_SHIFT: u32 = 23
Available on crate feature el2 only.
pub const HCCD_SHIFT: u32 = 23
el2 only.Offset of the HCCD field.
Sourcepub const E2TB_SHIFT: u32 = 24
Available on crate feature el2 only.
pub const E2TB_SHIFT: u32 = 24
el2 only.Offset of the E2TB field.
Sourcepub const TDCC_SHIFT: u32 = 27
Available on crate feature el2 only.
pub const TDCC_SHIFT: u32 = 27
el2 only.Offset of the TDCC field.
Sourcepub const MTPME_SHIFT: u32 = 28
Available on crate feature el2 only.
pub const MTPME_SHIFT: u32 = 28
el2 only.Offset of the MTPME field.
Sourcepub const HPMFZO_SHIFT: u32 = 29
Available on crate feature el2 only.
pub const HPMFZO_SHIFT: u32 = 29
el2 only.Offset of the HPMFZO field.
Sourcepub const PMSSE_SHIFT: u32 = 30
Available on crate feature el2 only.
pub const PMSSE_SHIFT: u32 = 30
el2 only.Offset of the PMSSE field.
Sourcepub const PMSSE_MASK: u64 = 0b11
Available on crate feature el2 only.
pub const PMSSE_MASK: u64 = 0b11
el2 only.Mask for the PMSSE field.
Sourcepub const HPMFZS_SHIFT: u32 = 36
Available on crate feature el2 only.
pub const HPMFZS_SHIFT: u32 = 36
el2 only.Offset of the HPMFZS field.
Sourcepub const PMEE_SHIFT: u32 = 40
Available on crate feature el2 only.
pub const PMEE_SHIFT: u32 = 40
el2 only.Offset of the PMEE field.
Sourcepub const EBWE_SHIFT: u32 = 43
Available on crate feature el2 only.
pub const EBWE_SHIFT: u32 = 43
el2 only.Offset of the EBWE field.
Sourcepub const ENSTEPOP_SHIFT: u32 = 50
Available on crate feature el2 only.
pub const ENSTEPOP_SHIFT: u32 = 50
el2 only.Offset of the EnSTEPOP field.
Sourcepub const fn hpmn(self) -> u8
Available on crate feature el2 only.
pub const fn hpmn(self) -> u8
el2 only.Returns the value of the HPMN field.
Sourcepub const fn set_hpmn(&mut self, value: u8)
Available on crate feature el2 only.
pub const fn set_hpmn(&mut self, value: u8)
el2 only.Sets the value of the HPMN field.
Sourcepub const fn with_hpmn(self, value: u8) -> Self
Available on crate feature el2 only.
pub const fn with_hpmn(self, value: u8) -> Self
el2 only.Returns a copy with the HPMN field set to the given value.
Sourcepub const fn e2pb(self) -> u8
Available on crate feature el2 only.
pub const fn e2pb(self) -> u8
el2 only.Returns the value of the E2PB field.
Sourcepub const fn set_e2pb(&mut self, value: u8)
Available on crate feature el2 only.
pub const fn set_e2pb(&mut self, value: u8)
el2 only.Sets the value of the E2PB field.
Sourcepub const fn with_e2pb(self, value: u8) -> Self
Available on crate feature el2 only.
pub const fn with_e2pb(self, value: u8) -> Self
el2 only.Returns a copy with the E2PB field set to the given value.
Sourcepub const fn e2tb(self) -> u8
Available on crate feature el2 only.
pub const fn e2tb(self) -> u8
el2 only.Returns the value of the E2TB field.
Sourcepub const fn set_e2tb(&mut self, value: u8)
Available on crate feature el2 only.
pub const fn set_e2tb(&mut self, value: u8)
el2 only.Sets the value of the E2TB field.
Sourcepub const fn with_e2tb(self, value: u8) -> Self
Available on crate feature el2 only.
pub const fn with_e2tb(self, value: u8) -> Self
el2 only.Returns a copy with the E2TB field set to the given value.
Sourcepub const fn pmsse(self) -> u8
Available on crate feature el2 only.
pub const fn pmsse(self) -> u8
el2 only.Returns the value of the PMSSE field.
Sourcepub const fn set_pmsse(&mut self, value: u8)
Available on crate feature el2 only.
pub const fn set_pmsse(&mut self, value: u8)
el2 only.Sets the value of the PMSSE field.
Sourcepub const fn with_pmsse(self, value: u8) -> Self
Available on crate feature el2 only.
pub const fn with_pmsse(self, value: u8) -> Self
el2 only.Returns a copy with the PMSSE field set to the given value.
Sourcepub const fn pmee(self) -> u8
Available on crate feature el2 only.
pub const fn pmee(self) -> u8
el2 only.Returns the value of the PMEE field.