pub struct Mpam3El3(/* private fields */);Expand description
MPAM3_EL3 system register value.
Holds information to generate MPAM labels for memory requests when executing at EL3.
Implementations
Sourceimpl Mpam3El3
impl Mpam3El3
Sourcepub const RT_ALTSP_NS: Self
pub const RT_ALTSP_NS: Self
RT_ALTSP_NS bit.
Sourceimpl Mpam3El3
impl Mpam3El3
Sourcepub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u64) -> Option<Self>
pub const fn from_bits(bits: u64) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u64) -> Self
pub const fn from_bits_truncate(bits: u64) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u64) -> Self
pub const fn from_bits_retain(bits: u64) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl Mpam3El3
impl Mpam3El3
Sourcepub const fn iter(&self) -> Iter<Mpam3El3>
pub const fn iter(&self) -> Iter<Mpam3El3>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<Mpam3El3>
pub const fn iter_names(&self) -> IterNames<Mpam3El3>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl Mpam3El3
impl Mpam3El3
Sourcepub const PARTID_SHIFT: u32 = 0
Available on crate feature el3 only.
pub const PARTID_SHIFT: u32 = 0
el3 only.Offset of the PARTID field.
Sourcepub const PARTID_MASK: u64 = 0b1111111111111111
Available on crate feature el3 only.
pub const PARTID_MASK: u64 = 0b1111111111111111
el3 only.Mask for the PARTID field.
Sourcepub const PARTID_I_SHIFT: u32 = 0
Available on crate feature el3 only.
pub const PARTID_I_SHIFT: u32 = 0
el3 only.Offset of the PARTID_I field.
Sourcepub const PARTID_I_MASK: u64 = 0b1111111111111111
Available on crate feature el3 only.
pub const PARTID_I_MASK: u64 = 0b1111111111111111
el3 only.Mask for the PARTID_I field.
Sourcepub const PARTID_D_SHIFT: u32 = 16
Available on crate feature el3 only.
pub const PARTID_D_SHIFT: u32 = 16
el3 only.Offset of the PARTID_D field.
Sourcepub const PARTID_D_MASK: u64 = 0b1111111111111111
Available on crate feature el3 only.
pub const PARTID_D_MASK: u64 = 0b1111111111111111
el3 only.Mask for the PARTID_D field.
Sourcepub const ALTPARTID_SHIFT: u32 = 16
Available on crate feature el3 only.
pub const ALTPARTID_SHIFT: u32 = 16
el3 only.Offset of the altPARTID field.
Sourcepub const ALTPARTID_MASK: u64 = 0b1111111111111111
Available on crate feature el3 only.
pub const ALTPARTID_MASK: u64 = 0b1111111111111111
el3 only.Mask for the altPARTID field.
Sourcepub const PMG_MASK: u64 = 0b1111111111111111
Available on crate feature el3 only.
pub const PMG_MASK: u64 = 0b1111111111111111
el3 only.Mask for the PMG field.
Sourcepub const PMG_I_SHIFT: u32 = 32
Available on crate feature el3 only.
pub const PMG_I_SHIFT: u32 = 32
el3 only.Offset of the PMG_I field.
Sourcepub const PMG_I_MASK: u64 = 0b11111111
Available on crate feature el3 only.
pub const PMG_I_MASK: u64 = 0b11111111
el3 only.Mask for the PMG_I field.
Sourcepub const PMG_D_SHIFT: u32 = 40
Available on crate feature el3 only.
pub const PMG_D_SHIFT: u32 = 40
el3 only.Offset of the PMG_D field.
Sourcepub const PMG_D_MASK: u64 = 0b11111111
Available on crate feature el3 only.
pub const PMG_D_MASK: u64 = 0b11111111
el3 only.Mask for the PMG_D field.
Sourcepub const ALTPMG_SHIFT: u32 = 48
Available on crate feature el3 only.
pub const ALTPMG_SHIFT: u32 = 48
el3 only.Offset of the altPMG field.
Sourcepub const ALTPMG_MASK: u64 = 0b1111111111111111
Available on crate feature el3 only.
pub const ALTPMG_MASK: u64 = 0b1111111111111111
el3 only.Mask for the altPMG field.
Sourcepub const RT_ALTSP_NS_SHIFT: u32 = 52
Available on crate feature el3 only.
pub const RT_ALTSP_NS_SHIFT: u32 = 52
el3 only.Offset of the RT_ALTSP_NS field.
Sourcepub const ALTSP_EL3_SHIFT: u32 = 55
Available on crate feature el3 only.
pub const ALTSP_EL3_SHIFT: u32 = 55
el3 only.Offset of the ALTSP_EL3 field.
Sourcepub const ALTSP_HFC_SHIFT: u32 = 56
Available on crate feature el3 only.
pub const ALTSP_HFC_SHIFT: u32 = 56
el3 only.Offset of the ALTSP_HFC field.
Sourcepub const ALTSP_HEN_SHIFT: u32 = 57
Available on crate feature el3 only.
pub const ALTSP_HEN_SHIFT: u32 = 57
el3 only.Offset of the ALTSP_HEN field.
Sourcepub const FORCE_NS_SHIFT: u32 = 60
Available on crate feature el3 only.
pub const FORCE_NS_SHIFT: u32 = 60
el3 only.Offset of the FORCE_NS field.
Sourcepub const SDEFLT_SHIFT: u32 = 61
Available on crate feature el3 only.
pub const SDEFLT_SHIFT: u32 = 61
el3 only.Offset of the SDEFLT field.
Sourcepub const TRAPLOWER_SHIFT: u32 = 62
Available on crate feature el3 only.
pub const TRAPLOWER_SHIFT: u32 = 62
el3 only.Offset of the TRAPLOWER field.
Sourcepub const MPAMEN_SHIFT: u32 = 63
Available on crate feature el3 only.
pub const MPAMEN_SHIFT: u32 = 63
el3 only.Offset of the MPAMEN field.
Sourcepub const fn partid(self) -> u16
Available on crate feature el3 only.
pub const fn partid(self) -> u16
el3 only.Returns the value of the PARTID field.
Sourcepub const fn set_partid(&mut self, value: u16)
Available on crate feature el3 only.
pub const fn set_partid(&mut self, value: u16)
el3 only.Sets the value of the PARTID field.
Sourcepub const fn with_partid(self, value: u16) -> Self
Available on crate feature el3 only.
pub const fn with_partid(self, value: u16) -> Self
el3 only.Returns a copy with the PARTID field set to the given value.
Sourcepub const fn partid_i(self) -> u16
Available on crate feature el3 only.
pub const fn partid_i(self) -> u16
el3 only.Returns the value of the PARTID_I field.
Sourcepub const fn set_partid_i(&mut self, value: u16)
Available on crate feature el3 only.
pub const fn set_partid_i(&mut self, value: u16)
el3 only.Sets the value of the PARTID_I field.
Sourcepub const fn with_partid_i(self, value: u16) -> Self
Available on crate feature el3 only.
pub const fn with_partid_i(self, value: u16) -> Self
el3 only.Returns a copy with the PARTID_I field set to the given value.
Sourcepub const fn partid_d(self) -> u16
Available on crate feature el3 only.
pub const fn partid_d(self) -> u16
el3 only.Returns the value of the PARTID_D field.
Sourcepub const fn set_partid_d(&mut self, value: u16)
Available on crate feature el3 only.
pub const fn set_partid_d(&mut self, value: u16)
el3 only.Sets the value of the PARTID_D field.
Sourcepub const fn with_partid_d(self, value: u16) -> Self
Available on crate feature el3 only.
pub const fn with_partid_d(self, value: u16) -> Self
el3 only.Returns a copy with the PARTID_D field set to the given value.
Sourcepub const fn altpartid(self) -> u16
Available on crate feature el3 only.
pub const fn altpartid(self) -> u16
el3 only.Returns the value of the altPARTID field.
Sourcepub const fn set_altpartid(&mut self, value: u16)
Available on crate feature el3 only.
pub const fn set_altpartid(&mut self, value: u16)
el3 only.Sets the value of the altPARTID field.
Sourcepub const fn with_altpartid(self, value: u16) -> Self
Available on crate feature el3 only.
pub const fn with_altpartid(self, value: u16) -> Self
el3 only.Returns a copy with the altPARTID field set to the given value.
Sourcepub const fn pmg(self) -> u16
Available on crate feature el3 only.
pub const fn pmg(self) -> u16
el3 only.Returns the value of the PMG field.
Sourcepub const fn set_pmg(&mut self, value: u16)
Available on crate feature el3 only.
pub const fn set_pmg(&mut self, value: u16)
el3 only.Sets the value of the PMG field.
Sourcepub const fn with_pmg(self, value: u16) -> Self
Available on crate feature el3 only.
pub const fn with_pmg(self, value: u16) -> Self
el3 only.Returns a copy with the PMG field set to the given value.
Sourcepub const fn pmg_i(self) -> u8
Available on crate feature el3 only.
pub const fn pmg_i(self) -> u8
el3 only.Returns the value of the PMG_I field.
Sourcepub const fn set_pmg_i(&mut self, value: u8)
Available on crate feature el3 only.
pub const fn set_pmg_i(&mut self, value: u8)
el3 only.Sets the value of the PMG_I field.
Sourcepub const fn with_pmg_i(self, value: u8) -> Self
Available on crate feature el3 only.
pub const fn with_pmg_i(self, value: u8) -> Self
el3 only.Returns a copy with the PMG_I field set to the given value.
Sourcepub const fn pmg_d(self) -> u8
Available on crate feature el3 only.
pub const fn pmg_d(self) -> u8
el3 only.Returns the value of the PMG_D field.
Sourcepub const fn set_pmg_d(&mut self, value: u8)
Available on crate feature el3 only.
pub const fn set_pmg_d(&mut self, value: u8)
el3 only.Sets the value of the PMG_D field.
Sourcepub const fn with_pmg_d(self, value: u8) -> Self
Available on crate feature el3 only.
pub const fn with_pmg_d(self, value: u8) -> Self
el3 only.Returns a copy with the PMG_D field set to the given value.
Sourcepub const fn altpmg(self) -> u16
Available on crate feature el3 only.
pub const fn altpmg(self) -> u16
el3 only.Returns the value of the altPMG field.
Sourcepub const fn set_altpmg(&mut self, value: u16)
Available on crate feature el3 only.
pub const fn set_altpmg(&mut self, value: u16)
el3 only.Sets the value of the altPMG field.
Sourcepub const fn with_altpmg(self, value: u16) -> Self
Available on crate feature el3 only.
pub const fn with_altpmg(self, value: u16) -> Self
el3 only.Returns a copy with the altPMG field set to the given value.