Par

Struct Par 

pub struct Par(/* private fields */);
PAR system register value.

Implementations

Source

impl Par

pub const F: Self

F bit.

pub const SS: Self

SS bit.

pub const FS_5: Self

FS[5] bit.

pub const S2WLK: Self

S2WLK bit.

pub const FSTAGE: Self

FSTAGE bit.

pub const NS: Self

NS bit.

pub const NOS: Self

NOS bit.

pub const LPAE: Self

LPAE bit.

Source

impl Par

pub const fn empty() -> Self

Get a flags value with all bits unset.

pub const fn all() -> Self

Get a flags value with all known bits set.

pub const fn bits(&self) -> u64

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u64) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u64) -> Self

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u64) -> Self

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in this flags value are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Self) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

pub const fn contains(&self, other: Self) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

pub fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in two flags values.

pub fn remove(&mut self, other: Self)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Self)

The bitwise exclusive-or (^) of the bits in two flags values.

pub fn set(&mut self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Self) -> Self

The bitwise and (&) of the bits in two flags values.

pub const fn union(self, other: Self) -> Self

The bitwise or (|) of the bits in two flags values.

pub const fn difference(self, other: Self) -> Self

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in two flags values.

pub const fn complement(self) -> Self

The bitwise negation (!) of the bits in a flags value, truncating the result.

Source

impl Par

pub const fn iter(&self) -> Iter<Par>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<Par>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.

Source

impl Par

pub const F_SHIFT: u32 = 0

Offset of the F field.

pub const FST_SHIFT: u32 = 1

Offset of the FST field.

pub const FST_MASK: u64 = 0b111111

Mask for the FST field.

pub const FS_4_0_SHIFT: u32 = 1

Offset of the FS[4:0] field.

pub const FS_4_0_MASK: u64 = 0b11111

Mask for the FS[4:0] field.

pub const SS_SHIFT: u32 = 1

Offset of the SS field.

pub const OUTER_1_0_SHIFT: u32 = 2

Offset of the Outer[1:0] field.

pub const OUTER_1_0_MASK: u64 = 0b11

Mask for the Outer[1:0] field.

pub const INNER_2_0_SHIFT: u32 = 4

Offset of the Inner[2:0] field.

pub const INNER_2_0_MASK: u64 = 0b111

Mask for the Inner[2:0] field.

pub const FS_5_SHIFT: u32 = 6

Offset of the FS[5] field.

pub const S2WLK_SHIFT: u32 = 8

Offset of the S2WLK field.

pub const FSTAGE_SHIFT: u32 = 9

Offset of the FSTAGE field.

pub const NS_SHIFT: u32 = 9

Offset of the NS field.

pub const NOS_SHIFT: u32 = 10

Offset of the NOS field.

pub const LPAE_SHIFT: u32 = 11

Offset of the LPAE field.

pub const ATTR_SHIFT: u32 = 56

Offset of the ATTR field.

pub const ATTR_MASK: u64 = 0b11111111

Mask for the ATTR field.

pub const fn fst(self) -> u8

Returns the value of the FST field.

pub const fn set_fst(&mut self, value: u8)

Sets the value of the FST field.

pub const fn fs_4_0(self) -> u8

Returns the value of the FS[4:0] field.

pub const fn set_fs_4_0(&mut self, value: u8)

Sets the value of the FS[4:0] field.

pub const fn outer_1_0(self) -> u8

Returns the value of the Outer[1:0] field.

pub const fn set_outer_1_0(&mut self, value: u8)

Sets the value of the Outer[1:0] field.

pub const fn inner_2_0(self) -> u8

Returns the value of the Inner[2:0] field.

pub const fn set_inner_2_0(&mut self, value: u8)

Sets the value of the Inner[2:0] field.

pub const fn attr(self) -> u8

Returns the value of the ATTR field.

pub const fn set_attr(&mut self, value: u8)

Sets the value of the ATTR field.