ScrEl3

Struct ScrEl3 

pub struct ScrEl3(/* private fields */);
SCR_EL3 system register value.

Implementations

Source

impl ScrEl3

pub const RES1: Self

RES1 bits in the SCR_EL3 register.

pub const NS: Self

Non-secure.

pub const IRQ: Self

Take physical IRQs at EL3.

pub const FIQ: Self

Take physical FIQs at EL3.

pub const EA: Self

Take external abort and SError exceptions at EL3.

pub const SMD: Self

Disable SMC instructions.

pub const HCE: Self

Enable HVC instructions.

pub const SIF: Self

Disable execution from non-secure memory.

pub const RW: Self

Enable AArch64 in lower ELs.

pub const ST: Self

Trap physical secure timer to EL3.

pub const TWI: Self

Trap WFI to EL3.

pub const TWE: Self

Trap WFE to EL3.

pub const TLOR: Self

Trap LOR register access to EL3.

pub const TERR: Self

Trap error record register access to EL3.

pub const APK: Self

Don’t trap PAC key registers to EL3.

pub const API: Self

Don’t trap PAuth instructions to EL3.

pub const EEL2: Self

Enable Secure EL2.

pub const EASE: Self

Synchronous external aborts are taken as SErrors.

pub const NMEA: Self

Take SError exceptions at EL3.

pub const FIEN: Self

Enable fault injection at lower ELs.

pub const TID3: Self

Trap ID group 3 registers to EL3.

pub const TID5: Self

Trap ID group 5 register to EL3.

pub const POE2EN: Self

POE2En bit.

pub const ENSCXT: Self

Enable SCXT at lower ELs.

pub const ATA: Self

Enable memory tagging at lower ELs.

pub const FGTEN: Self

Enable fine-grained traps to EL2.

pub const ECVEN: Self

Enable access to CNTPOFF_EL2.

pub const TWEDEN: Self

Enable a configurable delay for WFE traps.

pub const AMVOFFEN: Self

Enable activity monitors virtual offsets.

pub const ENAS0: Self

Enable ST64BV0 at lower ELs.

pub const ADEN: Self

Enable ACCDATA_EL1 at lower ELs.

pub const HXEN: Self

Enable HCRX_EL2.

pub const GCSEN: Self

Enable guarded control stack.

pub const TRNDR: Self

Trap RNDR and RNDRRS to EL3.

pub const ENTP2: Self

Enable TPIDR2_EL0 at lower ELs.

pub const RCWMASKEN: Self

Enable RCW and RCWS mask registers at lower ELs.

pub const TCR2EN: Self

Enable TCR2_ELx registers at lower ELs.

pub const SCTLR2EN: Self

Enable SCTLR2_ELx registers at lower ELs.

pub const PIEN: Self

Enable permission indirection and overlay registers at lower ELs.

pub const AIEN: Self

Enable MAIR2_ELx and AMAIR2_ELx at lower ELs.

pub const D128EN: Self

Enable 128-bit system registers at lower ELs.

pub const GPF: Self

Route GPFs to EL3.

pub const MECEN: Self

Enable MECID registers at EL2.

pub const ENFPM: Self

Enable access to FPMR at lower ELs.

pub const TMEA: Self

Take synchronous external abort and physical SError exception to EL3.

pub const TWERR: Self

Trap writes to Error Record registers to EL3.

pub const PFAREN: Self

Enable access to physical fault address registers at lower ELs.

pub const SRMASKEN: Self

Enable access to mask registers at lower ELs.

pub const ENIDCP128: Self

Enable implementation-defined 128-bit system registers.

pub const VTLBIDEN: Self

VTLBIDEn bit.

pub const DSE: Self

A delegated SError exception is pending.

pub const ENDSE: Self

Enable delegated SError exceptions.

pub const FGTEN2: Self

Enable fine-grained traps to EL2.

pub const HDBSSEN: Self

Enable HDBSSBR_EL2 and HDBSSPROD_EL2 registers at EL2.

pub const HACDBSEN: Self

Enable HACDBSBR_EL2 and HACDBSCONS_EL2 registers at EL2.

pub const NSE: Self

Non-secure realm world bit.

pub const TPLIMEN: Self

TPLIMEn bit.

Source

impl ScrEl3

pub const fn empty() -> Self

Get a flags value with all bits unset.

pub const fn all() -> Self

Get a flags value with all known bits set.

pub const fn bits(&self) -> u64

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u64) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u64) -> Self

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u64) -> Self

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in this flags value are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Self) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

pub const fn contains(&self, other: Self) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

pub fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in two flags values.

pub fn remove(&mut self, other: Self)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Self)

The bitwise exclusive-or (^) of the bits in two flags values.

pub fn set(&mut self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Self) -> Self

The bitwise and (&) of the bits in two flags values.

pub const fn union(self, other: Self) -> Self

The bitwise or (|) of the bits in two flags values.

pub const fn difference(self, other: Self) -> Self

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in two flags values.

pub const fn complement(self) -> Self

The bitwise negation (!) of the bits in a flags value, truncating the result.

Source

impl ScrEl3

pub const fn iter(&self) -> Iter<ScrEl3>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<ScrEl3>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.

Source

impl ScrEl3

pub const NS_SHIFT: u32 = 0

Available on crate feature el3 only.

Offset of the NS field.

pub const IRQ_SHIFT: u32 = 1

Available on crate feature el3 only.

Offset of the IRQ field.

pub const FIQ_SHIFT: u32 = 2

Available on crate feature el3 only.

Offset of the FIQ field.

pub const EA_SHIFT: u32 = 3

Available on crate feature el3 only.

Offset of the EA field.

pub const SMD_SHIFT: u32 = 7

Available on crate feature el3 only.

Offset of the SMD field.

pub const HCE_SHIFT: u32 = 8

Available on crate feature el3 only.

Offset of the HCE field.

pub const SIF_SHIFT: u32 = 9

Available on crate feature el3 only.

Offset of the SIF field.

pub const RW_SHIFT: u32 = 10

Available on crate feature el3 only.

Offset of the RW field.

pub const ST_SHIFT: u32 = 11

Available on crate feature el3 only.

Offset of the ST field.

pub const TWI_SHIFT: u32 = 12

Available on crate feature el3 only.

Offset of the TWI field.

pub const TWE_SHIFT: u32 = 13

Available on crate feature el3 only.

Offset of the TWE field.

pub const TLOR_SHIFT: u32 = 14

Available on crate feature el3 only.

Offset of the TLOR field.

pub const TERR_SHIFT: u32 = 15

Available on crate feature el3 only.

Offset of the TERR field.

pub const APK_SHIFT: u32 = 16

Available on crate feature el3 only.

Offset of the APK field.

pub const API_SHIFT: u32 = 17

Available on crate feature el3 only.

Offset of the API field.

pub const EEL2_SHIFT: u32 = 18

Available on crate feature el3 only.

Offset of the EEL2 field.

pub const EASE_SHIFT: u32 = 19

Available on crate feature el3 only.

Offset of the EASE field.

pub const NMEA_SHIFT: u32 = 20

Available on crate feature el3 only.

Offset of the NMEA field.

pub const FIEN_SHIFT: u32 = 21

Available on crate feature el3 only.

Offset of the FIEN field.

pub const TID3_SHIFT: u32 = 22

Available on crate feature el3 only.

Offset of the TID3 field.

pub const TID5_SHIFT: u32 = 23

Available on crate feature el3 only.

Offset of the TID5 field.

pub const POE2EN_SHIFT: u32 = 24

Available on crate feature el3 only.

Offset of the POE2En field.

pub const ENSCXT_SHIFT: u32 = 25

Available on crate feature el3 only.

Offset of the EnSCXT field.

pub const ATA_SHIFT: u32 = 26

Available on crate feature el3 only.

Offset of the ATA field.

pub const FGTEN_SHIFT: u32 = 27

Available on crate feature el3 only.

Offset of the FGTEn field.

pub const ECVEN_SHIFT: u32 = 28

Available on crate feature el3 only.

Offset of the ECVEn field.

pub const TWEDEN_SHIFT: u32 = 29

Available on crate feature el3 only.

Offset of the TWEDEn field.

pub const TWEDEL_SHIFT: u32 = 30

Available on crate feature el3 only.

Offset of the TWEDEL field.

pub const TWEDEL_MASK: u64 = 0b1111

Available on crate feature el3 only.

Mask for the TWEDEL field.

pub const AMVOFFEN_SHIFT: u32 = 35

Available on crate feature el3 only.

Offset of the AMVOFFEN field.

pub const ENAS0_SHIFT: u32 = 36

Available on crate feature el3 only.

Offset of the EnAS0 field.

pub const ADEN_SHIFT: u32 = 37

Available on crate feature el3 only.

Offset of the ADEn field.

pub const HXEN_SHIFT: u32 = 38

Available on crate feature el3 only.

Offset of the HXEn field.

pub const GCSEN_SHIFT: u32 = 39

Available on crate feature el3 only.

Offset of the GCSEn field.

pub const TRNDR_SHIFT: u32 = 40

Available on crate feature el3 only.

Offset of the TRNDR field.

pub const ENTP2_SHIFT: u32 = 41

Available on crate feature el3 only.

Offset of the EnTP2 field.

pub const RCWMASKEN_SHIFT: u32 = 42

Available on crate feature el3 only.

Offset of the RCWMASKEn field.

pub const TCR2EN_SHIFT: u32 = 43

Available on crate feature el3 only.

Offset of the TCR2En field.

pub const SCTLR2EN_SHIFT: u32 = 44

Available on crate feature el3 only.

Offset of the SCTLR2En field.

pub const PIEN_SHIFT: u32 = 45

Available on crate feature el3 only.

Offset of the PIEn field.

pub const AIEN_SHIFT: u32 = 46

Available on crate feature el3 only.

Offset of the AIEn field.

pub const D128EN_SHIFT: u32 = 47

Available on crate feature el3 only.

Offset of the D128En field.

pub const GPF_SHIFT: u32 = 48

Available on crate feature el3 only.

Offset of the GPF field.

pub const MECEN_SHIFT: u32 = 49

Available on crate feature el3 only.

Offset of the MECEn field.

pub const ENFPM_SHIFT: u32 = 50

Available on crate feature el3 only.

Offset of the EnFPM field.

pub const TMEA_SHIFT: u32 = 51

Available on crate feature el3 only.

Offset of the TMEA field.

pub const TWERR_SHIFT: u32 = 52

Available on crate feature el3 only.

Offset of the TWERR field.

pub const PFAREN_SHIFT: u32 = 53

Available on crate feature el3 only.

Offset of the PFAREn field.

pub const SRMASKEN_SHIFT: u32 = 54

Available on crate feature el3 only.

Offset of the SRMASKEn field.

pub const ENIDCP128_SHIFT: u32 = 55

Available on crate feature el3 only.

Offset of the EnIDCP128 field.

pub const VTLBIDEN_SHIFT: u32 = 56

Available on crate feature el3 only.

Offset of the VTLBIDEn field.

pub const DSE_SHIFT: u32 = 57

Available on crate feature el3 only.

Offset of the DSE field.

pub const ENDSE_SHIFT: u32 = 58

Available on crate feature el3 only.

Offset of the EnDSE field.

pub const FGTEN2_SHIFT: u32 = 59

Available on crate feature el3 only.

Offset of the FGTEn2 field.

pub const HDBSSEN_SHIFT: u32 = 60

Available on crate feature el3 only.

Offset of the HDBSSEn field.

pub const HACDBSEN_SHIFT: u32 = 61

Available on crate feature el3 only.

Offset of the HACDBSEn field.

pub const NSE_SHIFT: u32 = 62

Available on crate feature el3 only.

Offset of the NSE field.

pub const TPLIMEN_SHIFT: u32 = 63

Available on crate feature el3 only.

Offset of the TPLIMEn field.

pub const fn twedel(self) -> u8

Available on crate feature el3 only.

Returns the value of the TWEDEL field.

pub const fn set_twedel(&mut self, value: u8)

Available on crate feature el3 only.

Sets the value of the TWEDEL field.