pub struct ScrEl3(/* private fields */);Expand description
SCR_EL3 system register value.
Implementations
Sourceimpl ScrEl3
impl ScrEl3
Sourcepub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u64) -> Option<Self>
pub const fn from_bits(bits: u64) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u64) -> Self
pub const fn from_bits_truncate(bits: u64) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u64) -> Self
pub const fn from_bits_retain(bits: u64) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl ScrEl3
impl ScrEl3
Sourcepub const fn iter(&self) -> Iter<ScrEl3>
pub const fn iter(&self) -> Iter<ScrEl3>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<ScrEl3>
pub const fn iter_names(&self) -> IterNames<ScrEl3>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl ScrEl3
impl ScrEl3
Sourcepub const TLOR_SHIFT: u32 = 14
Available on crate feature el3 only.
pub const TLOR_SHIFT: u32 = 14
el3 only.Offset of the TLOR field.
Sourcepub const TERR_SHIFT: u32 = 15
Available on crate feature el3 only.
pub const TERR_SHIFT: u32 = 15
el3 only.Offset of the TERR field.
Sourcepub const EEL2_SHIFT: u32 = 18
Available on crate feature el3 only.
pub const EEL2_SHIFT: u32 = 18
el3 only.Offset of the EEL2 field.
Sourcepub const EASE_SHIFT: u32 = 19
Available on crate feature el3 only.
pub const EASE_SHIFT: u32 = 19
el3 only.Offset of the EASE field.
Sourcepub const NMEA_SHIFT: u32 = 20
Available on crate feature el3 only.
pub const NMEA_SHIFT: u32 = 20
el3 only.Offset of the NMEA field.
Sourcepub const FIEN_SHIFT: u32 = 21
Available on crate feature el3 only.
pub const FIEN_SHIFT: u32 = 21
el3 only.Offset of the FIEN field.
Sourcepub const TID3_SHIFT: u32 = 22
Available on crate feature el3 only.
pub const TID3_SHIFT: u32 = 22
el3 only.Offset of the TID3 field.
Sourcepub const TID5_SHIFT: u32 = 23
Available on crate feature el3 only.
pub const TID5_SHIFT: u32 = 23
el3 only.Offset of the TID5 field.
Sourcepub const POE2EN_SHIFT: u32 = 24
Available on crate feature el3 only.
pub const POE2EN_SHIFT: u32 = 24
el3 only.Offset of the POE2En field.
Sourcepub const ENSCXT_SHIFT: u32 = 25
Available on crate feature el3 only.
pub const ENSCXT_SHIFT: u32 = 25
el3 only.Offset of the EnSCXT field.
Sourcepub const FGTEN_SHIFT: u32 = 27
Available on crate feature el3 only.
pub const FGTEN_SHIFT: u32 = 27
el3 only.Offset of the FGTEn field.
Sourcepub const ECVEN_SHIFT: u32 = 28
Available on crate feature el3 only.
pub const ECVEN_SHIFT: u32 = 28
el3 only.Offset of the ECVEn field.
Sourcepub const TWEDEN_SHIFT: u32 = 29
Available on crate feature el3 only.
pub const TWEDEN_SHIFT: u32 = 29
el3 only.Offset of the TWEDEn field.
Sourcepub const TWEDEL_SHIFT: u32 = 30
Available on crate feature el3 only.
pub const TWEDEL_SHIFT: u32 = 30
el3 only.Offset of the TWEDEL field.
Sourcepub const TWEDEL_MASK: u64 = 0b1111
Available on crate feature el3 only.
pub const TWEDEL_MASK: u64 = 0b1111
el3 only.Mask for the TWEDEL field.
Sourcepub const AMVOFFEN_SHIFT: u32 = 35
Available on crate feature el3 only.
pub const AMVOFFEN_SHIFT: u32 = 35
el3 only.Offset of the AMVOFFEN field.
Sourcepub const ENAS0_SHIFT: u32 = 36
Available on crate feature el3 only.
pub const ENAS0_SHIFT: u32 = 36
el3 only.Offset of the EnAS0 field.
Sourcepub const ADEN_SHIFT: u32 = 37
Available on crate feature el3 only.
pub const ADEN_SHIFT: u32 = 37
el3 only.Offset of the ADEn field.
Sourcepub const HXEN_SHIFT: u32 = 38
Available on crate feature el3 only.
pub const HXEN_SHIFT: u32 = 38
el3 only.Offset of the HXEn field.
Sourcepub const GCSEN_SHIFT: u32 = 39
Available on crate feature el3 only.
pub const GCSEN_SHIFT: u32 = 39
el3 only.Offset of the GCSEn field.
Sourcepub const TRNDR_SHIFT: u32 = 40
Available on crate feature el3 only.
pub const TRNDR_SHIFT: u32 = 40
el3 only.Offset of the TRNDR field.
Sourcepub const ENTP2_SHIFT: u32 = 41
Available on crate feature el3 only.
pub const ENTP2_SHIFT: u32 = 41
el3 only.Offset of the EnTP2 field.
Sourcepub const RCWMASKEN_SHIFT: u32 = 42
Available on crate feature el3 only.
pub const RCWMASKEN_SHIFT: u32 = 42
el3 only.Offset of the RCWMASKEn field.
Sourcepub const TCR2EN_SHIFT: u32 = 43
Available on crate feature el3 only.
pub const TCR2EN_SHIFT: u32 = 43
el3 only.Offset of the TCR2En field.
Sourcepub const SCTLR2EN_SHIFT: u32 = 44
Available on crate feature el3 only.
pub const SCTLR2EN_SHIFT: u32 = 44
el3 only.Offset of the SCTLR2En field.
Sourcepub const PIEN_SHIFT: u32 = 45
Available on crate feature el3 only.
pub const PIEN_SHIFT: u32 = 45
el3 only.Offset of the PIEn field.
Sourcepub const AIEN_SHIFT: u32 = 46
Available on crate feature el3 only.
pub const AIEN_SHIFT: u32 = 46
el3 only.Offset of the AIEn field.
Sourcepub const D128EN_SHIFT: u32 = 47
Available on crate feature el3 only.
pub const D128EN_SHIFT: u32 = 47
el3 only.Offset of the D128En field.
Sourcepub const MECEN_SHIFT: u32 = 49
Available on crate feature el3 only.
pub const MECEN_SHIFT: u32 = 49
el3 only.Offset of the MECEn field.
Sourcepub const ENFPM_SHIFT: u32 = 50
Available on crate feature el3 only.
pub const ENFPM_SHIFT: u32 = 50
el3 only.Offset of the EnFPM field.
Sourcepub const TMEA_SHIFT: u32 = 51
Available on crate feature el3 only.
pub const TMEA_SHIFT: u32 = 51
el3 only.Offset of the TMEA field.
Sourcepub const TWERR_SHIFT: u32 = 52
Available on crate feature el3 only.
pub const TWERR_SHIFT: u32 = 52
el3 only.Offset of the TWERR field.
Sourcepub const PFAREN_SHIFT: u32 = 53
Available on crate feature el3 only.
pub const PFAREN_SHIFT: u32 = 53
el3 only.Offset of the PFAREn field.
Sourcepub const SRMASKEN_SHIFT: u32 = 54
Available on crate feature el3 only.
pub const SRMASKEN_SHIFT: u32 = 54
el3 only.Offset of the SRMASKEn field.
Sourcepub const ENIDCP128_SHIFT: u32 = 55
Available on crate feature el3 only.
pub const ENIDCP128_SHIFT: u32 = 55
el3 only.Offset of the EnIDCP128 field.
Sourcepub const VTLBIDEN_SHIFT: u32 = 56
Available on crate feature el3 only.
pub const VTLBIDEN_SHIFT: u32 = 56
el3 only.Offset of the VTLBIDEn field.
Sourcepub const ENDSE_SHIFT: u32 = 58
Available on crate feature el3 only.
pub const ENDSE_SHIFT: u32 = 58
el3 only.Offset of the EnDSE field.
Sourcepub const FGTEN2_SHIFT: u32 = 59
Available on crate feature el3 only.
pub const FGTEN2_SHIFT: u32 = 59
el3 only.Offset of the FGTEn2 field.
Sourcepub const HDBSSEN_SHIFT: u32 = 60
Available on crate feature el3 only.
pub const HDBSSEN_SHIFT: u32 = 60
el3 only.Offset of the HDBSSEn field.
Sourcepub const HACDBSEN_SHIFT: u32 = 61
Available on crate feature el3 only.
pub const HACDBSEN_SHIFT: u32 = 61
el3 only.Offset of the HACDBSEn field.
Sourcepub const TPLIMEN_SHIFT: u32 = 63
Available on crate feature el3 only.
pub const TPLIMEN_SHIFT: u32 = 63
el3 only.Offset of the TPLIMEn field.
Sourcepub const fn twedel(self) -> u8
Available on crate feature el3 only.
pub const fn twedel(self) -> u8
el3 only.Returns the value of the TWEDEL field.
Sourcepub const fn set_twedel(&mut self, value: u8)
Available on crate feature el3 only.
pub const fn set_twedel(&mut self, value: u8)
el3 only.Sets the value of the TWEDEL field.