pub struct TcrEl2(/* private fields */);Expand description
TCR_EL2 system register value.
Implementations
Sourceimpl TcrEl2
impl TcrEl2
Sourcepub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u64) -> Option<Self>
pub const fn from_bits(bits: u64) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u64) -> Self
pub const fn from_bits_truncate(bits: u64) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u64) -> Self
pub const fn from_bits_retain(bits: u64) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl TcrEl2
impl TcrEl2
Sourcepub const fn iter(&self) -> Iter<TcrEl2>
pub const fn iter(&self) -> Iter<TcrEl2>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<TcrEl2>
pub const fn iter_names(&self) -> IterNames<TcrEl2>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl TcrEl2
impl TcrEl2
Sourcepub const T0SZ_SHIFT: u32 = 0
Available on crate feature el2 only.
pub const T0SZ_SHIFT: u32 = 0
el2 only.Offset of the T0SZ field.
Sourcepub const T0SZ_MASK: u64 = 0b111111
Available on crate feature el2 only.
pub const T0SZ_MASK: u64 = 0b111111
el2 only.Mask for the T0SZ field.
Sourcepub const EPD0_SHIFT: u32 = 7
Available on crate feature el2 only.
pub const EPD0_SHIFT: u32 = 7
el2 only.Offset of the EPD0 field.
Sourcepub const IRGN0_SHIFT: u32 = 8
Available on crate feature el2 only.
pub const IRGN0_SHIFT: u32 = 8
el2 only.Offset of the IRGN0 field.
Sourcepub const IRGN0_MASK: u64 = 0b11
Available on crate feature el2 only.
pub const IRGN0_MASK: u64 = 0b11
el2 only.Mask for the IRGN0 field.
Sourcepub const ORGN0_SHIFT: u32 = 10
Available on crate feature el2 only.
pub const ORGN0_SHIFT: u32 = 10
el2 only.Offset of the ORGN0 field.
Sourcepub const ORGN0_MASK: u64 = 0b11
Available on crate feature el2 only.
pub const ORGN0_MASK: u64 = 0b11
el2 only.Mask for the ORGN0 field.
Sourcepub const T1SZ_SHIFT: u32 = 16
Available on crate feature el2 only.
pub const T1SZ_SHIFT: u32 = 16
el2 only.Offset of the T1SZ field.
Sourcepub const T1SZ_MASK: u64 = 0b111111
Available on crate feature el2 only.
pub const T1SZ_MASK: u64 = 0b111111
el2 only.Mask for the T1SZ field.
Sourcepub const EPD1_SHIFT: u32 = 23
Available on crate feature el2 only.
pub const EPD1_SHIFT: u32 = 23
el2 only.Offset of the EPD1 field.
Sourcepub const IRGN1_SHIFT: u32 = 24
Available on crate feature el2 only.
pub const IRGN1_SHIFT: u32 = 24
el2 only.Offset of the IRGN1 field.
Sourcepub const IRGN1_MASK: u64 = 0b11
Available on crate feature el2 only.
pub const IRGN1_MASK: u64 = 0b11
el2 only.Mask for the IRGN1 field.
Sourcepub const HWU59_SHIFT: u32 = 25
Available on crate feature el2 only.
pub const HWU59_SHIFT: u32 = 25
el2 only.Offset of the HWU59 field.
Sourcepub const HWU60_SHIFT: u32 = 26
Available on crate feature el2 only.
pub const HWU60_SHIFT: u32 = 26
el2 only.Offset of the HWU60 field.
Sourcepub const ORGN1_SHIFT: u32 = 26
Available on crate feature el2 only.
pub const ORGN1_SHIFT: u32 = 26
el2 only.Offset of the ORGN1 field.
Sourcepub const ORGN1_MASK: u64 = 0b11
Available on crate feature el2 only.
pub const ORGN1_MASK: u64 = 0b11
el2 only.Mask for the ORGN1 field.
Sourcepub const HWU61_SHIFT: u32 = 27
Available on crate feature el2 only.
pub const HWU61_SHIFT: u32 = 27
el2 only.Offset of the HWU61 field.
Sourcepub const HWU62_SHIFT: u32 = 28
Available on crate feature el2 only.
pub const HWU62_SHIFT: u32 = 28
el2 only.Offset of the HWU62 field.
Sourcepub const TBID_SHIFT: u32 = 29
Available on crate feature el2 only.
pub const TBID_SHIFT: u32 = 29
el2 only.Offset of the TBID field.
Sourcepub const TCMA_SHIFT: u32 = 30
Available on crate feature el2 only.
pub const TCMA_SHIFT: u32 = 30
el2 only.Offset of the TCMA field.
Sourcepub const TBI0_SHIFT: u32 = 37
Available on crate feature el2 only.
pub const TBI0_SHIFT: u32 = 37
el2 only.Offset of the TBI0 field.
Sourcepub const TBI1_SHIFT: u32 = 38
Available on crate feature el2 only.
pub const TBI1_SHIFT: u32 = 38
el2 only.Offset of the TBI1 field.
Sourcepub const HPD0_SHIFT: u32 = 41
Available on crate feature el2 only.
pub const HPD0_SHIFT: u32 = 41
el2 only.Offset of the HPD0 field.
Sourcepub const HPD1_SHIFT: u32 = 42
Available on crate feature el2 only.
pub const HPD1_SHIFT: u32 = 42
el2 only.Offset of the HPD1 field.
Sourcepub const HWU059_SHIFT: u32 = 43
Available on crate feature el2 only.
pub const HWU059_SHIFT: u32 = 43
el2 only.Offset of the HWU059 field.
Sourcepub const HWU060_SHIFT: u32 = 44
Available on crate feature el2 only.
pub const HWU060_SHIFT: u32 = 44
el2 only.Offset of the HWU060 field.
Sourcepub const HWU061_SHIFT: u32 = 45
Available on crate feature el2 only.
pub const HWU061_SHIFT: u32 = 45
el2 only.Offset of the HWU061 field.
Sourcepub const HWU062_SHIFT: u32 = 46
Available on crate feature el2 only.
pub const HWU062_SHIFT: u32 = 46
el2 only.Offset of the HWU062 field.
Sourcepub const HWU159_SHIFT: u32 = 47
Available on crate feature el2 only.
pub const HWU159_SHIFT: u32 = 47
el2 only.Offset of the HWU159 field.
Sourcepub const HWU160_SHIFT: u32 = 48
Available on crate feature el2 only.
pub const HWU160_SHIFT: u32 = 48
el2 only.Offset of the HWU160 field.
Sourcepub const HWU161_SHIFT: u32 = 49
Available on crate feature el2 only.
pub const HWU161_SHIFT: u32 = 49
el2 only.Offset of the HWU161 field.
Sourcepub const HWU162_SHIFT: u32 = 50
Available on crate feature el2 only.
pub const HWU162_SHIFT: u32 = 50
el2 only.Offset of the HWU162 field.
Sourcepub const TBID0_SHIFT: u32 = 51
Available on crate feature el2 only.
pub const TBID0_SHIFT: u32 = 51
el2 only.Offset of the TBID0 field.
Sourcepub const TBID1_SHIFT: u32 = 52
Available on crate feature el2 only.
pub const TBID1_SHIFT: u32 = 52
el2 only.Offset of the TBID1 field.
Sourcepub const NFD0_SHIFT: u32 = 53
Available on crate feature el2 only.
pub const NFD0_SHIFT: u32 = 53
el2 only.Offset of the NFD0 field.
Sourcepub const TVAD_SHIFT: u32 = 53
Available on crate feature el2 only.
pub const TVAD_SHIFT: u32 = 53
el2 only.Offset of the TVAD field.
Sourcepub const NFD1_SHIFT: u32 = 54
Available on crate feature el2 only.
pub const NFD1_SHIFT: u32 = 54
el2 only.Offset of the NFD1 field.
Sourcepub const E0PD0_SHIFT: u32 = 55
Available on crate feature el2 only.
pub const E0PD0_SHIFT: u32 = 55
el2 only.Offset of the E0PD0 field.
Sourcepub const E0PD1_SHIFT: u32 = 56
Available on crate feature el2 only.
pub const E0PD1_SHIFT: u32 = 56
el2 only.Offset of the E0PD1 field.
Sourcepub const TCMA0_SHIFT: u32 = 57
Available on crate feature el2 only.
pub const TCMA0_SHIFT: u32 = 57
el2 only.Offset of the TCMA0 field.
Sourcepub const TCMA1_SHIFT: u32 = 58
Available on crate feature el2 only.
pub const TCMA1_SHIFT: u32 = 58
el2 only.Offset of the TCMA1 field.
Sourcepub const MTX0_SHIFT: u32 = 60
Available on crate feature el2 only.
pub const MTX0_SHIFT: u32 = 60
el2 only.Offset of the MTX0 field.
Sourcepub const MTX1_SHIFT: u32 = 61
Available on crate feature el2 only.
pub const MTX1_SHIFT: u32 = 61
el2 only.Offset of the MTX1 field.
Sourcepub const fn t0sz(self) -> u8
Available on crate feature el2 only.
pub const fn t0sz(self) -> u8
el2 only.Returns the value of the T0SZ field.
Sourcepub const fn set_t0sz(&mut self, value: u8)
Available on crate feature el2 only.
pub const fn set_t0sz(&mut self, value: u8)
el2 only.Sets the value of the T0SZ field.
Sourcepub const fn with_t0sz(self, value: u8) -> Self
Available on crate feature el2 only.
pub const fn with_t0sz(self, value: u8) -> Self
el2 only.Returns a copy with the T0SZ field set to the given value.
Sourcepub const fn irgn0(self) -> u8
Available on crate feature el2 only.
pub const fn irgn0(self) -> u8
el2 only.Returns the value of the IRGN0 field.
Sourcepub const fn set_irgn0(&mut self, value: u8)
Available on crate feature el2 only.
pub const fn set_irgn0(&mut self, value: u8)
el2 only.Sets the value of the IRGN0 field.
Sourcepub const fn with_irgn0(self, value: u8) -> Self
Available on crate feature el2 only.
pub const fn with_irgn0(self, value: u8) -> Self
el2 only.Returns a copy with the IRGN0 field set to the given value.
Sourcepub const fn orgn0(self) -> u8
Available on crate feature el2 only.
pub const fn orgn0(self) -> u8
el2 only.Returns the value of the ORGN0 field.
Sourcepub const fn set_orgn0(&mut self, value: u8)
Available on crate feature el2 only.
pub const fn set_orgn0(&mut self, value: u8)
el2 only.Sets the value of the ORGN0 field.
Sourcepub const fn with_orgn0(self, value: u8) -> Self
Available on crate feature el2 only.
pub const fn with_orgn0(self, value: u8) -> Self
el2 only.Returns a copy with the ORGN0 field set to the given value.
Sourcepub const fn sh0(self) -> u8
Available on crate feature el2 only.
pub const fn sh0(self) -> u8
el2 only.Returns the value of the SH0 field.
Sourcepub const fn set_sh0(&mut self, value: u8)
Available on crate feature el2 only.
pub const fn set_sh0(&mut self, value: u8)
el2 only.Sets the value of the SH0 field.
Sourcepub const fn with_sh0(self, value: u8) -> Self
Available on crate feature el2 only.
pub const fn with_sh0(self, value: u8) -> Self
el2 only.Returns a copy with the SH0 field set to the given value.
Sourcepub const fn tg0(self) -> u8
Available on crate feature el2 only.
pub const fn tg0(self) -> u8
el2 only.Returns the value of the TG0 field.
Sourcepub const fn set_tg0(&mut self, value: u8)
Available on crate feature el2 only.
pub const fn set_tg0(&mut self, value: u8)
el2 only.Sets the value of the TG0 field.
Sourcepub const fn with_tg0(self, value: u8) -> Self
Available on crate feature el2 only.
pub const fn with_tg0(self, value: u8) -> Self
el2 only.Returns a copy with the TG0 field set to the given value.
Sourcepub const fn ps(self) -> u8
Available on crate feature el2 only.
pub const fn ps(self) -> u8
el2 only.Returns the value of the PS field.
Sourcepub const fn set_ps(&mut self, value: u8)
Available on crate feature el2 only.
pub const fn set_ps(&mut self, value: u8)
el2 only.Sets the value of the PS field.
Sourcepub const fn with_ps(self, value: u8) -> Self
Available on crate feature el2 only.
pub const fn with_ps(self, value: u8) -> Self
el2 only.Returns a copy with the PS field set to the given value.
Sourcepub const fn t1sz(self) -> u8
Available on crate feature el2 only.
pub const fn t1sz(self) -> u8
el2 only.Returns the value of the T1SZ field.
Sourcepub const fn set_t1sz(&mut self, value: u8)
Available on crate feature el2 only.
pub const fn set_t1sz(&mut self, value: u8)
el2 only.Sets the value of the T1SZ field.
Sourcepub const fn with_t1sz(self, value: u8) -> Self
Available on crate feature el2 only.
pub const fn with_t1sz(self, value: u8) -> Self
el2 only.Returns a copy with the T1SZ field set to the given value.
Sourcepub const fn irgn1(self) -> u8
Available on crate feature el2 only.
pub const fn irgn1(self) -> u8
el2 only.Returns the value of the IRGN1 field.
Sourcepub const fn set_irgn1(&mut self, value: u8)
Available on crate feature el2 only.
pub const fn set_irgn1(&mut self, value: u8)
el2 only.Sets the value of the IRGN1 field.
Sourcepub const fn with_irgn1(self, value: u8) -> Self
Available on crate feature el2 only.
pub const fn with_irgn1(self, value: u8) -> Self
el2 only.Returns a copy with the IRGN1 field set to the given value.
Sourcepub const fn orgn1(self) -> u8
Available on crate feature el2 only.
pub const fn orgn1(self) -> u8
el2 only.Returns the value of the ORGN1 field.
Sourcepub const fn set_orgn1(&mut self, value: u8)
Available on crate feature el2 only.
pub const fn set_orgn1(&mut self, value: u8)
el2 only.Sets the value of the ORGN1 field.
Sourcepub const fn with_orgn1(self, value: u8) -> Self
Available on crate feature el2 only.
pub const fn with_orgn1(self, value: u8) -> Self
el2 only.Returns a copy with the ORGN1 field set to the given value.
Sourcepub const fn sh1(self) -> u8
Available on crate feature el2 only.
pub const fn sh1(self) -> u8
el2 only.Returns the value of the SH1 field.
Sourcepub const fn set_sh1(&mut self, value: u8)
Available on crate feature el2 only.
pub const fn set_sh1(&mut self, value: u8)
el2 only.Sets the value of the SH1 field.
Sourcepub const fn with_sh1(self, value: u8) -> Self
Available on crate feature el2 only.
pub const fn with_sh1(self, value: u8) -> Self
el2 only.Returns a copy with the SH1 field set to the given value.
Sourcepub const fn tg1(self) -> u8
Available on crate feature el2 only.
pub const fn tg1(self) -> u8
el2 only.Returns the value of the TG1 field.
Sourcepub const fn set_tg1(&mut self, value: u8)
Available on crate feature el2 only.
pub const fn set_tg1(&mut self, value: u8)
el2 only.Sets the value of the TG1 field.
Sourcepub const fn with_tg1(self, value: u8) -> Self
Available on crate feature el2 only.
pub const fn with_tg1(self, value: u8) -> Self
el2 only.Returns a copy with the TG1 field set to the given value.
Sourcepub const fn ips(self) -> u8
Available on crate feature el2 only.
pub const fn ips(self) -> u8
el2 only.Returns the value of the IPS field.
Sourcepub const fn set_ips(&mut self, value: u8)
Available on crate feature el2 only.
pub const fn set_ips(&mut self, value: u8)
el2 only.Sets the value of the IPS field.
Sourcepub const fn with_ips(self, value: u8) -> Self
Available on crate feature el2 only.
pub const fn with_ips(self, value: u8) -> Self
el2 only.Returns a copy with the IPS field set to the given value.
Sourcepub const fn vtb(self) -> u8
Available on crate feature el2 only.
pub const fn vtb(self) -> u8
el2 only.Returns the value of the VTB field.