pub struct VtcrEl2(/* private fields */);Expand description
VTCR_EL2 system register value.
Implementations
Sourceimpl VtcrEl2
impl VtcrEl2
Sourcepub const ASSUREDONLY: Self
pub const ASSUREDONLY: Self
AssuredOnly bit.
Sourceimpl VtcrEl2
impl VtcrEl2
Sourcepub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u64) -> Option<Self>
pub const fn from_bits(bits: u64) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u64) -> Self
pub const fn from_bits_truncate(bits: u64) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u64) -> Self
pub const fn from_bits_retain(bits: u64) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl VtcrEl2
impl VtcrEl2
Sourcepub const fn iter(&self) -> Iter<VtcrEl2>
pub const fn iter(&self) -> Iter<VtcrEl2>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<VtcrEl2>
pub const fn iter_names(&self) -> IterNames<VtcrEl2>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl VtcrEl2
impl VtcrEl2
Sourcepub const T0SZ_SHIFT: u32 = 0
Available on crate feature el2 only.
pub const T0SZ_SHIFT: u32 = 0
el2 only.Offset of the T0SZ field.
Sourcepub const T0SZ_MASK: u64 = 0b111111
Available on crate feature el2 only.
pub const T0SZ_MASK: u64 = 0b111111
el2 only.Mask for the T0SZ field.
Sourcepub const IRGN0_SHIFT: u32 = 8
Available on crate feature el2 only.
pub const IRGN0_SHIFT: u32 = 8
el2 only.Offset of the IRGN0 field.
Sourcepub const IRGN0_MASK: u64 = 0b11
Available on crate feature el2 only.
pub const IRGN0_MASK: u64 = 0b11
el2 only.Mask for the IRGN0 field.
Sourcepub const ORGN0_SHIFT: u32 = 10
Available on crate feature el2 only.
pub const ORGN0_SHIFT: u32 = 10
el2 only.Offset of the ORGN0 field.
Sourcepub const ORGN0_MASK: u64 = 0b11
Available on crate feature el2 only.
pub const ORGN0_MASK: u64 = 0b11
el2 only.Mask for the ORGN0 field.
Sourcepub const HWU59_SHIFT: u32 = 25
Available on crate feature el2 only.
pub const HWU59_SHIFT: u32 = 25
el2 only.Offset of the HWU59 field.
Sourcepub const HWU60_SHIFT: u32 = 26
Available on crate feature el2 only.
pub const HWU60_SHIFT: u32 = 26
el2 only.Offset of the HWU60 field.
Sourcepub const HWU61_SHIFT: u32 = 27
Available on crate feature el2 only.
pub const HWU61_SHIFT: u32 = 27
el2 only.Offset of the HWU61 field.
Sourcepub const HWU62_SHIFT: u32 = 28
Available on crate feature el2 only.
pub const HWU62_SHIFT: u32 = 28
el2 only.Offset of the HWU62 field.
Sourcepub const ASSUREDONLY_SHIFT: u32 = 34
Available on crate feature el2 only.
pub const ASSUREDONLY_SHIFT: u32 = 34
el2 only.Offset of the AssuredOnly field.
Sourcepub const S2PIE_SHIFT: u32 = 36
Available on crate feature el2 only.
pub const S2PIE_SHIFT: u32 = 36
el2 only.Offset of the S2PIE field.
Sourcepub const S2POE_SHIFT: u32 = 37
Available on crate feature el2 only.
pub const S2POE_SHIFT: u32 = 37
el2 only.Offset of the S2POE field.
Sourcepub const D128_SHIFT: u32 = 38
Available on crate feature el2 only.
pub const D128_SHIFT: u32 = 38
el2 only.Offset of the D128 field.
Sourcepub const GCSH_SHIFT: u32 = 40
Available on crate feature el2 only.
pub const GCSH_SHIFT: u32 = 40
el2 only.Offset of the GCSH field.
Sourcepub const HAFT_SHIFT: u32 = 44
Available on crate feature el2 only.
pub const HAFT_SHIFT: u32 = 44
el2 only.Offset of the HAFT field.
Sourcepub const HDBSS_SHIFT: u32 = 45
Available on crate feature el2 only.
pub const HDBSS_SHIFT: u32 = 45
el2 only.Offset of the HDBSS field.
Sourcepub const fn t0sz(self) -> u8
Available on crate feature el2 only.
pub const fn t0sz(self) -> u8
el2 only.Returns the value of the T0SZ field.
Sourcepub const fn set_t0sz(&mut self, value: u8)
Available on crate feature el2 only.
pub const fn set_t0sz(&mut self, value: u8)
el2 only.Sets the value of the T0SZ field.
Sourcepub const fn with_t0sz(self, value: u8) -> Self
Available on crate feature el2 only.
pub const fn with_t0sz(self, value: u8) -> Self
el2 only.Returns a copy with the T0SZ field set to the given value.
Sourcepub const fn sl0(self) -> u8
Available on crate feature el2 only.
pub const fn sl0(self) -> u8
el2 only.Returns the value of the SL0 field.
Sourcepub const fn set_sl0(&mut self, value: u8)
Available on crate feature el2 only.
pub const fn set_sl0(&mut self, value: u8)
el2 only.Sets the value of the SL0 field.
Sourcepub const fn with_sl0(self, value: u8) -> Self
Available on crate feature el2 only.
pub const fn with_sl0(self, value: u8) -> Self
el2 only.Returns a copy with the SL0 field set to the given value.
Sourcepub const fn irgn0(self) -> u8
Available on crate feature el2 only.
pub const fn irgn0(self) -> u8
el2 only.Returns the value of the IRGN0 field.
Sourcepub const fn set_irgn0(&mut self, value: u8)
Available on crate feature el2 only.
pub const fn set_irgn0(&mut self, value: u8)
el2 only.Sets the value of the IRGN0 field.
Sourcepub const fn with_irgn0(self, value: u8) -> Self
Available on crate feature el2 only.
pub const fn with_irgn0(self, value: u8) -> Self
el2 only.Returns a copy with the IRGN0 field set to the given value.
Sourcepub const fn orgn0(self) -> u8
Available on crate feature el2 only.
pub const fn orgn0(self) -> u8
el2 only.Returns the value of the ORGN0 field.
Sourcepub const fn set_orgn0(&mut self, value: u8)
Available on crate feature el2 only.
pub const fn set_orgn0(&mut self, value: u8)
el2 only.Sets the value of the ORGN0 field.
Sourcepub const fn with_orgn0(self, value: u8) -> Self
Available on crate feature el2 only.
pub const fn with_orgn0(self, value: u8) -> Self
el2 only.Returns a copy with the ORGN0 field set to the given value.
Sourcepub const fn sh0(self) -> u8
Available on crate feature el2 only.
pub const fn sh0(self) -> u8
el2 only.Returns the value of the SH0 field.
Sourcepub const fn set_sh0(&mut self, value: u8)
Available on crate feature el2 only.
pub const fn set_sh0(&mut self, value: u8)
el2 only.Sets the value of the SH0 field.
Sourcepub const fn with_sh0(self, value: u8) -> Self
Available on crate feature el2 only.
pub const fn with_sh0(self, value: u8) -> Self
el2 only.Returns a copy with the SH0 field set to the given value.
Sourcepub const fn tg0(self) -> u8
Available on crate feature el2 only.
pub const fn tg0(self) -> u8
el2 only.Returns the value of the TG0 field.
Sourcepub const fn set_tg0(&mut self, value: u8)
Available on crate feature el2 only.
pub const fn set_tg0(&mut self, value: u8)
el2 only.Sets the value of the TG0 field.
Sourcepub const fn with_tg0(self, value: u8) -> Self
Available on crate feature el2 only.
pub const fn with_tg0(self, value: u8) -> Self
el2 only.Returns a copy with the TG0 field set to the given value.
Sourcepub const fn ps(self) -> u8
Available on crate feature el2 only.
pub const fn ps(self) -> u8
el2 only.Returns the value of the PS field.